AudioCallbackD class abstract

Inheritance
Mixed-in types

Constructors

AudioCallbackD([String? name])
AudioCallbackD.function(AudioCallbackFunctionD f, {String? name})
factory

Properties

function AudioCallbackFunctionD
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
jsFunction JSFunction
Essentially, just override it like so:
no setteroverride
name String
getter/setter pairinherited
nativeFunction int
no setterinherited
registry List<CallbackD<Function>>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
no setteroverride

Methods

attach() int
inherited
detach([bool keepAlive = false]) int
inherited
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns name.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

disposeRegistry() → void
override