setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
AudioStreamD setD(AudioStreamD o) {
sampleRate = o.sampleRate;
sampleSize = o.sampleSize;
channels = o.channels;
return this;
}
Copies the fields of o into this instance and returns this.
@override
AudioStreamD setD(AudioStreamD o) {
sampleRate = o.sampleRate;
sampleSize = o.sampleSize;
channels = o.channels;
return this;
}