setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
AutomationEventD setD(AutomationEventD o) {
frame = o.frame;
type = o.type;
params = .from(o.params);
return this;
}
Copies the fields of o into this instance and returns this.
@override
AutomationEventD setD(AutomationEventD o) {
frame = o.frame;
type = o.type;
params = .from(o.params);
return this;
}