CallbackD<D extends Function> class abstract

Mixed-in types
Implementers

Constructors

CallbackD([String? name])

Properties

function → D
no setter
hashCode int
The hash code for this object.
no setterinherited
jsFunction JSFunction
Essentially, just override it like so:
no setter
name String
getter/setter pairoverride-getter
nativeFunction int
no setter
registry List<CallbackD<Function>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
no setter

Methods

attach() int
detach([bool keepAlive = false]) int
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns name.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

disposeRegistry(List<CallbackD<Function>> registry) → void