structAllocateInto method
Allocates nested pointers into temp under key as needed.
Implementation
@override
void structAllocateInto(RaylibTemp temp, WasmStructPointer<ImageD> p, String key) {
_dataPtr = temp.Uint8$.RawArray(data);
}
Allocates nested pointers into temp under key as needed.
@override
void structAllocateInto(RaylibTemp temp, WasmStructPointer<ImageD> p, String key) {
_dataPtr = temp.Uint8$.RawArray(data);
}