setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
ModelAnimationD setD(ModelAnimationD o) {
bones = .from(o.bones);
framePoses = .from(o.framePoses);
name = o.name;
return this;
}
Copies the fields of o into this instance and returns this.
@override
ModelAnimationD setD(ModelAnimationD o) {
bones = .from(o.bones);
framePoses = .from(o.framePoses);
name = o.name;
return this;
}