RaylibAudio class

Inheritance

Constructors

RaylibAudio(Raylib rl)

Properties

AttachAudioMixedProcessor JSFunction<Function>
latefinal
AttachAudioStreamProcessor JSFunction<Function>
latefinal
CloseAudioDevice JSFunction<Function>
latefinal
DetachAudioMixedProcessor JSFunction<Function>
latefinal
DetachAudioStreamProcessor JSFunction<Function>
latefinal
ExportWave JSFunction<Function>
latefinal
ExportWaveAsCode JSFunction<Function>
latefinal
GetMasterVolume JSFunction<Function>
latefinal
GetMusicTimeLength JSFunction<Function>
latefinal
GetMusicTimePlayed JSFunction<Function>
latefinal
hashCode int
The hash code for this object.
no setterinherited
InitAudioDevice JSFunction<Function>
latefinal
IsAudioDeviceReady JSFunction<Function>
latefinal
IsAudioStreamPlaying JSFunction<Function>
latefinal
IsAudioStreamProcessed JSFunction<Function>
latefinal
IsAudioStreamValid JSFunction<Function>
latefinal
IsMusicStreamPlaying JSFunction<Function>
latefinal
IsMusicValid JSFunction<Function>
latefinal
IsSoundPlaying JSFunction<Function>
latefinal
IsSoundValid JSFunction<Function>
latefinal
IsWaveValid JSFunction<Function>
latefinal
LoadAudioStream JSFunction<Function>
latefinal
LoadMusicStream JSFunction<Function>
latefinal
LoadMusicStreamFromMemory JSFunction<Function>
latefinal
LoadSound JSFunction<Function>
latefinal
LoadSoundAlias JSFunction<Function>
latefinal
LoadSoundFromWave JSFunction<Function>
latefinal
LoadWave JSFunction<Function>
latefinal
LoadWaveFromMemory JSFunction<Function>
latefinal
LoadWaveSamples JSFunction<Function>
latefinal
n String
finalinherited
PauseAudioStream JSFunction<Function>
latefinal
PauseMusicStream JSFunction<Function>
latefinal
PauseSound JSFunction<Function>
latefinal
PlayAudioStream JSFunction<Function>
latefinal
PlayMusicStream JSFunction<Function>
latefinal
PlaySound JSFunction<Function>
latefinal
ResumeAudioStream JSFunction<Function>
latefinal
ResumeMusicStream JSFunction<Function>
latefinal
ResumeSound JSFunction<Function>
latefinal
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s String
finalinherited
SeekMusicStream JSFunction<Function>
latefinal
SetAudioStreamBufferSizeDefault JSFunction<Function>
latefinal
SetAudioStreamCallback JSFunction<Function>
latefinal
SetAudioStreamPan JSFunction<Function>
latefinal
SetAudioStreamPitch JSFunction<Function>
latefinal
SetAudioStreamVolume JSFunction<Function>
latefinal
SetMasterVolume JSFunction<Function>
latefinal
SetMusicPan JSFunction<Function>
latefinal
SetMusicPitch JSFunction<Function>
latefinal
SetMusicVolume JSFunction<Function>
latefinal
SetSoundPan JSFunction<Function>
latefinal
SetSoundPitch JSFunction<Function>
latefinal
SetSoundVolume JSFunction<Function>
latefinal
StopAudioStream JSFunction<Function>
latefinal
StopMusicStream JSFunction<Function>
latefinal
StopSound JSFunction<Function>
latefinal
UnloadAudioStream JSFunction<Function>
latefinal
UnloadMusicStream JSFunction<Function>
latefinal
UnloadSound JSFunction<Function>
latefinal
UnloadSoundAlias JSFunction<Function>
latefinal
UnloadWave JSFunction<Function>
latefinal
UnloadWaveSamples JSFunction<Function>
latefinal
UpdateAudioStream JSFunction<Function>
latefinal
UpdateMusicStream JSFunction<Function>
latefinal
UpdateSound JSFunction<Function>
latefinal
WaveCopy JSFunction<Function>
latefinal
WaveCrop JSFunction<Function>
latefinal
WaveFormat JSFunction<Function>
latefinal

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
doLoad() → void
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
load() → void
Override to perform one-time module initialization. Called by doLoad.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited