LoadSoundAlias property

WF2<void> LoadSoundAlias
latefinal

Create a new sound that shares the same sample data as the source sound, does not own the sound data

Implementation

late final WF2<void> LoadSoundAlias;