LoadSoundAlias method
Create a new sound that shares the same sample data as the source sound, does not own the sound data
Implementation
@override
SoundD LoadSoundAlias(
SoundD source,
) => run(
() => RaylibDebugLabels.LoadSoundAlias(source),
() => rl.Temp.Sound$.RefCapture(
RaylibCaptureIds.LoadSoundAlias(source),
(p) => rl.Audio.LoadSoundAlias.run2(
p.toJS,
rl.Temp.Sound$.Ref1(source).toJS,
),
),
);