RaylibAudioFlat class

Constructors

RaylibAudioFlat(dynamic rl)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

AttachAudioMixedProcessor(MemoryPointer<RFunction> processor) → void
AttachAudioStreamProcessor(AudioStreamD stream, MemoryPointer<RFunction> processor) → void
CloseAudioDevice() → void
DetachAudioMixedProcessor(MemoryPointer<RFunction> processor) → void
DetachAudioStreamProcessor(AudioStreamD stream, MemoryPointer<RFunction> processor) → void
ExportWave(WaveD wave, MemoryPointer<RChar> fileName) → bool
ExportWaveAsCode(WaveD wave, MemoryPointer<RChar> fileName) → bool
GetMasterVolume() → double
GetMusicTimeLength(MusicD music) → double
GetMusicTimePlayed(MusicD music) → double
InitAudioDevice() → void
IsAudioDeviceReady() → bool
IsAudioStreamPlaying(AudioStreamD stream) → bool
IsAudioStreamProcessed(AudioStreamD stream) → bool
IsAudioStreamValid(AudioStreamD stream) → bool
IsMusicStreamPlaying(MusicD music) → bool
IsMusicValid(MusicD music) → bool
IsSoundPlaying(SoundD sound) → bool
IsSoundValid(SoundD sound) → bool
IsWaveValid(WaveD wave) → bool
LoadAudioStream(int sampleRate, int sampleSize, int channels) → AudioStreamD
LoadMusicStream(MemoryPointer<RChar> fileName) → MusicD
LoadMusicStreamFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> data, int dataSize) → MusicD
LoadSound(MemoryPointer<RChar> fileName) → SoundD
LoadSoundAlias(SoundD source) → SoundD
LoadSoundFromWave(WaveD wave) → SoundD
LoadWave(MemoryPointer<RChar> fileName) → WaveD
LoadWaveFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> fileData, int dataSize) → WaveD
LoadWaveSamples(WaveD wave) → WasmMemoryPointer<RFloat>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
PauseAudioStream(AudioStreamD stream) → void
PauseMusicStream(MusicD music) → void
PauseSound(SoundD sound) → void
PlayAudioStream(AudioStreamD stream) → void
PlayMusicStream(MusicD music) → void
PlaySound(SoundD sound) → void
ResumeAudioStream(AudioStreamD stream) → void
ResumeMusicStream(MusicD music) → void
ResumeSound(SoundD sound) → void
SeekMusicStream(MusicD music, double position) → void
SetAudioStreamBufferSizeDefault(int size) → void
SetAudioStreamCallback(AudioStreamD stream, MemoryPointer<RFunction> callback) → void
SetAudioStreamPan(AudioStreamD stream, double pan) → void
SetAudioStreamPitch(AudioStreamD stream, double pitch) → void
SetAudioStreamVolume(AudioStreamD stream, double volume) → void
SetMasterVolume(double volume) → void
SetMusicPan(MusicD music, double pan) → void
SetMusicPitch(MusicD music, double pitch) → void
SetMusicVolume(MusicD music, double volume) → void
SetSoundPan(SoundD sound, double pan) → void
SetSoundPitch(SoundD sound, double pitch) → void
SetSoundVolume(SoundD sound, double volume) → void
StopAudioStream(AudioStreamD stream) → void
StopMusicStream(MusicD music) → void
StopSound(SoundD sound) → void
toString() → String
A string representation of this object.
inherited
UnloadAudioStream(AudioStreamD stream) → void
UnloadMusicStream(MusicD music) → void
UnloadSound(SoundD sound) → void
UnloadSoundAlias(SoundD alias) → void
UnloadWave(WaveD wave) → void
UnloadWaveSamples(MemoryPointer<RFloat> samples) → void
UpdateAudioStream(AudioStreamD stream, MemoryPointer<RVoid> data, int frameCount) → void
UpdateMusicStream(MusicD music) → void
UpdateSound(SoundD sound, MemoryPointer<RVoid> data, int sampleCount) → void
WaveCopy(WaveD wave) → WaveD
WaveCrop(StructPointer<WaveD> wave, int initFrame, int finalFrame) → void
WaveFormat(StructPointer<WaveD> wave, int sampleRate, int sampleSize, int channels) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited