CameraMoveRight property

WF3<void> CameraMoveRight
latefinal

Moves the camera target in its current right direction by distance.

If moveInWorldPlane is true, movement is constrained to the XZ plane regardless of the camera's pitch.

Implementation

late final WF3<void> CameraMoveRight;