CameraMoveRight method
Moves the camera target in its current right direction by distance.
If moveInWorldPlane is true, movement is constrained to the XZ plane
regardless of the camera's pitch.
Implementation
@override
void CameraMoveRight(
Camera3DD camera,
num distance,
bool moveInWorldPlane,
) => run(
() => RaylibDebugLabels.CameraMoveRight(camera, distance, moveInWorldPlane),
() => rl.Temp.Camera3D$.RefUpdate1(camera,
(pc) => rl.Camera.CameraMoveRight.run3(
pc.toJS,
distance.toJS,
moveInWorldPlane.toJS,
),
),
);