CameraPitch method

  1. @override
void CameraPitch(
  1. Camera3DD camera,
  2. num angle,
  3. bool lockView,
  4. bool rotateAroundTarget,
  5. bool rotateUp,
)
override

Rotates camera around its right vector by angle radians.

Pitch is "looking up and down".

If lockView is true, pitch is clamped to prevent flipping.

If rotateAroundTarget is true, the camera orbits its target; otherwise it rotates in place.

If rotateUp is true, the up vector is rotated as well (typically useful in CameraMode.CAMERA_FREE).

Implementation

@override
void CameraPitch(
  Camera3DD camera,
  num angle,
  bool lockView,
  bool rotateAroundTarget,
  bool rotateUp,
) => run(
  () => RaylibDebugLabels.CameraPitch(camera, angle, lockView, rotateAroundTarget, rotateUp),
  () => rl.Temp.Camera3D$.RefUpdate1(camera,
    (pc) => rl.Camera.CameraPitch.run5(
      pc.toJS,
      angle.toJS,
      lockView.toJS,
      rotateAroundTarget.toJS,
      rotateUp.toJS,
    ),
  ),
);