RaylibCore class

Inheritance

Constructors

RaylibCore(Raylib rl)

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
BeginBlendMode ↔ WF1<void>
Begin blending mode (alpha, additive, multiplied, subtract, custom)
latefinal
BeginDrawing ↔ WF0<void>
Setup canvas (framebuffer) to start drawing
latefinal
BeginMode2D ↔ WF1<void>
Begin 2D mode with custom camera (2D)
latefinal
BeginMode3D ↔ WF1<void>
Begin 3D mode with custom camera (3D)
latefinal
BeginScissorMode ↔ WF4<void>
Begin scissor mode (define screen area for following drawing)
latefinal
BeginShaderMode ↔ WF1<void>
Begin custom shader drawing
latefinal
BeginTextureMode ↔ WF1<void>
Begin drawing to render texture
latefinal
BeginVrStereoMode ↔ WF1<void>
Begin stereo rendering (requires VR simulator)
latefinal
ChangeDirectory ↔ WF1<bool>
Change working directory, return true on success
latefinal
CheckCollisionBoxes ↔ WF2<bool>
Check collision between two bounding boxes
latefinal
CheckCollisionBoxSphere ↔ WF3<bool>
Check collision between box and sphere
latefinal
CheckCollisionCircleLine ↔ WF4<bool>
Check if circle collides with a line created betweeen two points p1 and p2
latefinal
CheckCollisionCircleRec ↔ WF3<bool>
Check collision between circle and rectangle
latefinal
CheckCollisionCircles ↔ WF4<bool>
Check collision between two circles
latefinal
CheckCollisionLines ↔ WF5<bool>
Check the collision between two lines defined by two points each, returns collision point by reference
latefinal
CheckCollisionPointCircle ↔ WF3<bool>
Check if point is inside circle
latefinal
CheckCollisionPointLine ↔ WF4<bool>
Check if point belongs to line created between two points p1 and p2 with defined margin in pixels threshold
latefinal
CheckCollisionPointPoly ↔ WF3<bool>
Check if point is within a polygon described by array of vertices
latefinal
CheckCollisionPointRec ↔ WF2<bool>
Check if point is inside rectangle
latefinal
CheckCollisionPointTriangle ↔ WF4<bool>
Check if point is inside a triangle
latefinal
CheckCollisionRecs ↔ WF2<bool>
Check collision between two rectangles
latefinal
CheckCollisionSpheres ↔ WF4<bool>
Check collision between two spheres
latefinal
ClearBackground ↔ WF1<void>
Set background color (framebuffer clear color)
latefinal
ClearWindowState ↔ WF1<void>
Clear window configuration state flags
latefinal
CloseWindow ↔ WF0<void>
Close window and unload OpenGL context
latefinal
CodepointToUTF8 ↔ WF2<WasmMemoryPointer<RChar>>
Encode one codepoint into UTF-8 byte array (array length returned as parameter)
latefinal
ColorAlpha ↔ WF3<void>
Get color with alpha applied, alpha goes from 0.0 to 1.0
latefinal
ColorAlphaBlend ↔ WF4<void>
Get src alpha-blended into dst color with tint
latefinal
ColorBrightness ↔ WF3<void>
Get color with brightness correction, brightness factor goes from -1.0 to 1.0
latefinal
ColorContrast ↔ WF3<void>
Get color with contrast correction, contrast values between -1.0 and 1.0
latefinal
ColorFromHSV ↔ WF4<void>
Get a Color from HSV values, hue 0..360, saturation/value 0..1
latefinal
ColorFromNormalized ↔ WF2<void>
Get Color from normalized values 0..1
latefinal
ColorIsEqual ↔ WF2<bool>
Check if two colors are equal
latefinal
ColorLerp ↔ WF4<void>
Get color lerp interpolation between two colors, factor 0.0..1.0
latefinal
ColorNormalize ↔ WF2<void>
Get Color normalized as float 0..1
latefinal
ColorTint ↔ WF3<void>
Get color multiplied with another color
latefinal
ColorToHSV ↔ WF2<void>
Get HSV values for a Color, hue 0..360, saturation/value 0..1
latefinal
ColorToInt ↔ WF1<int>
Get hexadecimal value for a Color (0xRRGGBBAA)
latefinal
CompressData ↔ WF3<WasmMemoryPointer<RUnsignedChar>>
Compress data (DEFLATE algorithm)
latefinal
ComputeCRC32 ↔ WF2<int>
Compute CRC32 hash code
latefinal
ComputeMD5 ↔ WF2<WasmMemoryPointer<RUnsignedInt>>
Compute MD5 hash code
latefinal
ComputeSHA1 ↔ WF2<WasmMemoryPointer<RUnsignedInt>>
Compute SHA1 hash code
latefinal
ComputeSHA256 ↔ WF2<WasmMemoryPointer<RUnsignedInt>>
Compute SHA256 hash code
latefinal
DecodeDataBase64 ↔ WF2<WasmMemoryPointer<RUnsignedChar>>
Decode Base64 string data
latefinal
DecompressData ↔ WF3<WasmMemoryPointer<RUnsignedChar>>
Decompress data (DEFLATE algorithm)
latefinal
DirectoryExists ↔ WF1<bool>
Check if a directory path exists
latefinal
DisableCursor ↔ WF0<void>
Disables cursor (lock cursor)
latefinal
DisableEventWaiting ↔ WF0<void>
Disable waiting for events on EndDrawing(), automatic events polling
latefinal
DrawBillboard ↔ WF5<void>
Draw a billboard texture
latefinal
DrawBillboardPro ↔ WF9<void>
Draw a billboard texture defined by source and rotation
latefinal
DrawBillboardRec ↔ WF6<void>
Draw a billboard texture defined by source
latefinal
DrawBoundingBox ↔ WF2<void>
Draw bounding box (wires)
latefinal
DrawCapsule ↔ WF6<void>
Draw a capsule with the center of its sphere caps at startPos and endPos
latefinal
DrawCapsuleWires ↔ WF6<void>
Draw capsule wireframe with the center of its sphere caps at startPos and endPos
latefinal
DrawCircle ↔ WF4<void>
Draw a color-filled circle
latefinal
DrawCircle3D ↔ WF5<void>
Draw a circle in 3D world space
latefinal
DrawCircleGradient ↔ WF4<void>
Draw a gradient-filled circle
latefinal
DrawCircleLines ↔ WF4<void>
Draw circle outline
latefinal
DrawCircleLinesV ↔ WF3<void>
Draw circle outline (Vector version)
latefinal
DrawCircleSector ↔ WF6<void>
Draw a piece of a circle
latefinal
DrawCircleSectorLines ↔ WF6<void>
Draw circle sector outline
latefinal
DrawCircleV ↔ WF3<void>
Draw a color-filled circle (Vector version)
latefinal
DrawCube ↔ WF5<void>
Draw cube
latefinal
DrawCubeV ↔ WF3<void>
Draw cube (Vector version)
latefinal
DrawCubeWires ↔ WF5<void>
Draw cube wires
latefinal
DrawCubeWiresV ↔ WF3<void>
Draw cube wires (Vector version)
latefinal
DrawCylinder ↔ WF6<void>
Draw a cylinder/cone
latefinal
DrawCylinderEx ↔ WF6<void>
Draw a cylinder with base at startPos and top at endPos
latefinal
DrawCylinderWires ↔ WF6<void>
Draw a cylinder/cone wires
latefinal
DrawCylinderWiresEx ↔ WF6<void>
Draw a cylinder wires with base at startPos and top at endPos
latefinal
DrawEllipse ↔ WF5<void>
Draw ellipse
latefinal
DrawEllipseLines ↔ WF5<void>
Draw ellipse outline
latefinal
DrawEllipseLinesV ↔ WF4<void>
Draw ellipse outline (Vector version)
latefinal
DrawEllipseV ↔ WF4<void>
Draw ellipse (Vector version)
latefinal
DrawFPS ↔ WF2<void>
Draw current FPS
latefinal
DrawGrid ↔ WF2<void>
Draw a grid (centered at (0, 0, 0))
latefinal
DrawLine ↔ WF5<void>
Draw a line
latefinal
DrawLine3D ↔ WF3<void>
Draw a line in 3D world space
latefinal
DrawLineBezier ↔ WF4<void>
Draw line segment cubic-bezier in-out interpolation
latefinal
DrawLineDashed ↔ WF5<void>
Draw a dashed line
latefinal
DrawLineEx ↔ WF4<void>
Draw a line (using triangles/quads)
latefinal
DrawLineStrip ↔ WF3<void>
Draw lines sequence (using gl lines)
latefinal
DrawLineV ↔ WF3<void>
Draw a line (using gl lines)
latefinal
DrawMesh ↔ WF3<void>
Draw a 3d mesh with material and transform
latefinal
DrawMeshInstanced ↔ WF4<void>
Draw multiple mesh instances with material and different transforms
latefinal
DrawModel ↔ WF4<void>
Draw a model (with texture if set)
latefinal
DrawModelEx ↔ WF6<void>
Draw a model with extended parameters
latefinal
DrawModelWires ↔ WF4<void>
Draw a model wires (with texture if set)
latefinal
DrawModelWiresEx ↔ WF6<void>
Draw a model wires (with texture if set) with extended parameters
latefinal
DrawPixel ↔ WF3<void>
Draw a pixel using geometry Can be slow, use with care
latefinal
DrawPixelV ↔ WF2<void>
Draw a pixel using geometry (Vector version) Can be slow, use with care
latefinal
DrawPlane ↔ WF3<void>
Draw a plane XZ
latefinal
DrawPoint3D ↔ WF2<void>
Draw a point in 3D space, actually a small line
latefinal
DrawPoly ↔ WF5<void>
Draw a regular polygon (Vector version)
latefinal
DrawPolyLines ↔ WF5<void>
Draw a polygon outline of n sides
latefinal
DrawPolyLinesEx ↔ WF6<void>
Draw a polygon outline of n sides with extended parameters
latefinal
DrawRay ↔ WF2<void>
Draw a ray line
latefinal
DrawRectangle ↔ WF5<void>
Draw a color-filled rectangle
latefinal
DrawRectangleGradientEx ↔ WF5<void>
Draw a gradient-filled rectangle with custom vertex colors
latefinal
DrawRectangleGradientH ↔ WF6<void>
Draw a horizontal-gradient-filled rectangle
latefinal
DrawRectangleGradientV ↔ WF6<void>
Draw a vertical-gradient-filled rectangle
latefinal
DrawRectangleLines ↔ WF5<void>
Draw rectangle outline
latefinal
DrawRectangleLinesEx ↔ WF3<void>
Draw rectangle outline with extended parameters
latefinal
DrawRectanglePro ↔ WF4<void>
Draw a color-filled rectangle with pro parameters
latefinal
DrawRectangleRec ↔ WF2<void>
Draw a color-filled rectangle
latefinal
DrawRectangleRounded ↔ WF4<void>
Draw rectangle with rounded edges
latefinal
DrawRectangleRoundedLines ↔ WF4<void>
Draw rectangle lines with rounded edges
latefinal
DrawRectangleRoundedLinesEx ↔ WF5<void>
Draw rectangle with rounded edges outline
latefinal
DrawRectangleV ↔ WF3<void>
Draw a color-filled rectangle (Vector version)
latefinal
DrawRing ↔ WF7<void>
Draw ring
latefinal
DrawRingLines ↔ WF7<void>
Draw ring outline
latefinal
DrawSphere ↔ WF3<void>
Draw sphere
latefinal
DrawSphereEx ↔ WF5<void>
Draw sphere with extended parameters
latefinal
DrawSphereWires ↔ WF5<void>
Draw sphere wires
latefinal
DrawSplineBasis ↔ WF4<void>
Draw spline: B-Spline, minimum 4 points
latefinal
DrawSplineBezierCubic ↔ WF4<void>
Draw spline: Cubic Bezier, minimum 4 points (2 control points): p1, c2, c3, p4, c5, c6...
latefinal
DrawSplineBezierQuadratic ↔ WF4<void>
Draw spline: Quadratic Bezier, minimum 3 points (1 control point): p1, c2, p3, c4...
latefinal
DrawSplineCatmullRom ↔ WF4<void>
Draw spline: Catmull-Rom, minimum 4 points
latefinal
DrawSplineLinear ↔ WF4<void>
Draw spline: Linear, minimum 2 points
latefinal
DrawSplineSegmentBasis ↔ WF6<void>
Draw spline segment: B-Spline, 4 points
latefinal
DrawSplineSegmentBezierCubic ↔ WF6<void>
Draw spline segment: Cubic Bezier, 2 points, 2 control points
latefinal
DrawSplineSegmentBezierQuadratic ↔ WF5<void>
Draw spline segment: Quadratic Bezier, 2 points, 1 control point
latefinal
DrawSplineSegmentCatmullRom ↔ WF6<void>
Draw spline segment: Catmull-Rom, 4 points
latefinal
DrawSplineSegmentLinear ↔ WF4<void>
Draw spline segment: Linear, 2 points
latefinal
DrawText ↔ WF5<void>
Draw text (using default font)
latefinal
DrawTextCodepoint ↔ WF5<void>
Draw one character (codepoint)
latefinal
DrawTextCodepoints ↔ WF7<void>
Draw multiple character (codepoint)
latefinal
DrawTextEx ↔ WF6<void>
Draw text using font and additional parameters
latefinal
DrawTextPro ↔ WF8<void>
Draw text using Font and pro parameters (rotation)
latefinal
DrawTexture ↔ WF4<void>
Draw a Texture2D
latefinal
DrawTextureEx ↔ WF5<void>
Draw a Texture2D with extended parameters
latefinal
DrawTextureNPatch ↔ WF6<void>
Draws a texture (or part of it) that stretches or shrinks nicely
latefinal
DrawTexturePro ↔ WF6<void>
Draw a part of a texture defined by a rectangle with 'pro' parameters
latefinal
DrawTextureRec ↔ WF4<void>
Draw a part of a texture defined by a rectangle
latefinal
DrawTextureV ↔ WF3<void>
Draw a Texture2D with position defined as Vector2
latefinal
DrawTriangle ↔ WF4<void>
Draw a color-filled triangle (vertex in counter-clockwise order!)
latefinal
DrawTriangle3D ↔ WF4<void>
Draw a color-filled triangle (vertex in counter-clockwise order!)
latefinal
DrawTriangleFan ↔ WF3<void>
Draw a triangle fan defined by points (first vertex is the center)
latefinal
DrawTriangleLines ↔ WF4<void>
Draw triangle outline (vertex in counter-clockwise order!)
latefinal
DrawTriangleStrip ↔ WF3<void>
Draw a triangle strip defined by points
latefinal
DrawTriangleStrip3D ↔ WF3<void>
Draw a triangle strip defined by points
latefinal
EnableCursor ↔ WF0<void>
Enables cursor (unlock cursor)
latefinal
EnableEventWaiting ↔ WF0<void>
Enable waiting for events on EndDrawing(), no automatic event polling
latefinal
EncodeDataBase64 ↔ WF3<WasmMemoryPointer<RChar>>
Encode data to Base64 string
latefinal
EndBlendMode ↔ WF0<void>
End blending mode (reset to default: alpha blending)
latefinal
EndDrawing ↔ WF0<void>
End canvas drawing and swap buffers (double buffering)
latefinal
EndMode2D ↔ WF0<void>
Ends 2D mode with custom camera
latefinal
EndMode3D ↔ WF0<void>
Ends 3D mode and returns to default 2D orthographic mode
latefinal
EndScissorMode ↔ WF0<void>
End scissor mode
latefinal
EndShaderMode ↔ WF0<void>
End custom shader drawing (use default shader)
latefinal
EndTextureMode ↔ WF0<void>
Ends drawing to render texture
latefinal
EndVrStereoMode ↔ WF0<void>
End stereo rendering (requires VR simulator)
latefinal
ExportAutomationEventList ↔ WF2<bool>
Export automation events list as text file
latefinal
ExportDataAsCode ↔ WF3<bool>
Export data to code (.h), returns true on success
latefinal
ExportFontAsCode ↔ WF2<bool>
Export font as code file, returns true on success
latefinal
ExportImage ↔ WF2<bool>
Export image data to file, returns true on success
latefinal
ExportImageAsCode ↔ WF2<bool>
Export image as code file defining an array of bytes, returns true on success
latefinal
ExportImageToMemory ↔ WF3<WasmMemoryPointer<RUnsignedChar>>
Export image to memory buffer
latefinal
ExportMesh ↔ WF2<bool>
Export mesh data to file, returns true on success
latefinal
ExportMeshAsCode ↔ WF2<bool>
Export mesh as code file (.h) defining multiple arrays of vertex attributes
latefinal
Fade ↔ WF3<void>
Get color with alpha applied, alpha goes from 0.0 to 1.0
latefinal
FileCopy ↔ WF2<int>
Copy file from one path to another, dstPath created if it doesn't exist
latefinal
FileExists ↔ WF1<bool>
Check if file exists
latefinal
FileMove ↔ WF2<int>
Move file from one directory to another, dstPath created if it doesn't exist
latefinal
FileRemove ↔ WF1<int>
Remove file (if exists)
latefinal
FileRename ↔ WF2<int>
Rename file (if exists)
latefinal
FileTextFindIndex ↔ WF2<int>
Find text in existing file
latefinal
FileTextReplace ↔ WF3<int>
Replace text in an existing file
latefinal
GenImageCellular ↔ WF4<void>
Generate image: cellular algorithm, bigger tileSize means bigger cells
latefinal
GenImageChecked ↔ WF7<void>
Generate image: checked
latefinal
GenImageColor ↔ WF4<void>
Generate image: plain color
latefinal
GenImageFontAtlas ↔ WF7<void>
Generate image font atlas using chars info
latefinal
GenImageGradientLinear ↔ WF6<void>
Generate image: linear gradient, direction in degrees 0..360, 0=Vertical gradient
latefinal
GenImageGradientRadial ↔ WF6<void>
Generate image: radial gradient
latefinal
GenImageGradientSquare ↔ WF6<void>
Generate image: square gradient
latefinal
GenImagePerlinNoise ↔ WF6<void>
Generate image: perlin noise
latefinal
GenImageText ↔ WF4<void>
Generate image: grayscale image from text data
latefinal
GenImageWhiteNoise ↔ WF4<void>
Generate image: white noise
latefinal
GenMeshCone ↔ WF4<void>
Generate cone/pyramid mesh
latefinal
GenMeshCube ↔ WF4<void>
Generate cuboid mesh
latefinal
GenMeshCubicmap ↔ WF3<void>
Generate cubes-based map mesh from image data
latefinal
GenMeshCylinder ↔ WF4<void>
Generate cylinder mesh
latefinal
GenMeshHeightmap ↔ WF3<void>
Generate heightmap mesh from image data
latefinal
GenMeshHemiSphere ↔ WF4<void>
Generate half-sphere mesh (no bottom cap)
latefinal
GenMeshKnot ↔ WF5<void>
Generate trefoil knot mesh
latefinal
GenMeshPlane ↔ WF5<void>
Generate plane mesh (with subdivisions)
latefinal
GenMeshPoly ↔ WF3<void>
Generate polygonal mesh
latefinal
GenMeshSphere ↔ WF4<void>
Generate sphere mesh (standard sphere)
latefinal
GenMeshTangents ↔ WF1<void>
Compute mesh tangents
latefinal
GenMeshTorus ↔ WF5<void>
Generate torus mesh
latefinal
GenTextureMipmaps ↔ WF1<void>
Generate GPU mipmaps for a texture
latefinal
GetApplicationDirectory ↔ WF0<WasmMemoryPointer<RChar>>
Get the directory of the running application
latefinal
GetCameraMatrix ↔ WF2<void>
Get camera transform matrix (view matrix)
latefinal
GetCameraMatrix2D ↔ WF2<void>
Get camera 2d transform matrix
latefinal
GetCharPressed ↔ WF0<int>
Get char pressed (unicode), call it multiple times for chars queued, returns 0 when the queue is empty
latefinal
GetClipboardImage ↔ WF1<void>
Get clipboard image content
latefinal
GetClipboardText ↔ WF0<WasmMemoryPointer<RChar>>
Get clipboard text content
latefinal
GetCodepoint ↔ WF2<int>
Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
latefinal
GetCodepointCount ↔ WF1<int>
Get total number of codepoints in a UTF-8 encoded string
latefinal
GetCodepointNext ↔ WF2<int>
Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
latefinal
GetCodepointPrevious ↔ WF2<int>
Get previous codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
latefinal
GetCollisionRec ↔ WF3<void>
Get collision rectangle for two rectangles collision
latefinal
GetColor ↔ WF2<void>
Get Color structure from hexadecimal value
latefinal
GetCurrentMonitor ↔ WF0<int>
Get current monitor where window is placed
latefinal
GetDirectoryFileCount ↔ WF1<int>
Get the file count in a directory
latefinal
GetDirectoryFileCountEx ↔ WF3<int>
Get the file count in a directory with extension filtering and recursive directory scan.
latefinal
GetDirectoryPath ↔ WF1<WasmMemoryPointer<RChar>>
Get full path for a given fileName with path
latefinal
GetFileExtension ↔ WF1<WasmMemoryPointer<RChar>>
Get extension for a filename (includes dot: '.png')
latefinal
GetFileLength ↔ WF1<int>
Get file length in bytes
latefinal
GetFileModTime ↔ WF1<int>
Get file modification time (last write time)
latefinal
GetFileName ↔ WF1<WasmMemoryPointer<RChar>>
Get filename for a path string
latefinal
GetFileNameWithoutExt ↔ WF1<WasmMemoryPointer<RChar>>
Get filename without extension
latefinal
GetFontDefault ↔ WF1<void>
Get the default Font
latefinal
GetFPS ↔ WF0<int>
Get current FPS
latefinal
GetFrameTime ↔ WF0<double>
Get time in seconds for last frame drawn (delta time)
latefinal
GetGamepadAxisCount ↔ WF1<int>
Get gamepad axis count for a gamepad
latefinal
GetGamepadAxisMovement ↔ WF2<double>
Get axis movement value for a gamepad axis
latefinal
GetGamepadButtonPressed ↔ WF0<int>
Get the last gamepad button pressed
latefinal
GetGamepadName ↔ WF1<WasmMemoryPointer<RChar>>
Get gamepad internal name id
latefinal
GetGestureDetected ↔ WF0<int>
Get latest detected gesture
latefinal
GetGestureDragAngle ↔ WF0<double>
Get gesture drag angle
latefinal
GetGestureDragVector ↔ WF1<void>
Get gesture drag vector
latefinal
GetGestureHoldDuration ↔ WF0<double>
Get gesture hold time in seconds
latefinal
GetGesturePinchAngle ↔ WF0<double>
Get gesture pinch angle
latefinal
GetGesturePinchVector ↔ WF1<void>
Get gesture pinch delta
latefinal
GetGlyphAtlasRec ↔ WF3<void>
Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
latefinal
GetGlyphIndex ↔ WF2<int>
Get glyph index position in font for a codepoint (unicode character), fallback to '?' if not found
latefinal
GetGlyphInfo ↔ WF3<void>
Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
latefinal
GetImageAlphaBorder ↔ WF3<void>
Get image alpha border rectangle
latefinal
GetImageColor ↔ WF4<void>
Get image pixel color at (x, y) position
latefinal
GetKeyName ↔ WF1<WasmMemoryPointer<RChar>>
Get name of a QWERTY key on the current keyboard layout (eg returns string 'q' for KEY_A on an AZERTY keyboard)
latefinal
GetKeyPressed ↔ WF0<int>
Get key pressed (keycode), call it multiple times for keys queued, returns 0 when the queue is empty
latefinal
GetMeshBoundingBox ↔ WF2<void>
Compute mesh bounding box limits
latefinal
GetModelBoundingBox ↔ WF2<void>
Compute model bounding box limits (considers all meshes)
latefinal
GetMonitorCount ↔ WF0<int>
Get number of connected monitors
latefinal
GetMonitorHeight ↔ WF1<int>
Get specified monitor height (current video mode used by monitor)
latefinal
GetMonitorName ↔ WF1<WasmMemoryPointer<RChar>>
Get the human-readable, UTF-8 encoded name of the specified monitor
latefinal
GetMonitorPhysicalHeight ↔ WF1<int>
Get specified monitor physical height in millimetres
latefinal
GetMonitorPhysicalWidth ↔ WF1<int>
Get specified monitor physical width in millimetres
latefinal
GetMonitorPosition ↔ WF2<void>
Get specified monitor position
latefinal
GetMonitorRefreshRate ↔ WF1<int>
Get specified monitor refresh rate
latefinal
GetMonitorWidth ↔ WF1<int>
Get specified monitor width (current video mode used by monitor)
latefinal
GetMouseDelta ↔ WF1<void>
Get mouse delta between frames
latefinal
GetMousePosition ↔ WF1<void>
Get mouse position XY
latefinal
GetMouseWheelMove ↔ WF0<double>
Get mouse wheel movement for X or Y, whichever is larger
latefinal
GetMouseWheelMoveV ↔ WF1<void>
Get mouse wheel movement for both X and Y
latefinal
GetMouseX ↔ WF0<int>
Get mouse position X
latefinal
GetMouseY ↔ WF0<int>
Get mouse position Y
latefinal
GetPixelColor ↔ WF3<void>
Get Color from a source pixel pointer of certain format
latefinal
GetPixelDataSize ↔ WF3<int>
Get pixel data size in bytes for certain format
latefinal
GetPrevDirectoryPath ↔ WF1<WasmMemoryPointer<RChar>>
Get previous directory path for a given path
latefinal
GetRandomValue ↔ WF2<int>
Get a random value between min and max (both included)
latefinal
GetRayCollisionBox ↔ WF3<void>
Get collision info between ray and box
latefinal
GetRayCollisionMesh ↔ WF4<void>
Get collision info between ray and mesh
latefinal
GetRayCollisionQuad ↔ WF6<void>
Get collision info between ray and quad
latefinal
GetRayCollisionSphere ↔ WF4<void>
Get collision info between ray and sphere
latefinal
GetRayCollisionTriangle ↔ WF5<void>
Get collision info between ray and triangle
latefinal
GetRenderHeight ↔ WF0<int>
Get current render height (it considers HiDPI)
latefinal
GetRenderWidth ↔ WF0<int>
Get current render width (it considers HiDPI)
latefinal
GetScreenHeight ↔ WF0<int>
Get current screen height
latefinal
GetScreenToWorld2D ↔ WF3<void>
Get the world space position for a 2d camera screen space position
latefinal
GetScreenToWorldRay ↔ WF3<void>
Get a ray trace from screen position (i.e mouse)
latefinal
GetScreenToWorldRayEx ↔ WF5<void>
Get a ray trace from screen position (i.e mouse) in a viewport
latefinal
GetScreenWidth ↔ WF0<int>
Get current screen width
latefinal
GetShaderLocation ↔ WF2<int>
Get shader uniform location
latefinal
GetShaderLocationAttrib ↔ WF2<int>
Get shader attribute location
latefinal
GetShapesTexture ↔ WF1<void>
Get texture that is used for shapes drawing
latefinal
GetShapesTextureRectangle ↔ WF1<void>
Get texture source rectangle that is used for shapes drawing
latefinal
GetSplinePointBasis ↔ WF6<void>
Get (evaluate) spline point: B-Spline
latefinal
GetSplinePointBezierCubic ↔ WF6<void>
Get (evaluate) spline point: Cubic Bezier
latefinal
GetSplinePointBezierQuad ↔ WF5<void>
Get (evaluate) spline point: Quadratic Bezier
latefinal
GetSplinePointCatmullRom ↔ WF6<void>
Get (evaluate) spline point: Catmull-Rom
latefinal
GetSplinePointLinear ↔ WF4<void>
Get (evaluate) spline point: Linear
latefinal
GetTextBetween ↔ WF3<WasmMemoryPointer<RChar>>
Get text between two strings
latefinal
GetTime ↔ WF0<double>
Get elapsed time in seconds since InitWindow()
latefinal
GetTouchPointCount ↔ WF0<int>
Get number of touch points
latefinal
GetTouchPointId ↔ WF1<int>
Get touch point identifier for given index
latefinal
GetTouchPosition ↔ WF2<void>
Get touch position XY for a touch point index (relative to screen size)
latefinal
GetTouchX ↔ WF0<int>
Get touch position X for touch point 0 (relative to screen size)
latefinal
GetTouchY ↔ WF0<int>
Get touch position Y for touch point 0 (relative to screen size)
latefinal
GetWindowHandle ↔ WF0<WasmMemoryPointer<RVoid>>
Get native window handle
latefinal
GetWindowPosition ↔ WF1<void>
Get window position XY on monitor
latefinal
GetWindowScaleDPI ↔ WF1<void>
Get window scale DPI factor
latefinal
GetWorkingDirectory ↔ WF0<WasmMemoryPointer<RChar>>
Get current working directory
latefinal
GetWorldToScreen ↔ WF3<void>
Get the screen space position for a 3d world space position
latefinal
GetWorldToScreen2D ↔ WF3<void>
Get the screen space position for a 2d camera world space position
latefinal
GetWorldToScreenEx ↔ WF5<void>
Get size position for a 3d world space position
latefinal
hashCode → int
The hash code for this object.
no setterinherited
HideCursor ↔ WF0<void>
Hides cursor
latefinal
ImageAlphaClear ↔ WF3<void>
Clear alpha channel to desired color
latefinal
ImageAlphaCrop ↔ WF2<void>
Crop image depending on alpha value
latefinal
ImageAlphaMask ↔ WF2<void>
Apply alpha mask to image
latefinal
ImageAlphaPremultiply ↔ WF1<void>
Premultiply alpha channel
latefinal
ImageBlurGaussian ↔ WF2<void>
Apply Gaussian blur using a box blur approximation
latefinal
ImageClearBackground ↔ WF2<void>
Clear image background with given color
latefinal
ImageColorBrightness ↔ WF2<void>
Modify image color: brightness (-255 to 255)
latefinal
ImageColorContrast ↔ WF2<void>
Modify image color: contrast (-100 to 100)
latefinal
ImageColorGrayscale ↔ WF1<void>
Modify image color: grayscale
latefinal
ImageColorInvert ↔ WF1<void>
Modify image color: invert
latefinal
ImageColorReplace ↔ WF3<void>
Modify image color: replace color
latefinal
ImageColorTint ↔ WF2<void>
Modify image color: tint
latefinal
ImageCopy ↔ WF2<void>
Create an image duplicate (useful for transformations)
latefinal
ImageCrop ↔ WF2<void>
Crop an image to a defined rectangle
latefinal
ImageDither ↔ WF5<void>
Dither image data to 16bpp or lower (Floyd-Steinberg dithering)
latefinal
ImageDraw ↔ WF5<void>
Draw a source image within a destination image (tint applied to source)
latefinal
ImageDrawCircle ↔ WF5<void>
Draw a filled circle within an image
latefinal
ImageDrawCircleLines ↔ WF5<void>
Draw circle outline within an image
latefinal
ImageDrawCircleLinesV ↔ WF4<void>
Draw circle outline within an image (Vector version)
latefinal
ImageDrawCircleV ↔ WF4<void>
Draw a filled circle within an image (Vector version)
latefinal
ImageDrawLine ↔ WF6<void>
Draw line within an image
latefinal
ImageDrawLineEx ↔ WF5<void>
Draw a line defining thickness within an image
latefinal
ImageDrawLineV ↔ WF4<void>
Draw line within an image (Vector version)
latefinal
ImageDrawPixel ↔ WF4<void>
Draw pixel within an image
latefinal
ImageDrawPixelV ↔ WF3<void>
Draw pixel within an image (Vector version)
latefinal
ImageDrawRectangle ↔ WF6<void>
Draw rectangle within an image
latefinal
ImageDrawRectangleLines ↔ WF4<void>
Draw rectangle lines within an image
latefinal
ImageDrawRectangleRec ↔ WF3<void>
Draw rectangle within an image
latefinal
ImageDrawRectangleV ↔ WF4<void>
Draw rectangle within an image (Vector version)
latefinal
ImageDrawText ↔ WF6<void>
Draw text (using default font) within an image (destination)
latefinal
ImageDrawTextEx ↔ WF7<void>
Draw text (custom sprite font) within an image (destination)
latefinal
ImageDrawTriangle ↔ WF5<void>
Draw triangle within an image
latefinal
ImageDrawTriangleEx ↔ WF7<void>
Draw triangle with interpolated colors within an image
latefinal
ImageDrawTriangleFan ↔ WF4<void>
Draw a triangle fan defined by points within an image (first vertex is the center)
latefinal
ImageDrawTriangleLines ↔ WF5<void>
Draw triangle outline within an image
latefinal
ImageDrawTriangleStrip ↔ WF4<void>
Draw a triangle strip defined by points within an image
latefinal
ImageFlipHorizontal ↔ WF1<void>
Flip image horizontally
latefinal
ImageFlipVertical ↔ WF1<void>
Flip image vertically
latefinal
ImageFormat ↔ WF2<void>
Convert image data to desired format
latefinal
ImageFromChannel ↔ WF3<void>
Create an image from a selected channel of another image (GRAYSCALE)
latefinal
ImageFromImage ↔ WF3<void>
Create an image from another image piece
latefinal
ImageKernelConvolution ↔ WF3<void>
Apply custom square convolution kernel to image
latefinal
ImageMipmaps ↔ WF1<void>
Compute all mipmap levels for a provided image
latefinal
ImageResize ↔ WF3<void>
Resize image (Bicubic scaling algorithm)
latefinal
ImageResizeCanvas ↔ WF6<void>
Resize canvas and fill with color
latefinal
ImageResizeNN ↔ WF3<void>
Resize image (Nearest-Neighbor scaling algorithm)
latefinal
ImageRotate ↔ WF2<void>
Rotate image by input angle in degrees (-359 to 359)
latefinal
ImageRotateCCW ↔ WF1<void>
Rotate image counter-clockwise 90deg
latefinal
ImageRotateCW ↔ WF1<void>
Rotate image clockwise 90deg
latefinal
ImageText ↔ WF4<void>
Create an image from text (default font)
latefinal
ImageTextEx ↔ WF6<void>
Create an image from text (custom sprite font)
latefinal
ImageToPOT ↔ WF2<void>
Convert image to POT (power-of-two)
latefinal
InitWindow ↔ WF3<void>
Initialize window and OpenGL context
latefinal
IsCursorHidden ↔ WF0<bool>
Check if cursor is not visible
latefinal
IsCursorOnScreen ↔ WF0<bool>
Check if cursor is on the screen
latefinal
IsFileDropped ↔ WF0<bool>
Check if a file has been dropped into window
latefinal
IsFileExtension ↔ WF2<bool>
Check file extension (including point: .png, .wav)
latefinal
IsFileNameValid ↔ WF1<bool>
Check if fileName is valid for the platform/OS
latefinal
IsFontValid ↔ WF1<bool>
Check if a font is valid (font data loaded, WARNING: GPU texture not checked)
latefinal
IsGamepadAvailable ↔ WF1<bool>
Check if a gamepad is available
latefinal
IsGamepadButtonDown ↔ WF2<bool>
Check if a gamepad button is being pressed
latefinal
IsGamepadButtonPressed ↔ WF2<bool>
Check if a gamepad button has been pressed once
latefinal
IsGamepadButtonReleased ↔ WF2<bool>
Check if a gamepad button has been released once
latefinal
IsGamepadButtonUp ↔ WF2<bool>
Check if a gamepad button is NOT being pressed
latefinal
IsGestureDetected ↔ WF1<bool>
Check if a gesture have been detected
latefinal
IsImageValid ↔ WF1<bool>
Check if an image is valid (data and parameters)
latefinal
IsKeyDown ↔ WF1<bool>
Check if a key is being pressed
latefinal
IsKeyPressed ↔ WF1<bool>
Check if a key has been pressed once
latefinal
IsKeyPressedRepeat ↔ WF1<bool>
Check if a key has been pressed again
latefinal
IsKeyReleased ↔ WF1<bool>
Check if a key has been released once
latefinal
IsKeyUp ↔ WF1<bool>
Check if a key is NOT being pressed
latefinal
IsMaterialValid ↔ WF1<bool>
Check if a material is valid (shader assigned, map textures loaded in GPU)
latefinal
IsModelAnimationValid ↔ WF2<bool>
Check model animation skeleton match
latefinal
IsModelValid ↔ WF1<bool>
Check if a model is valid (loaded in GPU, VAO/VBOs)
latefinal
IsMouseButtonDown ↔ WF1<bool>
Check if a mouse button is being pressed
latefinal
IsMouseButtonPressed ↔ WF1<bool>
Check if a mouse button has been pressed once
latefinal
IsMouseButtonReleased ↔ WF1<bool>
Check if a mouse button has been released once
latefinal
IsMouseButtonUp ↔ WF1<bool>
Check if a mouse button is NOT being pressed
latefinal
IsPathFile ↔ WF1<bool>
Check if a given path is a file or a directory
latefinal
IsRenderTextureValid ↔ WF1<bool>
Check if a render texture is valid (loaded in GPU)
latefinal
IsShaderValid ↔ WF1<bool>
Check if a shader is valid (loaded on GPU)
latefinal
IsTextureValid ↔ WF1<bool>
Check if a texture is valid (loaded in GPU)
latefinal
IsWindowFocused ↔ WF0<bool>
Check if window is currently focused
latefinal
IsWindowFullscreen ↔ WF0<bool>
Check if window is currently fullscreen
latefinal
IsWindowHidden ↔ WF0<bool>
Check if window is currently hidden
latefinal
IsWindowMaximized ↔ WF0<bool>
Check if window is currently maximized
latefinal
IsWindowMinimized ↔ WF0<bool>
Check if window is currently minimized
latefinal
IsWindowReady ↔ WF0<bool>
Check if window has been initialized successfully
latefinal
IsWindowResized ↔ WF0<bool>
Check if window has been resized last frame
latefinal
IsWindowState ↔ WF1<bool>
Check if one specific window flag is enabled
latefinal
LoadAutomationEventList ↔ WF2<void>
Load automation events list from file, NULL for empty list
latefinal
LoadCodepoints ↔ WF2<WasmMemoryPointer<RInt>>
Load all codepoints from a UTF-8 text string, codepoints count returned by parameter
latefinal
LoadDirectoryFiles ↔ WF2<void>
Load directory filepaths
latefinal
LoadDirectoryFilesEx ↔ WF4<void>
Load directory filepaths with extension filtering and recursive directory scan.
latefinal
LoadDroppedFiles ↔ WF1<void>
Load dropped filepaths
latefinal
LoadFileData ↔ WF2<WasmMemoryPointer<RUnsignedChar>>
Load file data as byte array (read)
latefinal
LoadFileText ↔ WF1<WasmMemoryPointer<RChar>>
Load text data from file (read)
latefinal
LoadFont ↔ WF2<void>
Load font from file into GPU memory (VRAM)
latefinal
LoadFontData ↔ WF7<StructPointer<GlyphInfoD>>
Load font data for further use
latefinal
LoadFontEx ↔ WF5<void>
Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height
latefinal
LoadFontFromImage ↔ WF4<void>
Load font from Image (XNA style)
latefinal
LoadFontFromMemory ↔ WF7<void>
Load font from memory buffer, fileType refers to extension: i.e. '.ttf'
latefinal
LoadImage ↔ WF2<void>
Load image from file into CPU memory (RAM)
latefinal
LoadImageAnim ↔ WF3<void>
Load image sequence from file (frames appended to image.data)
latefinal
LoadImageAnimFromMemory ↔ WF5<void>
Load image sequence from memory buffer
latefinal
LoadImageColors ↔ WF1<StructPointer<ColorD>>
Load color data from image as a Color array (RGBA - 32bit)
latefinal
LoadImageFromMemory ↔ WF4<void>
Load image from memory buffer, fileType refers to extension: i.e. '.png'
latefinal
LoadImageFromScreen ↔ WF1<void>
Load image from screen buffer and (screenshot)
latefinal
LoadImageFromTexture ↔ WF2<void>
Load image from GPU texture data
latefinal
LoadImagePalette ↔ WF3<StructPointer<ColorD>>
Load colors palette from image as a Color array (RGBA - 32bit)
latefinal
LoadImageRaw ↔ WF6<void>
Load image from RAW file data
latefinal
LoadMaterialDefault ↔ WF1<void>
Load default material (Supports: DIFFUSE, SPECULAR, NORMAL maps)
latefinal
LoadMaterials ↔ WF2<StructPointer<MaterialD>>
Load materials from model file
latefinal
LoadModel ↔ WF2<void>
Load model from files (meshes and materials)
latefinal
LoadModelAnimations ↔ WF2<StructPointer<ModelAnimationD>>
Load model animations from file
latefinal
LoadModelFromMesh ↔ WF2<void>
Load model from generated mesh (default material)
latefinal
LoadRandomSequence ↔ WF3<WasmMemoryPointer<RInt>>
Load random values sequence, no values repeated, min and max included
latefinal
LoadRenderTexture ↔ WF3<void>
Load texture for rendering (framebuffer)
latefinal
LoadShader ↔ WF3<void>
Load shader from files and bind default locations
latefinal
LoadShaderFromMemory ↔ WF3<void>
Load shader from code strings and bind default locations
latefinal
LoadTextLines ↔ WF2<WasmMemoryPointer<RPointer<RChar>>>
Load text as separate lines ('\n')
latefinal
LoadTexture ↔ WF2<void>
Load texture from file into GPU memory (VRAM)
latefinal
LoadTextureCubemap ↔ WF3<void>
Load cubemap from image, multiple image cubemap layouts supported
latefinal
LoadTextureFromImage ↔ WF2<void>
Load texture from image data
latefinal
LoadUTF8 ↔ WF2<WasmMemoryPointer<RChar>>
Load UTF-8 text encoded from codepoints array
latefinal
LoadVrStereoConfig ↔ WF2<void>
Load VR stereo config for VR simulator device parameters
latefinal
MakeDirectory ↔ WF1<int>
Create directories (including full path requested), returns 0 on success
latefinal
MaximizeWindow ↔ WF0<void>
Set window state: maximized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
latefinal
MeasureText ↔ WF2<int>
Measure string width for default font
latefinal
MeasureTextCodepoints ↔ WF6<void>
Measure string size for an existing array of codepoints for Font
latefinal
MeasureTextEx ↔ WF5<void>
Measure string size for Font
latefinal
MinimizeWindow ↔ WF0<void>
Set window state: minimized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
latefinal
OpenURL ↔ WF1<void>
Open URL with default system browser (if available)
latefinal
PlayAutomationEvent ↔ WF1<void>
Play a recorded automation event
latefinal
PollInputEvents ↔ WF0<void>
Register all input events
latefinal
ProcessGestureEvent ↔ WF1<void>
Process gesture event and translate it into gestures
latefinal
RestoreWindow ↔ WF0<void>
Set window state: not minimized/maximized
latefinal
rl → Raylib
finalinherited
rn → String
Emscripten cwrap return type for anything other than structs and void.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rv → Null
Emscripten cwrap return type for functions returning void.
finalinherited
SaveFileData ↔ WF3<bool>
Save data to file from byte array (write), returns true on success
latefinal
SaveFileText ↔ WF2<bool>
Save text data to file (write), returns true on success
latefinal
SetAutomationEventBaseFrame ↔ WF1<void>
Set automation event internal base frame to start recording
latefinal
SetAutomationEventList ↔ WF1<void>
Set automation event list to record to
latefinal
SetClipboardText ↔ WF1<void>
Set clipboard text content
latefinal
SetConfigFlags ↔ WF1<void>
Setup init configuration flags (view ConfigFlags)
latefinal
SetExitKey ↔ WF1<void>
Set a custom key to exit program (default is ESC)
latefinal
SetGamepadMappings ↔ WF1<int>
Set internal gamepad mappings (SDL_GameControllerDB)
latefinal
SetGamepadVibration ↔ WF4<void>
Set gamepad vibration for both motors (duration in seconds)
latefinal
SetGesturesEnabled ↔ WF1<void>
Enable a set of gestures using flags Gesture
latefinal
SetLoadFileDataCallback ↔ WF1<void>
Set custom file binary data loader
latefinal
SetLoadFileTextCallback ↔ WF1<void>
Set custom file text data loader
latefinal
SetMaterialTexture ↔ WF3<void>
Set texture for a material map type (MATERIAL_MAP_DIFFUSE, MATERIAL_MAP_SPECULAR...)
latefinal
SetModelMeshMaterial ↔ WF3<void>
Set material for a mesh
latefinal
SetMouseCursor ↔ WF1<void>
Set mouse cursor
latefinal
SetMouseOffset ↔ WF2<void>
Set mouse offset
latefinal
SetMousePosition ↔ WF2<void>
Set mouse position XY
latefinal
SetMouseScale ↔ WF2<void>
Set mouse scaling
latefinal
SetPixelColor ↔ WF3<void>
Set color formatted into destination pixel pointer
latefinal
SetRandomSeed ↔ WF1<void>
Set the seed for the random number generator
latefinal
SetSaveFileDataCallback ↔ WF1<void>
Set custom file binary data saver
latefinal
SetSaveFileTextCallback ↔ WF1<void>
Set custom file text data saver
latefinal
SetShaderValue ↔ WF4<void>
Set shader uniform value
latefinal
SetShaderValueMatrix ↔ WF3<void>
Set shader uniform value (matrix 4x4)
latefinal
SetShaderValueTexture ↔ WF3<void>
Set shader uniform value for texture (sampler2d)
latefinal
SetShaderValueV ↔ WF5<void>
Set shader uniform value vector
latefinal
SetShapesTexture ↔ WF2<void>
Set texture and rectangle to be used on shapes drawing
latefinal
SetTargetFPS ↔ WF1<void>
Set target FPS (maximum)
latefinal
SetTextLineSpacing ↔ WF1<void>
Set vertical line spacing when drawing with line-breaks
latefinal
SetTextureFilter ↔ WF2<void>
Set texture scaling filter mode
latefinal
SetTextureWrap ↔ WF2<void>
Set texture wrapping mode
latefinal
SetTraceLogCallback ↔ WF1<void>
Set custom trace log
latefinal
SetTraceLogLevel ↔ WF1<void>
Set the current threshold (minimum) log level
latefinal
SetWindowFocused ↔ WF0<void>
Set window focused
latefinal
SetWindowIcon ↔ WF1<void>
Set icon for window (single image, RGBA 32bit)
latefinal
SetWindowIcons ↔ WF2<void>
Set icon for window (multiple images, RGBA 32bit)
latefinal
SetWindowMaxSize ↔ WF2<void>
Set window maximum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE)
latefinal
SetWindowMinSize ↔ WF2<void>
Set window minimum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE)
latefinal
SetWindowMonitor ↔ WF1<void>
Set monitor for the current window
latefinal
SetWindowOpacity ↔ WF1<void>
Set window opacity 0.0..1.0
latefinal
SetWindowPosition ↔ WF2<void>
Set window position on screen
latefinal
SetWindowSize ↔ WF2<void>
Set window dimensions
latefinal
SetWindowState ↔ WF1<void>
Set window configuration state using flags
latefinal
SetWindowTitle ↔ WF1<void>
Set title for window
latefinal
ShowCursor ↔ WF0<void>
Shows cursor
latefinal
StartAutomationEventRecording ↔ WF0<void>
Start recording automation events (AutomationEventList must be set)
latefinal
StopAutomationEventRecording ↔ WF0<void>
Stop recording automation events
latefinal
SwapScreenBuffer ↔ WF0<void>
Swap back buffer with front buffer (screen drawing)
latefinal
TakeScreenshot ↔ WF1<void>
Takes a screenshot of current screen (filename extension defines format)
latefinal
TextAppend ↔ WF3<void>
Append text at specific position and move cursor
latefinal
TextCopy ↔ WF2<int>
Copy one string to another, returns bytes copied
latefinal
TextFindIndex ↔ WF2<int>
Find first text occurrence within a string, -1 if not found
latefinal
TextFormat ↔ WF1<WasmMemoryPointer<RChar>>
Text formatting with variables (sprintf() style)
latefinal
TextInsert ↔ WF3<WasmMemoryPointer<RChar>>
Insert text in a defined byte position
latefinal
TextInsertAlloc ↔ WF3<WasmMemoryPointer<RChar>>
Insert text in a defined byte position, memory must be freed
latefinal
TextIsEqual ↔ WF2<bool>
Check if two text string are equal
latefinal
TextJoin ↔ WF3<WasmMemoryPointer<RChar>>
Join text strings with delimiter (delimiter is expected to be length of 1)
latefinal
TextLength ↔ WF1<int>
Get text length
latefinal
TextRemoveSpaces ↔ WF1<WasmMemoryPointer<RChar>>
Remove text spaces, concat words
latefinal
TextReplace ↔ WF3<WasmMemoryPointer<RChar>>
Replace text string with new string
latefinal
TextReplaceAlloc ↔ WF3<WasmMemoryPointer<RChar>>
Replace text string with new string, memory must be freed
latefinal
TextReplaceBetween ↔ WF4<WasmMemoryPointer<RChar>>
Replace text between two specific strings
latefinal
TextReplaceBetweenAlloc ↔ WF4<WasmMemoryPointer<RChar>>
Replace text between two specific strings, memory must be freed
latefinal
TextSplit ↔ WF3<WasmMemoryPointer<RPointer<RChar>>>
Split text into multiple strings
latefinal
TextSubtext ↔ WF3<WasmMemoryPointer<RChar>>
Get a piece of a text string
latefinal
TextToCamel ↔ WF1<WasmMemoryPointer<RChar>>
Get Camel case notation version of provided string
latefinal
TextToFloat ↔ WF1<double>
Get float value from text
latefinal
TextToInteger ↔ WF1<int>
Get integer value from text
latefinal
TextToLower ↔ WF1<WasmMemoryPointer<RChar>>
Get lower case version of provided string
latefinal
TextToPascal ↔ WF1<WasmMemoryPointer<RChar>>
Get Pascal case notation version of provided string
latefinal
TextToSnake ↔ WF1<WasmMemoryPointer<RChar>>
Get Snake case notation version of provided string
latefinal
TextToUpper ↔ WF1<WasmMemoryPointer<RChar>>
Get upper case version of provided string
latefinal
ToggleBorderlessWindowed ↔ WF0<void>
Toggle window state: borderless windowed, resizes window to match monitor resolution
latefinal
ToggleFullscreen ↔ WF0<void>
Toggle window state: fullscreen/windowed, resizes monitor to match window resolution
latefinal
TraceLog ↔ WF2<void>
Show trace log messages (LOG_DEBUG, LOG_INFO, LOG_WARNING, LOG_ERROR...)
latefinal
UnloadAutomationEventList ↔ WF1<void>
Unload automation events list from file
latefinal
UnloadCodepoints ↔ WF1<void>
Unload codepoints data from memory
latefinal
UnloadDirectoryFiles ↔ WF1<void>
Unload filepaths
latefinal
UnloadDroppedFiles ↔ WF1<void>
Unload dropped filepaths
latefinal
UnloadFileData ↔ WF1<void>
Unload file data allocated by LoadFileData()
latefinal
UnloadFileText ↔ WF1<void>
Unload file text data allocated by LoadFileText()
latefinal
UnloadFont ↔ WF1<void>
Unload font from GPU memory (VRAM)
latefinal
UnloadFontData ↔ WF2<void>
Unload font chars info data (RAM)
latefinal
UnloadImage ↔ WF1<void>
Unload image from CPU memory (RAM)
latefinal
UnloadImageColors ↔ WF1<void>
Unload color data loaded with LoadImageColors()
latefinal
UnloadImagePalette ↔ WF1<void>
Unload colors palette loaded with LoadImagePalette()
latefinal
UnloadMaterial ↔ WF1<void>
Unload material from GPU memory (VRAM)
latefinal
UnloadMesh ↔ WF1<void>
Unload mesh data from CPU and GPU
latefinal
UnloadModel ↔ WF1<void>
Unload model (including meshes) from memory (RAM and/or VRAM)
latefinal
UnloadModelAnimations ↔ WF2<void>
Unload animation array data
latefinal
UnloadRandomSequence ↔ WF1<void>
Unload random values sequence
latefinal
UnloadRenderTexture ↔ WF1<void>
Unload render texture from GPU memory (VRAM)
latefinal
UnloadShader ↔ WF1<void>
Unload shader from GPU memory (VRAM)
latefinal
UnloadTextLines ↔ WF2<void>
Unload text lines
latefinal
UnloadTexture ↔ WF1<void>
Unload texture from GPU memory (VRAM)
latefinal
UnloadUTF8 ↔ WF1<void>
Unload UTF-8 text encoded from codepoints array
latefinal
UnloadVrStereoConfig ↔ WF1<void>
Unload VR stereo config
latefinal
UpdateCamera ↔ WF2<void>
Update camera position for selected mode
latefinal
UpdateCameraPro ↔ WF4<void>
Update camera movement/rotation
latefinal
UpdateGestures ↔ WF0<void>
Update gestures detected (must be called every frame)
latefinal
UpdateMeshBuffer ↔ WF5<void>
Update mesh vertex data in GPU for a specific buffer index
latefinal
UpdateModelAnimation ↔ WF3<void>
Update model animation pose (CPU)
latefinal
UpdateModelAnimationEx ↔ WF6<void>
Update model animation data (vertex buffers / bone matrices) for a specific pose, defined by two different animations at specific frames blended together
latefinal
UpdateTexture ↔ WF2<void>
Update GPU texture with new data
latefinal
UpdateTextureRec ↔ WF3<void>
Update GPU texture rectangle with new data
latefinal
UploadMesh ↔ WF2<void>
Upload mesh vertex data in GPU and provide VAO/VBO ids
latefinal
WaitTime ↔ WF1<void>
Wait for some time (halt program execution)
latefinal
WindowShouldClose ↔ WF0<bool>
Check if application should close (KeyboardKey.KEY_ESCAPE pressed or windows close icon clicked)
latefinal

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
dwrap0<R>(String name) → WF0<R>
Binds a cwraped C function taking 0 arguments and returning a plain (non-struct) value.
inherited
dwrap1<R>(String name) → WF1<R>
Binds a cwraped C function taking 1 argument and returning a plain (non-struct) value.
inherited
dwrap2<R>(String name) → WF2<R>
Binds a cwraped C function taking 2 arguments and returning a plain (non-struct) value.
inherited
dwrap3<R>(String name) → WF3<R>
Binds a cwraped C function taking 3 arguments and returning a plain (non-struct) value.
inherited
dwrap4<R>(String name) → WF4<R>
Binds a cwraped C function taking 4 arguments and returning a plain (non-struct) value.
inherited
dwrap5<R>(String name) → WF5<R>
Binds a cwraped C function taking 5 arguments and returning a plain (non-struct) value.
inherited
dwrap6<R>(String name) → WF6<R>
Binds a cwraped C function taking 6 arguments and returning a plain (non-struct) value.
inherited
dwrap7<R>(String name) → WF7<R>
Binds a cwraped C function taking 7 arguments and returning a plain (non-struct) value.
inherited
dwrap8<R>(String name) → WF8<R>
Binds a cwraped C function taking 8 arguments and returning a plain (non-struct) value.
inherited
dwrap9<R>(String name) → WF9<R>
Binds a cwraped C function taking 9 arguments and returning a plain (non-struct) value.
inherited
load() → void
Override to perform one-time module initialization.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
pwrap0<X extends RType>(String name) → WF0<WasmMemoryPointer<X>>
Binds a cwraped C function taking 0 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap1<X extends RType>(String name) → WF1<WasmMemoryPointer<X>>
Binds a cwraped C function taking 1 argument and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap2<X extends RType>(String name) → WF2<WasmMemoryPointer<X>>
Binds a cwraped C function taking 2 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap3<X extends RType>(String name) → WF3<WasmMemoryPointer<X>>
Binds a cwraped C function taking 3 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap4<X extends RType>(String name) → WF4<WasmMemoryPointer<X>>
Binds a cwraped C function taking 4 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap5<X extends RType>(String name) → WF5<WasmMemoryPointer<X>>
Binds a cwraped C function taking 5 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap6<X extends RType>(String name) → WF6<WasmMemoryPointer<X>>
Binds a cwraped C function taking 6 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap7<X extends RType>(String name) → WF7<WasmMemoryPointer<X>>
Binds a cwraped C function taking 7 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap8<X extends RType>(String name) → WF8<WasmMemoryPointer<X>>
Binds a cwraped C function taking 8 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap9<X extends RType>(String name) → WF9<WasmMemoryPointer<X>>
Binds a cwraped C function taking 9 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
qwrap0<X extends RaylibStruct<X>>(String name) → WF0<StructPointer<X>>
Binds a cwraped C function taking 0 arguments and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap1<X extends RaylibStruct<X>>(String name) → WF1<StructPointer<X>>
Binds a cwraped C function taking 1 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap2<X extends RaylibStruct<X>>(String name) → WF2<StructPointer<X>>
Binds a cwraped C function taking 2 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap3<X extends RaylibStruct<X>>(String name) → WF3<StructPointer<X>>
Binds a cwraped C function taking 3 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap4<X extends RaylibStruct<X>>(String name) → WF4<StructPointer<X>>
Binds a cwraped C function taking 4 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap5<X extends RaylibStruct<X>>(String name) → WF5<StructPointer<X>>
Binds a cwraped C function taking 5 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap6<X extends RaylibStruct<X>>(String name) → WF6<StructPointer<X>>
Binds a cwraped C function taking 6 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap7<X extends RaylibStruct<X>>(String name) → WF7<StructPointer<X>>
Binds a cwraped C function taking 7 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap8<X extends RaylibStruct<X>>(String name) → WF8<StructPointer<X>>
Binds a cwraped C function taking 8 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap9<X extends RaylibStruct<X>>(String name) → WF9<StructPointer<X>>
Binds a cwraped C function taking 9 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
swrap0(String name) → WF1<void>
Binds a cwraped C function taking 0 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap1(String name) → WF2<void>
Binds a cwraped C function taking 1 argument that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap2(String name) → WF3<void>
Binds a cwraped C function taking 2 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap3(String name) → WF4<void>
Binds a cwraped C function taking 3 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap4(String name) → WF5<void>
Binds a cwraped C function taking 4 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap5(String name) → WF6<void>
Binds a cwraped C function taking 5 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap6(String name) → WF7<void>
Binds a cwraped C function taking 6 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap7(String name) → WF8<void>
Binds a cwraped C function taking 7 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap8(String name) → WF9<void>
Binds a cwraped C function taking 8 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
symbol<X extends RType>(String name) → WasmMemoryPointer<X>
Resolves a global symbol exported by the WASM module and wraps its address as a WasmMemoryPointer.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited