RaylibCoreD class

Inheritance

Constructors

RaylibCoreD(Raylib rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
RaylibCaptureIds RaylibCoreModuleCaptureIds
Capture ID generator for pointer slots allocated by this module.
finalinherited
RaylibDebugLabels RaylibCoreModuleDebugLabels
Debug label generator for this module's function calls.
finalinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

BeginBlendMode(BlendMode mode) → void
Begin blending mode (alpha, additive, multiplied, subtract, custom)
override
BeginDrawing() → void
Setup canvas (framebuffer) to start drawing
override
BeginMode2D(Camera2DD camera) → void
Begin 2D mode with custom camera (2D)
override
BeginMode3D(Camera3DD camera) → void
Begin 3D mode with custom camera (3D)
override
BeginScissorMode(num x, num y, num width, num height) → void
Begin scissor mode (define screen area for following drawing)
override
BeginShaderMode(ShaderD shader) → void
Begin custom shader drawing
override
BeginTextureMode(RenderTextureD target) → void
Begin drawing to render texture
override
BeginVrStereoMode(VrStereoConfigD config) → void
Begin stereo rendering (requires VR simulator)
override
ChangeDirectory(String dir) bool
Change working directory, return true on success
override
CheckCollisionBoxes(BoundingBoxD box1, BoundingBoxD box2) bool
Check collision between two bounding boxes
override
CheckCollisionBoxSphere(BoundingBoxD box, Vector3D center, num radius) bool
Check collision between box and sphere
override
CheckCollisionCircleLine(Vector2D center, num radius, Vector2D p1, Vector2D p2) bool
Check if circle collides with a line created betweeen two points p1 and p2
override
CheckCollisionCircleRec(Vector2D center, num radius, RectangleD rec) bool
Check collision between circle and rectangle
override
CheckCollisionCircles(Vector2D center1, num radius1, Vector2D center2, num radius2) bool
Check collision between two circles
override
CheckCollisionLines(Vector2D startPos1, Vector2D endPos1, Vector2D startPos2, Vector2D endPos2) → (bool, Vector2D)
Check the collision between two lines defined by two points each, returns collision point by reference
override
CheckCollisionPointCircle(Vector2D point, Vector2D center, num radius) bool
Check if point is inside circle
override
CheckCollisionPointLine(Vector2D point, Vector2D p1, Vector2D p2, num threshold) bool
Check if point belongs to line created between two points p1 and p2 with defined margin in pixels threshold
override
CheckCollisionPointPoly(Vector2D point, List<Vector2D> points) bool
Check if point is within a polygon described by array of vertices
override
CheckCollisionPointRec(Vector2D point, RectangleD rec) bool
Check if point is inside rectangle
override
CheckCollisionPointTriangle(Vector2D point, Vector2D p1, Vector2D p2, Vector2D p3) bool
Check if point is inside a triangle
override
CheckCollisionRecs(RectangleD rec1, RectangleD rec2) bool
Check collision between two rectangles
override
CheckCollisionSpheres(Vector3D center1, num radius1, Vector3D center2, num radius2) bool
Check collision between two spheres
override
ClearBackground(ColorD color) → void
Set background color (framebuffer clear color)
override
ClearWindowState(Iterable<ConfigFlags> flags) → void
Clear window configuration state flags
override
CloseWindow() → void
Close window and unload OpenGL context
override
CodepointToUTF8(num codepoint) → (String, int)
Encode one codepoint into UTF-8 byte array (array length returned as parameter)
override
ColorAlpha(ColorD color, num alpha) ColorD
Get color with alpha applied, alpha goes from 0.0 to 1.0
override
ColorAlphaBlend(ColorD dst, ColorD src, ColorD tint) ColorD
Get src alpha-blended into dst color with tint
override
ColorBrightness(ColorD color, num factor) ColorD
Get color with brightness correction, brightness factor goes from -1.0 to 1.0
override
ColorContrast(ColorD color, num contrast) ColorD
Get color with contrast correction, contrast values between -1.0 and 1.0
override
ColorFromHSV(num hue, num saturation, num value) ColorD
Get a Color from HSV values, hue 0..360, saturation/value 0..1
override
ColorFromNormalized(Vector4D normalized) ColorD
Get Color from normalized values 0..1
override
ColorIsEqual(ColorD col1, ColorD col2) bool
Check if two colors are equal
override
ColorLerp(ColorD color1, ColorD color2, num factor) ColorD
Get color lerp interpolation between two colors, factor 0.0..1.0
override
ColorNormalize(ColorD color) Vector4D
Get Color normalized as float 0..1
override
ColorTint(ColorD color, ColorD tint) ColorD
Get color multiplied with another color
override
ColorToHSV(ColorD color) Vector3D
Get HSV values for a Color, hue 0..360, saturation/value 0..1
override
ColorToInt(ColorD color) int
Get hexadecimal value for a Color (0xRRGGBBAA)
override
CompressData(Uint8List data) Uint8List
Compress data (DEFLATE algorithm)
override
ComputeCRC32(Uint8List data) int
Compute CRC32 hash code
override
ComputeMD5(Uint8List data) Uint8List
Compute MD5 hash code
override
ComputeSHA1(Uint8List data) Uint8List
Compute SHA1 hash code
override
debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
DecodeDataBase64(Uint8List data) Uint8List
Decode Base64 string data
override
DecompressData(Uint8List compData) Uint8List
Decompress data (DEFLATE algorithm)
override
DirectoryExists(String dirPath) bool
Check if a directory path exists
override
DisableCursor() → void
Disables cursor (lock cursor)
override
DisableEventWaiting() → void
Disable waiting for events on EndDrawing(), automatic events polling
override
disableSync<T>(T f()) → T
Executes f with RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
override
doLoad() → void
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
DrawBillboard(Camera3DD camera, TextureD texture, Vector3D position, num scale, ColorD tint) → void
Draw a billboard texture
override
DrawBillboardPro(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector3D up, Vector2D size, Vector2D origin, num rotation, ColorD tint) → void
Draw a billboard texture defined by source and rotation
override
DrawBillboardRec(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector2D size, ColorD tint) → void
Draw a billboard texture defined by source
override
DrawBoundingBox(BoundingBoxD box, ColorD color) → void
Draw bounding box (wires)
override
DrawCapsule(Vector3D startPos, Vector3D endPos, num radius, num slices, num rings, ColorD color) → void
Draw a capsule with the center of its sphere caps at startPos and endPos
override
DrawCapsuleWires(Vector3D startPos, Vector3D endPos, num radius, num slices, num rings, ColorD color) → void
Draw capsule wireframe with the center of its sphere caps at startPos and endPos
override
DrawCircle(num centerX, num centerY, num radius, ColorD color) → void
Draw a color-filled circle
override
DrawCircle3D(Vector3D center, num radius, Vector3D rotationAxis, num rotationAngle, ColorD color) → void
Draw a circle in 3D world space
override
DrawCircleGradient(num centerX, num centerY, num radius, ColorD inner, ColorD outer) → void
Draw a gradient-filled circle
override
DrawCircleLines(num centerX, num centerY, num radius, ColorD color) → void
Draw circle outline
override
DrawCircleLinesV(Vector2D center, num radius, ColorD color) → void
Draw circle outline (Vector version)
override
DrawCircleSector(Vector2D center, num radius, num startAngle, num endAngle, num segments, ColorD color) → void
Draw a piece of a circle
override
DrawCircleSectorLines(Vector2D center, num radius, num startAngle, num endAngle, num segments, ColorD color) → void
Draw circle sector outline
override
DrawCircleV(Vector2D center, num radius, ColorD color) → void
Draw a color-filled circle (Vector version)
override
DrawCube(Vector3D position, num width, num height, num length, ColorD color) → void
Draw cube
override
DrawCubeV(Vector3D position, Vector3D size, ColorD color) → void
Draw cube (Vector version)
override
DrawCubeWires(Vector3D position, num width, num height, num length, ColorD color) → void
Draw cube wires
override
DrawCubeWiresV(Vector3D position, Vector3D size, ColorD color) → void
Draw cube wires (Vector version)
override
DrawCylinder(Vector3D position, num radiusTop, num radiusBottom, num height, num slices, ColorD color) → void
Draw a cylinder/cone
override
DrawCylinderEx(Vector3D startPos, Vector3D endPos, num startRadius, num endRadius, num sides, ColorD color) → void
Draw a cylinder with base at startPos and top at endPos
override
DrawCylinderWires(Vector3D position, num radiusTop, num radiusBottom, num height, num slices, ColorD color) → void
Draw a cylinder/cone wires
override
DrawCylinderWiresEx(Vector3D startPos, Vector3D endPos, num startRadius, num endRadius, num sides, ColorD color) → void
Draw a cylinder wires with base at startPos and top at endPos
override
DrawEllipse(num centerX, num centerY, num radiusH, num radiusV, ColorD color) → void
Draw ellipse
override
DrawEllipseLines(num centerX, num centerY, num radiusH, num radiusV, ColorD color) → void
Draw ellipse outline
override
DrawFPS(num posX, num posY) → void
Draw current FPS
override
DrawGrid(num slices, num spacing) → void
Draw a grid (centered at (0, 0, 0))
override
DrawLine(num startPosX, num startPosY, num endPosX, num endPosY, ColorD color) → void
Draw a line
override
DrawLine3D(Vector3D startPos, Vector3D endPos, ColorD color) → void
Draw a line in 3D world space
override
DrawLineBezier(Vector2D startPos, Vector2D endPos, num thick, ColorD color) → void
Draw line segment cubic-bezier in-out interpolation
override
DrawLineEx(Vector2D startPos, Vector2D endPos, num thick, ColorD color) → void
Draw a line (using triangles/quads)
override
DrawLineStrip(List<Vector2D> points, ColorD color) → void
Draw lines sequence (using gl lines)
override
DrawLineV(Vector2D startPos, Vector2D endPos, ColorD color) → void
Draw a line (using gl lines)
override
DrawMesh(MeshD mesh, MaterialD material, MatrixD transform) → void
Draw a 3d mesh with material and transform
override
DrawMeshInstanced(MeshD mesh, MaterialD material, List<MatrixD> transforms) → void
Draw multiple mesh instances with material and different transforms
override
DrawModel(ModelD model, Vector3D position, num scale, ColorD tint) → void
Draw a model (with texture if set)
override
DrawModelEx(ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint) → void
Draw a model with extended parameters
override
DrawModelPoints(ModelD model, Vector3D position, num scale, ColorD tint) → void
Draw a model as points
override
DrawModelPointsEx(ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint) → void
Draw a model as points with extended parameters
override
DrawModelWires(ModelD model, Vector3D position, num scale, ColorD tint) → void
Draw a model wires (with texture if set)
override
DrawModelWiresEx(ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint) → void
Draw a model wires (with texture if set) with extended parameters
override
DrawPixel(num posX, num posY, ColorD color) → void
Draw a pixel using geometry Can be slow, use with care
override
DrawPixelV(Vector2D position, ColorD color) → void
Draw a pixel using geometry (Vector version) Can be slow, use with care
override
DrawPlane(Vector3D centerPos, Vector2D size, ColorD color) → void
Draw a plane XZ
override
DrawPoint3D(Vector3D position, ColorD color) → void
Draw a point in 3D space, actually a small line
override
DrawPoly(Vector2D center, num sides, num radius, num rotation, ColorD color) → void
Draw a regular polygon (Vector version)
override
DrawPolyLines(Vector2D center, num sides, num radius, num rotation, ColorD color) → void
Draw a polygon outline of n sides
override
DrawPolyLinesEx(Vector2D center, num sides, num radius, num rotation, num lineThick, ColorD color) → void
Draw a polygon outline of n sides with extended parameters
override
DrawRay(RayD ray, ColorD color) → void
Draw a ray line
override
DrawRectangle(num posX, num posY, num width, num height, ColorD color) → void
Draw a color-filled rectangle
override
DrawRectangleGradientEx(RectangleD rec, ColorD topLeft, ColorD bottomLeft, ColorD topRight, ColorD bottomRight) → void
Draw a gradient-filled rectangle with custom vertex colors
override
DrawRectangleGradientH(num posX, num posY, num width, num height, ColorD left, ColorD right) → void
Draw a horizontal-gradient-filled rectangle
override
DrawRectangleGradientV(num posX, num posY, num width, num height, ColorD top, ColorD bottom) → void
Draw a vertical-gradient-filled rectangle
override
DrawRectangleLines(num posX, num posY, num width, num height, ColorD color) → void
Draw rectangle outline
override
DrawRectangleLinesEx(RectangleD rec, num lineThick, ColorD color) → void
Draw rectangle outline with extended parameters
override
DrawRectanglePro(RectangleD rec, Vector2D origin, num rotation, ColorD color) → void
Draw a color-filled rectangle with pro parameters
override
DrawRectangleRec(RectangleD rec, ColorD color) → void
Draw a color-filled rectangle
override
DrawRectangleRounded(RectangleD rec, num roundness, num segments, ColorD color) → void
Draw rectangle with rounded edges
override
DrawRectangleRoundedLines(RectangleD rec, num roundness, num segments, ColorD color) → void
Draw rectangle lines with rounded edges
override
DrawRectangleRoundedLinesEx(RectangleD rec, num roundness, num segments, num lineThick, ColorD color) → void
Draw rectangle with rounded edges outline
override
DrawRectangleV(Vector2D position, Vector2D size, ColorD color) → void
Draw a color-filled rectangle (Vector version)
override
DrawRing(Vector2D center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorD color) → void
Draw ring
override
DrawRingLines(Vector2D center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorD color) → void
Draw ring outline
override
DrawSphere(Vector3D centerPos, num radius, ColorD color) → void
Draw sphere
override
DrawSphereEx(Vector3D centerPos, num radius, num rings, num slices, ColorD color) → void
Draw sphere with extended parameters
override
DrawSphereWires(Vector3D centerPos, num radius, num rings, num slices, ColorD color) → void
Draw sphere wires
override
DrawSplineBasis(List<Vector2D> points, num thick, ColorD color) → void
Draw spline: B-Spline, minimum 4 points
override
DrawSplineBezierCubic(List<Vector2D> points, num thick, ColorD color) → void
Draw spline: Cubic Bezier, minimum 4 points (2 control points): p1, c2, c3, p4, c5, c6...
override
DrawSplineBezierQuadratic(List<Vector2D> points, num thick, ColorD color) → void
Draw spline: Quadratic Bezier, minimum 3 points (1 control point): p1, c2, p3, c4...
override
DrawSplineCatmullRom(List<Vector2D> points, num thick, ColorD color) → void
Draw spline: Catmull-Rom, minimum 4 points
override
DrawSplineLinear(List<Vector2D> points, num thick, ColorD color) → void
Draw spline: Linear, minimum 2 points
override
DrawSplineSegmentBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num thick, ColorD color) → void
Draw spline segment: B-Spline, 4 points
override
DrawSplineSegmentBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, num thick, ColorD color) → void
Draw spline segment: Cubic Bezier, 2 points, 2 control points
override
DrawSplineSegmentBezierQuadratic(Vector2D p1, Vector2D c2, Vector2D p3, num thick, ColorD color) → void
Draw spline segment: Quadratic Bezier, 2 points, 1 control point
override
DrawSplineSegmentCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num thick, ColorD color) → void
Draw spline segment: Catmull-Rom, 4 points
override
DrawSplineSegmentLinear(Vector2D p1, Vector2D p2, num thick, ColorD color) → void
Draw spline segment: Linear, 2 points
override
DrawText(String text, num posX, num posY, num fontSize, ColorD color) → void
Draw text (using default font)
override
DrawTextCodepoint(FontD font, num codepoint, Vector2D position, num fontSize, ColorD tint) → void
Draw one character (codepoint)
override
DrawTextCodepoints(FontD font, Int32List codepoints, Vector2D position, num fontSize, num spacing, ColorD tint) → void
Draw multiple character (codepoint)
override
DrawTextEx(FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint) → void
Draw text using font and additional parameters
override
DrawTextPro(FontD font, String text, Vector2D position, Vector2D origin, num rotation, num fontSize, num spacing, ColorD tint) → void
Draw text using Font and pro parameters (rotation)
override
DrawTexture(TextureD texture, num posX, num posY, ColorD tint) → void
Draw a Texture2D
override
DrawTextureEx(TextureD texture, Vector2D position, num rotation, num scale, ColorD tint) → void
Draw a Texture2D with extended parameters
override
DrawTextureNPatch(TextureD texture, NPatchInfoD nPatchInfo, RectangleD dest, Vector2D origin, num rotation, ColorD tint) → void
Draws a texture (or part of it) that stretches or shrinks nicely
override
DrawTexturePro(TextureD texture, RectangleD source, RectangleD dest, Vector2D origin, num rotation, ColorD tint) → void
Draw a part of a texture defined by a rectangle with 'pro' parameters
override
DrawTextureRec(TextureD texture, RectangleD source, Vector2D position, ColorD tint) → void
Draw a part of a texture defined by a rectangle
override
DrawTextureV(TextureD texture, Vector2D position, ColorD tint) → void
Draw a Texture2D with position defined as Vector2
override
DrawTriangle(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
Draw a color-filled triangle (vertex in counter-clockwise order!)
override
DrawTriangle3D(Vector3D v1, Vector3D v2, Vector3D v3, ColorD color) → void
Draw a color-filled triangle (vertex in counter-clockwise order!)
override
DrawTriangleFan(List<Vector2D> points, ColorD color) → void
Draw a triangle fan defined by points (first vertex is the center)
override
DrawTriangleLines(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
Draw triangle outline (vertex in counter-clockwise order!)
override
DrawTriangleStrip(List<Vector2D> points, ColorD color) → void
Draw a triangle strip defined by points
override
DrawTriangleStrip3D(List<Vector3D> points, ColorD color) → void
Draw a triangle strip defined by points
override
EnableCursor() → void
Enables cursor (unlock cursor)
override
EnableEventWaiting() → void
Enable waiting for events on EndDrawing(), no automatic event polling
override
EncodeDataBase64(Uint8List data) Uint8List
Encode data to Base64 string
override
EndBlendMode() → void
End blending mode (reset to default: alpha blending)
override
EndDrawing() → void
End canvas drawing and swap buffers (double buffering)
override
EndMode2D() → void
Ends 2D mode with custom camera
override
EndMode3D() → void
Ends 3D mode and returns to default 2D orthographic mode
override
EndScissorMode() → void
End scissor mode
override
EndShaderMode() → void
End custom shader drawing (use default shader)
override
EndTextureMode() → void
Ends drawing to render texture
override
EndVrStereoMode() → void
End stereo rendering (requires VR simulator)
override
ExportAutomationEventList(AutomationEventListD list, String fileName) bool
Export automation events list as text file
override
ExportDataAsCode(Uint8List data, String fileName) bool
Export data to code (.h), returns true on success
override
ExportFontAsCode(FontD font, String fileName) bool
Export font as code file, returns true on success
override
ExportImage(ImageD image, String fileName) bool
Export image data to file, returns true on success
override
ExportImageAsCode(ImageD image, String fileName) bool
Export image as code file defining an array of bytes, returns true on success
override
ExportImageToMemory(ImageD image, String fileType) → (int, int)
Export image to memory buffer
override
ExportMesh(MeshD mesh, String fileName) bool
Export mesh data to file, returns true on success
override
ExportMeshAsCode(MeshD mesh, String fileName) bool
Export mesh as code file (.h) defining multiple arrays of vertex attributes
override
Fade(ColorD color, num alpha) ColorD
Get color with alpha applied, alpha goes from 0.0 to 1.0
override
FileExists(String fileName) bool
Check if file exists
override
GenImageCellular(num width, num height, num tileSize) ImageD
Generate image: cellular algorithm, bigger tileSize means bigger cells
override
GenImageChecked(num width, num height, num checksX, num checksY, ColorD col1, ColorD col2) ImageD
Generate image: checked
override
GenImageColor(num width, num height, ColorD color) ImageD
Generate image: plain color
override
GenImageFontAtlas(List<GlyphInfoD> glyphs, num fontSize, num padding, num packMethod) → (ImageD, List<RectangleD>)
Generate image font atlas using chars info
override
GenImageGradientLinear(num width, num height, num direction, ColorD start, ColorD end) ImageD
Generate image: linear gradient, direction in degrees 0..360, 0=Vertical gradient
override
GenImageGradientRadial(num width, num height, num density, ColorD inner, ColorD outer) ImageD
Generate image: radial gradient
override
GenImageGradientSquare(num width, num height, num density, ColorD inner, ColorD outer) ImageD
Generate image: square gradient
override
GenImagePerlinNoise(num width, num height, num offsetX, num offsetY, num scale) ImageD
Generate image: perlin noise
override
GenImageText(num width, num height, String text) ImageD
Generate image: grayscale image from text data
override
GenImageWhiteNoise(num width, num height, num factor) ImageD
Generate image: white noise
override
GenMeshCone(num radius, num height, num slices) MeshD
Generate cone/pyramid mesh
override
GenMeshCube(num width, num height, num length) MeshD
Generate cuboid mesh
override
GenMeshCubicmap(ImageD cubicmap, Vector3D cubeSize) MeshD
Generate cubes-based map mesh from image data
override
GenMeshCylinder(num radius, num height, num slices) MeshD
Generate cylinder mesh
override
GenMeshHeightmap(ImageD heightmap, Vector3D size) MeshD
Generate heightmap mesh from image data
override
GenMeshHemiSphere(num radius, num rings, num slices) MeshD
Generate half-sphere mesh (no bottom cap)
override
GenMeshKnot(num radius, num size, num radSeg, num sides) MeshD
Generate trefoil knot mesh
override
GenMeshPlane(num width, num length, num resX, num resZ) MeshD
Generate plane mesh (with subdivisions)
override
GenMeshPoly(num sides, num radius) MeshD
Generate polygonal mesh
override
GenMeshSphere(num radius, num rings, num slices) MeshD
Generate sphere mesh (standard sphere)
override
GenMeshTangents(MeshD mesh) → void
Compute mesh tangents
override
GenMeshTorus(num radius, num size, num radSeg, num sides) MeshD
Generate torus mesh
override
GenTextureMipmaps(TextureD texture) → void
Generate GPU mipmaps for a texture
override
GetApplicationDirectory() String
Get the directory of the running application
override
GetCameraMatrix(Camera3DD camera) MatrixD
Get camera transform matrix (view matrix)
override
GetCameraMatrix2D(Camera2DD camera) MatrixD
Get camera 2d transform matrix
override
GetCharPressed() int
Get char pressed (unicode), call it multiple times for chars queued, returns 0 when the queue is empty
override
GetClipboardImage() ImageD
Get clipboard image content
override
GetClipboardText() String
Get clipboard text content
override
GetCodepoint(String text) → (int, int)
Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
override
GetCodepointCount(String text) int
Get total number of codepoints in a UTF-8 encoded string
override
GetCodepointNext(String text) → (int, int)
Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
override
GetCodepointPrevious(String text) → (int, int)
Get previous codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
override
GetCollisionRec(RectangleD rec1, RectangleD rec2) RectangleD
Get collision rectangle for two rectangles collision
override
GetColor(num hexValue) ColorD
Get Color structure from hexadecimal value
override
GetCurrentMonitor() int
Get current monitor where window is placed
override
GetDirectoryPath(String filePath) String
Get full path for a given fileName with path
override
GetFileExtension(String fileName) String
Get extension for a filename (includes dot: '.png')
override
GetFileLength(String fileName) int
Get file length in bytes
override
GetFileModTime(String fileName) int
Get file modification time (last write time)
override
GetFileName(String filePath) String
Get filename for a path string
override
GetFileNameWithoutExt(String filePath) String
Get filename without extension
override
GetFontDefault() FontD
Get the default Font
override
GetFPS() int
Get current FPS
override
GetFrameTime() double
Get time in seconds for last frame drawn (delta time)
override
GetGamepadAxisCount(num gamepad) int
Get gamepad axis count for a gamepad
override
GetGamepadAxisMovement(num gamepad, GamepadAxis axis) double
Get axis movement value for a gamepad axis
override
GetGamepadButtonPressed() GamepadButton
Get the last gamepad button pressed
override
GetGamepadName(num gamepad) String
Get gamepad internal name id
override
GetGestureDetected() Gesture
Get latest detected gesture
override
GetGestureDragAngle() double
Get gesture drag angle
override
GetGestureDragVector() Vector2D
Get gesture drag vector
override
GetGestureHoldDuration() double
Get gesture hold time in seconds
override
GetGesturePinchAngle() double
Get gesture pinch angle
override
GetGesturePinchVector() Vector2D
Get gesture pinch delta
override
GetGlyphAtlasRec(FontD font, num codepoint) RectangleD
Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
override
GetGlyphIndex(FontD font, num codepoint) int
Get glyph index position in font for a codepoint (unicode character), fallback to '?' if not found
override
GetGlyphInfo(FontD font, num codepoint) GlyphInfoD
Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
override
GetImageAlphaBorder(ImageD image, num threshold) RectangleD
Get image alpha border rectangle
override
GetImageColor(ImageD image, num x, num y) ColorD
Get image pixel color at (x, y) position
override
GetKeyPressed() int
Get key pressed (keycode), call it multiple times for keys queued, returns 0 when the queue is empty
override
GetMeshBoundingBox(MeshD mesh) BoundingBoxD
Compute mesh bounding box limits
override
GetModelBoundingBox(ModelD model) BoundingBoxD
Compute model bounding box limits (considers all meshes)
override
GetMonitorCount() int
Get number of connected monitors
override
GetMonitorHeight(num monitor) int
Get specified monitor height (current video mode used by monitor)
override
GetMonitorName(num monitor) String
Get the human-readable, UTF-8 encoded name of the specified monitor
override
GetMonitorPhysicalHeight(num monitor) int
Get specified monitor physical height in millimetres
override
GetMonitorPhysicalWidth(num monitor) int
Get specified monitor physical width in millimetres
override
GetMonitorPosition(num monitor) Vector2D
Get specified monitor position
override
GetMonitorRefreshRate(num monitor) int
Get specified monitor refresh rate
override
GetMonitorWidth(num monitor) int
Get specified monitor width (current video mode used by monitor)
override
GetMouseButtonInfo(MouseButton button) MouseButtonInfo
inherited
GetMouseDelta() Vector2D
Get mouse delta between frames
override
GetMouseInfo() MouseInfo<Vector2D>
inherited
GetMousePosition() Vector2D
Get mouse position XY
override
GetMouseWheelMove() double
Get mouse wheel movement for X or Y, whichever is larger
override
GetMouseWheelMoveV() Vector2D
Get mouse wheel movement for both X and Y
override
GetMouseX() int
Get mouse position X
override
GetMouseY() int
Get mouse position Y
override
GetPixelDataSize(num width, num height, PixelFormat format) int
Get pixel data size in bytes for certain format
override
GetPrevDirectoryPath(String dirPath) String
Get previous directory path for a given path
override
GetRandomValue(num min, num max) int
Get a random value between min and max (both included)
override
GetRayCollisionBox(RayD ray, BoundingBoxD box) RayCollisionD
Get collision info between ray and box
override
GetRayCollisionMesh(RayD ray, MeshD mesh, MatrixD transform) RayCollisionD
Get collision info between ray and mesh
override
GetRayCollisionQuad(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3, Vector3D p4) RayCollisionD
Get collision info between ray and quad
override
GetRayCollisionSphere(RayD ray, Vector3D center, num radius) RayCollisionD
Get collision info between ray and sphere
override
GetRayCollisionTriangle(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3) RayCollisionD
Get collision info between ray and triangle
override
GetRenderHeight() int
Get current render height (it considers HiDPI)
override
GetRenderWidth() int
Get current render width (it considers HiDPI)
override
GetScreenHeight() int
Get current screen height
override
GetScreenToWorld2D(Vector2D position, Camera2DD camera) Vector2D
Get the world space position for a 2d camera screen space position
override
GetScreenToWorldRay(Vector2D position, Camera3DD camera) RayD
Get a ray trace from screen position (i.e mouse)
override
GetScreenToWorldRayEx(Vector2D position, Camera3DD camera, num width, num height) RayD
Get a ray trace from screen position (i.e mouse) in a viewport
override
GetScreenWidth() int
Get current screen width
override
GetShaderLocation(ShaderD shader, String uniformName) int
Get shader uniform location
override
GetShaderLocationAttrib(ShaderD shader, String attribName) int
Get shader attribute location
override
GetShapesTexture() TextureD
Get texture that is used for shapes drawing
override
GetShapesTextureRectangle() RectangleD
Get texture source rectangle that is used for shapes drawing
override
GetSplinePointBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num t) Vector2D
Get (evaluate) spline point: B-Spline
override
GetSplinePointBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, num t) Vector2D
Get (evaluate) spline point: Cubic Bezier
override
GetSplinePointBezierQuad(Vector2D p1, Vector2D c2, Vector2D p3, num t) Vector2D
Get (evaluate) spline point: Quadratic Bezier
override
GetSplinePointCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num t) Vector2D
Get (evaluate) spline point: Catmull-Rom
override
GetSplinePointLinear(Vector2D startPos, Vector2D endPos, num t) Vector2D
Get (evaluate) spline point: Linear
override
GetTime() double
Get elapsed time in seconds since InitWindow()
override
GetTouchPointCount() int
Get number of touch points
override
GetTouchPointId(num index) int
Get touch point identifier for given index
override
GetTouchPosition(num index) Vector2D
Get touch position XY for a touch point index (relative to screen size)
override
GetTouchX() int
Get touch position X for touch point 0 (relative to screen size)
override
GetTouchY() int
Get touch position Y for touch point 0 (relative to screen size)
override
GetWindowPosition() Vector2D
Get window position XY on monitor
override
GetWindowScaleDPI() Vector2D
Get window scale DPI factor
override
GetWorkingDirectory() String
Get current working directory
override
GetWorldToScreen(Vector3D position, Camera3DD camera) Vector2D
Get the screen space position for a 3d world space position
override
GetWorldToScreen2D(Vector2D position, Camera2DD camera) Vector2D
Get the screen space position for a 2d camera world space position
override
GetWorldToScreenEx(Vector3D position, Camera3DD camera, num width, num height) Vector2D
Get size position for a 3d world space position
override
HideCursor() → void
Hides cursor
override
ImageAlphaClear(ImageD image, ColorD color, num threshold) → void
Clear alpha channel to desired color
override
ImageAlphaCrop(ImageD image, num threshold) → void
Crop image depending on alpha value
override
ImageAlphaMask(ImageD image, ImageD alphaMask) → void
Apply alpha mask to image
override
ImageAlphaPremultiply(ImageD image) → void
Premultiply alpha channel
override
ImageBlurGaussian(ImageD image, num blurSize) → void
Apply Gaussian blur using a box blur approximation
override
ImageClearBackground(ImageD dst, ColorD color) → void
Clear image background with given color
override
ImageColorBrightness(ImageD image, num brightness) → void
Modify image color: brightness (-255 to 255)
override
ImageColorContrast(ImageD image, num contrast) → void
Modify image color: contrast (-100 to 100)
override
ImageColorGrayscale(ImageD image) → void
Modify image color: grayscale
override
ImageColorInvert(ImageD image) → void
Modify image color: invert
override
ImageColorReplace(ImageD image, ColorD color, ColorD replace) → void
Modify image color: replace color
override
ImageColorTint(ImageD image, ColorD color) → void
Modify image color: tint
override
ImageCopy(ImageD image) ImageD
Create an image duplicate (useful for transformations)
override
ImageCrop(ImageD image, RectangleD crop) → void
Crop an image to a defined rectangle
override
ImageDither(ImageD image, num rBpp, num gBpp, num bBpp, num aBpp) → void
Dither image data to 16bpp or lower (Floyd-Steinberg dithering)
override
ImageDraw(ImageD dst, ImageD src, RectangleD srcRec, RectangleD dstRec, ColorD tint) → void
Draw a source image within a destination image (tint applied to source)
override
ImageDrawCircle(ImageD dst, num centerX, num centerY, num radius, ColorD color) → void
Draw a filled circle within an image
override
ImageDrawCircleLines(ImageD dst, num centerX, num centerY, num radius, ColorD color) → void
Draw circle outline within an image
override
ImageDrawCircleLinesV(ImageD dst, Vector2D center, num radius, ColorD color) → void
Draw circle outline within an image (Vector version)
override
ImageDrawCircleV(ImageD dst, Vector2D center, num radius, ColorD color) → void
Draw a filled circle within an image (Vector version)
override
ImageDrawLine(ImageD dst, num startPosX, num startPosY, num endPosX, num endPosY, ColorD color) → void
Draw line within an image
override
ImageDrawLineEx(ImageD dst, Vector2D start, Vector2D end, num thick, ColorD color) → void
Draw a line defining thickness within an image
override
ImageDrawLineV(ImageD dst, Vector2D start, Vector2D end, ColorD color) → void
Draw line within an image (Vector version)
override
ImageDrawPixel(ImageD dst, num posX, num posY, ColorD color) → void
Draw pixel within an image
override
ImageDrawPixelV(ImageD dst, Vector2D position, ColorD color) → void
Draw pixel within an image (Vector version)
override
ImageDrawRectangle(ImageD dst, num posX, num posY, num width, num height, ColorD color) → void
Draw rectangle within an image
override
ImageDrawRectangleLines(ImageD dst, RectangleD rec, num thick, ColorD color) → void
Draw rectangle lines within an image
override
ImageDrawRectangleRec(ImageD dst, RectangleD rec, ColorD color) → void
Draw rectangle within an image
override
ImageDrawRectangleV(ImageD dst, Vector2D position, Vector2D size, ColorD color) → void
Draw rectangle within an image (Vector version)
override
ImageDrawText(ImageD dst, String text, num posX, num posY, num fontSize, ColorD color) → void
Draw text (using default font) within an image (destination)
override
ImageDrawTextEx(ImageD dst, FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint) → void
Draw text (custom sprite font) within an image (destination)
override
ImageDrawTriangle(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
Draw triangle within an image
override
ImageDrawTriangleEx(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD c1, ColorD c2, ColorD c3) → void
Draw triangle with interpolated colors within an image
override
ImageDrawTriangleFan(ImageD dst, List<Vector2D> points, ColorD color) → void
Draw a triangle fan defined by points within an image (first vertex is the center)
override
ImageDrawTriangleLines(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
Draw triangle outline within an image
override
ImageDrawTriangleStrip(ImageD dst, List<Vector2D> points, ColorD color) → void
Draw a triangle strip defined by points within an image
override
ImageFlipHorizontal(ImageD image) → void
Flip image horizontally
override
ImageFlipVertical(ImageD image) → void
Flip image vertically
override
ImageFormat(ImageD image, PixelFormat newFormat) → void
Convert image data to desired format
override
ImageFromChannel(ImageD image, num selectedChannel) ImageD
Create an image from a selected channel of another image (GRAYSCALE)
override
ImageFromImage(ImageD image, RectangleD rec) ImageD
Create an image from another image piece
override
ImageKernelConvolution(ImageD image, List<double> kernel) → void
Apply custom square convolution kernel to image
override
ImageMipmaps(ImageD image) → void
Compute all mipmap levels for a provided image
override
ImageResize(ImageD image, num newWidth, num newHeight) → void
Resize image (Bicubic scaling algorithm)
override
ImageResizeCanvas(ImageD image, num newWidth, num newHeight, num offsetX, num offsetY, ColorD fill) → void
Resize canvas and fill with color
override
ImageResizeNN(ImageD image, num newWidth, num newHeight) → void
Resize image (Nearest-Neighbor scaling algorithm)
override
ImageRotate(ImageD image, num degrees) → void
Rotate image by input angle in degrees (-359 to 359)
override
ImageRotateCCW(ImageD image) → void
Rotate image counter-clockwise 90deg
override
ImageRotateCW(ImageD image) → void
Rotate image clockwise 90deg
override
ImageText(String text, num fontSize, ColorD color) ImageD
Create an image from text (default font)
override
ImageTextEx(FontD font, String text, num fontSize, num spacing, ColorD tint) ImageD
Create an image from text (custom sprite font)
override
ImageToPOT(ImageD image, ColorD fill) → void
Convert image to POT (power-of-two)
override
InitWindow(num width, num height, String title) → void
Initialize window and OpenGL context
override
IsCursorHidden() bool
Check if cursor is not visible
override
IsCursorOnScreen() bool
Check if cursor is on the screen
override
IsFileDropped() bool
Check if a file has been dropped into window
override
IsFileExtension(String fileName, String ext) bool
Check file extension (including point: .png, .wav)
override
IsFileNameValid(String fileName) bool
Check if fileName is valid for the platform/OS
override
IsFontValid(FontD font) bool
Check if a font is valid (font data loaded, WARNING: GPU texture not checked)
override
IsGamepadAvailable(num gamepad) bool
Check if a gamepad is available
override
IsGamepadButtonDown(num gamepad, GamepadButton button) bool
Check if a gamepad button is being pressed
override
IsGamepadButtonPressed(num gamepad, GamepadButton button) bool
Check if a gamepad button has been pressed once
override
IsGamepadButtonReleased(num gamepad, GamepadButton button) bool
Check if a gamepad button has been released once
override
IsGamepadButtonUp(num gamepad, GamepadButton button) bool
Check if a gamepad button is NOT being pressed
override
IsGestureDetected(Gesture key) bool
Check if a gesture have been detected
override
IsImageValid(ImageD image) bool
Check if an image is valid (data and parameters)
override
IsKeyDown(KeyboardKey key) bool
Check if a key is being pressed
override
IsKeyPressed(KeyboardKey key) bool
Check if a key has been pressed once
override
IsKeyPressedRepeat(KeyboardKey key) bool
Check if a key has been pressed again
override
IsKeyReleased(KeyboardKey key) bool
Check if a key has been released once
override
IsKeyUp(KeyboardKey key) bool
Check if a key is NOT being pressed
override
IsMaterialValid(MaterialD material) bool
Check if a material is valid (shader assigned, map textures loaded in GPU)
override
IsModelAnimationValid(ModelD model, ModelAnimationD anim) bool
Check model animation skeleton match
override
IsModelValid(ModelD model) bool
Check if a model is valid (loaded in GPU, VAO/VBOs)
override
IsMouseButtonDown(MouseButton button) bool
Check if a mouse button is being pressed
override
IsMouseButtonPressed(MouseButton button) bool
Check if a mouse button has been pressed once
override
IsMouseButtonReleased(MouseButton button) bool
Check if a mouse button has been released once
override
IsMouseButtonUp(MouseButton button) bool
Check if a mouse button is NOT being pressed
override
IsPathFile(String path) bool
Check if a given path is a file or a directory
override
IsRenderTextureValid(RenderTextureD target) bool
Check if a render texture is valid (loaded in GPU)
override
IsShaderValid(ShaderD shader) bool
Check if a shader is valid (loaded on GPU)
override
IsTextureValid(TextureD texture) bool
Check if a texture is valid (loaded in GPU)
override
IsWindowFocused() bool
Check if window is currently focused
override
IsWindowFullscreen() bool
Check if window is currently fullscreen
override
IsWindowHidden() bool
Check if window is currently hidden
override
IsWindowMaximized() bool
Check if window is currently maximized
override
IsWindowMinimized() bool
Check if window is currently minimized
override
IsWindowReady() bool
Check if window has been initialized successfully
override
IsWindowResized() bool
Check if window has been resized last frame
override
IsWindowState(ConfigFlags flag) bool
Check if one specific window flag is enabled
override
load() → void
Override to perform one-time module initialization. Called by doLoad.
inherited
LoadAutomationEventList(String? fileName) AutomationEventListD
Load automation events list from file, NULL for empty list
override
LoadCodepoints(String text) Int32List
Load all codepoints from a UTF-8 text string, codepoints count returned by parameter
override
LoadDirectoryFiles(String dirPath) FilePathListD
Load directory filepaths
override
LoadDirectoryFilesEx(String basePath, String filter, bool scanSubdirs) FilePathListD
Load directory filepaths with extension filtering and recursive directory scan. Use 'DIR' in the filter string to include directories in the result
override
LoadDroppedFiles() FilePathListD
Load dropped filepaths
override
LoadFileData(String fileName) Uint8List
Load file data as byte array (read)
override
LoadFileText(String fileName) String
Load text data from file (read)
override
LoadFont(String fileName) FontD
Load font from file into GPU memory (VRAM)
override
LoadFontData(Uint8List fileData, num fontSize, Int32List? codepoints, num? codepointCount, FontType type) List<GlyphInfoD>
Load font data for further use
override
LoadFontEx(String fileName, num fontSize, [Int32List? codepoints, num? codePointCount]) FontD
Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height
override
LoadFontFromImage(ImageD image, ColorD key, num firstChar) FontD
Load font from Image (XNA style)
override
LoadFontFromMemory(String fileType, Uint8List fileData, num fontSize, Int32List codepoints) FontD
Load font from memory buffer, fileType refers to extension: i.e. '.ttf'
override
LoadImage(String fileName) ImageD
Load image from file into CPU memory (RAM)
override
LoadImageAnim(String fileName) ImageD
Load image sequence from file (frames appended to image.data)
override
LoadImageAnimFromMemory(String fileType, Uint8List fileData) ImageD
Load image sequence from memory buffer
override
LoadImageColors(ImageD image) List<ColorD>
Load color data from image as a Color array (RGBA - 32bit)
override
LoadImageFromMemory(String fileType, Uint8List fileData) ImageD
Load image from memory buffer, fileType refers to extension: i.e. '.png'
override
LoadImageFromScreen() ImageD
Load image from screen buffer and (screenshot)
override
LoadImageFromTexture(TextureD texture) ImageD
Load image from GPU texture data
override
LoadImagePalette(ImageD image, num maxPaletteSize) List<ColorD>
Load colors palette from image as a Color array (RGBA - 32bit)
override
LoadImageRaw(String fileName, num width, num height, PixelFormat format, num headerSize) ImageD
Load image from RAW file data
override
LoadMaterialDefault() MaterialD
Load default material (Supports: DIFFUSE, SPECULAR, NORMAL maps)
override
LoadMaterials(String fileName) List<MaterialD>
Load materials from model file
override
LoadModel(String fileName) ModelD
Load model from files (meshes and materials)
override
LoadModelAnimations(String fileName) List<ModelAnimationD>
Load model animations from file
override
LoadModelFromMesh(MeshD mesh) ModelD
Load model from generated mesh (default material)
override
LoadRandomSequence(int count, int min, int max, [int? seed]) List<int>
Load random values sequence, no values repeated
inherited
LoadRenderTexture(num width, num height) RenderTextureD
Load texture for rendering (framebuffer)
override
LoadShader(String? vsFileName, String? fsFileName) ShaderD
Load shader from files and bind default locations
override
LoadShaderFromMemory(String? vsCode, String? fsCode) ShaderD
Load shader from code strings and bind default locations
override
LoadTexture(String fileName) TextureD
Load texture from file into GPU memory (VRAM)
override
LoadTextureCubemap(ImageD image, CubemapLayout layout) TextureD
Load cubemap from image, multiple image cubemap layouts supported
override
LoadTextureFromImage(ImageD image) TextureD
Load texture from image data
override
LoadUTF8(Int32List codepoints) String
Load UTF-8 text encoded from codepoints array
override
LoadVrStereoConfig(VrDeviceInfoD device) VrStereoConfigD
Load VR stereo config for VR simulator device parameters
override
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
MakeDirectory(String dirPath) int
Create directories (including full path requested), returns 0 on success
override
MaximizeWindow() → void
Set window state: maximized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
override
MeasureText(String text, num fontSize) int
Measure string width for default font
override
MeasureTextEx(FontD font, String text, num fontSize, num spacing) Vector2D
Measure string size for Font
override
MinimizeWindow() → void
Set window state: minimized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
OpenURL(String url) → void
Open URL with default system browser (if available)
override
PlayAutomationEvent(AutomationEventD event) → void
Play a recorded automation event
override
PollInputEvents() → void
Register all input events
override
RestoreWindow() → void
Set window state: not minimized/maximized
override
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
SaveFileData(String fileName, Uint8List data) bool
Save data to file from byte array (write), returns true on success
override
SaveFileText(String fileName, String text) bool
Save text data to file (write), returns true on success
override
SetAutomationEventBaseFrame(int frame) → void
Set automation event internal base frame to start recording
override
SetAutomationEventList(AutomationEventListD list) → void
Set automation event list to record to
override
SetClipboardText(String text) → void
Set clipboard text content
override
SetConfigFlags(Iterable<ConfigFlags> flags) → void
Setup init configuration flags (view ConfigFlags)
override
SetExitKey(KeyboardKey key) → void
Set a custom key to exit program (default is ESC)
override
SetGamepadMappings(String mappings) int
Set internal gamepad mappings (SDL_GameControllerDB)
override
SetGamepadVibration(num gamepad, num leftMotor, num rightMotor, num duration) → void
Set gamepad vibration for both motors (duration in seconds)
override
SetGesturesEnabled(Iterable<Gesture> flags) → void
Enable a set of gestures using flags Gesture
override
SetLoadFileDataCallback(LoadFileDataCallbackD? callback) → void
Set custom file binary data loader
override
SetLoadFileTextCallback(LoadFileTextCallbackD? callback) → void
Set custom file text data loader
override
SetMaterialTexture(MaterialD material, MaterialMapIndex mapType, TextureD texture) → void
Set texture for a material map type (MATERIAL_MAP_DIFFUSE, MATERIAL_MAP_SPECULAR...)
override
SetModelMeshMaterial(ModelD model, num meshId, num materialId) → void
Set material for a mesh
override
SetMouseCursor(MouseCursor cursor) → void
Set mouse cursor
override
SetMouseOffset(num offsetX, num offsetY) → void
Set mouse offset
override
SetMousePosition(num x, num y) → void
Set mouse position XY
override
SetMouseScale(num scaleX, num scaleY) → void
Set mouse scaling
override
SetRandomSeed(num seed) → void
Set the seed for the random number generator
override
SetSaveFileDataCallback(SaveFileDataCallbackD? callback) → void
Set custom file binary data saver
override
SetSaveFileTextCallback(SaveFileTextCallbackD? callback) → void
Set custom file text data saver
override
SetShaderValue(ShaderD shader, num locIndex, List<num> value, ShaderUniformDataType uniformType) → void
Set shader uniform value
override
SetShaderValueMatrix(ShaderD shader, num locIndex, MatrixD mat) → void
Set shader uniform value (matrix 4x4)
override
SetShaderValueTexture(ShaderD shader, num locIndex, TextureD texture) → void
Set shader uniform value for texture (sampler2d)
override
SetShaderValueV(ShaderD shader, num locIndex, List<num> value, ShaderUniformDataType uniformType, num count) → void
Set shader uniform value vector
override
SetShapesTexture(TextureD texture, RectangleD source) → void
Set texture and rectangle to be used on shapes drawing
override
SetTargetFPS(num fps) → void
Set target FPS (maximum)
override
SetTextLineSpacing(num spacing) → void
Set vertical line spacing when drawing with line-breaks
override
SetTextureFilter(TextureD texture, TextureFilter filter) → void
Set texture scaling filter mode
override
SetTextureWrap(TextureD texture, TextureWrap wrap) → void
Set texture wrapping mode
override
SetTraceLogLevel(TraceLogLevel logLevel) → void
Set the current threshold (minimum) log level
override
SetWindowFocused() → void
Set window focused
override
SetWindowIcon(ImageD image) → void
Set icon for window (single image, RGBA 32bit)
override
SetWindowIcons(List<ImageD> images) → void
Set icon for window (multiple images, RGBA 32bit)
override
SetWindowMaxSize(num width, num height) → void
Set window maximum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE)
override
SetWindowMinSize(num width, num height) → void
Set window minimum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE)
override
SetWindowMonitor(num monitor) → void
Set monitor for the current window
override
SetWindowOpacity(num opacity) → void
Set window opacity 0.0..1.0
override
SetWindowPosition(num x, num y) → void
Set window position on screen
override
SetWindowSize(num width, num height) → void
Set window dimensions
override
SetWindowState(Iterable<ConfigFlags> flags) → void
Set window configuration state using flags
override
SetWindowTitle(String title) → void
Set title for window
override
ShowCursor() → void
Shows cursor
override
StartAutomationEventRecording() → void
Start recording automation events (AutomationEventList must be set)
override
StopAutomationEventRecording() → void
Stop recording automation events
override
SwapScreenBuffer() → void
Swap back buffer with front buffer (screen drawing)
override
TakeScreenshot(String fileName) → void
Takes a screenshot of current screen (filename extension defines format)
override
ToggleBorderlessWindowed() → void
Toggle window state: borderless windowed, resizes window to match monitor resolution
override
ToggleFullscreen() → void
Toggle window state: fullscreen/windowed, resizes monitor to match window resolution
override
toString() String
A string representation of this object.
inherited
TraceLog(TraceLogLevel logLevel, String text) → void
Show trace log messages (LOG_DEBUG, LOG_INFO, LOG_WARNING, LOG_ERROR...)
override
UnloadAutomationEventList(AutomationEventListD list) → void
Unload automation events list from file
override
UnloadDirectoryFiles(FilePathListD files) → void
Unload filepaths
override
UnloadDroppedFiles(FilePathListD files) → void
Unload dropped filepaths
override
UnloadFont(FontD font) → void
Unload font from GPU memory (VRAM)
override
UnloadFontData(List<GlyphInfoD> glyphs) → void
Unload font chars info data (RAM)
override
UnloadImage(ImageD image) → void
Unload image from CPU memory (RAM)
override
UnloadMaterial(MaterialD material) → void
Unload material from GPU memory (VRAM)
override
UnloadMesh(MeshD mesh) → void
Unload mesh data from CPU and GPU
override
UnloadModel(ModelD model) → void
Unload model (including meshes) from memory (RAM and/or VRAM)
override
UnloadModelAnimation(ModelAnimationD anim) → void
Unload animation data
override
UnloadModelAnimations(List<ModelAnimationD> animations) → void
Unload animation array data
override
UnloadRenderTexture(RenderTextureD target) → void
Unload render texture from GPU memory (VRAM)
override
UnloadShader(ShaderD shader) → void
Unload shader from GPU memory (VRAM)
override
UnloadTexture(TextureD texture) → void
Unload texture from GPU memory (VRAM)
override
UnloadVrStereoConfig(VrStereoConfigD config) → void
Unload VR stereo config
override
UpdateCamera(Camera3DD camera, CameraMode mode) → void
Update camera position for selected mode
override
UpdateCameraPro(Camera3DD camera, Vector3D movement, Vector3D rotation, num zoom) → void
Update camera movement/rotation
override
UpdateMeshBuffer(MeshD mesh, num index, TypedDataList data, num offset) → void
Update mesh vertex data in GPU for a specific buffer index
override
UpdateModelAnimation(ModelD model, ModelAnimationD anim, num frame) → void
Update model animation pose (CPU)
override
UpdateModelAnimationBones(ModelD model, ModelAnimationD anim, num frame) → void
Update model animation mesh bone matrices (GPU skinning)
override
UpdateTexture(TextureD texture, Uint8List pixels) → void
Update GPU texture with new data
override
UpdateTextureRec(TextureD texture, RectangleD rec, Uint8List pixels) → void
Update GPU texture rectangle with new data
override
UploadMesh(MeshD mesh, bool dynamic) → void
Upload mesh vertex data in GPU and provide VAO/VBO ids
override
WaitTime(num seconds) → void
Wait for some time (halt program execution)
override
WindowShouldClose() bool
Check if application should close (KeyboardKey.KEY_ESCAPE pressed or windows close icon clicked)
override

Operators

operator ==(Object other) bool
The equality operator.
inherited