RaylibCoreFlat class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
BeginBlendMode(int mode)
→ void
-
-
BeginDrawing()
→ void
-
-
BeginMode2D(Camera2DD camera)
→ void
-
-
BeginMode3D(Camera3DD camera)
→ void
-
-
BeginScissorMode(int x, int y, int width, int height)
→ void
-
-
BeginShaderMode(ShaderD shader)
→ void
-
-
BeginTextureMode(RenderTextureD target)
→ void
-
-
BeginVrStereoMode(VrStereoConfigD config)
→ void
-
-
ChangeDirectory(MemoryPointer<RChar> dir)
→ bool
-
-
CheckCollisionBoxes(BoundingBoxD box1, BoundingBoxD box2)
→ bool
-
-
CheckCollisionBoxSphere(BoundingBoxD box, Vector3D center, double radius)
→ bool
-
-
CheckCollisionCircleLine(Vector2D center, double radius, Vector2D p1, Vector2D p2)
→ bool
-
-
CheckCollisionCircleRec(Vector2D center, double radius, RectangleD rec)
→ bool
-
-
CheckCollisionCircles(Vector2D center1, double radius1, Vector2D center2, double radius2)
→ bool
-
-
CheckCollisionLines(Vector2D startPos1, Vector2D endPos1, Vector2D startPos2, Vector2D endPos2, StructPointer<Vector2D> collisionPoint)
→ bool
-
-
CheckCollisionPointCircle(Vector2D point, Vector2D center, double radius)
→ bool
-
-
CheckCollisionPointLine(Vector2D point, Vector2D p1, Vector2D p2, int threshold)
→ bool
-
-
CheckCollisionPointPoly(Vector2D point, StructPointer<Vector2D> points, int pointCount)
→ bool
-
-
CheckCollisionPointRec(Vector2D point, RectangleD rec)
→ bool
-
-
CheckCollisionPointTriangle(Vector2D point, Vector2D p1, Vector2D p2, Vector2D p3)
→ bool
-
-
CheckCollisionRecs(RectangleD rec1, RectangleD rec2)
→ bool
-
-
CheckCollisionSpheres(Vector3D center1, double radius1, Vector3D center2, double radius2)
→ bool
-
-
ClearBackground(ColorD color)
→ void
-
-
ClearWindowState(int flags)
→ void
-
-
CloseWindow()
→ void
-
-
CodepointToUTF8(int codepoint, MemoryPointer<RInt> utf8Size)
→ WasmMemoryPointer<RChar>
-
-
ColorAlpha(ColorD color, double alpha)
→ ColorD
-
-
ColorAlphaBlend(ColorD dst, ColorD src, ColorD tint)
→ ColorD
-
-
ColorBrightness(ColorD color, double factor)
→ ColorD
-
-
ColorContrast(ColorD color, double contrast)
→ ColorD
-
-
ColorFromHSV(double hue, double saturation, double value)
→ ColorD
-
-
ColorFromNormalized(Vector4D normalized)
→ ColorD
-
-
ColorIsEqual(ColorD col1, ColorD col2)
→ bool
-
-
ColorLerp(ColorD color1, ColorD color2, double factor)
→ ColorD
-
-
ColorNormalize(ColorD color)
→ Vector4D
-
-
ColorTint(ColorD color, ColorD tint)
→ ColorD
-
-
ColorToHSV(ColorD color)
→ Vector3D
-
-
ColorToInt(ColorD color)
→ int
-
-
CompressData(MemoryPointer<RUnsignedChar> data, int dataSize, MemoryPointer<RInt> compDataSize)
→ WasmMemoryPointer<RUnsignedChar>
-
-
ComputeCRC32(MemoryPointer<RUnsignedChar> data, int dataSize)
→ int
-
-
ComputeMD5(MemoryPointer<RUnsignedChar> data, int dataSize)
→ WasmMemoryPointer<RUnsignedInt>
-
-
ComputeSHA1(MemoryPointer<RUnsignedChar> data, int dataSize)
→ WasmMemoryPointer<RUnsignedInt>
-
-
ComputeSHA256(MemoryPointer<RUnsignedChar> data, int dataSize)
→ WasmMemoryPointer<RUnsignedInt>
-
-
DecodeDataBase64(MemoryPointer<RChar> data, MemoryPointer<RInt> outputSize)
→ WasmMemoryPointer<RUnsignedChar>
-
-
DecompressData(MemoryPointer<RUnsignedChar> compData, int compDataSize, MemoryPointer<RInt> dataSize)
→ WasmMemoryPointer<RUnsignedChar>
-
-
DirectoryExists(MemoryPointer<RChar> dirPath)
→ bool
-
-
DisableCursor()
→ void
-
-
DisableEventWaiting()
→ void
-
-
DrawBillboard(Camera3DD camera, TextureD texture, Vector3D position, double scale, ColorD tint)
→ void
-
-
DrawBillboardPro(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector3D up, Vector2D size, Vector2D origin, double rotation, ColorD tint)
→ void
-
-
DrawBillboardRec(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector2D size, ColorD tint)
→ void
-
-
DrawBoundingBox(BoundingBoxD box, ColorD color)
→ void
-
-
DrawCapsule(Vector3D startPos, Vector3D endPos, double radius, int slices, int rings, ColorD color)
→ void
-
-
DrawCapsuleWires(Vector3D startPos, Vector3D endPos, double radius, int slices, int rings, ColorD color)
→ void
-
-
DrawCircle(int centerX, int centerY, double radius, ColorD color)
→ void
-
-
DrawCircle3D(Vector3D center, double radius, Vector3D rotationAxis, double rotationAngle, ColorD color)
→ void
-
-
DrawCircleGradient(Vector2D center, double radius, ColorD inner, ColorD outer)
→ void
-
-
DrawCircleLines(int centerX, int centerY, double radius, ColorD color)
→ void
-
-
DrawCircleLinesV(Vector2D center, double radius, ColorD color)
→ void
-
-
DrawCircleSector(Vector2D center, double radius, double startAngle, double endAngle, int segments, ColorD color)
→ void
-
-
DrawCircleSectorLines(Vector2D center, double radius, double startAngle, double endAngle, int segments, ColorD color)
→ void
-
-
DrawCircleV(Vector2D center, double radius, ColorD color)
→ void
-
-
DrawCube(Vector3D position, double width, double height, double length, ColorD color)
→ void
-
-
DrawCubeV(Vector3D position, Vector3D size, ColorD color)
→ void
-
-
DrawCubeWires(Vector3D position, double width, double height, double length, ColorD color)
→ void
-
-
DrawCubeWiresV(Vector3D position, Vector3D size, ColorD color)
→ void
-
-
DrawCylinder(Vector3D position, double radiusTop, double radiusBottom, double height, int slices, ColorD color)
→ void
-
-
DrawCylinderEx(Vector3D startPos, Vector3D endPos, double startRadius, double endRadius, int sides, ColorD color)
→ void
-
-
DrawCylinderWires(Vector3D position, double radiusTop, double radiusBottom, double height, int slices, ColorD color)
→ void
-
-
DrawCylinderWiresEx(Vector3D startPos, Vector3D endPos, double startRadius, double endRadius, int sides, ColorD color)
→ void
-
-
DrawEllipse(int centerX, int centerY, double radiusH, double radiusV, ColorD color)
→ void
-
-
DrawEllipseLines(int centerX, int centerY, double radiusH, double radiusV, ColorD color)
→ void
-
-
DrawEllipseLinesV(Vector2D center, double radiusH, double radiusV, ColorD color)
→ void
-
-
DrawEllipseV(Vector2D center, double radiusH, double radiusV, ColorD color)
→ void
-
-
DrawFPS(int posX, int posY)
→ void
-
-
DrawGrid(int slices, double spacing)
→ void
-
-
DrawLine(int startPosX, int startPosY, int endPosX, int endPosY, ColorD color)
→ void
-
-
DrawLine3D(Vector3D startPos, Vector3D endPos, ColorD color)
→ void
-
-
DrawLineBezier(Vector2D startPos, Vector2D endPos, double thick, ColorD color)
→ void
-
-
DrawLineDashed(Vector2D startPos, Vector2D endPos, int dashSize, int spaceSize, ColorD color)
→ void
-
-
DrawLineEx(Vector2D startPos, Vector2D endPos, double thick, ColorD color)
→ void
-
-
DrawLineStrip(StructPointer<Vector2D> points, int pointCount, ColorD color)
→ void
-
-
DrawLineV(Vector2D startPos, Vector2D endPos, ColorD color)
→ void
-
-
DrawMesh(MeshD mesh, MaterialD material, MatrixD transform)
→ void
-
-
DrawMeshInstanced(MeshD mesh, MaterialD material, StructPointer<MatrixD> transforms, int instances)
→ void
-
-
DrawModel(ModelD model, Vector3D position, double scale, ColorD tint)
→ void
-
-
DrawModelEx(ModelD model, Vector3D position, Vector3D rotationAxis, double rotationAngle, Vector3D scale, ColorD tint)
→ void
-
-
DrawModelWires(ModelD model, Vector3D position, double scale, ColorD tint)
→ void
-
-
DrawModelWiresEx(ModelD model, Vector3D position, Vector3D rotationAxis, double rotationAngle, Vector3D scale, ColorD tint)
→ void
-
-
DrawPixel(int posX, int posY, ColorD color)
→ void
-
-
DrawPixelV(Vector2D position, ColorD color)
→ void
-
-
DrawPlane(Vector3D centerPos, Vector2D size, ColorD color)
→ void
-
-
DrawPoint3D(Vector3D position, ColorD color)
→ void
-
-
DrawPoly(Vector2D center, int sides, double radius, double rotation, ColorD color)
→ void
-
-
DrawPolyLines(Vector2D center, int sides, double radius, double rotation, ColorD color)
→ void
-
-
DrawPolyLinesEx(Vector2D center, int sides, double radius, double rotation, double lineThick, ColorD color)
→ void
-
-
DrawRay(RayD ray, ColorD color)
→ void
-
-
DrawRectangle(int posX, int posY, int width, int height, ColorD color)
→ void
-
-
DrawRectangleGradientEx(RectangleD rec, ColorD topLeft, ColorD bottomLeft, ColorD topRight, ColorD bottomRight)
→ void
-
-
DrawRectangleGradientH(int posX, int posY, int width, int height, ColorD left, ColorD right)
→ void
-
-
DrawRectangleGradientV(int posX, int posY, int width, int height, ColorD top, ColorD bottom)
→ void
-
-
DrawRectangleLines(int posX, int posY, int width, int height, ColorD color)
→ void
-
-
DrawRectangleLinesEx(RectangleD rec, double lineThick, ColorD color)
→ void
-
-
DrawRectanglePro(RectangleD rec, Vector2D origin, double rotation, ColorD color)
→ void
-
-
DrawRectangleRec(RectangleD rec, ColorD color)
→ void
-
-
DrawRectangleRounded(RectangleD rec, double roundness, int segments, ColorD color)
→ void
-
-
DrawRectangleRoundedLines(RectangleD rec, double roundness, int segments, ColorD color)
→ void
-
-
DrawRectangleRoundedLinesEx(RectangleD rec, double roundness, int segments, double lineThick, ColorD color)
→ void
-
-
DrawRectangleV(Vector2D position, Vector2D size, ColorD color)
→ void
-
-
DrawRing(Vector2D center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorD color)
→ void
-
-
DrawRingLines(Vector2D center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorD color)
→ void
-
-
DrawSphere(Vector3D centerPos, double radius, ColorD color)
→ void
-
-
DrawSphereEx(Vector3D centerPos, double radius, int rings, int slices, ColorD color)
→ void
-
-
DrawSphereWires(Vector3D centerPos, double radius, int rings, int slices, ColorD color)
→ void
-
-
DrawSplineBasis(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color)
→ void
-
-
DrawSplineBezierCubic(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color)
→ void
-
-
DrawSplineBezierQuadratic(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color)
→ void
-
-
DrawSplineCatmullRom(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color)
→ void
-
-
DrawSplineLinear(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color)
→ void
-
-
DrawSplineSegmentBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, double thick, ColorD color)
→ void
-
-
DrawSplineSegmentBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, double thick, ColorD color)
→ void
-
-
DrawSplineSegmentBezierQuadratic(Vector2D p1, Vector2D c2, Vector2D p3, double thick, ColorD color)
→ void
-
-
DrawSplineSegmentCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, double thick, ColorD color)
→ void
-
-
DrawSplineSegmentLinear(Vector2D p1, Vector2D p2, double thick, ColorD color)
→ void
-
-
DrawText(MemoryPointer<RChar> text, int posX, int posY, int fontSize, ColorD color)
→ void
-
-
DrawTextCodepoint(FontD font, int codepoint, Vector2D position, double fontSize, ColorD tint)
→ void
-
-
DrawTextCodepoints(FontD font, MemoryPointer<RInt> codepoints, int codepointCount, Vector2D position, double fontSize, double spacing, ColorD tint)
→ void
-
-
DrawTextEx(FontD font, MemoryPointer<RChar> text, Vector2D position, double fontSize, double spacing, ColorD tint)
→ void
-
-
DrawTextPro(FontD font, MemoryPointer<RChar> text, Vector2D position, Vector2D origin, double rotation, double fontSize, double spacing, ColorD tint)
→ void
-
-
DrawTexture(TextureD texture, int posX, int posY, ColorD tint)
→ void
-
-
DrawTextureEx(TextureD texture, Vector2D position, double rotation, double scale, ColorD tint)
→ void
-
-
DrawTextureNPatch(TextureD texture, NPatchInfoD nPatchInfo, RectangleD dest, Vector2D origin, double rotation, ColorD tint)
→ void
-
-
DrawTexturePro(TextureD texture, RectangleD source, RectangleD dest, Vector2D origin, double rotation, ColorD tint)
→ void
-
-
DrawTextureRec(TextureD texture, RectangleD source, Vector2D position, ColorD tint)
→ void
-
-
DrawTextureV(TextureD texture, Vector2D position, ColorD tint)
→ void
-
-
DrawTriangle(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
-
DrawTriangle3D(Vector3D v1, Vector3D v2, Vector3D v3, ColorD color)
→ void
-
-
DrawTriangleFan(StructPointer<Vector2D> points, int pointCount, ColorD color)
→ void
-
-
DrawTriangleLines(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
-
DrawTriangleStrip(StructPointer<Vector2D> points, int pointCount, ColorD color)
→ void
-
-
DrawTriangleStrip3D(StructPointer<Vector3D> points, int pointCount, ColorD color)
→ void
-
-
EnableCursor()
→ void
-
-
EnableEventWaiting()
→ void
-
-
EncodeDataBase64(MemoryPointer<RUnsignedChar> data, int dataSize, MemoryPointer<RInt> outputSize)
→ WasmMemoryPointer<RChar>
-
-
EndBlendMode()
→ void
-
-
EndDrawing()
→ void
-
-
EndMode2D()
→ void
-
-
EndMode3D()
→ void
-
-
EndScissorMode()
→ void
-
-
EndShaderMode()
→ void
-
-
EndTextureMode()
→ void
-
-
EndVrStereoMode()
→ void
-
-
ExportAutomationEventList(AutomationEventListD list, MemoryPointer<RChar> fileName)
→ bool
-
-
ExportDataAsCode(MemoryPointer<RUnsignedChar> data, int dataSize, MemoryPointer<RChar> fileName)
→ bool
-
-
ExportFontAsCode(FontD font, MemoryPointer<RChar> fileName)
→ bool
-
-
ExportImage(ImageD image, MemoryPointer<RChar> fileName)
→ bool
-
-
ExportImageAsCode(ImageD image, MemoryPointer<RChar> fileName)
→ bool
-
-
ExportImageToMemory(ImageD image, MemoryPointer<RChar> fileType, MemoryPointer<RInt> fileSize)
→ WasmMemoryPointer<RUnsignedChar>
-
-
ExportMesh(MeshD mesh, MemoryPointer<RChar> fileName)
→ bool
-
-
ExportMeshAsCode(MeshD mesh, MemoryPointer<RChar> fileName)
→ bool
-
-
Fade(ColorD color, double alpha)
→ ColorD
-
-
FileCopy(MemoryPointer<RChar> srcPath, MemoryPointer<RChar> dstPath)
→ int
-
-
FileExists(MemoryPointer<RChar> fileName)
→ bool
-
-
FileMove(MemoryPointer<RChar> srcPath, MemoryPointer<RChar> dstPath)
→ int
-
-
FileRemove(MemoryPointer<RChar> fileName)
→ int
-
-
FileRename(MemoryPointer<RChar> fileName, MemoryPointer<RChar> fileRename)
→ int
-
-
FileTextFindIndex(MemoryPointer<RChar> fileName, MemoryPointer<RChar> search)
→ int
-
-
FileTextReplace(MemoryPointer<RChar> fileName, MemoryPointer<RChar> search, MemoryPointer<RChar> replacement)
→ int
-
-
GenImageCellular(int width, int height, int tileSize)
→ ImageD
-
-
GenImageChecked(int width, int height, int checksX, int checksY, ColorD col1, ColorD col2)
→ ImageD
-
-
GenImageColor(int width, int height, ColorD color)
→ ImageD
-
-
GenImageFontAtlas(StructPointer<GlyphInfoD> glyphs, MemoryPointer<RPointer<RStruct>> glyphRecs, int glyphCount, int fontSize, int padding, int packMethod)
→ ImageD
-
-
GenImageGradientLinear(int width, int height, int direction, ColorD start, ColorD end)
→ ImageD
-
-
GenImageGradientRadial(int width, int height, double density, ColorD inner, ColorD outer)
→ ImageD
-
-
GenImageGradientSquare(int width, int height, double density, ColorD inner, ColorD outer)
→ ImageD
-
-
GenImagePerlinNoise(int width, int height, int offsetX, int offsetY, double scale)
→ ImageD
-
-
GenImageText(int width, int height, MemoryPointer<RChar> text)
→ ImageD
-
-
GenImageWhiteNoise(int width, int height, double factor)
→ ImageD
-
-
GenMeshCone(double radius, double height, int slices)
→ MeshD
-
-
GenMeshCube(double width, double height, double length)
→ MeshD
-
-
GenMeshCubicmap(ImageD cubicmap, Vector3D cubeSize)
→ MeshD
-
-
GenMeshCylinder(double radius, double height, int slices)
→ MeshD
-
-
GenMeshHeightmap(ImageD heightmap, Vector3D size)
→ MeshD
-
-
GenMeshHemiSphere(double radius, int rings, int slices)
→ MeshD
-
-
GenMeshKnot(double radius, double size, int radSeg, int sides)
→ MeshD
-
-
GenMeshPlane(double width, double length, int resX, int resZ)
→ MeshD
-
-
GenMeshPoly(int sides, double radius)
→ MeshD
-
-
GenMeshSphere(double radius, int rings, int slices)
→ MeshD
-
-
GenMeshTangents(StructPointer<MeshD> mesh)
→ void
-
-
GenMeshTorus(double radius, double size, int radSeg, int sides)
→ MeshD
-
-
GenTextureMipmaps(StructPointer<TextureD> texture)
→ void
-
-
GetApplicationDirectory()
→ WasmMemoryPointer<RChar>
-
-
GetCameraMatrix(Camera3DD camera)
→ MatrixD
-
-
GetCameraMatrix2D(Camera2DD camera)
→ MatrixD
-
-
GetCharPressed()
→ int
-
-
GetClipboardImage()
→ ImageD
-
-
GetClipboardText()
→ WasmMemoryPointer<RChar>
-
-
GetCodepoint(MemoryPointer<RChar> text, MemoryPointer<RInt> codepointSize)
→ int
-
-
GetCodepointCount(MemoryPointer<RChar> text)
→ int
-
-
GetCodepointNext(MemoryPointer<RChar> text, MemoryPointer<RInt> codepointSize)
→ int
-
-
GetCodepointPrevious(MemoryPointer<RChar> text, MemoryPointer<RInt> codepointSize)
→ int
-
-
GetCollisionRec(RectangleD rec1, RectangleD rec2)
→ RectangleD
-
-
GetColor(int hexValue)
→ ColorD
-
-
GetCurrentMonitor()
→ int
-
-
GetDirectoryFileCount(MemoryPointer<RChar> dirPath)
→ int
-
-
GetDirectoryFileCountEx(MemoryPointer<RChar> basePath, MemoryPointer<RChar> filter, bool scanSubdirs)
→ int
-
-
GetDirectoryPath(MemoryPointer<RChar> filePath)
→ WasmMemoryPointer<RChar>
-
-
GetFileExtension(MemoryPointer<RChar> fileName)
→ WasmMemoryPointer<RChar>
-
-
GetFileLength(MemoryPointer<RChar> fileName)
→ int
-
-
GetFileModTime(MemoryPointer<RChar> fileName)
→ int
-
-
GetFileName(MemoryPointer<RChar> filePath)
→ WasmMemoryPointer<RChar>
-
-
GetFileNameWithoutExt(MemoryPointer<RChar> filePath)
→ WasmMemoryPointer<RChar>
-
-
GetFontDefault()
→ FontD
-
-
GetFPS()
→ int
-
-
GetFrameTime()
→ double
-
-
GetGamepadAxisCount(int gamepad)
→ int
-
-
GetGamepadAxisMovement(int gamepad, int axis)
→ double
-
-
GetGamepadButtonPressed()
→ int
-
-
GetGamepadName(int gamepad)
→ WasmMemoryPointer<RChar>
-
-
GetGestureDetected()
→ int
-
-
GetGestureDragAngle()
→ double
-
-
GetGestureDragVector()
→ Vector2D
-
-
GetGestureHoldDuration()
→ double
-
-
GetGesturePinchAngle()
→ double
-
-
GetGesturePinchVector()
→ Vector2D
-
-
GetGlyphAtlasRec(FontD font, int codepoint)
→ RectangleD
-
-
GetGlyphIndex(FontD font, int codepoint)
→ int
-
-
GetGlyphInfo(FontD font, int codepoint)
→ GlyphInfoD
-
-
GetImageAlphaBorder(ImageD image, double threshold)
→ RectangleD
-
-
GetImageColor(ImageD image, int x, int y)
→ ColorD
-
-
GetKeyName(int key)
→ WasmMemoryPointer<RChar>
-
-
GetKeyPressed()
→ int
-
-
GetMeshBoundingBox(MeshD mesh)
→ BoundingBoxD
-
-
GetModelBoundingBox(ModelD model)
→ BoundingBoxD
-
-
GetMonitorCount()
→ int
-
-
GetMonitorHeight(int monitor)
→ int
-
-
GetMonitorName(int monitor)
→ WasmMemoryPointer<RChar>
-
-
GetMonitorPhysicalHeight(int monitor)
→ int
-
-
GetMonitorPhysicalWidth(int monitor)
→ int
-
-
GetMonitorPosition(int monitor)
→ Vector2D
-
-
GetMonitorRefreshRate(int monitor)
→ int
-
-
GetMonitorWidth(int monitor)
→ int
-
-
GetMouseDelta()
→ Vector2D
-
-
GetMousePosition()
→ Vector2D
-
-
GetMouseWheelMove()
→ double
-
-
GetMouseWheelMoveV()
→ Vector2D
-
-
GetMouseX()
→ int
-
-
GetMouseY()
→ int
-
-
GetPixelColor(MemoryPointer<RVoid> srcPtr, int format)
→ ColorD
-
-
GetPixelDataSize(int width, int height, int format)
→ int
-
-
GetPrevDirectoryPath(MemoryPointer<RChar> dirPath)
→ WasmMemoryPointer<RChar>
-
-
GetRandomValue(int min, int max)
→ int
-
-
GetRayCollisionBox(RayD ray, BoundingBoxD box)
→ RayCollisionD
-
-
GetRayCollisionMesh(RayD ray, MeshD mesh, MatrixD transform)
→ RayCollisionD
-
-
GetRayCollisionQuad(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3, Vector3D p4)
→ RayCollisionD
-
-
GetRayCollisionSphere(RayD ray, Vector3D center, double radius)
→ RayCollisionD
-
-
GetRayCollisionTriangle(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3)
→ RayCollisionD
-
-
GetRenderHeight()
→ int
-
-
GetRenderWidth()
→ int
-
-
GetScreenHeight()
→ int
-
-
GetScreenToWorld2D(Vector2D position, Camera2DD camera)
→ Vector2D
-
-
GetScreenToWorldRay(Vector2D position, Camera3DD camera)
→ RayD
-
-
GetScreenToWorldRayEx(Vector2D position, Camera3DD camera, int width, int height)
→ RayD
-
-
GetScreenWidth()
→ int
-
-
GetShaderLocation(ShaderD shader, MemoryPointer<RChar> uniformName)
→ int
-
-
GetShaderLocationAttrib(ShaderD shader, MemoryPointer<RChar> attribName)
→ int
-
-
GetShapesTexture()
→ TextureD
-
-
GetShapesTextureRectangle()
→ RectangleD
-
-
GetSplinePointBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, double t)
→ Vector2D
-
-
GetSplinePointBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, double t)
→ Vector2D
-
-
GetSplinePointBezierQuad(Vector2D p1, Vector2D c2, Vector2D p3, double t)
→ Vector2D
-
-
GetSplinePointCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, double t)
→ Vector2D
-
-
GetSplinePointLinear(Vector2D startPos, Vector2D endPos, double t)
→ Vector2D
-
-
GetTextBetween(MemoryPointer<RChar> text, MemoryPointer<RChar> begin, MemoryPointer<RChar> end)
→ WasmMemoryPointer<RChar>
-
-
GetTime()
→ double
-
-
GetTouchPointCount()
→ int
-
-
GetTouchPointId(int index)
→ int
-
-
GetTouchPosition(int index)
→ Vector2D
-
-
GetTouchX()
→ int
-
-
GetTouchY()
→ int
-
-
GetWindowHandle()
→ WasmMemoryPointer<RVoid>
-
-
GetWindowPosition()
→ Vector2D
-
-
GetWindowScaleDPI()
→ Vector2D
-
-
GetWorkingDirectory()
→ WasmMemoryPointer<RChar>
-
-
GetWorldToScreen(Vector3D position, Camera3DD camera)
→ Vector2D
-
-
GetWorldToScreen2D(Vector2D position, Camera2DD camera)
→ Vector2D
-
-
GetWorldToScreenEx(Vector3D position, Camera3DD camera, int width, int height)
→ Vector2D
-
-
HideCursor()
→ void
-
-
ImageAlphaClear(StructPointer<ImageD> image, ColorD color, double threshold)
→ void
-
-
ImageAlphaCrop(StructPointer<ImageD> image, double threshold)
→ void
-
-
ImageAlphaMask(StructPointer<ImageD> image, ImageD alphaMask)
→ void
-
-
ImageAlphaPremultiply(StructPointer<ImageD> image)
→ void
-
-
ImageBlurGaussian(StructPointer<ImageD> image, int blurSize)
→ void
-
-
ImageClearBackground(StructPointer<ImageD> dst, ColorD color)
→ void
-
-
ImageColorBrightness(StructPointer<ImageD> image, int brightness)
→ void
-
-
ImageColorContrast(StructPointer<ImageD> image, double contrast)
→ void
-
-
ImageColorGrayscale(StructPointer<ImageD> image)
→ void
-
-
ImageColorInvert(StructPointer<ImageD> image)
→ void
-
-
ImageColorReplace(StructPointer<ImageD> image, ColorD color, ColorD replace)
→ void
-
-
ImageColorTint(StructPointer<ImageD> image, ColorD color)
→ void
-
-
ImageCopy(ImageD image)
→ ImageD
-
-
ImageCrop(StructPointer<ImageD> image, RectangleD crop)
→ void
-
-
ImageDither(StructPointer<ImageD> image, int rBpp, int gBpp, int bBpp, int aBpp)
→ void
-
-
ImageDraw(StructPointer<ImageD> dst, ImageD src, RectangleD srcRec, RectangleD dstRec, ColorD tint)
→ void
-
-
ImageDrawCircle(StructPointer<ImageD> dst, int centerX, int centerY, int radius, ColorD color)
→ void
-
-
ImageDrawCircleLines(StructPointer<ImageD> dst, int centerX, int centerY, int radius, ColorD color)
→ void
-
-
ImageDrawCircleLinesV(StructPointer<ImageD> dst, Vector2D center, int radius, ColorD color)
→ void
-
-
ImageDrawCircleV(StructPointer<ImageD> dst, Vector2D center, int radius, ColorD color)
→ void
-
-
ImageDrawLine(StructPointer<ImageD> dst, int startPosX, int startPosY, int endPosX, int endPosY, ColorD color)
→ void
-
-
ImageDrawLineEx(StructPointer<ImageD> dst, Vector2D start, Vector2D end, int thick, ColorD color)
→ void
-
-
ImageDrawLineV(StructPointer<ImageD> dst, Vector2D start, Vector2D end, ColorD color)
→ void
-
-
ImageDrawPixel(StructPointer<ImageD> dst, int posX, int posY, ColorD color)
→ void
-
-
ImageDrawPixelV(StructPointer<ImageD> dst, Vector2D position, ColorD color)
→ void
-
-
ImageDrawRectangle(StructPointer<ImageD> dst, int posX, int posY, int width, int height, ColorD color)
→ void
-
-
ImageDrawRectangleLines(StructPointer<ImageD> dst, RectangleD rec, int thick, ColorD color)
→ void
-
-
ImageDrawRectangleRec(StructPointer<ImageD> dst, RectangleD rec, ColorD color)
→ void
-
-
ImageDrawRectangleV(StructPointer<ImageD> dst, Vector2D position, Vector2D size, ColorD color)
→ void
-
-
ImageDrawText(StructPointer<ImageD> dst, MemoryPointer<RChar> text, int posX, int posY, int fontSize, ColorD color)
→ void
-
-
ImageDrawTextEx(StructPointer<ImageD> dst, FontD font, MemoryPointer<RChar> text, Vector2D position, double fontSize, double spacing, ColorD tint)
→ void
-
-
ImageDrawTriangle(StructPointer<ImageD> dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
-
ImageDrawTriangleEx(StructPointer<ImageD> dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD c1, ColorD c2, ColorD c3)
→ void
-
-
ImageDrawTriangleFan(StructPointer<ImageD> dst, StructPointer<Vector2D> points, int pointCount, ColorD color)
→ void
-
-
ImageDrawTriangleLines(StructPointer<ImageD> dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
-
ImageDrawTriangleStrip(StructPointer<ImageD> dst, StructPointer<Vector2D> points, int pointCount, ColorD color)
→ void
-
-
ImageFlipHorizontal(StructPointer<ImageD> image)
→ void
-
-
ImageFlipVertical(StructPointer<ImageD> image)
→ void
-
-
ImageFormat(StructPointer<ImageD> image, int newFormat)
→ void
-
-
ImageFromChannel(ImageD image, int selectedChannel)
→ ImageD
-
-
ImageFromImage(ImageD image, RectangleD rec)
→ ImageD
-
-
ImageKernelConvolution(StructPointer<ImageD> image, MemoryPointer<RFloat> kernel, int kernelSize)
→ void
-
-
ImageMipmaps(StructPointer<ImageD> image)
→ void
-
-
ImageResize(StructPointer<ImageD> image, int newWidth, int newHeight)
→ void
-
-
ImageResizeCanvas(StructPointer<ImageD> image, int newWidth, int newHeight, int offsetX, int offsetY, ColorD fill)
→ void
-
-
ImageResizeNN(StructPointer<ImageD> image, int newWidth, int newHeight)
→ void
-
-
ImageRotate(StructPointer<ImageD> image, int degrees)
→ void
-
-
ImageRotateCCW(StructPointer<ImageD> image)
→ void
-
-
ImageRotateCW(StructPointer<ImageD> image)
→ void
-
-
ImageText(MemoryPointer<RChar> text, int fontSize, ColorD color)
→ ImageD
-
-
ImageTextEx(FontD font, MemoryPointer<RChar> text, double fontSize, double spacing, ColorD tint)
→ ImageD
-
-
ImageToPOT(StructPointer<ImageD> image, ColorD fill)
→ void
-
-
InitWindow(int width, int height, MemoryPointer<RChar> title)
→ void
-
-
IsCursorHidden()
→ bool
-
-
IsCursorOnScreen()
→ bool
-
-
IsFileDropped()
→ bool
-
-
IsFileExtension(MemoryPointer<RChar> fileName, MemoryPointer<RChar> ext)
→ bool
-
-
IsFileNameValid(MemoryPointer<RChar> fileName)
→ bool
-
-
IsFontValid(FontD font)
→ bool
-
-
IsGamepadAvailable(int gamepad)
→ bool
-
-
IsGamepadButtonDown(int gamepad, int button)
→ bool
-
-
IsGamepadButtonPressed(int gamepad, int button)
→ bool
-
-
IsGamepadButtonReleased(int gamepad, int button)
→ bool
-
-
IsGamepadButtonUp(int gamepad, int button)
→ bool
-
-
IsGestureDetected(int gesture)
→ bool
-
-
IsImageValid(ImageD image)
→ bool
-
-
IsKeyDown(int key)
→ bool
-
-
IsKeyPressed(int key)
→ bool
-
-
IsKeyPressedRepeat(int key)
→ bool
-
-
IsKeyReleased(int key)
→ bool
-
-
IsKeyUp(int key)
→ bool
-
-
IsMaterialValid(MaterialD material)
→ bool
-
-
IsModelAnimationValid(ModelD model, ModelAnimationD anim)
→ bool
-
-
IsModelValid(ModelD model)
→ bool
-
-
IsMouseButtonDown(int button)
→ bool
-
-
IsMouseButtonPressed(int button)
→ bool
-
-
IsMouseButtonReleased(int button)
→ bool
-
-
IsMouseButtonUp(int button)
→ bool
-
-
IsPathFile(MemoryPointer<RChar> path)
→ bool
-
-
IsRenderTextureValid(RenderTextureD target)
→ bool
-
-
IsShaderValid(ShaderD shader)
→ bool
-
-
IsTextureValid(TextureD texture)
→ bool
-
-
IsWindowFocused()
→ bool
-
-
IsWindowFullscreen()
→ bool
-
-
IsWindowHidden()
→ bool
-
-
IsWindowMaximized()
→ bool
-
-
IsWindowMinimized()
→ bool
-
-
IsWindowReady()
→ bool
-
-
IsWindowResized()
→ bool
-
-
IsWindowState(int flag)
→ bool
-
-
LoadAutomationEventList(MemoryPointer<RChar> fileName)
→ AutomationEventListD
-
-
LoadCodepoints(MemoryPointer<RChar> text, MemoryPointer<RInt> count)
→ WasmMemoryPointer<RInt>
-
-
LoadDirectoryFiles(MemoryPointer<RChar> dirPath)
→ FilePathListD
-
-
LoadDirectoryFilesEx(MemoryPointer<RChar> basePath, MemoryPointer<RChar> filter, bool scanSubdirs)
→ FilePathListD
-
-
LoadDroppedFiles()
→ FilePathListD
-
-
LoadFileData(MemoryPointer<RChar> fileName, MemoryPointer<RInt> dataSize)
→ WasmMemoryPointer<RUnsignedChar>
-
-
LoadFileText(MemoryPointer<RChar> fileName)
→ WasmMemoryPointer<RChar>
-
-
LoadFont(MemoryPointer<RChar> fileName)
→ FontD
-
-
LoadFontData(MemoryPointer<RUnsignedChar> fileData, int dataSize, int fontSize, MemoryPointer<RInt> codepoints, int codepointCount, int type, MemoryPointer<RInt> glyphCount)
→ StructPointer<GlyphInfoD>
-
-
LoadFontEx(MemoryPointer<RChar> fileName, int fontSize, MemoryPointer<RInt> codepoints, int codepointCount)
→ FontD
-
-
LoadFontFromImage(ImageD image, ColorD key, int firstChar)
→ FontD
-
-
LoadFontFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> fileData, int dataSize, int fontSize, MemoryPointer<RInt> codepoints, int codepointCount)
→ FontD
-
-
LoadImage(MemoryPointer<RChar> fileName)
→ ImageD
-
-
LoadImageAnim(MemoryPointer<RChar> fileName, MemoryPointer<RInt> frames)
→ ImageD
-
-
LoadImageAnimFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> fileData, int dataSize, MemoryPointer<RInt> frames)
→ ImageD
-
-
LoadImageColors(ImageD image)
→ StructPointer<ColorD>
-
-
LoadImageFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> fileData, int dataSize)
→ ImageD
-
-
LoadImageFromScreen()
→ ImageD
-
-
LoadImageFromTexture(TextureD texture)
→ ImageD
-
-
LoadImagePalette(ImageD image, int maxPaletteSize, MemoryPointer<RInt> colorCount)
→ StructPointer<ColorD>
-
-
LoadImageRaw(MemoryPointer<RChar> fileName, int width, int height, int format, )
→ ImageD
-
-
LoadMaterialDefault()
→ MaterialD
-
-
LoadMaterials(MemoryPointer<RChar> fileName, MemoryPointer<RInt> materialCount)
→ StructPointer<MaterialD>
-
-
LoadModel(MemoryPointer<RChar> fileName)
→ ModelD
-
-
LoadModelAnimations(MemoryPointer<RChar> fileName, MemoryPointer<RInt> animCount)
→ StructPointer<ModelAnimationD>
-
-
LoadModelFromMesh(MeshD mesh)
→ ModelD
-
-
LoadRandomSequence(int count, int min, int max)
→ WasmMemoryPointer<RInt>
-
-
LoadRenderTexture(int width, int height)
→ RenderTextureD
-
-
LoadShader(MemoryPointer<RChar> vsFileName, MemoryPointer<RChar> fsFileName)
→ ShaderD
-
-
LoadShaderFromMemory(MemoryPointer<RChar> vsCode, MemoryPointer<RChar> fsCode)
→ ShaderD
-
-
LoadTextLines(MemoryPointer<RChar> text, MemoryPointer<RInt> count)
→ WasmMemoryPointer<RPointer<RChar>>
-
-
LoadTexture(MemoryPointer<RChar> fileName)
→ TextureD
-
-
LoadTextureCubemap(ImageD image, int layout)
→ TextureD
-
-
LoadTextureFromImage(ImageD image)
→ TextureD
-
-
LoadUTF8(MemoryPointer<RInt> codepoints, int length)
→ WasmMemoryPointer<RChar>
-
-
LoadVrStereoConfig(VrDeviceInfoD device)
→ VrStereoConfigD
-
-
MakeDirectory(MemoryPointer<RChar> dirPath)
→ int
-
-
MaximizeWindow()
→ void
-
-
MeasureText(MemoryPointer<RChar> text, int fontSize)
→ int
-
-
MeasureTextCodepoints(FontD font, MemoryPointer<RInt> codepoints, int length, double fontSize, double spacing)
→ Vector2D
-
-
MeasureTextEx(FontD font, MemoryPointer<RChar> text, double fontSize, double spacing)
→ Vector2D
-
-
MinimizeWindow()
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
OpenURL(MemoryPointer<RChar> url)
→ void
-
-
PlayAutomationEvent(AutomationEventD event)
→ void
-
-
PollInputEvents()
→ void
-
-
ProcessGestureEvent(GestureEventD event)
→ void
-
-
RestoreWindow()
→ void
-
-
SaveFileData(MemoryPointer<RChar> fileName, MemoryPointer<RVoid> data, int dataSize)
→ bool
-
-
SaveFileText(MemoryPointer<RChar> fileName, MemoryPointer<RChar> text)
→ bool
-
-
SetAutomationEventBaseFrame(int frame)
→ void
-
-
SetAutomationEventList(StructPointer<AutomationEventListD> list)
→ void
-
-
SetClipboardText(MemoryPointer<RChar> text)
→ void
-
-
SetConfigFlags(int flags)
→ void
-
-
SetExitKey(int key)
→ void
-
-
SetGamepadMappings(MemoryPointer<RChar> mappings)
→ int
-
-
SetGamepadVibration(int gamepad, double leftMotor, double rightMotor, double duration)
→ void
-
-
SetGesturesEnabled(int flags)
→ void
-
-
SetLoadFileDataCallback(MemoryPointer<RFunction<LoadFileDataCallbackBase>> callback)
→ void
-
-
SetLoadFileTextCallback(MemoryPointer<RFunction<LoadFileTextCallbackBase>> callback)
→ void
-
-
SetMaterialTexture(StructPointer<MaterialD> material, int mapType, TextureD texture)
→ void
-
-
SetModelMeshMaterial(StructPointer<ModelD> model, int meshId, int materialId)
→ void
-
-
SetMouseCursor(int cursor)
→ void
-
-
SetMouseOffset(int offsetX, int offsetY)
→ void
-
-
SetMousePosition(int x, int y)
→ void
-
-
SetMouseScale(double scaleX, double scaleY)
→ void
-
-
SetPixelColor(MemoryPointer<RVoid> dstPtr, ColorD color, int format)
→ void
-
-
SetRandomSeed(int seed)
→ void
-
-
SetSaveFileDataCallback(MemoryPointer<RFunction<SaveFileDataCallbackBase>> callback)
→ void
-
-
SetSaveFileTextCallback(MemoryPointer<RFunction<SaveFileTextCallbackBase>> callback)
→ void
-
-
SetShaderValueMatrix(ShaderD shader, int locIndex, MatrixD mat)
→ void
-
-
SetShaderValueTexture(ShaderD shader, int locIndex, TextureD texture)
→ void
-
-
SetShaderValueV(ShaderD shader, int locIndex, MemoryPointer<RVoid> value, int uniformType, int count)
→ void
-
-
SetShapesTexture(TextureD texture, RectangleD source)
→ void
-
-
SetTargetFPS(int fps)
→ void
-
-
SetTextLineSpacing(int spacing)
→ void
-
-
SetTextureFilter(TextureD texture, int filter)
→ void
-
-
SetTextureWrap(TextureD texture, int wrap)
→ void
-
-
SetTraceLogCallback(MemoryPointer<RFunction<TraceLogCallbackBase>> callback)
→ void
-
-
SetTraceLogLevel(int logLevel)
→ void
-
-
SetWindowFocused()
→ void
-
-
SetWindowIcon(ImageD image)
→ void
-
-
SetWindowIcons(StructPointer<ImageD> images, int count)
→ void
-
-
SetWindowMaxSize(int width, int height)
→ void
-
-
SetWindowMinSize(int width, int height)
→ void
-
-
SetWindowMonitor(int monitor)
→ void
-
-
SetWindowOpacity(double opacity)
→ void
-
-
SetWindowPosition(int x, int y)
→ void
-
-
SetWindowSize(int width, int height)
→ void
-
-
SetWindowState(int flags)
→ void
-
-
SetWindowTitle(MemoryPointer<RChar> title)
→ void
-
-
ShowCursor()
→ void
-
-
StartAutomationEventRecording()
→ void
-
-
StopAutomationEventRecording()
→ void
-
-
SwapScreenBuffer()
→ void
-
-
TakeScreenshot(MemoryPointer<RChar> fileName)
→ void
-
-
TextAppend(MemoryPointer<RChar> text, MemoryPointer<RChar> append, MemoryPointer<RInt> position)
→ void
-
-
TextCopy(MemoryPointer<RChar> dst, MemoryPointer<RChar> src)
→ int
-
-
TextFindIndex(MemoryPointer<RChar> text, MemoryPointer<RChar> find)
→ int
-
-
TextInsert(MemoryPointer<RChar> text, MemoryPointer<RChar> insert, int position)
→ WasmMemoryPointer<RChar>
-
-
TextInsertAlloc(MemoryPointer<RChar> text, MemoryPointer<RChar> insert, int position)
→ WasmMemoryPointer<RChar>
-
-
TextIsEqual(MemoryPointer<RChar> text1, MemoryPointer<RChar> text2)
→ bool
-
-
TextJoin(MemoryPointer<RPointer<RChar>> textList, int count, MemoryPointer<RChar> delimiter)
→ WasmMemoryPointer<RChar>
-
-
TextLength(MemoryPointer<RChar> text)
→ int
-
-
TextRemoveSpaces(MemoryPointer<RChar> text)
→ WasmMemoryPointer<RChar>
-
-
TextReplace(MemoryPointer<RChar> text, MemoryPointer<RChar> replace, MemoryPointer<RChar> by)
→ WasmMemoryPointer<RChar>
-
-
TextReplaceAlloc(MemoryPointer<RChar> text, MemoryPointer<RChar> replace, MemoryPointer<RChar> by)
→ WasmMemoryPointer<RChar>
-
-
TextReplaceBetween(MemoryPointer<RChar> text, MemoryPointer<RChar> begin, MemoryPointer<RChar> end, MemoryPointer<RChar> replacement)
→ WasmMemoryPointer<RChar>
-
-
TextReplaceBetweenAlloc(MemoryPointer<RChar> text, MemoryPointer<RChar> begin, MemoryPointer<RChar> end, MemoryPointer<RChar> replacement)
→ WasmMemoryPointer<RChar>
-
-
TextSplit(MemoryPointer<RChar> text, int delimiter, MemoryPointer<RInt> count)
→ WasmMemoryPointer<RPointer<RChar>>
-
-
TextSubtext(MemoryPointer<RChar> text, int position, int length)
→ WasmMemoryPointer<RChar>
-
-
TextToCamel(MemoryPointer<RChar> text)
→ WasmMemoryPointer<RChar>
-
-
TextToFloat(MemoryPointer<RChar> text)
→ double
-
-
TextToInteger(MemoryPointer<RChar> text)
→ int
-
-
TextToLower(MemoryPointer<RChar> text)
→ WasmMemoryPointer<RChar>
-
-
TextToPascal(MemoryPointer<RChar> text)
→ WasmMemoryPointer<RChar>
-
-
TextToSnake(MemoryPointer<RChar> text)
→ WasmMemoryPointer<RChar>
-
-
TextToUpper(MemoryPointer<RChar> text)
→ WasmMemoryPointer<RChar>
-
-
ToggleBorderlessWindowed()
→ void
-
-
ToggleFullscreen()
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
TraceLog(int logLevel, MemoryPointer<RChar> text)
→ void
-
-
UnloadAutomationEventList(AutomationEventListD list)
→ void
-
-
UnloadCodepoints(MemoryPointer<RInt> codepoints)
→ void
-
-
UnloadDirectoryFiles(FilePathListD files)
→ void
-
-
UnloadDroppedFiles(FilePathListD files)
→ void
-
-
UnloadFileData(MemoryPointer<RUnsignedChar> data)
→ void
-
-
UnloadFileText(MemoryPointer<RChar> text)
→ void
-
-
UnloadFont(FontD font)
→ void
-
-
UnloadFontData(StructPointer<GlyphInfoD> glyphs, int glyphCount)
→ void
-
-
UnloadImage(ImageD image)
→ void
-
-
UnloadImageColors(StructPointer<ColorD> colors)
→ void
-
-
UnloadImagePalette(StructPointer<ColorD> colors)
→ void
-
-
UnloadMaterial(MaterialD material)
→ void
-
-
UnloadMesh(MeshD mesh)
→ void
-
-
UnloadModel(ModelD model)
→ void
-
-
UnloadModelAnimations(StructPointer<ModelAnimationD> animations, int animCount)
→ void
-
-
UnloadRandomSequence(MemoryPointer<RInt> sequence)
→ void
-
-
UnloadRenderTexture(RenderTextureD target)
→ void
-
-
UnloadShader(ShaderD shader)
→ void
-
-
UnloadTextLines(MemoryPointer<RPointer<RChar>> text, int lineCount)
→ void
-
-
UnloadTexture(TextureD texture)
→ void
-
-
UnloadUTF8(MemoryPointer<RChar> text)
→ void
-
-
UnloadVrStereoConfig(VrStereoConfigD config)
→ void
-
-
UpdateCamera(StructPointer<Camera3DD> camera, int mode)
→ void
-
-
UpdateCameraPro(StructPointer<Camera3DD> camera, Vector3D movement, Vector3D rotation, double zoom)
→ void
-
-
UpdateGestures()
→ void
-
-
UpdateMeshBuffer(MeshD mesh, int index, MemoryPointer<RVoid> data, int dataSize, int offset)
→ void
-
-
UpdateModelAnimation(ModelD model, ModelAnimationD anim, double frame)
→ void
-
-
UpdateModelAnimationEx(ModelD model, ModelAnimationD animA, double frameA, ModelAnimationD animB, double frameB, double blend)
→ void
-
-
UpdateTexture(TextureD texture, MemoryPointer<RVoid> pixels)
→ void
-
-
UpdateTextureRec(TextureD texture, RectangleD rec, MemoryPointer<RVoid> pixels)
→ void
-
-
UploadMesh(StructPointer<MeshD> mesh, bool dynamic)
→ void
-
-
WaitTime(double seconds)
→ void
-
-
WindowShouldClose()
→ bool
-