RaylibGuiD class

Inheritance

Constructors

RaylibGuiD(Raylib rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
RAYGUI_COLORBARALPHA_CHECKED_SIZE int
no setterinherited
RAYGUI_GRID_ALPHA double
no setterinherited
RAYGUI_GROUPBOX_LINE_THICK int
no setterinherited
RAYGUI_ICON_DATA_ELEMENTS int
no setterinherited
RAYGUI_ICON_MAX_ICONS int
no setterinherited
RAYGUI_ICON_MAX_NAME_LENGTH int
no setterinherited
RAYGUI_ICON_SIZE int
no setterinherited
RAYGUI_ICON_TEXT_PADDING int
no setterinherited
RAYGUI_ICONS List<int>
no setterinherited
RAYGUI_LINE_MARGIN_TEXT int
no setterinherited
RAYGUI_LINE_TEXT_PADDING int
no setterinherited
RAYGUI_MAX_CONTROLS int
no setterinherited
RAYGUI_MAX_LINE_BUFFER_SIZE int
no setterinherited
RAYGUI_MAX_PROPS_BASE int
no setterinherited
RAYGUI_MAX_PROPS_EXTENDED int
no setterinherited
RAYGUI_MAX_TEXT_LINES int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_MIN_MOUSE_WHEEL_SPEED int
no setterinherited
RAYGUI_MIN_SCROLLBAR_HEIGHT int
no setterinherited
RAYGUI_MIN_SCROLLBAR_WIDTH int
no setterinherited
RAYGUI_PANEL_BORDER_WIDTH int
no setterinherited
RAYGUI_SCROLLBAR_LEFT_SIDE int
no setterinherited
RAYGUI_SCROLLBAR_RIGHT_SIDE int
no setterinherited
RAYGUI_TABBAR_ITEM_WIDTH int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY int
no setterinherited
RAYGUI_TEXTFORMAT_MAX_SIZE int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_TEXTINPUTBOX_HEIGHT int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_ITEMS int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_TEXT_SIZE int
no setterinherited
RAYGUI_TOGGLEGROUP_MAX_ITEMS int
no setterinherited
RAYGUI_VALUEBOX_MAX_CHARS int
no setterinherited
RAYGUI_VERSION String
no setterinherited
RAYGUI_VERSION_MAJOR int
no setterinherited
RAYGUI_VERSION_MINOR int
no setterinherited
RAYGUI_VERSION_PATCH int
no setterinherited
RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT int
no setterinherited
RaylibCaptureIds RaylibGuiModuleCaptureIds
Capture ID generator for pointer slots allocated by this module.
finalinherited
RaylibDebugLabels RaylibGuiModuleDebugLabels
Debug label generator for this module's function calls.
finalinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
doLoad() → void
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
GuiButton(RectangleD bounds, String? text) int
override
GuiCheckBox(RectangleD bounds, String? text, bool checked) → (int, bool)
override
GuiColorBarAlpha(RectangleD bounds, num alpha) → (int, double)
override
GuiColorBarHue(RectangleD bounds, num value) → (int, double)
override
GuiColorPanel(RectangleD bounds, ColorD color) → (int, ColorD)
override
GuiColorPanelHSV(RectangleD bounds, [Vector3D? colorHsv]) → (int, Vector3D)
override
GuiColorPicker(RectangleD bounds, ColorD? color) → (int, ColorD)
override
GuiColorPickerHSV(RectangleD bounds, [Vector3D? colorHsv]) → (int, Vector3D)
override
GuiComboBox(RectangleD bounds, String? text, num active) → (int, int)
override
GuiDisable() → void
override
GuiDisableTooltip() → void
override
GuiDrawIcon(GuiIconName iconId, num posX, num posY, num pixelSize, ColorD color) → void
override
GuiDropdownBox(RectangleD bounds, String? text, num active, bool editMode) → (int, int)
override
GuiDummyRec(RectangleD bounds, String? text) int
override
GuiEnable() → void
override
GuiEnableTooltip() → void
override
GuiGetFont() FontD
override
GuiGetIcons() List<int>
override
GuiGetState() int
override
GuiGetStyle(GuiControl control, GuiProperty property) int
override
GuiGetTextWidth(String? text) int
override
GuiGrid(RectangleD bounds, num spacing, num subdivs, [Vector2D? mouseCell]) int
override
GuiGroupBox(RectangleD bounds, String? text) int
override
GuiIconText(GuiIconName iconId, String? text) String
override
GuiIsLocked() bool
override
GuiLabel(RectangleD bounds, String? text) int
override
GuiLabelButton(RectangleD bounds, String? text) int
override
GuiLine(RectangleD bounds, String? text) int
override
GuiListView(RectangleD bounds, String? text, {int? scrollIndex, int? active}) → (int, int, int)
override
GuiListViewEx(RectangleD bounds, List<String> text, {int? scrollIndex, int? active, int? focus}) → (int, int, int, int)
override
GuiLoadIcons(String fileName, bool loadIconsName) List<String>
override
GuiLoadStyle(String fileName) → void
override
GuiLoadStyleDefault() → void
override
GuiLock() → void
override
GuiMessageBox(RectangleD bounds, String? title, String message, String buttons) int
override
GuiPanel(RectangleD bounds, String? text) int
override
GuiProgressBar(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
override
GuiScrollPanel(RectangleD bounds, String? text, RectangleD content, Vector2D scroll, [RectangleD? view]) int
override
GuiSetAlpha(num alpha) → void
override
GuiSetFont(FontD font) → void
override
GuiSetIconScale(num scale) → void
override
GuiSetState(GuiState state) → void
override
GuiSetStyle(GuiControl control, GuiProperty property, num value) → void
override
GuiSetTooltip(String? tooltip) → void
override
GuiSlider(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
override
GuiSliderBar(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
override
GuiSpinner(RectangleD bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (int, int)
override
GuiStatusBar(RectangleD bounds, String? text) int
override
GuiTabBar(RectangleD bounds, List<String> text) → (int, int)
override
GuiTextBox(RectangleD bounds, String? text, num textSize, bool editMode) → (int, String)
override
GuiTextInputBox(RectangleD bounds, String? title, String? message, String buttons, String? text, num textMaxSize, bool? secretViewActive) → (int, String, bool?)
override
GuiToggle(RectangleD bounds, String? text, bool active) → (int, bool)
override
GuiToggleGroup(RectangleD bounds, String? text, num active) → (int, int)
override
GuiToggleSlider(RectangleD bounds, String? text, num active) → (int, int)
override
GuiUnlock() → void
override
GuiValueBox(RectangleD bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (int, int)
override
GuiValueBoxFloat(RectangleD bounds, String? text, String textValue, num value, bool editMode) → (int, double)
override
GuiWindowBox(RectangleD bounds, String? title) int
override
load() → void
Override to perform one-time module initialization. Called by doLoad.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited