GuiWindowBox method
Window Box control, shows a window that can be closed
Implementation
@override
int GuiWindowBox(
RectangleD bounds,
MemoryPointer<RChar> title,
) => _wasm.GuiWindowBox(
$.Rectangle$.Ref1(bounds).toJS,
title.toJS,
);
Window Box control, shows a window that can be closed
@override
int GuiWindowBox(
RectangleD bounds,
MemoryPointer<RChar> title,
) => _wasm.GuiWindowBox(
$.Rectangle$.Ref1(bounds).toJS,
title.toJS,
);