rn property

String rn
final

Emscripten cwrap return type for anything other than structs and void.

Functions using this return type do not use the WASM structure-return (sret) convention, so their argument count matches the C signature.

Implementation

final String rn = _n;