rv property

Null rv
final

Emscripten cwrap return type for functions returning void.

Also used for functions returning a struct, which use the WASM structure-return (sret) convention. Such functions receive an additional hidden return-pointer argument (first argument), so their cwrap argument count is one greater than their C signature.

Implementation

final Null rv = null;