RaylibRlgl class
- Inheritance
-
- Object
- RaylibModule<
Raylib> - RaylibModuleWasm
- RaylibRlgl
- Mixed-in types
Constructors
- RaylibRlgl(Raylib rl)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- n → String
-
finalinherited
- rl → Raylib
-
finalinherited
- RL_BLEND_COLOR → int
-
See RaylibRlglConstants.RL_BLEND_COLOR.
no setterinherited
- RL_BLEND_DST_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_DST_ALPHA.
no setterinherited
- RL_BLEND_DST_RGB → int
-
See RaylibRlglConstants.RL_BLEND_DST_RGB.
no setterinherited
- RL_BLEND_EQUATION → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION.
no setterinherited
- RL_BLEND_EQUATION_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION_ALPHA.
no setterinherited
- RL_BLEND_EQUATION_RGB → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION_RGB.
no setterinherited
- RL_BLEND_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_SRC_ALPHA.
no setterinherited
- RL_BLEND_SRC_RGB → int
-
See RaylibRlglConstants.RL_BLEND_SRC_RGB.
no setterinherited
- RL_COMPUTE_SHADER → int
-
See RaylibRlglConstants.RL_COMPUTE_SHADER.
no setterinherited
- RL_CONSTANT_ALPHA → int
-
See RaylibRlglConstants.RL_CONSTANT_ALPHA.
no setterinherited
- RL_CONSTANT_COLOR → int
-
See RaylibRlglConstants.RL_CONSTANT_COLOR.
no setterinherited
- RL_CULL_DISTANCE_FAR → double
-
See RaylibRlglConstants.RL_CULL_DISTANCE_FAR.
no setterinherited
- RL_CULL_DISTANCE_NEAR → double
-
See RaylibRlglConstants.RL_CULL_DISTANCE_NEAR.
no setterinherited
- RL_DEFAULT_BATCH_BUFFER_ELEMENTS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFER_ELEMENTS.
no setterinherited
- RL_DEFAULT_BATCH_BUFFERS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFERS.
no setterinherited
- RL_DEFAULT_BATCH_DRAWCALLS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_DRAWCALLS.
no setterinherited
- RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEIDS → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEIDS.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEWEIGHTS → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEWEIGHTS.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_COLOR → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_COLOR.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_INDICES → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_INDICES.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_NORMAL → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_NORMAL.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_POSITION → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_POSITION.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_TANGENT → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_TANGENT.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD.
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD2 → int
-
See RaylibRlglConstants.RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD2.
no setterinherited
- RL_DRAW_FRAMEBUFFER → int
-
See RaylibRlglConstants.RL_DRAW_FRAMEBUFFER.
no setterinherited
- RL_DST_ALPHA → int
-
See RaylibRlglConstants.RL_DST_ALPHA.
no setterinherited
- RL_DST_COLOR → int
-
See RaylibRlglConstants.RL_DST_COLOR.
no setterinherited
- RL_DYNAMIC_COPY → int
-
See RaylibRlglConstants.RL_DYNAMIC_COPY.
no setterinherited
- RL_DYNAMIC_DRAW → int
-
See RaylibRlglConstants.RL_DYNAMIC_DRAW.
no setterinherited
- RL_DYNAMIC_READ → int
-
See RaylibRlglConstants.RL_DYNAMIC_READ.
no setterinherited
- RL_FLOAT → int
-
See RaylibRlglConstants.RL_FLOAT.
no setterinherited
- RL_FRAGMENT_SHADER → int
-
See RaylibRlglConstants.RL_FRAGMENT_SHADER.
no setterinherited
- RL_FUNC_ADD → int
-
See RaylibRlglConstants.RL_FUNC_ADD.
no setterinherited
- RL_FUNC_REVERSE_SUBTRACT → int
-
See RaylibRlglConstants.RL_FUNC_REVERSE_SUBTRACT.
no setterinherited
- RL_FUNC_SUBTRACT → int
-
See RaylibRlglConstants.RL_FUNC_SUBTRACT.
no setterinherited
- RL_LINES → int
-
See RaylibRlglConstants.RL_LINES.
no setterinherited
- RL_MAX → int
-
See RaylibRlglConstants.RL_MAX.
no setterinherited
- RL_MAX_MATRIX_STACK_SIZE → int
-
See RaylibRlglConstants.RL_MAX_MATRIX_STACK_SIZE.
no setterinherited
- RL_MAX_SHADER_LOCATIONS → int
-
See RaylibRlglConstants.RL_MAX_SHADER_LOCATIONS.
no setterinherited
- RL_MIN → int
-
See RaylibRlglConstants.RL_MIN.
no setterinherited
- RL_MODELVIEW → int
-
See RaylibRlglConstants.RL_MODELVIEW.
no setterinherited
- RL_ONE → int
-
See RaylibRlglConstants.RL_ONE.
no setterinherited
- RL_ONE_MINUS_CONSTANT_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_ALPHA.
no setterinherited
- RL_ONE_MINUS_CONSTANT_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_COLOR.
no setterinherited
- RL_ONE_MINUS_DST_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_DST_ALPHA.
no setterinherited
- RL_ONE_MINUS_DST_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_DST_COLOR.
no setterinherited
- RL_ONE_MINUS_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_SRC_ALPHA.
no setterinherited
- RL_ONE_MINUS_SRC_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_SRC_COLOR.
no setterinherited
- RL_PROJECTION → int
-
See RaylibRlglConstants.RL_PROJECTION.
no setterinherited
- RL_QUADS → int
-
See RaylibRlglConstants.RL_QUADS.
no setterinherited
- RL_READ_FRAMEBUFFER → int
-
See RaylibRlglConstants.RL_READ_FRAMEBUFFER.
no setterinherited
- RL_SHADER_LOC_MAP_DIFFUSE → int
-
See RaylibRlglConstants.RL_SHADER_LOC_MAP_DIFFUSE.
no setterinherited
- RL_SHADER_LOC_MAP_SPECULAR → int
-
See RaylibRlglConstants.RL_SHADER_LOC_MAP_SPECULAR.
no setterinherited
- RL_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_SRC_ALPHA.
no setterinherited
- RL_SRC_ALPHA_SATURATE → int
-
See RaylibRlglConstants.RL_SRC_ALPHA_SATURATE.
no setterinherited
- RL_SRC_COLOR → int
-
See RaylibRlglConstants.RL_SRC_COLOR.
no setterinherited
- RL_STATIC_COPY → int
-
See RaylibRlglConstants.RL_STATIC_COPY.
no setterinherited
- RL_STATIC_DRAW → int
-
See RaylibRlglConstants.RL_STATIC_DRAW.
no setterinherited
- RL_STATIC_READ → int
-
See RaylibRlglConstants.RL_STATIC_READ.
no setterinherited
- RL_STREAM_COPY → int
-
See RaylibRlglConstants.RL_STREAM_COPY.
no setterinherited
- RL_STREAM_DRAW → int
-
See RaylibRlglConstants.RL_STREAM_DRAW.
no setterinherited
- RL_STREAM_READ → int
-
See RaylibRlglConstants.RL_STREAM_READ.
no setterinherited
- RL_TEXTURE → int
-
See RaylibRlglConstants.RL_TEXTURE.
no setterinherited
- RL_TEXTURE_FILTER_ANISOTROPIC → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_ANISOTROPIC.
no setterinherited
- RL_TEXTURE_FILTER_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR.
no setterinherited
- RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_MIP_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_LINEAR.
no setterinherited
- RL_TEXTURE_FILTER_MIP_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR.
no setterinherited
- RL_TEXTURE_MAG_FILTER → int
-
See RaylibRlglConstants.RL_TEXTURE_MAG_FILTER.
no setterinherited
- RL_TEXTURE_MIN_FILTER → int
-
See RaylibRlglConstants.RL_TEXTURE_MIN_FILTER.
no setterinherited
- RL_TEXTURE_MIPMAP_BIAS_RATIO → int
-
See RaylibRlglConstants.RL_TEXTURE_MIPMAP_BIAS_RATIO.
no setterinherited
- RL_TEXTURE_WRAP_CLAMP → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_CLAMP.
no setterinherited
- RL_TEXTURE_WRAP_MIRROR_CLAMP → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_CLAMP.
no setterinherited
- RL_TEXTURE_WRAP_MIRROR_REPEAT → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_REPEAT.
no setterinherited
- RL_TEXTURE_WRAP_REPEAT → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_REPEAT.
no setterinherited
- RL_TEXTURE_WRAP_S → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_S.
no setterinherited
- RL_TEXTURE_WRAP_T → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_T.
no setterinherited
- RL_TRIANGLES → int
-
See RaylibRlglConstants.RL_TRIANGLES.
no setterinherited
- RL_UNSIGNED_BYTE → int
-
See RaylibRlglConstants.RL_UNSIGNED_BYTE.
no setterinherited
- RL_VERTEX_SHADER → int
-
See RaylibRlglConstants.RL_VERTEX_SHADER.
no setterinherited
- RL_ZERO → int
-
See RaylibRlglConstants.RL_ZERO.
no setterinherited
-
rlActiveDrawBuffers
↔ JSFunction<
Function> -
latefinal
-
rlActiveTextureSlot
↔ JSFunction<
Function> -
latefinal
-
rlBegin
↔ JSFunction<
Function> -
latefinal
-
rlBindFramebuffer
↔ JSFunction<
Function> -
latefinal
-
rlBindImageTexture
↔ JSFunction<
Function> -
latefinal
-
rlBindShaderBuffer
↔ JSFunction<
Function> -
latefinal
-
rlBlitFramebuffer
↔ JSFunction<
Function> -
latefinal
-
rlCheckErrors
↔ JSFunction<
Function> -
latefinal
-
rlCheckRenderBatchLimit
↔ JSFunction<
Function> -
latefinal
-
rlClearColor
↔ JSFunction<
Function> -
latefinal
-
rlClearScreenBuffers
↔ JSFunction<
Function> -
latefinal
-
rlColor3f
↔ JSFunction<
Function> -
latefinal
-
rlColor4f
↔ JSFunction<
Function> -
latefinal
-
rlColor4ub
↔ JSFunction<
Function> -
latefinal
-
rlColorMask
↔ JSFunction<
Function> -
latefinal
-
rlCompileShader
↔ JSFunction<
Function> -
latefinal
-
rlComputeShaderDispatch
↔ JSFunction<
Function> -
latefinal
-
rlCopyShaderBuffer
↔ JSFunction<
Function> -
latefinal
-
rlCubemapParameters
↔ JSFunction<
Function> -
latefinal
-
rlDisableBackfaceCulling
↔ JSFunction<
Function> -
latefinal
-
rlDisableColorBlend
↔ JSFunction<
Function> -
latefinal
-
rlDisableDepthMask
↔ JSFunction<
Function> -
latefinal
-
rlDisableDepthTest
↔ JSFunction<
Function> -
latefinal
-
rlDisableFramebuffer
↔ JSFunction<
Function> -
latefinal
-
rlDisableScissorTest
↔ JSFunction<
Function> -
latefinal
-
rlDisableShader
↔ JSFunction<
Function> -
latefinal
-
rlDisableSmoothLines
↔ JSFunction<
Function> -
latefinal
-
rlDisableStereoRender
↔ JSFunction<
Function> -
latefinal
-
rlDisableTexture
↔ JSFunction<
Function> -
latefinal
-
rlDisableTextureCubemap
↔ JSFunction<
Function> -
latefinal
-
rlDisableVertexArray
↔ JSFunction<
Function> -
latefinal
-
rlDisableVertexAttribute
↔ JSFunction<
Function> -
latefinal
-
rlDisableVertexBuffer
↔ JSFunction<
Function> -
latefinal
-
rlDisableVertexBufferElement
↔ JSFunction<
Function> -
latefinal
-
rlDisableWireMode
↔ JSFunction<
Function> -
latefinal
-
rlDrawRenderBatch
↔ JSFunction<
Function> -
latefinal
-
rlDrawRenderBatchActive
↔ JSFunction<
Function> -
latefinal
-
rlDrawVertexArray
↔ JSFunction<
Function> -
latefinal
-
rlDrawVertexArrayElements
↔ JSFunction<
Function> -
latefinal
-
rlDrawVertexArrayElementsInstanced
↔ JSFunction<
Function> -
latefinal
-
rlDrawVertexArrayInstanced
↔ JSFunction<
Function> -
latefinal
-
rlEnableBackfaceCulling
↔ JSFunction<
Function> -
latefinal
-
rlEnableColorBlend
↔ JSFunction<
Function> -
latefinal
-
rlEnableDepthMask
↔ JSFunction<
Function> -
latefinal
-
rlEnableDepthTest
↔ JSFunction<
Function> -
latefinal
-
rlEnableFramebuffer
↔ JSFunction<
Function> -
latefinal
-
rlEnablePointMode
↔ JSFunction<
Function> -
latefinal
-
rlEnableScissorTest
↔ JSFunction<
Function> -
latefinal
-
rlEnableShader
↔ JSFunction<
Function> -
latefinal
-
rlEnableSmoothLines
↔ JSFunction<
Function> -
latefinal
-
rlEnableStereoRender
↔ JSFunction<
Function> -
latefinal
-
rlEnableTexture
↔ JSFunction<
Function> -
latefinal
-
rlEnableTextureCubemap
↔ JSFunction<
Function> -
latefinal
-
rlEnableVertexArray
↔ JSFunction<
Function> -
latefinal
-
rlEnableVertexAttribute
↔ JSFunction<
Function> -
latefinal
-
rlEnableVertexBuffer
↔ JSFunction<
Function> -
latefinal
-
rlEnableVertexBufferElement
↔ JSFunction<
Function> -
latefinal
-
rlEnableWireMode
↔ JSFunction<
Function> -
latefinal
-
rlEnd
↔ JSFunction<
Function> -
latefinal
-
rlFramebufferAttach
↔ JSFunction<
Function> -
latefinal
-
rlFramebufferComplete
↔ JSFunction<
Function> -
latefinal
-
rlFrustum
↔ JSFunction<
Function> -
latefinal
-
rlGenTextureMipmaps
↔ JSFunction<
Function> -
latefinal
-
rlGetActiveFramebuffer
↔ JSFunction<
Function> -
latefinal
-
rlGetCullDistanceFar
↔ JSFunction<
Function> -
latefinal
-
rlGetCullDistanceNear
↔ JSFunction<
Function> -
latefinal
-
rlGetFramebufferHeight
↔ JSFunction<
Function> -
latefinal
-
rlGetFramebufferWidth
↔ JSFunction<
Function> -
latefinal
-
rlGetGlTextureFormats
↔ JSFunction<
Function> -
latefinal
-
rlGetLineWidth
↔ JSFunction<
Function> -
latefinal
-
rlGetLocationAttrib
↔ JSFunction<
Function> -
latefinal
-
rlGetLocationUniform
↔ JSFunction<
Function> -
latefinal
-
rlGetMatrixModelview
↔ JSFunction<
Function> -
latefinal
-
rlGetMatrixProjection
↔ JSFunction<
Function> -
latefinal
-
rlGetMatrixProjectionStereo
↔ JSFunction<
Function> -
latefinal
-
rlGetMatrixTransform
↔ JSFunction<
Function> -
latefinal
-
rlGetMatrixViewOffsetStereo
↔ JSFunction<
Function> -
latefinal
-
rlGetPixelFormatName
↔ JSFunction<
Function> -
latefinal
-
rlGetShaderBufferSize
↔ JSFunction<
Function> -
latefinal
-
rlGetShaderIdDefault
↔ JSFunction<
Function> -
latefinal
-
rlGetShaderLocsDefault
↔ JSFunction<
Function> -
latefinal
-
rlGetTextureIdDefault
↔ JSFunction<
Function> -
latefinal
-
rlGetVersion
↔ JSFunction<
Function> -
latefinal
- RLGL_VERSION → String
-
See RaylibRlglConstants.RLGL_VERSION.
no setterinherited
-
rlglClose
↔ JSFunction<
Function> -
latefinal
-
rlglInit
↔ JSFunction<
Function> -
latefinal
-
rlIsStereoRenderEnabled
↔ JSFunction<
Function> -
latefinal
-
rlLoadComputeShaderProgram
↔ JSFunction<
Function> -
latefinal
-
rlLoadDrawCube
↔ JSFunction<
Function> -
latefinal
-
rlLoadDrawQuad
↔ JSFunction<
Function> -
latefinal
-
rlLoadExtensions
↔ JSFunction<
Function> -
latefinal
-
rlLoadFramebuffer
↔ JSFunction<
Function> -
latefinal
-
rlLoadIdentity
↔ JSFunction<
Function> -
latefinal
-
rlLoadRenderBatch
↔ JSFunction<
Function> -
latefinal
-
rlLoadShaderBuffer
↔ JSFunction<
Function> -
latefinal
-
rlLoadShaderCode
↔ JSFunction<
Function> -
latefinal
-
rlLoadShaderProgram
↔ JSFunction<
Function> -
latefinal
-
rlLoadTexture
↔ JSFunction<
Function> -
latefinal
-
rlLoadTextureCubemap
↔ JSFunction<
Function> -
latefinal
-
rlLoadTextureDepth
↔ JSFunction<
Function> -
latefinal
-
rlLoadVertexArray
↔ JSFunction<
Function> -
latefinal
-
rlLoadVertexBuffer
↔ JSFunction<
Function> -
latefinal
-
rlLoadVertexBufferElement
↔ JSFunction<
Function> -
latefinal
-
rlMatrixMode
↔ JSFunction<
Function> -
latefinal
-
rlMultMatrixf
↔ JSFunction<
Function> -
latefinal
-
rlNormal3f
↔ JSFunction<
Function> -
latefinal
-
rlOrtho
↔ JSFunction<
Function> -
latefinal
-
rlPopMatrix
↔ JSFunction<
Function> -
latefinal
-
rlPushMatrix
↔ JSFunction<
Function> -
latefinal
-
rlReadScreenPixels
↔ JSFunction<
Function> -
latefinal
-
rlReadShaderBuffer
↔ JSFunction<
Function> -
latefinal
-
rlReadTexturePixels
↔ JSFunction<
Function> -
latefinal
-
rlRotatef
↔ JSFunction<
Function> -
latefinal
-
rlScalef
↔ JSFunction<
Function> -
latefinal
-
rlScissor
↔ JSFunction<
Function> -
latefinal
-
rlSetBlendFactors
↔ JSFunction<
Function> -
latefinal
-
rlSetBlendFactorsSeparate
↔ JSFunction<
Function> -
latefinal
-
rlSetBlendMode
↔ JSFunction<
Function> -
latefinal
-
rlSetClipPlanes
↔ JSFunction<
Function> -
latefinal
-
rlSetCullFace
↔ JSFunction<
Function> -
latefinal
-
rlSetFramebufferHeight
↔ JSFunction<
Function> -
latefinal
-
rlSetFramebufferWidth
↔ JSFunction<
Function> -
latefinal
-
rlSetLineWidth
↔ JSFunction<
Function> -
latefinal
-
rlSetMatrixModelview
↔ JSFunction<
Function> -
latefinal
-
rlSetMatrixProjection
↔ JSFunction<
Function> -
latefinal
-
rlSetMatrixProjectionStereo
↔ JSFunction<
Function> -
latefinal
-
rlSetMatrixViewOffsetStereo
↔ JSFunction<
Function> -
latefinal
-
rlSetRenderBatchActive
↔ JSFunction<
Function> -
latefinal
-
rlSetShader
↔ JSFunction<
Function> -
latefinal
-
rlSetTexture
↔ JSFunction<
Function> -
latefinal
-
rlSetUniform
↔ JSFunction<
Function> -
latefinal
-
rlSetUniformMatrices
↔ JSFunction<
Function> -
latefinal
-
rlSetUniformMatrix
↔ JSFunction<
Function> -
latefinal
-
rlSetUniformSampler
↔ JSFunction<
Function> -
latefinal
-
rlSetVertexAttribute
↔ JSFunction<
Function> -
latefinal
-
rlSetVertexAttributeDefault
↔ JSFunction<
Function> -
latefinal
-
rlSetVertexAttributeDivisor
↔ JSFunction<
Function> -
latefinal
-
rlTexCoord2f
↔ JSFunction<
Function> -
latefinal
-
rlTextureParameters
↔ JSFunction<
Function> -
latefinal
-
rlTranslatef
↔ JSFunction<
Function> -
latefinal
-
rlUnloadFramebuffer
↔ JSFunction<
Function> -
latefinal
-
rlUnloadRenderBatch
↔ JSFunction<
Function> -
latefinal
-
rlUnloadShaderBuffer
↔ JSFunction<
Function> -
latefinal
-
rlUnloadShaderProgram
↔ JSFunction<
Function> -
latefinal
-
rlUnloadTexture
↔ JSFunction<
Function> -
latefinal
-
rlUnloadVertexArray
↔ JSFunction<
Function> -
latefinal
-
rlUnloadVertexBuffer
↔ JSFunction<
Function> -
latefinal
-
rlUpdateShaderBuffer
↔ JSFunction<
Function> -
latefinal
-
rlUpdateTexture
↔ JSFunction<
Function> -
latefinal
-
rlUpdateVertexBuffer
↔ JSFunction<
Function> -
latefinal
-
rlUpdateVertexBufferElements
↔ JSFunction<
Function> -
latefinal
-
rlVertex2f
↔ JSFunction<
Function> -
latefinal
-
rlVertex2i
↔ JSFunction<
Function> -
latefinal
-
rlVertex3f
↔ JSFunction<
Function> -
latefinal
-
rlViewport
↔ JSFunction<
Function> -
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s → String
-
finalinherited
Methods
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
doLoad(
) → void -
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
-
load(
) → void -
Override to perform one-time module initialization. Called by doLoad.
inherited
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited