RaylibVector2Ext class
Methods
debug (bool v )
→ void
Enables or disables debug logging for this module.
inherited
debugError (String message )
→ void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter (bool filter (String ) )
→ void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo (String message )
→ void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime (bool v )
→ void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn (String message )
→ void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync <T > (T f () )
→ T
Executes f with RaylibTemp syncing temporarily disabled,
restoring the previous sync state afterward.
inherited
dispose ()
→ void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed <D extends RaylibStruct <D > > (D struct , void fn (StructPointer <D > ptr ) )
→ void
Disposes struct, invokes fn with its underlying pointer, and then frees
the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted <D extends RaylibStruct <D > > (D struct , void fn (StructPointer <D > ptr ) )
→ void
Disposes struct, invokes fn with its underlying pointer, and then
unslots the temporary allocation backing the pointer, if any.
inherited
dwrap0 <R > (String name )
→ WF0 <R >
Binds a cwraped C function taking 0 arguments and returning a plain
(non-struct) value.
inherited
dwrap1 <R > (String name )
→ WF1 <R >
Binds a cwraped C function taking 1 argument and returning a plain
(non-struct) value.
inherited
dwrap2 <R > (String name )
→ WF2 <R >
Binds a cwraped C function taking 2 arguments and returning a plain
(non-struct) value.
inherited
dwrap3 <R > (String name )
→ WF3 <R >
Binds a cwraped C function taking 3 arguments and returning a plain
(non-struct) value.
inherited
dwrap4 <R > (String name )
→ WF4 <R >
Binds a cwraped C function taking 4 arguments and returning a plain
(non-struct) value.
inherited
dwrap5 <R > (String name )
→ WF5 <R >
Binds a cwraped C function taking 5 arguments and returning a plain
(non-struct) value.
inherited
dwrap6 <R > (String name )
→ WF6 <R >
Binds a cwraped C function taking 6 arguments and returning a plain
(non-struct) value.
inherited
dwrap7 <R > (String name )
→ WF7 <R >
Binds a cwraped C function taking 7 arguments and returning a plain
(non-struct) value.
inherited
dwrap8 <R > (String name )
→ WF8 <R >
Binds a cwraped C function taking 8 arguments and returning a plain
(non-struct) value.
inherited
dwrap9 <R > (String name )
→ WF9 <R >
Binds a cwraped C function taking 9 arguments and returning a plain
(non-struct) value.
inherited
load ()
→ void
Override to perform one-time module initialization.
inherited
logError (Object ? message )
→ void
inherited
logInfo (Object ? message )
→ void
inherited
logWarn (Object ? message )
→ void
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose (void fn () )
→ void
Registers fn to be called when this module is disposed.
inherited
pwrap0 <X extends RType > (String name )
→ WF0 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 0 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap1 <X extends RType > (String name )
→ WF1 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 1 argument and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap2 <X extends RType > (String name )
→ WF2 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 2 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap3 <X extends RType > (String name )
→ WF3 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 3 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap4 <X extends RType > (String name )
→ WF4 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 4 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap5 <X extends RType > (String name )
→ WF5 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 5 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap6 <X extends RType > (String name )
→ WF6 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 6 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap7 <X extends RType > (String name )
→ WF7 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 7 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap8 <X extends RType > (String name )
→ WF8 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 8 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap9 <X extends RType > (String name )
→ WF9 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 9 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
qwrap0 <X extends RaylibStruct <X > > (String name )
→ WF0 <StructPointer <X > >
Binds a cwraped C function taking 0 arguments and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap1 <X extends RaylibStruct <X > > (String name )
→ WF1 <StructPointer <X > >
Binds a cwraped C function taking 1 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap2 <X extends RaylibStruct <X > > (String name )
→ WF2 <StructPointer <X > >
Binds a cwraped C function taking 2 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap3 <X extends RaylibStruct <X > > (String name )
→ WF3 <StructPointer <X > >
Binds a cwraped C function taking 3 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap4 <X extends RaylibStruct <X > > (String name )
→ WF4 <StructPointer <X > >
Binds a cwraped C function taking 4 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap5 <X extends RaylibStruct <X > > (String name )
→ WF5 <StructPointer <X > >
Binds a cwraped C function taking 5 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap6 <X extends RaylibStruct <X > > (String name )
→ WF6 <StructPointer <X > >
Binds a cwraped C function taking 6 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap7 <X extends RaylibStruct <X > > (String name )
→ WF7 <StructPointer <X > >
Binds a cwraped C function taking 7 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap8 <X extends RaylibStruct <X > > (String name )
→ WF8 <StructPointer <X > >
Binds a cwraped C function taking 8 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap9 <X extends RaylibStruct <X > > (String name )
→ WF9 <StructPointer <X > >
Binds a cwraped C function taking 9 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
run <T > (String name (), T f () )
→ T
Executes f, logging its label (and optionally timing it) when debug is enabled
and the label passes all filters.
inherited
swrap0 (String name )
→ WF1 <void >
Binds a cwraped C function taking 0 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap1 (String name )
→ WF2 <void >
Binds a cwraped C function taking 1 argument that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap2 (String name )
→ WF3 <void >
Binds a cwraped C function taking 2 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap3 (String name )
→ WF4 <void >
Binds a cwraped C function taking 3 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap4 (String name )
→ WF5 <void >
Binds a cwraped C function taking 4 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap5 (String name )
→ WF6 <void >
Binds a cwraped C function taking 5 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap6 (String name )
→ WF7 <void >
Binds a cwraped C function taking 6 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap7 (String name )
→ WF8 <void >
Binds a cwraped C function taking 7 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap8 (String name )
→ WF9 <void >
Binds a cwraped C function taking 8 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
symbol <X extends RType > (String name )
→ WasmMemoryPointer <X >
Resolves a global symbol exported by the WASM module and wraps its
address as a WasmMemoryPointer .
inherited
toString ()
→ String
A string representation of this object.
inherited
raylib_dartified_web 6.0.0