RaylibVector3ExtFlat class

Inheritance

Constructors

RaylibVector3ExtFlat(Raylib rl)

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
rl → Raylib
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
load() → void
Override to perform one-time module initialization.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() → String
A string representation of this object.
inherited
Vector3Add(Vector3D v1, Vector3D v2) → Vector3D
Add two vectors
override
Vector3AddValue(Vector3D v, double add) → Vector3D
Add vector and double value
override
Vector3Angle(Vector3D v1, Vector3D v2) → double
Calculate angle between two vectors
override
Vector3Barycenter(Vector3D p, Vector3D a, Vector3D b, Vector3D c) → Vector3D
Compute barycenter coordinates (u, v, w) for point p with respect to triangle (a, b, c)
override
Vector3Clamp(Vector3D v, Vector3D min, Vector3D max) → Vector3D
Clamp the components of the vector between min and max values specified by the given vectors
override
Vector3ClampValue(Vector3D v, double min, double max) → Vector3D
Clamp the magnitude of the vector between two values
override
Vector3CrossProduct(Vector3D v1, Vector3D v2) → Vector3D
Calculate two vectors cross product
override
Vector3CubicHermite(Vector3D v1, Vector3D tangent1, Vector3D v2, Vector3D tangent2, double amount) → Vector3D
Calculate cubic hermite interpolation between two vectors and their tangents as described in the GLTF 2.0 specification: https://registry.khronos.org/glTF/specs/2.0/glTF-2.0.html#interpolation-cubic
override
Vector3Distance(Vector3D v1, Vector3D v2) → double
Calculate distance between two vectors
override
Vector3DistanceSqr(Vector3D v1, Vector3D v2) → double
Calculate square distance between two vectors
override
Vector3Divide(Vector3D v1, Vector3D v2) → Vector3D
Divide vector by vector
override
Vector3DotProduct(Vector3D v1, Vector3D v2) → double
Calculate two vectors dot product
override
Vector3Equals(Vector3D p, Vector3D q) → bool
Check whether two given vectors are almost equal
override
Vector3Invert(Vector3D v) → Vector3D
Invert the given vector
override
Vector3Length(Vector3D v) → double
Calculate vector length
override
Vector3LengthSqr(Vector3D v) → double
Calculate vector square length
override
Vector3Lerp(Vector3D v1, Vector3D v2, double amount) → Vector3D
Calculate linear interpolation between two vectors
override
Vector3Max(Vector3D v1, Vector3D v2) → Vector3D
Get max value for each pair of components
override
Vector3Min(Vector3D v1, Vector3D v2) → Vector3D
Get min value for each pair of components
override
Vector3MoveTowards(Vector3D v, Vector3D target, double maxDistance) → Vector3D
Move Vector towards target
override
Vector3Multiply(Vector3D v1, Vector3D v2) → Vector3D
Multiply vector by vector
override
Vector3Negate(Vector3D v) → Vector3D
Negate provided vector (invert direction)
override
Vector3Normalize(Vector3D v) → Vector3D
Normalize provided vector
override
Vector3One() → Vector3D
Vector with components value 1.0f
override
Vector3OrthoNormalize(StructPointer<Vector3D> v1, StructPointer<Vector3D> v2) → void
Orthonormalize provided vectors Makes vectors normalized and orthogonal to each other Gram-Schmidt function implementation
override
Vector3Perpendicular(Vector3D v) → Vector3D
Calculate one vector perpendicular vector
override
Vector3Project(Vector3D v1, Vector3D v2) → Vector3D
Calculate the projection of the vector v1 on to v2
override
Vector3Reflect(Vector3D v, Vector3D normal) → Vector3D
Calculate reflected vector to normal
override
Vector3Refract(Vector3D v, Vector3D n, double r) → Vector3D
Compute the direction of a refracted ray v: normalized direction of the incoming ray n: normalized normal vector of the interface of two optical media r: ratio of the refractive index of the medium from where the ray comes to the refractive index of the medium on the other side of the surface
override
Vector3Reject(Vector3D v1, Vector3D v2) → Vector3D
Calculate the rejection of the vector v1 on to v2
override
Vector3RotateByAxisAngle(Vector3D v, Vector3D axis, double angle) → Vector3D
Rotates a vector around an axis
override
Vector3RotateByQuaternion(Vector3D v, QuaternionD q) → Vector3D
Transform a vector by quaternion rotation
override
Vector3Scale(Vector3D v, double scalar) → Vector3D
Multiply vector by scalar
override
Vector3Subtract(Vector3D v1, Vector3D v2) → Vector3D
Subtract two vectors
override
Vector3SubtractValue(Vector3D v, double sub) → Vector3D
Subtract vector by double value
override
Vector3ToFloatV(Vector3D v) → float3D
Get Vector3 as float array
override
Vector3Transform(Vector3D v, MatrixD mat) → Vector3D
Transforms a Vector3 by a given Matrix
override
Vector3Unproject(Vector3D source, MatrixD projection, MatrixD view) → Vector3D
Projects a Vector3 from screen space into object space
override
Vector3Zero() → Vector3D
Vector with components value 0.0f
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited