setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
RectangleD setD(RectangleD o) {
return set(o.x, o.y, o.width, o.height);
}
Copies the fields of o into this instance and returns this.
@override
RectangleD setD(RectangleD o) {
return set(o.x, o.y, o.width, o.height);
}