copy method
Returns a deep copy of this instance without originalPointer.
Useful when you need an independent value that should not accidentally sync back into raylib-owned memory.
Implementation
@override
D copy() => clone();
Returns a deep copy of this instance without originalPointer.
Useful when you need an independent value that should not accidentally sync back into raylib-owned memory.
@override
D copy() => clone();