structAllocateInto method
Allocates nested pointers into temp under key as needed.
Implementation
@override
void structAllocateInto(RaylibTemp temp, WasmStructPointer<T> p, String key) {}
Allocates nested pointers into temp under key as needed.
@override
void structAllocateInto(RaylibTemp temp, WasmStructPointer<T> p, String key) {}