WasmBoolPointer class

Inheritance

Constructors

WasmBoolPointer(int address)
WasmBoolPointer.nullptr()
factory

Properties

address int
finalinherited
byteSize int
finalinherited
defaultValue bool
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isNotNull bool
no setterinherited
isNull bool
no setterinherited
ref bool
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSNumber
no setterinherited
value bool
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(int index) int
inherited
readArray(int count) List<bool>
inherited
readerAt([int offset = 0]) WasmReader
inherited
toString() String
A string representation of this object.
inherited
writeArray(List<bool> array) → void
inherited
writerAt([int offset = 0]) WasmWriter
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) bool
override
operator []=(int index, bool v) → void
override