WasmFloat64Pointer class

Inheritance

Constructors

WasmFloat64Pointer(int address)
WasmFloat64Pointer.nullptr()
factory

Properties

address int
finalinherited
byteSize int
finalinherited
defaultFunc double Function()
finalinherited
defaultValue double
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isNotNull bool
no setterinherited
isNull bool
no setterinherited
readerFunc double Function(WasmReader reader)
finalinherited
ref double
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSNumber
no setterinherited
typedHeap Float64List
no setteroverride
value double
getter/setter pairinherited
writerFunc → void Function(WasmWriter writer, double value)
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(int index) int
inherited
readArray(int count) List<double>
inherited
readerAt([int offset = 0]) WasmReader
inherited
readTypedArray(int count) Float64List
override
setAll(List<double> values) → void
inherited
toString() String
A string representation of this object.
inherited
view(int length) Float64List
override
writeArray(List<double> array) → void
inherited
writerAt([int offset = 0]) WasmWriter
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) double
inherited
operator []=(int index, double v) → void
inherited