WasmInt32Pointer class

Inheritance

Constructors

WasmInt32Pointer(int address)
WasmInt32Pointer.nullptr()
factory

Properties

address int
finalinherited
byteSize int
finalinherited
defaultFunc int Function()
finalinherited
defaultValue int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isNotNull bool
no setterinherited
isNull bool
no setterinherited
readerFunc int Function(WasmReader reader)
finalinherited
ref int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSNumber
no setterinherited
typedHeap Int32List
no setteroverride
value int
getter/setter pairinherited
writerFunc → void Function(WasmWriter writer, int value)
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(int index) int
inherited
readArray(int count) List<int>
inherited
readerAt([int offset = 0]) WasmReader
inherited
readTypedArray(int count) Int32List
override
setAll(List<int> values) → void
inherited
toString() String
A string representation of this object.
inherited
view(int length) Int32List
override
writeArray(List<int> array) → void
inherited
writerAt([int offset = 0]) WasmWriter
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) int
inherited
operator []=(int index, int v) → void
inherited