rawArrayFunc property
Converts a flat List<X> into an allocated P array.
The caller is responsible for the lifetime of the inner pointers.
Implementation
@override
final WasmSizedPointer<X> Function(List<X> array) rawArrayFunc;
Converts a flat List<X> into an allocated P array.
The caller is responsible for the lifetime of the inner pointers.
@override
final WasmSizedPointer<X> Function(List<X> array) rawArrayFunc;