WasmPointer<T> class abstract

Implementers

Constructors

WasmPointer(int address)

Properties

address int
final
hashCode int
The hash code for this object.
no setterinherited
isNotNull bool
no setter
isNull bool
no setter
ref ↔ T
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSNumber
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readerAt([int offset = 0]) WasmReader
toString() String
A string representation of this object.
inherited
writerAt([int offset = 0]) WasmWriter

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) → T
operator []=(int index, T v) → void