WasmStringPointer class
- Inheritance
-
- Object
- WasmPointer<
String> - WasmSizedPointer<
String> - WasmStringPointer
Constructors
- WasmStringPointer(int address)
- WasmStringPointer.nullptr()
-
factory
Properties
- address → int
-
finalinherited
- byteSize → int
-
finalinherited
- defaultValue → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotNull → bool
-
no setterinherited
- isNull → bool
-
no setterinherited
- ref ↔ String
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toJS → JSNumber
-
no setterinherited
- value ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offset(
int index) → int -
inherited
-
readArray(
int count) → List< String> -
inherited
-
readerAt(
[int offset = 0]) → WasmReader -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeArray(
List< String> array) → void -
inherited
-
writerAt(
[int offset = 0]) → WasmWriter -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → String -
override
-
operator []=(
int index, String v) → void -
override