WasmStringPointerPointer class

Inheritance

Properties

address int
finalinherited
byteSize int
finalinherited
defaultValue WasmStringPointer
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isNotNull bool
no setterinherited
isNull bool
no setterinherited
ref WasmStringPointer
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSNumber
no setterinherited
value WasmStringPointer
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(int index) int
inherited
readArray(int count) List<WasmStringPointer>
inherited
readerAt([int offset = 0]) WasmReader
inherited
readStrings(int count) List<String>
toString() String
A string representation of this object.
inherited
writeArray(List<WasmStringPointer> array) → void
inherited
writerAt([int offset = 0]) WasmWriter
inherited
writeStrings(List<String> strings) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) WasmStringPointer
override
operator []=(int index, WasmStringPointer v) → void
override