indexSetterFunc property
Overwrites the i-th element of the array at ptr with value.
Implementation
@override
late final void Function(WasmStructPointer<T> ptr, int i, T value) indexSetterFunc;
Overwrites the i-th element of the array at ptr with value.
@override
late final void Function(WasmStructPointer<T> ptr, int i, T value) indexSetterFunc;