indexerFunc property
Returns the C struct at index i of the array at ptr.
Implementation
@override
late final T Function(WasmStructPointer<T> ptr, int i) indexerFunc;
Returns the C struct at index i of the array at ptr.
@override
late final T Function(WasmStructPointer<T> ptr, int i) indexerFunc;