pointerToStruct property
Converts a P to its Dart-side X wrapper, referencing the memory at that pointer.
Implementation
@override
late final T Function(WasmStructPointer<T> ptr) pointerToStruct;
Converts a P to its Dart-side X wrapper, referencing the memory at that pointer.
@override
late final T Function(WasmStructPointer<T> ptr) pointerToStruct;