setCFunc property
Copies the raw C struct value into the i-th element of the array at ptr.
Implementation
@override
late final void Function(WasmStructPointer<T> ptr, int i, T value) setCFunc;
Copies the raw C struct value into the i-th element of the array at ptr.
@override
late final void Function(WasmStructPointer<T> ptr, int i, T value) setCFunc;