updateFunc property
Copies the fields of source into the native memory at ptr.
Implementation
@override
late final void Function(WasmStructPointer<T> ptr, T source) updateFunc;
Copies the fields of source into the native memory at ptr.
@override
late final void Function(WasmStructPointer<T> ptr, T source) updateFunc;