writeIntoFunc property
Writes the Dart value value into the struct at ptr.
Implementation
@override
late final void Function(WasmStructPointer<T> ptr, T value) writeIntoFunc;
Writes the Dart value value into the struct at ptr.
@override
late final void Function(WasmStructPointer<T> ptr, T value) writeIntoFunc;