GuiDropdownBoxProperty enum

GuiDropdownBoxProperty

DropdownBox

Inheritance
Mixed-in types
Available extensions

Values

ARROW_PADDING → const GuiDropdownBoxProperty

ARROW_PADDING

DropdownBox arrow separation from border and items

const GuiDropdownBoxProperty(16)

DROPDOWN_ITEMS_SPACING

DropdownBox items separation

const GuiDropdownBoxProperty(17)

DROPDOWN_ARROW_HIDDEN

DropdownBox arrow hidden

const GuiDropdownBoxProperty(18)

DROPDOWN_ROLL_UP

DropdownBox roll up flag: 0-Roll down, 1-Roll up

const GuiDropdownBoxProperty(19)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → GuiDropdownBoxProperty
Returns the GuiDropdownBoxProperty for the given native value.

Constants

values → const List<GuiDropdownBoxProperty>
A constant List of the values in this enum, in order of their declaration.