GuiToggleProperty enum

GuiToggleProperty

Toggle/ToggleGroup

Inheritance
Mixed-in types
Available extensions

Values

GROUP_PADDING → const GuiToggleProperty

GROUP_PADDING

ToggleGroup separation between toggles

const GuiToggleProperty(16)
GROUP_WIDTH_FULL → const GuiToggleProperty

GROUP_WIDTH_FULL

ToggleGroup bounds width considers all items: 0-Width per item, 1-Full width

const GuiToggleProperty(17)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → GuiToggleProperty
Returns the GuiToggleProperty for the given native value.

Constants

values → const List<GuiToggleProperty>
A constant List of the values in this enum, in order of their declaration.