MaterialMapIndex enum

Raylib MaterialMapIndex enum.

Inheritance
Available extensions

Values

MATERIAL_MAP_ALBEDO → const MaterialMapIndex

MATERIAL_MAP_ALBEDO

const MaterialMapIndex(0)
MATERIAL_MAP_METALNESS → const MaterialMapIndex

MATERIAL_MAP_METALNESS

const MaterialMapIndex(1)
MATERIAL_MAP_NORMAL → const MaterialMapIndex

MATERIAL_MAP_NORMAL

const MaterialMapIndex(2)
MATERIAL_MAP_ROUGHNESS → const MaterialMapIndex

MATERIAL_MAP_ROUGHNESS

const MaterialMapIndex(3)
MATERIAL_MAP_OCCLUSION → const MaterialMapIndex

MATERIAL_MAP_OCCLUSION

const MaterialMapIndex(4)
MATERIAL_MAP_EMISSION → const MaterialMapIndex

MATERIAL_MAP_EMISSION

const MaterialMapIndex(5)
MATERIAL_MAP_HEIGHT → const MaterialMapIndex

MATERIAL_MAP_HEIGHT

const MaterialMapIndex(6)
MATERIAL_MAP_CUBEMAP → const MaterialMapIndex

MATERIAL_MAP_CUBEMAP

const MaterialMapIndex(7)
MATERIAL_MAP_IRRADIANCE → const MaterialMapIndex

MATERIAL_MAP_IRRADIANCE

const MaterialMapIndex(8)
MATERIAL_MAP_PREFILTER → const MaterialMapIndex

MATERIAL_MAP_PREFILTER

const MaterialMapIndex(9)
MATERIAL_MAP_BRDF → const MaterialMapIndex

MATERIAL_MAP_BRDF

const MaterialMapIndex(10)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) MaterialMapIndex
Returns the MaterialMapIndex for the given native value.

Constants

values → const List<MaterialMapIndex>
A constant List of the values in this enum, in order of their declaration.