MatrixField enum

Inheritance
Mixed-in types
Available extensions

Values

m0 → const MatrixField
m4 → const MatrixField
m8 → const MatrixField
m12 → const MatrixField
m1 → const MatrixField
m5 → const MatrixField
m9 → const MatrixField
m13 → const MatrixField
m2 → const MatrixField
m6 → const MatrixField
m10 → const MatrixField
m14 → const MatrixField
m3 → const MatrixField
m7 → const MatrixField
m11 → const MatrixField
m15 → const MatrixField

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MatrixField>
A constant List of the values in this enum, in order of their declaration.