RSize class final
Unsigned pointer-sized integer. Maps to C size_t.
- Inheritance
- Mixed-in types
Constructors
- RSize()
-
const
Properties
- alignment → int
-
Natural alignment for this field, per C rules,
arrays align to their element size, not their total size.
no setterinherited
- byteSize → int
-
Size of a single element.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
V> (MemoryPointer< RType> p, int offset) → V? -
Read this RType from a
pat givenoffset.override -
toString(
) → String -
A string representation of this object.
inherited
-
write<
V> (MemoryPointer< RType> p, int offset, V? value) → void -
Write a
valueof RType into apat givenoffset.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited