maxStructByteSize property

int maxStructByteSize
getter/setter pair

Maximum size, in bytes, of a struct supported by internal scratch buffers.

These buffers are used for fast byte-level equality checks of structs. Increase this if a struct larger than the default limit needs to be compared using ==.

Implementation

static int maxStructByteSize = 1024;