LoadRandomSequence abstract method
Load random values sequence, no values repeated, min and max included
Implementation
MemoryPointer<RInt> LoadRandomSequence(
int count,
int min,
int max,
);
Load random values sequence, no values repeated, min and max included
MemoryPointer<RInt> LoadRandomSequence(
int count,
int min,
int max,
);