RaylibCoreModuleCaptureIds class

Produces stable slot key strings identifying the allocation origin of each Core module function's captured Struct.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

GenImageCellular(num width, num height, num tileSize) String
Capture ID for RaylibCoreModuleBase.GenImageCellular.
GenImageChecked(num width, num height, num checksX, num checksY, ColorBase<ColorBase> col1, ColorBase<ColorBase> col2) String
Capture ID for RaylibCoreModuleBase.GenImageChecked.
GenImageColor(num width, num height, ColorBase<ColorBase> color) String
Capture ID for RaylibCoreModuleBase.GenImageColor.
GenImageFontAtlas(List<GlyphInfoBase<GlyphInfoBase<dynamic, ImageBase>, ImageBase>> glyphs, num fontSize, num padding, num packMethod) String
Capture ID for RaylibCoreModuleBase.GenImageFontAtlas.
GenImageGradientLinear(num width, num height, num direction, ColorBase<ColorBase> start, ColorBase<ColorBase> end) String
Capture ID for RaylibCoreModuleBase.GenImageGradientLinear.
GenImageGradientRadial(num width, num height, num density, ColorBase<ColorBase> inner, ColorBase<ColorBase> outer) String
Capture ID for RaylibCoreModuleBase.GenImageGradientRadial.
GenImageGradientSquare(num width, num height, num density, ColorBase<ColorBase> inner, ColorBase<ColorBase> outer) String
Capture ID for RaylibCoreModuleBase.GenImageGradientSquare.
GenImagePerlinNoise(num width, num height, num offsetX, num offsetY, num scale) String
Capture ID for RaylibCoreModuleBase.GenImagePerlinNoise.
GenImageText(num width, num height, String text) String
Capture ID for RaylibCoreModuleBase.GenImageText.
GenImageWhiteNoise(num width, num height, num factor) String
Capture ID for RaylibCoreModuleBase.GenImageWhiteNoise.
GenMeshCone(num radius, num height, num slices) String
Capture ID for RaylibCoreModuleBase.GenMeshCone.
GenMeshCube(num width, num height, num length) String
Capture ID for RaylibCoreModuleBase.GenMeshCube.
GenMeshCubicmap(ImageBase<ImageBase> cubicmap, Vector3Base<Vector3Base, MatrixBase, QuaternionBase, Vector4Base> cubeSize) String
Capture ID for RaylibCoreModuleBase.GenMeshCubicmap.
GenMeshCylinder(num radius, num height, num slices) String
Capture ID for RaylibCoreModuleBase.GenMeshCylinder.
GenMeshHeightmap(ImageBase<ImageBase> heightmap, Vector3Base<Vector3Base, MatrixBase, QuaternionBase, Vector4Base> size) String
Capture ID for RaylibCoreModuleBase.GenMeshHeightmap.
GenMeshHemiSphere(num radius, num rings, num slices) String
Capture ID for RaylibCoreModuleBase.GenMeshHemiSphere.
GenMeshKnot(num radius, num size, num radSeg, num sides) String
Capture ID for RaylibCoreModuleBase.GenMeshKnot.
GenMeshPlane(num width, num length, num resX, num resZ) String
Capture ID for RaylibCoreModuleBase.GenMeshPlane.
GenMeshPoly(num sides, num radius) String
Capture ID for RaylibCoreModuleBase.GenMeshPoly.
GenMeshSphere(num radius, num rings, num slices) String
Capture ID for RaylibCoreModuleBase.GenMeshSphere.
GenMeshTorus(num radius, num size, num radSeg, num sides) String
Capture ID for RaylibCoreModuleBase.GenMeshTorus.
GetClipboardImage() String
Capture ID for RaylibCoreModuleBase.GetClipboardImage.
GetFontDefault() String
Capture ID for RaylibCoreModuleBase.GetFontDefault.
ImageCopy(ImageBase<ImageBase> image) String
Capture ID for RaylibCoreModuleBase.ImageCopy.
ImageFromChannel(ImageBase<ImageBase> image, num selectedChannel) String
Capture ID for RaylibCoreModuleBase.ImageFromChannel.
ImageFromImage(ImageBase<ImageBase> image, RectangleBase<RectangleBase> rec) String
Capture ID for RaylibCoreModuleBase.ImageFromImage.
ImageText(String text, num fontSize, ColorBase<ColorBase> color) String
Capture ID for RaylibCoreModuleBase.ImageText.
ImageTextEx(FontBase<FontBase<dynamic, TextureBase, RectangleBase, GlyphInfoBase<dynamic, ImageBase>, ImageBase>, TextureBase, RectangleBase, GlyphInfoBase<dynamic, ImageBase>, ImageBase> font, String text, num fontSize, num spacing, ColorBase<ColorBase> tint) String
Capture ID for RaylibCoreModuleBase.ImageTextEx.
LoadAutomationEventList(String? fileName) String
Capture ID for RaylibCoreModuleBase.LoadAutomationEventList.
LoadDirectoryFiles(String dirPath) String
Capture ID for RaylibCoreModuleBase.LoadDirectoryFiles.
LoadDirectoryFilesEx(String basePath, String filter, bool scanSubdirs) String
Capture ID for RaylibCoreModuleBase.LoadDirectoryFilesEx.
LoadDroppedFiles() String
Capture ID for RaylibCoreModuleBase.LoadDroppedFiles.
LoadFont(String fileName) String
Capture ID for RaylibCoreModuleBase.LoadFont.
LoadFontEx(String fileName, num fontSize, [Int32List? codepoints, num? codePointCount]) String
Capture ID for RaylibCoreModuleBase.LoadFontEx.
LoadFontFromImage(ImageBase<ImageBase> image, ColorBase<ColorBase> key, num firstChar) String
Capture ID for RaylibCoreModuleBase.LoadFontFromImage.
LoadFontFromMemory(String fileType, Uint8List fileData, num fontSize, Int32List codepoints) String
Capture ID for RaylibCoreModuleBase.LoadFontFromMemory.
LoadImage(String fileName) String
Capture ID for RaylibCoreModuleBase.LoadImage.
LoadImageAnim(String fileName) String
Capture ID for RaylibCoreModuleBase.LoadImageAnim.
LoadImageAnimFromMemory(String fileType, Uint8List fileData) String
Capture ID for RaylibCoreModuleBase.LoadImageAnimFromMemory.
LoadImageFromMemory(String fileType, Uint8List fileData) String
Capture ID for RaylibCoreModuleBase.LoadImageFromMemory.
LoadImageFromScreen() String
Capture ID for RaylibCoreModuleBase.LoadImageFromScreen.
LoadImageFromTexture(TextureBase<TextureBase> texture) String
Capture ID for RaylibCoreModuleBase.LoadImageFromTexture.
LoadImageRaw(String fileName, num width, num height, PixelFormat format, num headerSize) String
Capture ID for RaylibCoreModuleBase.LoadImageRaw.
LoadMaterialDefault() String
Capture ID for RaylibCoreModuleBase.LoadMaterialDefault.
LoadModel(String fileName) String
Capture ID for RaylibCoreModuleBase.LoadModel.
LoadModelFromMesh(MeshBase<MeshBase<dynamic, MatrixBase, Vector3Base, QuaternionBase, Vector4Base>, MatrixBase, Vector3Base, QuaternionBase, Vector4Base> mesh) String
Capture ID for RaylibCoreModuleBase.LoadModelFromMesh.
LoadRenderTexture(num width, num height) String
Capture ID for RaylibCoreModuleBase.LoadRenderTexture.
LoadShader(String? vsFileName, String? fsFileName) String
Capture ID for RaylibCoreModuleBase.LoadShader.
LoadShaderFromMemory(String? vsCode, String? fsCode) String
Capture ID for RaylibCoreModuleBase.LoadShaderFromMemory.
LoadTexture(String fileName) String
Capture ID for RaylibCoreModuleBase.LoadTexture.
LoadTextureCubemap(ImageBase<ImageBase> image, CubemapLayout layout) String
Capture ID for RaylibCoreModuleBase.LoadTextureCubemap.
LoadTextureFromImage(ImageBase<ImageBase> image) String
Capture ID for RaylibCoreModuleBase.LoadTextureFromImage.
LoadVrStereoConfig(VrDeviceInfoBase<VrDeviceInfoBase> device) String
Capture ID for RaylibCoreModuleBase.LoadVrStereoConfig.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited