Slot method
Returns the pointer stored under key, or null if the slot does not
exist. Does not allocate.
Implementation
MemoryPointer<R>? Slot(String key) => slots[key]?.$1;
Returns the pointer stored under key, or null if the slot does not
exist. Does not allocate.
MemoryPointer<R>? Slot(String key) => slots[key]?.$1;