RawPtr method
Returns the pointer of pointers.
The caller is responsible for freeing the returned pointer.
Implementation
MemoryPointer<RPointer<RChar>> RawPtr(int count) => _allocatePointer(count);
Returns the pointer of pointers.
The caller is responsible for freeing the returned pointer.
MemoryPointer<RPointer<RChar>> RawPtr(int count) => _allocatePointer(count);