allocKey property
The RaylibTempBase slot key used during the most recent RaylibTempStructAllocatorBase.PointerTo allocation.
Implementation
String? allocKey;
The RaylibTempBase slot key used during the most recent RaylibTempStructAllocatorBase.PointerTo allocation.
String? allocKey;