RaylibTempUtils class

Constructors

RaylibTempUtils(RaylibTemp<RaylibBase> temp)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temp → RaylibTemp<RaylibBase>
final

Methods

memcmp(MemoryPointer<RType> a, MemoryPointer<RType> b, int n) → int
memcpy(MemoryPointer<RType> dest, MemoryPointer<RType> src, int n) → void
memset(MemoryPointer<RType> ptr, int value, int size) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
realloc(MemoryPointer<RType> oldPtr, int oldSize, int newSize) → MemoryPointer<RVoid>
strcmp(MemoryPointer<RType> a, MemoryPointer<RType> b) → int
strcpy(MemoryPointer<RType> dest, MemoryPointer<RType> src) → void
strlen(MemoryPointer<RType> ptr) → int
strncat(MemoryPointer<RType> dest, MemoryPointer<RType> src, int n) → void
strncpy(MemoryPointer<RType> dest, MemoryPointer<RType> src, int n) → void
strnlen(MemoryPointer<RType> ptr, int maxLen) → int
strstr(MemoryPointer<RType> haystack, MemoryPointer<RType> needle) → MemoryPointer<RVoid>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited