struct property
Describes the raw memory layout, construction, and pointer representation of this struct type.
Implementation
static final StructType<RlDrawCallD> struct = .new(
factory: RlDrawCallD.new,
layout: .aligned<RlDrawCallField>({
.mode: RInt(), // Drawing mode: LINES, TRIANGLES, QUADS
.vertexCount: RInt(), // Number of vertex of the draw
.vertexAlignment: RInt(), // Number of vertex required for index alignment (LINES, TRIANGLES)
.textureId: RUnsignedInt(), // Texture id to be used on the draw -> Use to create new draw call if changes
}),
);