StructPointerValueField<E, R extends RType> class
A pointer-to-single-value field. Holds a PointerCodec concretely, no
casting, since a pointer field's on-struct type genuinely differs from
StructValueField's R slot (it's RPointer<R>, not R).
- Inheritance
-
- Object
- StructFieldBase<
E> - StructPointerValueField
- Available extensions
Constructors
-
StructPointerValueField(int offset, PointerCodec<
E, R> codec) -
const
Properties
-
codec
→ PointerCodec<
E, R> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allocate(
RaylibTemp< RaylibBase> temp, MemoryPointer<RType> p, String key, {int count = 1, bool raw = false}) → void -
override
-
live(
MemoryPointer< RType> ? ptrOf(), List<E> initial) → StructLiveList<E, R> -
Available on StructPointerValueField<
List< , provided by the LivePointerFixedArrayFieldX extensionE> , RArray<R> > -
live(
MemoryPointer< RType> ? ptrOf()) → LivePointerSync<R> -
Available on StructPointerValueField<
E, R> , provided by the LivePointerSyncFieldX extension -
live(
MemoryPointer< RType> ? ptrOf()) → LivePointerSync<R> -
Available on StructPointerValueField<
dynamic, R> , provided by the LivePointerUnknownSyncFieldX extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
MemoryPointer< RType> p) → E -
override
-
readOr(
MemoryPointer< RType> ? p, E fallback) → E -
inherited
-
readSafe(
MemoryPointer< RType> p, E fallback) → E -
toString(
) → String -
A string representation of this object.
inherited
-
write(
MemoryPointer< RType> p, E value) → E -
override
-
writeOr(
MemoryPointer< RType> ? p, E value) → E -
inherited
-
writeSafe(
MemoryPointer< RType> p, E value) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited