StructStringValueField<R extends RTypeIntLike> class

A pointer-or-array-to-string-value field. Holds a StringCodec concretely.

Inheritance

Constructors

StructStringValueField(int offset, StringCodec<R> codec)
const

Properties

codec → StringCodec<R>
final
hashCode → int
The hash code for this object.
no setterinherited
offset → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocate(RaylibTemp<RaylibBase> temp, MemoryPointer<RType> p, String key, {int count = 1, bool raw = false}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(MemoryPointer<RType> p) → String
override
readBounded(MemoryPointer<RType> p, int maxLength) → String
readOr(MemoryPointer<RType>? p, String fallback) → String
inherited
toString() → String
A string representation of this object.
inherited
write(MemoryPointer<RType> p, String value) → String
override
writeOr(MemoryPointer<RType>? p, String value) → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited