JSConsole class

Available extensions
Annotations

Constructors

JSConsole()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

error(Object? value) → void

Available on JSConsole, provided by the JSConsoleExtension extension

log(Object? value) → void

Available on JSConsole, provided by the JSConsoleExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
warn(Object? value) → void

Available on JSConsole, provided by the JSConsoleExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited