LightD class
- Inheritance
- Mixed-in types
Constructors
-
LightD({WasmStructPointer<
LightD> ? originalPointer, LightType type = .LIGHT_POINT, bool enabled = false, Vector3D? position, Vector3D? target, ColorD? color, double attenuation = 0, int enabledLoc = 0, int typeLoc = 0, int positionLoc = 0, int targetLoc = 0, int colorLoc = 0, int attenuationLoc = 0}) - LightD.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
- attenuation ↔ double
-
getter/setter pairoverride
- attenuationLoc ↔ int
-
getter/setter pairoverride
- color ↔ ColorD
-
getter/setter pairoverride
- colorLoc ↔ int
-
getter/setter pairoverride
- enabled ↔ bool
-
getter/setter pairoverride
- enabledLoc ↔ int
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
originalPointer
↔ WasmStructPointer<
LightD> ? -
The C-owned or RaylibTemp-owned native pointer for this struct, if any.
getter/setter pairinherited
- position ↔ Vector3D
-
getter/setter pairoverride
- positionLoc ↔ int
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- structRequiresOriginalPointer → bool
-
Whether this struct requires an originalPointer to function correctly.
no setterinherited
- target ↔ Vector3D
-
getter/setter pairoverride
- targetLoc ↔ int
-
getter/setter pairoverride
- type ↔ LightType
-
getter/setter pairoverride
- typeLoc ↔ int
-
getter/setter pairoverride
- wasmByteSize → int
-
no setteroverride
Methods
-
clone(
) → LightD -
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
override
-
copy(
) → LightD -
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
-
getOriginalPointer(
) → WasmStructPointer< LightD> -
Returns originalPointer, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOriginalPointerAndDispose(
) → WasmStructPointer< LightD> -
Returns originalPointer and immediately calls structMarkDisposed.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setD(
LightD o) → LightD -
Copies the fields of
ointo this instance and returnsthis.override -
signature(
) → String -
Returns a human-readable representation of this struct's current field values.
inherited
-
structAllocateInto(
RaylibTemp temp, WasmStructPointer< LightD> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.inherited -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears originalPointer.
inherited
-
structOnOp(
void callback(WasmStructPointer< LightD> p)) → void -
Calls
callbackwith originalPointer if it is set, otherwise no-ops.inherited -
structReadFrom(
WasmStructPointer< LightD> p) → void -
Reads all fields from the memory at
p.inherited -
structSetTag(
String newTag) → LightD -
Sets RaylibTempStructState.tag to
newTagand returnsthisfor chaining.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires originalPointer.
inherited
-
structSyncInto(
RaylibTemp temp, WasmStructPointer< LightD> p, String key) → void -
Syncs Dart-side fields into the already-allocated native pointer
p. Defaults to structWriteInto.inherited -
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires originalPointer.
inherited
-
structWriteInto(
WasmStructPointer< LightD> p) → void -
Writes all fields into the memory at
p.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
wasmReader(
[int? offset]) → WasmReader -
inherited
-
wasmReaderOr(
int address) → WasmReader -
inherited
-
wasmReadFrom(
WasmReader reader) → void -
override
-
wasmWriteInto(
WasmWriter writer) → void -
override
-
wasmWriter(
[int? offset]) → WasmWriter -
inherited
-
wasmWriterOr(
int address) → WasmReader -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
wasmPointer(
int ptr) → WasmStructPointer< LightD> -
wasmPointerPointer(
int ptr) → WasmStructPointerPointer< LightD>