Raylib class

Inheritance

Constructors

Raylib(void dartMain(Raylib), {RaylibTempBaseOptions? tempOptions, Random? random})

Properties

Audio RaylibAudio
getter/setter pair
AudioD RaylibAudioD
See RaylibAudioModuleBase.
getter/setter pairoverride-getter
Camera RaylibCamera
getter/setter pair
CameraD RaylibCameraD
See RaylibCameraModuleBase.
getter/setter pairoverride-getter
Color RaylibColors
See RaylibColorExtensionBase.
getter/setter pairoverride-getter
Core RaylibCore
getter/setter pair
CoreD RaylibCoreD
See RaylibCoreModuleBase.
getter/setter pairoverride-getter
DEG2RAD double
See RaylibConstants.DEG2RAD.
finalinherited
Ease RaylibEasings
See RaylibEaseExtensionBase.
getter/setter pairoverride-getter
EPSILON double
See RaylibConstants.EPSILON.
finalinherited
Gui RaylibGui
getter/setter pair
GuiD RaylibGuiD
See RaylibGuiModuleBase.
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setterinherited
LightD RaylibLightD
See RaylibLightModuleBase.
getter/setter pairoverride-getter
M_1_PI double
See RaylibConstants.M_1_PI.
finalinherited
M_2_PI double
See RaylibConstants.M_2_PI.
finalinherited
M_2_SQRTPI double
See RaylibConstants.M_2_SQRTPI.
finalinherited
M_E double
See RaylibConstants.M_E.
finalinherited
M_LN10 double
See RaylibConstants.M_LN10.
finalinherited
M_LN2 double
See RaylibConstants.M_LN2.
finalinherited
M_LOG10E double
See RaylibConstants.M_LOG10E.
finalinherited
M_LOG2E double
See RaylibConstants.M_LOG2E.
finalinherited
M_PI double
See RaylibConstants.M_PI.
finalinherited
M_PI_2 double
See RaylibConstants.M_PI_2.
finalinherited
M_PI_4 double
See RaylibConstants.M_PI_4.
finalinherited
M_SQRT1_2 double
See RaylibConstants.M_SQRT1_2.
finalinherited
M_SQRT2 double
See RaylibConstants.M_SQRT2.
finalinherited
MATERIAL_MAP_DIFFUSE MaterialMapIndex
See RaylibConstants.MATERIAL_MAP_DIFFUSE.
finalinherited
MATERIAL_MAP_SPECULAR MaterialMapIndex
See RaylibConstants.MATERIAL_MAP_SPECULAR.
finalinherited
Matrix RaylibMatrices
See RaylibMatrixExtensionBase.
getter/setter pairoverride-getter
MAX_MATERIAL_MAPS int
See RaylibConstants.MAX_MATERIAL_MAPS.
finalinherited
PI double
See RaylibConstants.PI.
finalinherited
Quat RaylibQuaternions
See RaylibQuaternionExtensionBase.
getter/setter pairoverride-getter
RAD2DEG double
See RaylibConstants.RAD2DEG.
finalinherited
RAND_MAX int
See RaylibConstants.RAND_MAX.
finalinherited
random Random
Random number generator used by rand and randC.
getter/setter pairinherited
RAYLIB_VERSION String
See RaylibConstants.RAYLIB_VERSION.
finalinherited
RAYLIB_VERSION_MAJOR int
See RaylibConstants.RAYLIB_VERSION_MAJOR.
finalinherited
RAYLIB_VERSION_MINOR int
See RaylibConstants.RAYLIB_VERSION_MINOR.
finalinherited
RAYLIB_VERSION_PATCH int
See RaylibConstants.RAYLIB_VERSION_PATCH.
finalinherited
registeredModules List<RaylibModule<RaylibBase>>
All currently registered modules.
no setterinherited
Rlgl RaylibRlgl
getter/setter pair
RlglD RaylibRlglD
See RaylibRlglModuleBase.
getter/setter pairoverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SHADER_LOC_MAP_DIFFUSE int
See RaylibConstants.SHADER_LOC_MAP_DIFFUSE.
finalinherited
SHADER_LOC_MAP_SPECULAR int
See RaylibConstants.SHADER_LOC_MAP_SPECULAR.
finalinherited
Temp RaylibTemp
See RaylibTempBase.
getter/setter pairoverride-getter
tempOptions RaylibTempBaseOptions
finalinherited
Utils RaylibUtils
See RaylibUtilsModuleBase.
getter/setter pairoverride-getter
Vector RaylibVectors
See RaylibVectorExtensionBase.
getter/setter pairoverride-getter

Methods

cancelMainLoop() → void
Clamp(num value, num min, num max) double
See RaylibFunctions.Clamp.
inherited
debugEverything(bool debug) → void
Enables or disables debug logging across all modules and the temp allocator.
inherited
dispose() → void
Disposes all registered modules.
inherited
FloatEquals(double x, double y) bool
See RaylibFunctions.FloatEquals.
inherited
Lerp(num start, num end, num amount) double
See RaylibFunctions.Lerp.
inherited
logError(Object? message) → void
Logs a message at the error level.
override
logInfo(Object? message) → void
Logs a message at the info level.
override
logWarn(Object? message) → void
Logs a message at the warn level.
override
module<T extends RaylibModule<RaylibBase>>() → T
Returns the registered module of type T. Throws if not registered.
inherited
Normalize(num value, num start, num end) double
See RaylibFunctions.Normalize.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rand() double
Returns a random double in [0.0, 1.0).
inherited
randC() double
Returns a random double in [0.0, RAND_MAX), mirroring C's rand() range.
inherited
registerModule<T extends RaylibModule<RaylibBase>>(T module) → T
Registers module, calls RaylibModule.doLoad on it, and returns it. Throws StateError if a module of the same type is already registered.
inherited
Remap(num value, num inputStart, num inputEnd, num outputStart, num outputEnd) double
See RaylibFunctions.Remap.
inherited
setMainLoop(void loop()) → void
timeIt<T>(String label, T fn()) → T
Executes fn, logs its elapsed time under label, and rethrows any exception with timing info attached.
inherited
toString() String
A string representation of this object.
inherited
Wrap(num value, num min, num max) double
See RaylibFunctions.Wrap.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Raylib
no setter