RaylibAudio class
- Inheritance
-
- Object
- RaylibModule<
Raylib> - RaylibModuleWasm
- RaylibAudio
Constructors
- RaylibAudio(Raylib rl)
Properties
- AttachAudioMixedProcessor ↔ JSFunction
-
latefinal
- AttachAudioStreamProcessor ↔ JSFunction
-
latefinal
- CloseAudioDevice ↔ JSFunction
-
latefinal
- DetachAudioMixedProcessor ↔ JSFunction
-
latefinal
- DetachAudioStreamProcessor ↔ JSFunction
-
latefinal
- ExportWave ↔ JSFunction
-
latefinal
- ExportWaveAsCode ↔ JSFunction
-
latefinal
- GetMasterVolume ↔ JSFunction
-
latefinal
- GetMusicTimeLength ↔ JSFunction
-
latefinal
- GetMusicTimePlayed ↔ JSFunction
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- InitAudioDevice ↔ JSFunction
-
latefinal
- IsAudioDeviceReady ↔ JSFunction
-
latefinal
- IsAudioStreamPlaying ↔ JSFunction
-
latefinal
- IsAudioStreamProcessed ↔ JSFunction
-
latefinal
- IsAudioStreamValid ↔ JSFunction
-
latefinal
- IsMusicStreamPlaying ↔ JSFunction
-
latefinal
- IsMusicValid ↔ JSFunction
-
latefinal
- IsSoundPlaying ↔ JSFunction
-
latefinal
- IsSoundValid ↔ JSFunction
-
latefinal
- IsWaveValid ↔ JSFunction
-
latefinal
- LoadAudioStream ↔ JSFunction
-
latefinal
- LoadMusicStream ↔ JSFunction
-
latefinal
- LoadMusicStreamFromMemory ↔ JSFunction
-
latefinal
- LoadSound ↔ JSFunction
-
latefinal
- LoadSoundAlias ↔ JSFunction
-
latefinal
- LoadSoundFromWave ↔ JSFunction
-
latefinal
- LoadWave ↔ JSFunction
-
latefinal
- LoadWaveFromMemory ↔ JSFunction
-
latefinal
- LoadWaveSamples ↔ JSFunction
-
latefinal
- n → String
-
finalinherited
- PauseAudioStream ↔ JSFunction
-
latefinal
- PauseMusicStream ↔ JSFunction
-
latefinal
- PauseSound ↔ JSFunction
-
latefinal
- PlayAudioStream ↔ JSFunction
-
latefinal
- PlayMusicStream ↔ JSFunction
-
latefinal
- PlaySound ↔ JSFunction
-
latefinal
- ResumeAudioStream ↔ JSFunction
-
latefinal
- ResumeMusicStream ↔ JSFunction
-
latefinal
- ResumeSound ↔ JSFunction
-
latefinal
- rl → Raylib
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s → String
-
finalinherited
- SeekMusicStream ↔ JSFunction
-
latefinal
- SetAudioStreamBufferSizeDefault ↔ JSFunction
-
latefinal
- SetAudioStreamCallback ↔ JSFunction
-
latefinal
- SetAudioStreamPan ↔ JSFunction
-
latefinal
- SetAudioStreamPitch ↔ JSFunction
-
latefinal
- SetAudioStreamVolume ↔ JSFunction
-
latefinal
- SetMasterVolume ↔ JSFunction
-
latefinal
- SetMusicPan ↔ JSFunction
-
latefinal
- SetMusicPitch ↔ JSFunction
-
latefinal
- SetMusicVolume ↔ JSFunction
-
latefinal
- SetSoundPan ↔ JSFunction
-
latefinal
- SetSoundPitch ↔ JSFunction
-
latefinal
- SetSoundVolume ↔ JSFunction
-
latefinal
- StopAudioStream ↔ JSFunction
-
latefinal
- StopMusicStream ↔ JSFunction
-
latefinal
- StopSound ↔ JSFunction
-
latefinal
- UnloadAudioStream ↔ JSFunction
-
latefinal
- UnloadMusicStream ↔ JSFunction
-
latefinal
- UnloadSound ↔ JSFunction
-
latefinal
- UnloadSoundAlias ↔ JSFunction
-
latefinal
- UnloadWave ↔ JSFunction
-
latefinal
- UnloadWaveSamples ↔ JSFunction
-
latefinal
- UpdateAudioStream ↔ JSFunction
-
latefinal
- UpdateMusicStream ↔ JSFunction
-
latefinal
- UpdateSound ↔ JSFunction
-
latefinal
- WaveCopy ↔ JSFunction
-
latefinal
- WaveCrop ↔ JSFunction
-
latefinal
- WaveFormat ↔ JSFunction
-
latefinal
Methods
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
doLoad(
) → void -
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
-
load(
) → void -
Override to perform one-time module initialization. Called by doLoad.
inherited
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited