RaylibCore class
Properties
$
→ RaylibTemp <RaylibBase >
See RaylibTemp .
no setter inherited
BeginBlendMode
↔ WF1 <void >
Begin blending mode (alpha, additive, multiplied, subtract, custom)
late final
BeginDrawing
↔ WF0 <void >
Setup canvas (framebuffer) to start drawing
late final
BeginMode2D
↔ WF1 <void >
Begin 2D mode with custom camera (2D)
late final
BeginMode3D
↔ WF1 <void >
Begin 3D mode with custom camera (3D)
late final
BeginScissorMode
↔ WF4 <void >
Begin scissor mode (define screen area for following drawing)
late final
BeginShaderMode
↔ WF1 <void >
Begin custom shader drawing
late final
BeginTextureMode
↔ WF1 <void >
Begin drawing to render texture
late final
BeginVrStereoMode
↔ WF1 <void >
Begin stereo rendering (requires VR simulator)
late final
ChangeDirectory
↔ WF1 <bool >
Change working directory, return true on success
late final
CheckCollisionBoxes
↔ WF2 <bool >
Check collision between two bounding boxes
late final
CheckCollisionBoxSphere
↔ WF3 <bool >
Check collision between box and sphere
late final
CheckCollisionCircleLine
↔ WF4 <bool >
Check if circle collides with a line created betweeen two points p1 and p2
late final
CheckCollisionCircleRec
↔ WF3 <bool >
Check collision between circle and rectangle
late final
CheckCollisionCircles
↔ WF4 <bool >
Check collision between two circles
late final
CheckCollisionLines
↔ WF5 <bool >
Check the collision between two lines defined by two points each, returns collision point by reference
late final
CheckCollisionPointCircle
↔ WF3 <bool >
Check if point is inside circle
late final
CheckCollisionPointLine
↔ WF4 <bool >
Check if point belongs to line created between two points p1 and p2 with defined margin in pixels threshold
late final
CheckCollisionPointPoly
↔ WF3 <bool >
Check if point is within a polygon described by array of vertices
late final
CheckCollisionPointRec
↔ WF2 <bool >
Check if point is inside rectangle
late final
CheckCollisionPointTriangle
↔ WF4 <bool >
Check if point is inside a triangle
late final
CheckCollisionRecs
↔ WF2 <bool >
Check collision between two rectangles
late final
CheckCollisionSpheres
↔ WF4 <bool >
Check collision between two spheres
late final
ClearBackground
↔ WF1 <void >
Set background color (framebuffer clear color)
late final
ClearWindowState
↔ WF1 <void >
Clear window configuration state flags
late final
CloseWindow
↔ WF0 <void >
Close window and unload OpenGL context
late final
CodepointToUTF8
↔ WF2 <WasmMemoryPointer <RChar > >
Encode one codepoint into UTF-8 byte array (array length returned as parameter)
late final
ColorAlpha
↔ WF3 <void >
Get color with alpha applied, alpha goes from 0.0 to 1.0
late final
ColorAlphaBlend
↔ WF4 <void >
Get src alpha-blended into dst color with tint
late final
ColorBrightness
↔ WF3 <void >
Get color with brightness correction, brightness factor goes from -1.0 to 1.0
late final
ColorContrast
↔ WF3 <void >
Get color with contrast correction, contrast values between -1.0 and 1.0
late final
ColorFromHSV
↔ WF4 <void >
Get a Color from HSV values, hue 0..360, saturation/value 0..1
late final
ColorFromNormalized
↔ WF2 <void >
Get Color from normalized values 0..1
late final
ColorIsEqual
↔ WF2 <bool >
Check if two colors are equal
late final
ColorLerp
↔ WF4 <void >
Get color lerp interpolation between two colors, factor 0.0..1.0
late final
ColorNormalize
↔ WF2 <void >
Get Color normalized as float 0..1
late final
ColorTint
↔ WF3 <void >
Get color multiplied with another color
late final
ColorToHSV
↔ WF2 <void >
Get HSV values for a Color, hue 0..360, saturation/value 0..1
late final
ColorToInt
↔ WF1 <int >
Get hexadecimal value for a Color (0xRRGGBBAA)
late final
CompressData
↔ WF3 <WasmMemoryPointer <RUnsignedChar > >
Compress data (DEFLATE algorithm)
late final
ComputeCRC32
↔ WF2 <int >
Compute CRC32 hash code
late final
ComputeMD5
↔ WF2 <WasmMemoryPointer <RUnsignedInt > >
Compute MD5 hash code
late final
ComputeSHA1
↔ WF2 <WasmMemoryPointer <RUnsignedInt > >
Compute SHA1 hash code
late final
ComputeSHA256
↔ WF2 <WasmMemoryPointer <RUnsignedInt > >
Compute SHA256 hash code
late final
DecodeDataBase64
↔ WF2 <WasmMemoryPointer <RUnsignedChar > >
Decode Base64 string data
late final
DecompressData
↔ WF3 <WasmMemoryPointer <RUnsignedChar > >
Decompress data (DEFLATE algorithm)
late final
DirectoryExists
↔ WF1 <bool >
Check if a directory path exists
late final
DisableCursor
↔ WF0 <void >
Disables cursor (lock cursor)
late final
DisableEventWaiting
↔ WF0 <void >
Disable waiting for events on EndDrawing(), automatic events polling
late final
DrawBillboard
↔ WF5 <void >
Draw a billboard texture
late final
DrawBillboardPro
↔ WF9 <void >
Draw a billboard texture defined by source and rotation
late final
DrawBillboardRec
↔ WF6 <void >
Draw a billboard texture defined by source
late final
DrawBoundingBox
↔ WF2 <void >
Draw bounding box (wires)
late final
DrawCapsule
↔ WF6 <void >
Draw a capsule with the center of its sphere caps at startPos and endPos
late final
DrawCapsuleWires
↔ WF6 <void >
Draw capsule wireframe with the center of its sphere caps at startPos and endPos
late final
DrawCircle
↔ WF4 <void >
Draw a color-filled circle
late final
DrawCircle3D
↔ WF5 <void >
Draw a circle in 3D world space
late final
DrawCircleGradient
↔ WF4 <void >
Draw a gradient-filled circle
late final
DrawCircleLines
↔ WF4 <void >
Draw circle outline
late final
DrawCircleLinesV
↔ WF3 <void >
Draw circle outline (Vector version)
late final
DrawCircleSector
↔ WF6 <void >
Draw a piece of a circle
late final
DrawCircleSectorLines
↔ WF6 <void >
Draw circle sector outline
late final
DrawCircleV
↔ WF3 <void >
Draw a color-filled circle (Vector version)
late final
DrawCube
↔ WF5 <void >
Draw cube
late final
DrawCubeV
↔ WF3 <void >
Draw cube (Vector version)
late final
DrawCubeWires
↔ WF5 <void >
Draw cube wires
late final
DrawCubeWiresV
↔ WF3 <void >
Draw cube wires (Vector version)
late final
DrawCylinder
↔ WF6 <void >
Draw a cylinder/cone
late final
DrawCylinderEx
↔ WF6 <void >
Draw a cylinder with base at startPos and top at endPos
late final
DrawCylinderWires
↔ WF6 <void >
Draw a cylinder/cone wires
late final
DrawCylinderWiresEx
↔ WF6 <void >
Draw a cylinder wires with base at startPos and top at endPos
late final
DrawEllipse
↔ WF5 <void >
Draw ellipse
late final
DrawEllipseLines
↔ WF5 <void >
Draw ellipse outline
late final
DrawEllipseLinesV
↔ WF4 <void >
Draw ellipse outline (Vector version)
late final
DrawEllipseV
↔ WF4 <void >
Draw ellipse (Vector version)
late final
DrawFPS
↔ WF2 <void >
Draw current FPS
late final
DrawGrid
↔ WF2 <void >
Draw a grid (centered at (0, 0, 0))
late final
DrawLine
↔ WF5 <void >
Draw a line
late final
DrawLine3D
↔ WF3 <void >
Draw a line in 3D world space
late final
DrawLineBezier
↔ WF4 <void >
Draw line segment cubic-bezier in-out interpolation
late final
DrawLineDashed
↔ WF5 <void >
Draw a dashed line
late final
DrawLineEx
↔ WF4 <void >
Draw a line (using triangles/quads)
late final
DrawLineStrip
↔ WF3 <void >
Draw lines sequence (using gl lines)
late final
DrawLineV
↔ WF3 <void >
Draw a line (using gl lines)
late final
DrawMesh
↔ WF3 <void >
Draw a 3d mesh with material and transform
late final
DrawMeshInstanced
↔ WF4 <void >
Draw multiple mesh instances with material and different transforms
late final
DrawModel
↔ WF4 <void >
Draw a model (with texture if set)
late final
DrawModelEx
↔ WF6 <void >
Draw a model with extended parameters
late final
DrawModelWires
↔ WF4 <void >
Draw a model wires (with texture if set)
late final
DrawModelWiresEx
↔ WF6 <void >
Draw a model wires (with texture if set) with extended parameters
late final
DrawPixel
↔ WF3 <void >
Draw a pixel using geometry Can be slow, use with care
late final
DrawPixelV
↔ WF2 <void >
Draw a pixel using geometry (Vector version) Can be slow, use with care
late final
DrawPlane
↔ WF3 <void >
Draw a plane XZ
late final
DrawPoint3D
↔ WF2 <void >
Draw a point in 3D space, actually a small line
late final
DrawPoly
↔ WF5 <void >
Draw a regular polygon (Vector version)
late final
DrawPolyLines
↔ WF5 <void >
Draw a polygon outline of n sides
late final
DrawPolyLinesEx
↔ WF6 <void >
Draw a polygon outline of n sides with extended parameters
late final
DrawRay
↔ WF2 <void >
Draw a ray line
late final
DrawRectangle
↔ WF5 <void >
Draw a color-filled rectangle
late final
DrawRectangleGradientEx
↔ WF5 <void >
Draw a gradient-filled rectangle with custom vertex colors
late final
DrawRectangleGradientH
↔ WF6 <void >
Draw a horizontal-gradient-filled rectangle
late final
DrawRectangleGradientV
↔ WF6 <void >
Draw a vertical-gradient-filled rectangle
late final
DrawRectangleLines
↔ WF5 <void >
Draw rectangle outline
late final
DrawRectangleLinesEx
↔ WF3 <void >
Draw rectangle outline with extended parameters
late final
DrawRectanglePro
↔ WF4 <void >
Draw a color-filled rectangle with pro parameters
late final
DrawRectangleRec
↔ WF2 <void >
Draw a color-filled rectangle
late final
DrawRectangleRounded
↔ WF4 <void >
Draw rectangle with rounded edges
late final
DrawRectangleRoundedLines
↔ WF4 <void >
Draw rectangle lines with rounded edges
late final
DrawRectangleRoundedLinesEx
↔ WF5 <void >
Draw rectangle with rounded edges outline
late final
DrawRectangleV
↔ WF3 <void >
Draw a color-filled rectangle (Vector version)
late final
DrawRing
↔ WF7 <void >
Draw ring
late final
DrawRingLines
↔ WF7 <void >
Draw ring outline
late final
DrawSphere
↔ WF3 <void >
Draw sphere
late final
DrawSphereEx
↔ WF5 <void >
Draw sphere with extended parameters
late final
DrawSphereWires
↔ WF5 <void >
Draw sphere wires
late final
DrawSplineBasis
↔ WF4 <void >
Draw spline: B-Spline, minimum 4 points
late final
DrawSplineBezierCubic
↔ WF4 <void >
Draw spline: Cubic Bezier, minimum 4 points (2 control points): p1, c2, c3, p4, c5, c6...
late final
DrawSplineBezierQuadratic
↔ WF4 <void >
Draw spline: Quadratic Bezier, minimum 3 points (1 control point): p1, c2, p3, c4...
late final
DrawSplineCatmullRom
↔ WF4 <void >
Draw spline: Catmull-Rom, minimum 4 points
late final
DrawSplineLinear
↔ WF4 <void >
Draw spline: Linear, minimum 2 points
late final
DrawSplineSegmentBasis
↔ WF6 <void >
Draw spline segment: B-Spline, 4 points
late final
DrawSplineSegmentBezierCubic
↔ WF6 <void >
Draw spline segment: Cubic Bezier, 2 points, 2 control points
late final
DrawSplineSegmentBezierQuadratic
↔ WF5 <void >
Draw spline segment: Quadratic Bezier, 2 points, 1 control point
late final
DrawSplineSegmentCatmullRom
↔ WF6 <void >
Draw spline segment: Catmull-Rom, 4 points
late final
DrawSplineSegmentLinear
↔ WF4 <void >
Draw spline segment: Linear, 2 points
late final
DrawText
↔ WF5 <void >
Draw text (using default font)
late final
DrawTextCodepoint
↔ WF5 <void >
Draw one character (codepoint)
late final
DrawTextCodepoints
↔ WF7 <void >
Draw multiple character (codepoint)
late final
DrawTextEx
↔ WF6 <void >
Draw text using font and additional parameters
late final
DrawTextPro
↔ WF8 <void >
Draw text using Font and pro parameters (rotation)
late final
DrawTexture
↔ WF4 <void >
Draw a Texture2D
late final
DrawTextureEx
↔ WF5 <void >
Draw a Texture2D with extended parameters
late final
DrawTextureNPatch
↔ WF6 <void >
Draws a texture (or part of it) that stretches or shrinks nicely
late final
DrawTexturePro
↔ WF6 <void >
Draw a part of a texture defined by a rectangle with 'pro' parameters
late final
DrawTextureRec
↔ WF4 <void >
Draw a part of a texture defined by a rectangle
late final
DrawTextureV
↔ WF3 <void >
Draw a Texture2D with position defined as Vector2
late final
DrawTriangle
↔ WF4 <void >
Draw a color-filled triangle (vertex in counter-clockwise order!)
late final
DrawTriangle3D
↔ WF4 <void >
Draw a color-filled triangle (vertex in counter-clockwise order!)
late final
DrawTriangleFan
↔ WF3 <void >
Draw a triangle fan defined by points (first vertex is the center)
late final
DrawTriangleLines
↔ WF4 <void >
Draw triangle outline (vertex in counter-clockwise order!)
late final
DrawTriangleStrip
↔ WF3 <void >
Draw a triangle strip defined by points
late final
DrawTriangleStrip3D
↔ WF3 <void >
Draw a triangle strip defined by points
late final
EnableCursor
↔ WF0 <void >
Enables cursor (unlock cursor)
late final
EnableEventWaiting
↔ WF0 <void >
Enable waiting for events on EndDrawing(), no automatic event polling
late final
EncodeDataBase64
↔ WF3 <WasmMemoryPointer <RChar > >
Encode data to Base64 string
late final
EndBlendMode
↔ WF0 <void >
End blending mode (reset to default: alpha blending)
late final
EndDrawing
↔ WF0 <void >
End canvas drawing and swap buffers (double buffering)
late final
EndMode2D
↔ WF0 <void >
Ends 2D mode with custom camera
late final
EndMode3D
↔ WF0 <void >
Ends 3D mode and returns to default 2D orthographic mode
late final
EndScissorMode
↔ WF0 <void >
End scissor mode
late final
EndShaderMode
↔ WF0 <void >
End custom shader drawing (use default shader)
late final
EndTextureMode
↔ WF0 <void >
Ends drawing to render texture
late final
EndVrStereoMode
↔ WF0 <void >
End stereo rendering (requires VR simulator)
late final
ExportAutomationEventList
↔ WF2 <bool >
Export automation events list as text file
late final
ExportDataAsCode
↔ WF3 <bool >
Export data to code (.h), returns true on success
late final
ExportFontAsCode
↔ WF2 <bool >
Export font as code file, returns true on success
late final
ExportImage
↔ WF2 <bool >
Export image data to file, returns true on success
late final
ExportImageAsCode
↔ WF2 <bool >
Export image as code file defining an array of bytes, returns true on success
late final
ExportImageToMemory
↔ WF3 <WasmMemoryPointer <RUnsignedChar > >
Export image to memory buffer
late final
ExportMesh
↔ WF2 <bool >
Export mesh data to file, returns true on success
late final
ExportMeshAsCode
↔ WF2 <bool >
Export mesh as code file (.h) defining multiple arrays of vertex attributes
late final
Fade
↔ WF3 <void >
Get color with alpha applied, alpha goes from 0.0 to 1.0
late final
FileCopy
↔ WF2 <int >
Copy file from one path to another, dstPath created if it doesn't exist
late final
FileExists
↔ WF1 <bool >
Check if file exists
late final
FileMove
↔ WF2 <int >
Move file from one directory to another, dstPath created if it doesn't exist
late final
FileRemove
↔ WF1 <int >
Remove file (if exists)
late final
FileRename
↔ WF2 <int >
Rename file (if exists)
late final
FileTextFindIndex
↔ WF2 <int >
Find text in existing file
late final
FileTextReplace
↔ WF3 <int >
Replace text in an existing file
late final
GenImageCellular
↔ WF4 <void >
Generate image: cellular algorithm, bigger tileSize means bigger cells
late final
GenImageChecked
↔ WF7 <void >
Generate image: checked
late final
GenImageColor
↔ WF4 <void >
Generate image: plain color
late final
GenImageFontAtlas
↔ WF7 <void >
Generate image font atlas using chars info
late final
GenImageGradientLinear
↔ WF6 <void >
Generate image: linear gradient, direction in degrees 0..360, 0=Vertical gradient
late final
GenImageGradientRadial
↔ WF6 <void >
Generate image: radial gradient
late final
GenImageGradientSquare
↔ WF6 <void >
Generate image: square gradient
late final
GenImagePerlinNoise
↔ WF6 <void >
Generate image: perlin noise
late final
GenImageText
↔ WF4 <void >
Generate image: grayscale image from text data
late final
GenImageWhiteNoise
↔ WF4 <void >
Generate image: white noise
late final
GenMeshCone
↔ WF4 <void >
Generate cone/pyramid mesh
late final
GenMeshCube
↔ WF4 <void >
Generate cuboid mesh
late final
GenMeshCubicmap
↔ WF3 <void >
Generate cubes-based map mesh from image data
late final
GenMeshCylinder
↔ WF4 <void >
Generate cylinder mesh
late final
GenMeshHeightmap
↔ WF3 <void >
Generate heightmap mesh from image data
late final
GenMeshHemiSphere
↔ WF4 <void >
Generate half-sphere mesh (no bottom cap)
late final
GenMeshKnot
↔ WF5 <void >
Generate trefoil knot mesh
late final
GenMeshPlane
↔ WF5 <void >
Generate plane mesh (with subdivisions)
late final
GenMeshPoly
↔ WF3 <void >
Generate polygonal mesh
late final
GenMeshSphere
↔ WF4 <void >
Generate sphere mesh (standard sphere)
late final
GenMeshTangents
↔ WF1 <void >
Compute mesh tangents
late final
GenMeshTorus
↔ WF5 <void >
Generate torus mesh
late final
GenTextureMipmaps
↔ WF1 <void >
Generate GPU mipmaps for a texture
late final
GetApplicationDirectory
↔ WF0 <WasmMemoryPointer <RChar > >
Get the directory of the running application
late final
GetCameraMatrix
↔ WF2 <void >
Get camera transform matrix (view matrix)
late final
GetCameraMatrix2D
↔ WF2 <void >
Get camera 2d transform matrix
late final
GetCharPressed
↔ WF0 <int >
Get char pressed (unicode), call it multiple times for chars queued, returns 0 when the queue is empty
late final
GetClipboardImage
↔ WF1 <void >
Get clipboard image content
late final
GetClipboardText
↔ WF0 <WasmMemoryPointer <RChar > >
Get clipboard text content
late final
GetCodepoint
↔ WF2 <int >
Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
late final
GetCodepointCount
↔ WF1 <int >
Get total number of codepoints in a UTF-8 encoded string
late final
GetCodepointNext
↔ WF2 <int >
Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
late final
GetCodepointPrevious
↔ WF2 <int >
Get previous codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
late final
GetCollisionRec
↔ WF3 <void >
Get collision rectangle for two rectangles collision
late final
GetColor
↔ WF2 <void >
Get Color structure from hexadecimal value
late final
GetCurrentMonitor
↔ WF0 <int >
Get current monitor where window is placed
late final
GetDirectoryFileCount
↔ WF1 <int >
Get the file count in a directory
late final
GetDirectoryFileCountEx
↔ WF3 <int >
Get the file count in a directory with extension filtering and recursive directory scan.
late final
GetDirectoryPath
↔ WF1 <WasmMemoryPointer <RChar > >
Get full path for a given fileName with path
late final
GetFileExtension
↔ WF1 <WasmMemoryPointer <RChar > >
Get extension for a filename (includes dot: '.png')
late final
GetFileLength
↔ WF1 <int >
Get file length in bytes
late final
GetFileModTime
↔ WF1 <int >
Get file modification time (last write time)
late final
GetFileName
↔ WF1 <WasmMemoryPointer <RChar > >
Get filename for a path string
late final
GetFileNameWithoutExt
↔ WF1 <WasmMemoryPointer <RChar > >
Get filename without extension
late final
GetFontDefault
↔ WF1 <void >
Get the default Font
late final
GetFPS
↔ WF0 <int >
Get current FPS
late final
GetFrameTime
↔ WF0 <double >
Get time in seconds for last frame drawn (delta time)
late final
GetGamepadAxisCount
↔ WF1 <int >
Get gamepad axis count for a gamepad
late final
GetGamepadAxisMovement
↔ WF2 <double >
Get axis movement value for a gamepad axis
late final
GetGamepadButtonPressed
↔ WF0 <int >
Get the last gamepad button pressed
late final
GetGamepadName
↔ WF1 <WasmMemoryPointer <RChar > >
Get gamepad internal name id
late final
GetGestureDetected
↔ WF0 <int >
Get latest detected gesture
late final
GetGestureDragAngle
↔ WF0 <double >
Get gesture drag angle
late final
GetGestureDragVector
↔ WF1 <void >
Get gesture drag vector
late final
GetGestureHoldDuration
↔ WF0 <double >
Get gesture hold time in seconds
late final
GetGesturePinchAngle
↔ WF0 <double >
Get gesture pinch angle
late final
GetGesturePinchVector
↔ WF1 <void >
Get gesture pinch delta
late final
GetGlyphAtlasRec
↔ WF3 <void >
Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
late final
GetGlyphIndex
↔ WF2 <int >
Get glyph index position in font for a codepoint (unicode character), fallback to '?' if not found
late final
GetGlyphInfo
↔ WF3 <void >
Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
late final
GetImageAlphaBorder
↔ WF3 <void >
Get image alpha border rectangle
late final
GetImageColor
↔ WF4 <void >
Get image pixel color at (x, y) position
late final
GetKeyName
↔ WF1 <WasmMemoryPointer <RChar > >
Get name of a QWERTY key on the current keyboard layout (eg returns string 'q' for KEY_A on an AZERTY keyboard)
late final
GetKeyPressed
↔ WF0 <int >
Get key pressed (keycode), call it multiple times for keys queued, returns 0 when the queue is empty
late final
GetMeshBoundingBox
↔ WF2 <void >
Compute mesh bounding box limits
late final
GetModelBoundingBox
↔ WF2 <void >
Compute model bounding box limits (considers all meshes)
late final
GetMonitorCount
↔ WF0 <int >
Get number of connected monitors
late final
GetMonitorHeight
↔ WF1 <int >
Get specified monitor height (current video mode used by monitor)
late final
GetMonitorName
↔ WF1 <WasmMemoryPointer <RChar > >
Get the human-readable, UTF-8 encoded name of the specified monitor
late final
GetMonitorPhysicalHeight
↔ WF1 <int >
Get specified monitor physical height in millimetres
late final
GetMonitorPhysicalWidth
↔ WF1 <int >
Get specified monitor physical width in millimetres
late final
GetMonitorPosition
↔ WF2 <void >
Get specified monitor position
late final
GetMonitorRefreshRate
↔ WF1 <int >
Get specified monitor refresh rate
late final
GetMonitorWidth
↔ WF1 <int >
Get specified monitor width (current video mode used by monitor)
late final
GetMouseDelta
↔ WF1 <void >
Get mouse delta between frames
late final
GetMousePosition
↔ WF1 <void >
Get mouse position XY
late final
GetMouseWheelMove
↔ WF0 <double >
Get mouse wheel movement for X or Y, whichever is larger
late final
GetMouseWheelMoveV
↔ WF1 <void >
Get mouse wheel movement for both X and Y
late final
GetMouseX
↔ WF0 <int >
Get mouse position X
late final
GetMouseY
↔ WF0 <int >
Get mouse position Y
late final
GetPixelColor
↔ WF3 <void >
Get Color from a source pixel pointer of certain format
late final
GetPixelDataSize
↔ WF3 <int >
Get pixel data size in bytes for certain format
late final
GetPrevDirectoryPath
↔ WF1 <WasmMemoryPointer <RChar > >
Get previous directory path for a given path
late final
GetRandomValue
↔ WF2 <int >
Get a random value between min and max (both included)
late final
GetRayCollisionBox
↔ WF3 <void >
Get collision info between ray and box
late final
GetRayCollisionMesh
↔ WF4 <void >
Get collision info between ray and mesh
late final
GetRayCollisionQuad
↔ WF6 <void >
Get collision info between ray and quad
late final
GetRayCollisionSphere
↔ WF4 <void >
Get collision info between ray and sphere
late final
GetRayCollisionTriangle
↔ WF5 <void >
Get collision info between ray and triangle
late final
GetRenderHeight
↔ WF0 <int >
Get current render height (it considers HiDPI)
late final
GetRenderWidth
↔ WF0 <int >
Get current render width (it considers HiDPI)
late final
GetScreenHeight
↔ WF0 <int >
Get current screen height
late final
GetScreenToWorld2D
↔ WF3 <void >
Get the world space position for a 2d camera screen space position
late final
GetScreenToWorldRay
↔ WF3 <void >
Get a ray trace from screen position (i.e mouse)
late final
GetScreenToWorldRayEx
↔ WF5 <void >
Get a ray trace from screen position (i.e mouse) in a viewport
late final
GetScreenWidth
↔ WF0 <int >
Get current screen width
late final
GetShaderLocation
↔ WF2 <int >
Get shader uniform location
late final
GetShaderLocationAttrib
↔ WF2 <int >
Get shader attribute location
late final
GetShapesTexture
↔ WF1 <void >
Get texture that is used for shapes drawing
late final
GetShapesTextureRectangle
↔ WF1 <void >
Get texture source rectangle that is used for shapes drawing
late final
GetSplinePointBasis
↔ WF6 <void >
Get (evaluate) spline point: B-Spline
late final
GetSplinePointBezierCubic
↔ WF6 <void >
Get (evaluate) spline point: Cubic Bezier
late final
GetSplinePointBezierQuad
↔ WF5 <void >
Get (evaluate) spline point: Quadratic Bezier
late final
GetSplinePointCatmullRom
↔ WF6 <void >
Get (evaluate) spline point: Catmull-Rom
late final
GetSplinePointLinear
↔ WF4 <void >
Get (evaluate) spline point: Linear
late final
GetTextBetween
↔ WF3 <WasmMemoryPointer <RChar > >
Get text between two strings
late final
GetTime
↔ WF0 <double >
Get elapsed time in seconds since InitWindow()
late final
GetTouchPointCount
↔ WF0 <int >
Get number of touch points
late final
GetTouchPointId
↔ WF1 <int >
Get touch point identifier for given index
late final
GetTouchPosition
↔ WF2 <void >
Get touch position XY for a touch point index (relative to screen size)
late final
GetTouchX
↔ WF0 <int >
Get touch position X for touch point 0 (relative to screen size)
late final
GetTouchY
↔ WF0 <int >
Get touch position Y for touch point 0 (relative to screen size)
late final
GetWindowHandle
↔ WF0 <WasmMemoryPointer <RVoid > >
Get native window handle
late final
GetWindowPosition
↔ WF1 <void >
Get window position XY on monitor
late final
GetWindowScaleDPI
↔ WF1 <void >
Get window scale DPI factor
late final
GetWorkingDirectory
↔ WF0 <WasmMemoryPointer <RChar > >
Get current working directory
late final
GetWorldToScreen
↔ WF3 <void >
Get the screen space position for a 3d world space position
late final
GetWorldToScreen2D
↔ WF3 <void >
Get the screen space position for a 2d camera world space position
late final
GetWorldToScreenEx
↔ WF5 <void >
Get size position for a 3d world space position
late final
hashCode
→ int
The hash code for this object.
no setter inherited
HideCursor
↔ WF0 <void >
Hides cursor
late final
ImageAlphaClear
↔ WF3 <void >
Clear alpha channel to desired color
late final
ImageAlphaCrop
↔ WF2 <void >
Crop image depending on alpha value
late final
ImageAlphaMask
↔ WF2 <void >
Apply alpha mask to image
late final
ImageAlphaPremultiply
↔ WF1 <void >
Premultiply alpha channel
late final
ImageBlurGaussian
↔ WF2 <void >
Apply Gaussian blur using a box blur approximation
late final
ImageClearBackground
↔ WF2 <void >
Clear image background with given color
late final
ImageColorBrightness
↔ WF2 <void >
Modify image color: brightness (-255 to 255)
late final
ImageColorContrast
↔ WF2 <void >
Modify image color: contrast (-100 to 100)
late final
ImageColorGrayscale
↔ WF1 <void >
Modify image color: grayscale
late final
ImageColorInvert
↔ WF1 <void >
Modify image color: invert
late final
ImageColorReplace
↔ WF3 <void >
Modify image color: replace color
late final
ImageColorTint
↔ WF2 <void >
Modify image color: tint
late final
ImageCopy
↔ WF2 <void >
Create an image duplicate (useful for transformations)
late final
ImageCrop
↔ WF2 <void >
Crop an image to a defined rectangle
late final
ImageDither
↔ WF5 <void >
Dither image data to 16bpp or lower (Floyd-Steinberg dithering)
late final
ImageDraw
↔ WF5 <void >
Draw a source image within a destination image (tint applied to source)
late final
ImageDrawCircle
↔ WF5 <void >
Draw a filled circle within an image
late final
ImageDrawCircleLines
↔ WF5 <void >
Draw circle outline within an image
late final
ImageDrawCircleLinesV
↔ WF4 <void >
Draw circle outline within an image (Vector version)
late final
ImageDrawCircleV
↔ WF4 <void >
Draw a filled circle within an image (Vector version)
late final
ImageDrawLine
↔ WF6 <void >
Draw line within an image
late final
ImageDrawLineEx
↔ WF5 <void >
Draw a line defining thickness within an image
late final
ImageDrawLineV
↔ WF4 <void >
Draw line within an image (Vector version)
late final
ImageDrawPixel
↔ WF4 <void >
Draw pixel within an image
late final
ImageDrawPixelV
↔ WF3 <void >
Draw pixel within an image (Vector version)
late final
ImageDrawRectangle
↔ WF6 <void >
Draw rectangle within an image
late final
ImageDrawRectangleLines
↔ WF4 <void >
Draw rectangle lines within an image
late final
ImageDrawRectangleRec
↔ WF3 <void >
Draw rectangle within an image
late final
ImageDrawRectangleV
↔ WF4 <void >
Draw rectangle within an image (Vector version)
late final
ImageDrawText
↔ WF6 <void >
Draw text (using default font) within an image (destination)
late final
ImageDrawTextEx
↔ WF7 <void >
Draw text (custom sprite font) within an image (destination)
late final
ImageDrawTriangle
↔ WF5 <void >
Draw triangle within an image
late final
ImageDrawTriangleEx
↔ WF7 <void >
Draw triangle with interpolated colors within an image
late final
ImageDrawTriangleFan
↔ WF4 <void >
Draw a triangle fan defined by points within an image (first vertex is the center)
late final
ImageDrawTriangleLines
↔ WF5 <void >
Draw triangle outline within an image
late final
ImageDrawTriangleStrip
↔ WF4 <void >
Draw a triangle strip defined by points within an image
late final
ImageFlipHorizontal
↔ WF1 <void >
Flip image horizontally
late final
ImageFlipVertical
↔ WF1 <void >
Flip image vertically
late final
ImageFormat
↔ WF2 <void >
Convert image data to desired format
late final
ImageFromChannel
↔ WF3 <void >
Create an image from a selected channel of another image (GRAYSCALE)
late final
ImageFromImage
↔ WF3 <void >
Create an image from another image piece
late final
ImageKernelConvolution
↔ WF3 <void >
Apply custom square convolution kernel to image
late final
ImageMipmaps
↔ WF1 <void >
Compute all mipmap levels for a provided image
late final
ImageResize
↔ WF3 <void >
Resize image (Bicubic scaling algorithm)
late final
ImageResizeCanvas
↔ WF6 <void >
Resize canvas and fill with color
late final
ImageResizeNN
↔ WF3 <void >
Resize image (Nearest-Neighbor scaling algorithm)
late final
ImageRotate
↔ WF2 <void >
Rotate image by input angle in degrees (-359 to 359)
late final
ImageRotateCCW
↔ WF1 <void >
Rotate image counter-clockwise 90deg
late final
ImageRotateCW
↔ WF1 <void >
Rotate image clockwise 90deg
late final
ImageText
↔ WF4 <void >
Create an image from text (default font)
late final
ImageTextEx
↔ WF6 <void >
Create an image from text (custom sprite font)
late final
ImageToPOT
↔ WF2 <void >
Convert image to POT (power-of-two)
late final
InitWindow
↔ WF3 <void >
Initialize window and OpenGL context
late final
IsCursorHidden
↔ WF0 <bool >
Check if cursor is not visible
late final
IsCursorOnScreen
↔ WF0 <bool >
Check if cursor is on the screen
late final
IsFileDropped
↔ WF0 <bool >
Check if a file has been dropped into window
late final
IsFileExtension
↔ WF2 <bool >
Check file extension (including point: .png, .wav)
late final
IsFileNameValid
↔ WF1 <bool >
Check if fileName is valid for the platform/OS
late final
IsFontValid
↔ WF1 <bool >
Check if a font is valid (font data loaded, WARNING: GPU texture not checked)
late final
IsGamepadAvailable
↔ WF1 <bool >
Check if a gamepad is available
late final
IsGamepadButtonDown
↔ WF2 <bool >
Check if a gamepad button is being pressed
late final
IsGamepadButtonPressed
↔ WF2 <bool >
Check if a gamepad button has been pressed once
late final
IsGamepadButtonReleased
↔ WF2 <bool >
Check if a gamepad button has been released once
late final
IsGamepadButtonUp
↔ WF2 <bool >
Check if a gamepad button is NOT being pressed
late final
IsGestureDetected
↔ WF1 <bool >
Check if a gesture have been detected
late final
IsImageValid
↔ WF1 <bool >
Check if an image is valid (data and parameters)
late final
IsKeyDown
↔ WF1 <bool >
Check if a key is being pressed
late final
IsKeyPressed
↔ WF1 <bool >
Check if a key has been pressed once
late final
IsKeyPressedRepeat
↔ WF1 <bool >
Check if a key has been pressed again
late final
IsKeyReleased
↔ WF1 <bool >
Check if a key has been released once
late final
IsKeyUp
↔ WF1 <bool >
Check if a key is NOT being pressed
late final
IsMaterialValid
↔ WF1 <bool >
Check if a material is valid (shader assigned, map textures loaded in GPU)
late final
IsModelAnimationValid
↔ WF2 <bool >
Check model animation skeleton match
late final
IsModelValid
↔ WF1 <bool >
Check if a model is valid (loaded in GPU, VAO/VBOs)
late final
IsMouseButtonDown
↔ WF1 <bool >
Check if a mouse button is being pressed
late final
IsMouseButtonPressed
↔ WF1 <bool >
Check if a mouse button has been pressed once
late final
IsMouseButtonReleased
↔ WF1 <bool >
Check if a mouse button has been released once
late final
IsMouseButtonUp
↔ WF1 <bool >
Check if a mouse button is NOT being pressed
late final
IsPathFile
↔ WF1 <bool >
Check if a given path is a file or a directory
late final
IsRenderTextureValid
↔ WF1 <bool >
Check if a render texture is valid (loaded in GPU)
late final
IsShaderValid
↔ WF1 <bool >
Check if a shader is valid (loaded on GPU)
late final
IsTextureValid
↔ WF1 <bool >
Check if a texture is valid (loaded in GPU)
late final
IsWindowFocused
↔ WF0 <bool >
Check if window is currently focused
late final
IsWindowFullscreen
↔ WF0 <bool >
Check if window is currently fullscreen
late final
IsWindowHidden
↔ WF0 <bool >
Check if window is currently hidden
late final
IsWindowMaximized
↔ WF0 <bool >
Check if window is currently maximized
late final
IsWindowMinimized
↔ WF0 <bool >
Check if window is currently minimized
late final
IsWindowReady
↔ WF0 <bool >
Check if window has been initialized successfully
late final
IsWindowResized
↔ WF0 <bool >
Check if window has been resized last frame
late final
IsWindowState
↔ WF1 <bool >
Check if one specific window flag is enabled
late final
LoadAutomationEventList
↔ WF2 <void >
Load automation events list from file, NULL for empty list
late final
LoadCodepoints
↔ WF2 <WasmMemoryPointer <RInt > >
Load all codepoints from a UTF-8 text string, codepoints count returned by parameter
late final
LoadDirectoryFiles
↔ WF2 <void >
Load directory filepaths
late final
LoadDirectoryFilesEx
↔ WF4 <void >
Load directory filepaths with extension filtering and recursive directory scan.
late final
LoadDroppedFiles
↔ WF1 <void >
Load dropped filepaths
late final
LoadFileData
↔ WF2 <WasmMemoryPointer <RUnsignedChar > >
Load file data as byte array (read)
late final
LoadFileText
↔ WF1 <WasmMemoryPointer <RChar > >
Load text data from file (read)
late final
LoadFont
↔ WF2 <void >
Load font from file into GPU memory (VRAM)
late final
LoadFontData
↔ WF7 <StructPointer <GlyphInfoD > >
Load font data for further use
late final
LoadFontEx
↔ WF5 <void >
Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height
late final
LoadFontFromImage
↔ WF4 <void >
Load font from Image (XNA style)
late final
LoadFontFromMemory
↔ WF7 <void >
Load font from memory buffer, fileType refers to extension: i.e. '.ttf'
late final
LoadImage
↔ WF2 <void >
Load image from file into CPU memory (RAM)
late final
LoadImageAnim
↔ WF3 <void >
Load image sequence from file (frames appended to image.data)
late final
LoadImageAnimFromMemory
↔ WF5 <void >
Load image sequence from memory buffer
late final
LoadImageColors
↔ WF1 <StructPointer <ColorD > >
Load color data from image as a Color array (RGBA - 32bit)
late final
LoadImageFromMemory
↔ WF4 <void >
Load image from memory buffer, fileType refers to extension: i.e. '.png'
late final
LoadImageFromScreen
↔ WF1 <void >
Load image from screen buffer and (screenshot)
late final
LoadImageFromTexture
↔ WF2 <void >
Load image from GPU texture data
late final
LoadImagePalette
↔ WF3 <StructPointer <ColorD > >
Load colors palette from image as a Color array (RGBA - 32bit)
late final
LoadImageRaw
↔ WF6 <void >
Load image from RAW file data
late final
LoadMaterialDefault
↔ WF1 <void >
Load default material (Supports: DIFFUSE, SPECULAR, NORMAL maps)
late final
LoadMaterials
↔ WF2 <StructPointer <MaterialD > >
Load materials from model file
late final
LoadModel
↔ WF2 <void >
Load model from files (meshes and materials)
late final
LoadModelAnimations
↔ WF2 <StructPointer <ModelAnimationD > >
Load model animations from file
late final
LoadModelFromMesh
↔ WF2 <void >
Load model from generated mesh (default material)
late final
LoadRandomSequence
↔ WF3 <WasmMemoryPointer <RInt > >
Load random values sequence, no values repeated, min and max included
late final
LoadRenderTexture
↔ WF3 <void >
Load texture for rendering (framebuffer)
late final
LoadShader
↔ WF3 <void >
Load shader from files and bind default locations
late final
LoadShaderFromMemory
↔ WF3 <void >
Load shader from code strings and bind default locations
late final
LoadTextLines
↔ WF2 <WasmMemoryPointer <RPointer <RChar > > >
Load text as separate lines ('\n')
late final
LoadTexture
↔ WF2 <void >
Load texture from file into GPU memory (VRAM)
late final
LoadTextureCubemap
↔ WF3 <void >
Load cubemap from image, multiple image cubemap layouts supported
late final
LoadTextureFromImage
↔ WF2 <void >
Load texture from image data
late final
LoadUTF8
↔ WF2 <WasmMemoryPointer <RChar > >
Load UTF-8 text encoded from codepoints array
late final
LoadVrStereoConfig
↔ WF2 <void >
Load VR stereo config for VR simulator device parameters
late final
MakeDirectory
↔ WF1 <int >
Create directories (including full path requested), returns 0 on success
late final
MaximizeWindow
↔ WF0 <void >
Set window state: maximized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
late final
MeasureText
↔ WF2 <int >
Measure string width for default font
late final
MeasureTextCodepoints
↔ WF6 <void >
Measure string size for an existing array of codepoints for Font
late final
MeasureTextEx
↔ WF5 <void >
Measure string size for Font
late final
MinimizeWindow
↔ WF0 <void >
Set window state: minimized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
late final
OpenURL
↔ WF1 <void >
Open URL with default system browser (if available)
late final
PlayAutomationEvent
↔ WF1 <void >
Play a recorded automation event
late final
PollInputEvents
↔ WF0 <void >
Register all input events
late final
ProcessGestureEvent
↔ WF1 <void >
Process gesture event and translate it into gestures
late final
RestoreWindow
↔ WF0 <void >
Set window state: not minimized/maximized
late final
rl
→ Raylib
final inherited
rn
→ String
Emscripten cwrap return type for anything other than structs and void.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
rv
→ Null
Emscripten cwrap return type for functions returning void.
final inherited
SaveFileData
↔ WF3 <bool >
Save data to file from byte array (write), returns true on success
late final
SaveFileText
↔ WF2 <bool >
Save text data to file (write), returns true on success
late final
SetAutomationEventBaseFrame
↔ WF1 <void >
Set automation event internal base frame to start recording
late final
SetAutomationEventList
↔ WF1 <void >
Set automation event list to record to
late final
SetClipboardText
↔ WF1 <void >
Set clipboard text content
late final
SetConfigFlags
↔ WF1 <void >
Setup init configuration flags (view ConfigFlags )
late final
SetExitKey
↔ WF1 <void >
Set a custom key to exit program (default is ESC)
late final
SetGamepadMappings
↔ WF1 <int >
Set internal gamepad mappings (SDL_GameControllerDB)
late final
SetGamepadVibration
↔ WF4 <void >
Set gamepad vibration for both motors (duration in seconds)
late final
SetGesturesEnabled
↔ WF1 <void >
Enable a set of gestures using flags Gesture
late final
SetLoadFileDataCallback
↔ WF1 <void >
Set custom file binary data loader
late final
SetLoadFileTextCallback
↔ WF1 <void >
Set custom file text data loader
late final
SetMaterialTexture
↔ WF3 <void >
Set texture for a material map type (MATERIAL_MAP_DIFFUSE, MATERIAL_MAP_SPECULAR...)
late final
SetModelMeshMaterial
↔ WF3 <void >
Set material for a mesh
late final
SetMouseCursor
↔ WF1 <void >
Set mouse cursor
late final
SetMouseOffset
↔ WF2 <void >
Set mouse offset
late final
SetMousePosition
↔ WF2 <void >
Set mouse position XY
late final
SetMouseScale
↔ WF2 <void >
Set mouse scaling
late final
SetPixelColor
↔ WF3 <void >
Set color formatted into destination pixel pointer
late final
SetRandomSeed
↔ WF1 <void >
Set the seed for the random number generator
late final
SetSaveFileDataCallback
↔ WF1 <void >
Set custom file binary data saver
late final
SetSaveFileTextCallback
↔ WF1 <void >
Set custom file text data saver
late final
SetShaderValue
↔ WF4 <void >
Set shader uniform value
late final
SetShaderValueMatrix
↔ WF3 <void >
Set shader uniform value (matrix 4x4)
late final
SetShaderValueTexture
↔ WF3 <void >
Set shader uniform value for texture (sampler2d)
late final
SetShaderValueV
↔ WF5 <void >
Set shader uniform value vector
late final
SetShapesTexture
↔ WF2 <void >
Set texture and rectangle to be used on shapes drawing
late final
SetTargetFPS
↔ WF1 <void >
Set target FPS (maximum)
late final
SetTextLineSpacing
↔ WF1 <void >
Set vertical line spacing when drawing with line-breaks
late final
SetTextureFilter
↔ WF2 <void >
Set texture scaling filter mode
late final
SetTextureWrap
↔ WF2 <void >
Set texture wrapping mode
late final
SetTraceLogCallback
↔ WF1 <void >
Set custom trace log
late final
SetTraceLogLevel
↔ WF1 <void >
Set the current threshold (minimum) log level
late final
SetWindowFocused
↔ WF0 <void >
Set window focused
late final
SetWindowIcon
↔ WF1 <void >
Set icon for window (single image, RGBA 32bit)
late final
SetWindowIcons
↔ WF2 <void >
Set icon for window (multiple images, RGBA 32bit)
late final
SetWindowMaxSize
↔ WF2 <void >
Set window maximum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE )
late final
SetWindowMinSize
↔ WF2 <void >
Set window minimum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE )
late final
SetWindowMonitor
↔ WF1 <void >
Set monitor for the current window
late final
SetWindowOpacity
↔ WF1 <void >
Set window opacity 0.0..1.0
late final
SetWindowPosition
↔ WF2 <void >
Set window position on screen
late final
SetWindowSize
↔ WF2 <void >
Set window dimensions
late final
SetWindowState
↔ WF1 <void >
Set window configuration state using flags
late final
SetWindowTitle
↔ WF1 <void >
Set title for window
late final
ShowCursor
↔ WF0 <void >
Shows cursor
late final
StartAutomationEventRecording
↔ WF0 <void >
Start recording automation events (AutomationEventList must be set)
late final
StopAutomationEventRecording
↔ WF0 <void >
Stop recording automation events
late final
SwapScreenBuffer
↔ WF0 <void >
Swap back buffer with front buffer (screen drawing)
late final
TakeScreenshot
↔ WF1 <void >
Takes a screenshot of current screen (filename extension defines format)
late final
TextAppend
↔ WF3 <void >
Append text at specific position and move cursor
late final
TextCopy
↔ WF2 <int >
Copy one string to another, returns bytes copied
late final
TextFindIndex
↔ WF2 <int >
Find first text occurrence within a string, -1 if not found
late final
TextFormat
↔ WF1 <WasmMemoryPointer <RChar > >
Text formatting with variables (sprintf() style)
late final
TextInsert
↔ WF3 <WasmMemoryPointer <RChar > >
Insert text in a defined byte position
late final
TextInsertAlloc
↔ WF3 <WasmMemoryPointer <RChar > >
Insert text in a defined byte position, memory must be freed
late final
TextIsEqual
↔ WF2 <bool >
Check if two text string are equal
late final
TextJoin
↔ WF3 <WasmMemoryPointer <RChar > >
Join text strings with delimiter (delimiter is expected to be length of 1)
late final
TextLength
↔ WF1 <int >
Get text length
late final
TextRemoveSpaces
↔ WF1 <WasmMemoryPointer <RChar > >
Remove text spaces, concat words
late final
TextReplace
↔ WF3 <WasmMemoryPointer <RChar > >
Replace text string with new string
late final
TextReplaceAlloc
↔ WF3 <WasmMemoryPointer <RChar > >
Replace text string with new string, memory must be freed
late final
TextReplaceBetween
↔ WF4 <WasmMemoryPointer <RChar > >
Replace text between two specific strings
late final
TextReplaceBetweenAlloc
↔ WF4 <WasmMemoryPointer <RChar > >
Replace text between two specific strings, memory must be freed
late final
TextSplit
↔ WF3 <WasmMemoryPointer <RPointer <RChar > > >
Split text into multiple strings
late final
TextSubtext
↔ WF3 <WasmMemoryPointer <RChar > >
Get a piece of a text string
late final
TextToCamel
↔ WF1 <WasmMemoryPointer <RChar > >
Get Camel case notation version of provided string
late final
TextToFloat
↔ WF1 <double >
Get float value from text
late final
TextToInteger
↔ WF1 <int >
Get integer value from text
late final
TextToLower
↔ WF1 <WasmMemoryPointer <RChar > >
Get lower case version of provided string
late final
TextToPascal
↔ WF1 <WasmMemoryPointer <RChar > >
Get Pascal case notation version of provided string
late final
TextToSnake
↔ WF1 <WasmMemoryPointer <RChar > >
Get Snake case notation version of provided string
late final
TextToUpper
↔ WF1 <WasmMemoryPointer <RChar > >
Get upper case version of provided string
late final
ToggleBorderlessWindowed
↔ WF0 <void >
Toggle window state: borderless windowed, resizes window to match monitor resolution
late final
ToggleFullscreen
↔ WF0 <void >
Toggle window state: fullscreen/windowed, resizes monitor to match window resolution
late final
TraceLog
↔ WF2 <void >
Show trace log messages (LOG_DEBUG, LOG_INFO, LOG_WARNING, LOG_ERROR...)
late final
UnloadAutomationEventList
↔ WF1 <void >
Unload automation events list from file
late final
UnloadCodepoints
↔ WF1 <void >
Unload codepoints data from memory
late final
UnloadDirectoryFiles
↔ WF1 <void >
Unload filepaths
late final
UnloadDroppedFiles
↔ WF1 <void >
Unload dropped filepaths
late final
UnloadFileData
↔ WF1 <void >
Unload file data allocated by LoadFileData()
late final
UnloadFileText
↔ WF1 <void >
Unload file text data allocated by LoadFileText()
late final
UnloadFont
↔ WF1 <void >
Unload font from GPU memory (VRAM)
late final
UnloadFontData
↔ WF2 <void >
Unload font chars info data (RAM)
late final
UnloadImage
↔ WF1 <void >
Unload image from CPU memory (RAM)
late final
UnloadImageColors
↔ WF1 <void >
Unload color data loaded with LoadImageColors()
late final
UnloadImagePalette
↔ WF1 <void >
Unload colors palette loaded with LoadImagePalette()
late final
UnloadMaterial
↔ WF1 <void >
Unload material from GPU memory (VRAM)
late final
UnloadMesh
↔ WF1 <void >
Unload mesh data from CPU and GPU
late final
UnloadModel
↔ WF1 <void >
Unload model (including meshes) from memory (RAM and/or VRAM)
late final
UnloadModelAnimations
↔ WF2 <void >
Unload animation array data
late final
UnloadRandomSequence
↔ WF1 <void >
Unload random values sequence
late final
UnloadRenderTexture
↔ WF1 <void >
Unload render texture from GPU memory (VRAM)
late final
UnloadShader
↔ WF1 <void >
Unload shader from GPU memory (VRAM)
late final
UnloadTextLines
↔ WF2 <void >
Unload text lines
late final
UnloadTexture
↔ WF1 <void >
Unload texture from GPU memory (VRAM)
late final
UnloadUTF8
↔ WF1 <void >
Unload UTF-8 text encoded from codepoints array
late final
UnloadVrStereoConfig
↔ WF1 <void >
Unload VR stereo config
late final
UpdateCamera
↔ WF2 <void >
Update camera position for selected mode
late final
UpdateCameraPro
↔ WF4 <void >
Update camera movement/rotation
late final
UpdateGestures
↔ WF0 <void >
Update gestures detected (must be called every frame)
late final
UpdateMeshBuffer
↔ WF5 <void >
Update mesh vertex data in GPU for a specific buffer index
late final
UpdateModelAnimation
↔ WF3 <void >
Update model animation pose (CPU)
late final
UpdateModelAnimationEx
↔ WF6 <void >
Update model animation data (vertex buffers / bone matrices) for a specific pose,
defined by two different animations at specific frames blended together
late final
UpdateTexture
↔ WF2 <void >
Update GPU texture with new data
late final
UpdateTextureRec
↔ WF3 <void >
Update GPU texture rectangle with new data
late final
UploadMesh
↔ WF2 <void >
Upload mesh vertex data in GPU and provide VAO/VBO ids
late final
WaitTime
↔ WF1 <void >
Wait for some time (halt program execution)
late final
WindowShouldClose
↔ WF0 <bool >
Check if application should close (KeyboardKey.KEY_ESCAPE pressed or windows close icon clicked)
late final
Methods
debug (bool v )
→ void
Enables or disables debug logging for this module.
inherited
debugError (String message )
→ void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter (bool filter (String ) )
→ void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo (String message )
→ void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime (bool v )
→ void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn (String message )
→ void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync <T > (T f () )
→ T
Executes f with RaylibTemp syncing temporarily disabled,
restoring the previous sync state afterward.
inherited
dispose ()
→ void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed <D extends RaylibStruct <D > > (D struct , void fn (StructPointer <D > ptr ) )
→ void
Disposes struct, invokes fn with its underlying pointer, and then frees
the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted <D extends RaylibStruct <D > > (D struct , void fn (StructPointer <D > ptr ) )
→ void
Disposes struct, invokes fn with its underlying pointer, and then
unslots the temporary allocation backing the pointer, if any.
inherited
dwrap0 <R > (String name )
→ WF0 <R >
Binds a cwraped C function taking 0 arguments and returning a plain
(non-struct) value.
inherited
dwrap1 <R > (String name )
→ WF1 <R >
Binds a cwraped C function taking 1 argument and returning a plain
(non-struct) value.
inherited
dwrap2 <R > (String name )
→ WF2 <R >
Binds a cwraped C function taking 2 arguments and returning a plain
(non-struct) value.
inherited
dwrap3 <R > (String name )
→ WF3 <R >
Binds a cwraped C function taking 3 arguments and returning a plain
(non-struct) value.
inherited
dwrap4 <R > (String name )
→ WF4 <R >
Binds a cwraped C function taking 4 arguments and returning a plain
(non-struct) value.
inherited
dwrap5 <R > (String name )
→ WF5 <R >
Binds a cwraped C function taking 5 arguments and returning a plain
(non-struct) value.
inherited
dwrap6 <R > (String name )
→ WF6 <R >
Binds a cwraped C function taking 6 arguments and returning a plain
(non-struct) value.
inherited
dwrap7 <R > (String name )
→ WF7 <R >
Binds a cwraped C function taking 7 arguments and returning a plain
(non-struct) value.
inherited
dwrap8 <R > (String name )
→ WF8 <R >
Binds a cwraped C function taking 8 arguments and returning a plain
(non-struct) value.
inherited
dwrap9 <R > (String name )
→ WF9 <R >
Binds a cwraped C function taking 9 arguments and returning a plain
(non-struct) value.
inherited
load ()
→ void
Override to perform one-time module initialization.
inherited
logError (Object ? message )
→ void
inherited
logInfo (Object ? message )
→ void
inherited
logWarn (Object ? message )
→ void
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose (void fn () )
→ void
Registers fn to be called when this module is disposed.
inherited
pwrap0 <X extends RType > (String name )
→ WF0 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 0 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap1 <X extends RType > (String name )
→ WF1 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 1 argument and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap2 <X extends RType > (String name )
→ WF2 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 2 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap3 <X extends RType > (String name )
→ WF3 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 3 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap4 <X extends RType > (String name )
→ WF4 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 4 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap5 <X extends RType > (String name )
→ WF5 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 5 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap6 <X extends RType > (String name )
→ WF6 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 6 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap7 <X extends RType > (String name )
→ WF7 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 7 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap8 <X extends RType > (String name )
→ WF8 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 8 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap9 <X extends RType > (String name )
→ WF9 <WasmMemoryPointer <X > >
Binds a cwraped C function taking 9 arguments and returning a
pointer, wrapped as WasmMemoryPointer<X>.
inherited
qwrap0 <X extends RaylibStruct <X > > (String name )
→ WF0 <StructPointer <X > >
Binds a cwraped C function taking 0 arguments and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap1 <X extends RaylibStruct <X > > (String name )
→ WF1 <StructPointer <X > >
Binds a cwraped C function taking 1 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap2 <X extends RaylibStruct <X > > (String name )
→ WF2 <StructPointer <X > >
Binds a cwraped C function taking 2 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap3 <X extends RaylibStruct <X > > (String name )
→ WF3 <StructPointer <X > >
Binds a cwraped C function taking 3 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap4 <X extends RaylibStruct <X > > (String name )
→ WF4 <StructPointer <X > >
Binds a cwraped C function taking 4 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap5 <X extends RaylibStruct <X > > (String name )
→ WF5 <StructPointer <X > >
Binds a cwraped C function taking 5 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap6 <X extends RaylibStruct <X > > (String name )
→ WF6 <StructPointer <X > >
Binds a cwraped C function taking 6 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap7 <X extends RaylibStruct <X > > (String name )
→ WF7 <StructPointer <X > >
Binds a cwraped C function taking 7 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap8 <X extends RaylibStruct <X > > (String name )
→ WF8 <StructPointer <X > >
Binds a cwraped C function taking 8 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
qwrap9 <X extends RaylibStruct <X > > (String name )
→ WF9 <StructPointer <X > >
Binds a cwraped C function taking 9 argument and returning a
struct pointer, wrapped as StructPointer<X>.
inherited
run <T > (String name (), T f () )
→ T
Executes f, logging its label (and optionally timing it) when debug is enabled
and the label passes all filters.
inherited
swrap0 (String name )
→ WF1 <void >
Binds a cwraped C function taking 0 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap1 (String name )
→ WF2 <void >
Binds a cwraped C function taking 1 argument that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap2 (String name )
→ WF3 <void >
Binds a cwraped C function taking 2 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap3 (String name )
→ WF4 <void >
Binds a cwraped C function taking 3 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap4 (String name )
→ WF5 <void >
Binds a cwraped C function taking 4 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap5 (String name )
→ WF6 <void >
Binds a cwraped C function taking 5 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap6 (String name )
→ WF7 <void >
Binds a cwraped C function taking 6 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap7 (String name )
→ WF8 <void >
Binds a cwraped C function taking 7 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
swrap8 (String name )
→ WF9 <void >
Binds a cwraped C function taking 8 arguments that returns a struct
via the WASM structure-return (sret) convention.
inherited
symbol <X extends RType > (String name )
→ WasmMemoryPointer <X >
Resolves a global symbol exported by the WASM module and wraps its
address as a WasmMemoryPointer .
inherited
toString ()
→ String
A string representation of this object.
inherited
raylib_dartified_web 6.0.1