RaylibCoreD class

Inheritance

Constructors

RaylibCoreD(Raylib rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
RaylibCaptureIds RaylibCoreModuleCaptureIds
Capture ID generator for pointer slots allocated by this module.
finalinherited
RaylibDebugLabels RaylibCoreModuleDebugLabels
Debug label generator for this module's function calls.
finalinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

BeginBlendMode(BlendMode mode) → void
override
BeginDrawing() → void
override
BeginMode2D(Camera2DD camera) → void
override
BeginMode3D(Camera3DD camera) → void
override
BeginScissorMode(num x, num y, num width, num height) → void
override
BeginShaderMode(ShaderD shader) → void
override
BeginTextureMode(RenderTextureD target) → void
override
BeginVrStereoMode(VrStereoConfigD config) → void
override
ChangeDirectory(String dir) bool
override
CheckCollisionBoxes(BoundingBoxD box1, BoundingBoxD box2) bool
override
CheckCollisionBoxSphere(BoundingBoxD box, Vector3D center, num radius) bool
override
CheckCollisionCircleLine(Vector2D center, num radius, Vector2D p1, Vector2D p2) bool
override
CheckCollisionCircleRec(Vector2D center, num radius, RectangleD rec) bool
override
CheckCollisionCircles(Vector2D center1, num radius1, Vector2D center2, num radius2) bool
override
CheckCollisionLines(Vector2D startPos1, Vector2D endPos1, Vector2D startPos2, Vector2D endPos2) → (bool, Vector2D)
override
CheckCollisionPointCircle(Vector2D point, Vector2D center, num radius) bool
override
CheckCollisionPointLine(Vector2D point, Vector2D p1, Vector2D p2, num threshold) bool
override
CheckCollisionPointPoly(Vector2D point, List<Vector2D> points) bool
override
CheckCollisionPointRec(Vector2D point, RectangleD rec) bool
override
CheckCollisionPointTriangle(Vector2D point, Vector2D p1, Vector2D p2, Vector2D p3) bool
override
CheckCollisionRecs(RectangleD rec1, RectangleD rec2) bool
override
CheckCollisionSpheres(Vector3D center1, num radius1, Vector3D center2, num radius2) bool
override
ClearBackground(ColorD color) → void
override
ClearWindowState(Iterable<ConfigFlags> flags) → void
override
CloseWindow() → void
override
CodepointToUTF8(num codepoint) → (String, int)
override
ColorAlpha(ColorD color, num alpha) ColorD
override
ColorAlphaBlend(ColorD dst, ColorD src, ColorD tint) ColorD
override
ColorBrightness(ColorD color, num factor) ColorD
override
ColorContrast(ColorD color, num contrast) ColorD
override
ColorFromHSV(num hue, num saturation, num value) ColorD
override
ColorFromNormalized(Vector4D normalized) ColorD
override
ColorIsEqual(ColorD col1, ColorD col2) bool
override
ColorLerp(ColorD color1, ColorD color2, num factor) ColorD
override
ColorNormalize(ColorD color) Vector4D
override
ColorTint(ColorD color, ColorD tint) ColorD
override
ColorToHSV(ColorD color) Vector3D
override
ColorToInt(ColorD color) int
override
CompressData(Uint8List data) Uint8List
override
ComputeCRC32(Uint8List data) int
override
ComputeMD5(Uint8List data) Uint8List
override
ComputeSHA1(Uint8List data) Uint8List
override
debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
DecodeDataBase64(Uint8List data) Uint8List
override
DecompressData(Uint8List compData) Uint8List
override
DirectoryExists(String dirPath) bool
override
DisableCursor() → void
override
DisableEventWaiting() → void
override
disableSync<T>(T f()) → T
Executes f with RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
override
doLoad() → void
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
DrawBillboard(Camera3DD camera, TextureD texture, Vector3D position, num scale, ColorD tint) → void
override
DrawBillboardPro(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector3D up, Vector2D size, Vector2D origin, num rotation, ColorD tint) → void
override
DrawBillboardRec(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector2D size, ColorD tint) → void
override
DrawBoundingBox(BoundingBoxD box, ColorD color) → void
override
DrawCapsule(Vector3D startPos, Vector3D endPos, num radius, num slices, num rings, ColorD color) → void
override
DrawCapsuleWires(Vector3D startPos, Vector3D endPos, num radius, num slices, num rings, ColorD color) → void
override
DrawCircle(num centerX, num centerY, num radius, ColorD color) → void
override
DrawCircle3D(Vector3D center, num radius, Vector3D rotationAxis, num rotationAngle, ColorD color) → void
override
DrawCircleGradient(num centerX, num centerY, num radius, ColorD inner, ColorD outer) → void
override
DrawCircleLines(num centerX, num centerY, num radius, ColorD color) → void
override
DrawCircleLinesV(Vector2D center, num radius, ColorD color) → void
override
DrawCircleSector(Vector2D center, num radius, num startAngle, num endAngle, num segments, ColorD color) → void
override
DrawCircleSectorLines(Vector2D center, num radius, num startAngle, num endAngle, num segments, ColorD color) → void
override
DrawCircleV(Vector2D center, num radius, ColorD color) → void
override
DrawCube(Vector3D position, num width, num height, num length, ColorD color) → void
override
DrawCubeV(Vector3D position, Vector3D size, ColorD color) → void
override
DrawCubeWires(Vector3D position, num width, num height, num length, ColorD color) → void
override
DrawCubeWiresV(Vector3D position, Vector3D size, ColorD color) → void
override
DrawCylinder(Vector3D position, num radiusTop, num radiusBottom, num height, num slices, ColorD color) → void
override
DrawCylinderEx(Vector3D startPos, Vector3D endPos, num startRadius, num endRadius, num sides, ColorD color) → void
override
DrawCylinderWires(Vector3D position, num radiusTop, num radiusBottom, num height, num slices, ColorD color) → void
override
DrawCylinderWiresEx(Vector3D startPos, Vector3D endPos, num startRadius, num endRadius, num sides, ColorD color) → void
override
DrawEllipse(num centerX, num centerY, num radiusH, num radiusV, ColorD color) → void
override
DrawEllipseLines(num centerX, num centerY, num radiusH, num radiusV, ColorD color) → void
override
DrawFPS(num posX, num posY) → void
override
DrawGrid(num slices, num spacing) → void
override
DrawLine(num startPosX, num startPosY, num endPosX, num endPosY, ColorD color) → void
override
DrawLine3D(Vector3D startPos, Vector3D endPos, ColorD color) → void
override
DrawLineBezier(Vector2D startPos, Vector2D endPos, num thick, ColorD color) → void
override
DrawLineEx(Vector2D startPos, Vector2D endPos, num thick, ColorD color) → void
override
DrawLineStrip(List<Vector2D> points, ColorD color) → void
override
DrawLineV(Vector2D startPos, Vector2D endPos, ColorD color) → void
override
DrawMesh(MeshD mesh, MaterialD material, MatrixD transform) → void
override
DrawMeshInstanced(MeshD mesh, MaterialD material, List<MatrixD> transforms) → void
override
DrawModel(ModelD model, Vector3D position, num scale, ColorD tint) → void
override
DrawModelEx(ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint) → void
override
DrawModelPoints(ModelD model, Vector3D position, num scale, ColorD tint) → void
override
DrawModelPointsEx(ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint) → void
override
DrawModelWires(ModelD model, Vector3D position, num scale, ColorD tint) → void
override
DrawModelWiresEx(ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint) → void
override
DrawPixel(num posX, num posY, ColorD color) → void
override
DrawPixelV(Vector2D position, ColorD color) → void
override
DrawPlane(Vector3D centerPos, Vector2D size, ColorD color) → void
override
DrawPoint3D(Vector3D position, ColorD color) → void
override
DrawPoly(Vector2D center, num sides, num radius, num rotation, ColorD color) → void
override
DrawPolyLines(Vector2D center, num sides, num radius, num rotation, ColorD color) → void
override
DrawPolyLinesEx(Vector2D center, num sides, num radius, num rotation, num lineThick, ColorD color) → void
override
DrawRay(RayD ray, ColorD color) → void
override
DrawRectangle(num posX, num posY, num width, num height, ColorD color) → void
override
DrawRectangleGradientEx(RectangleD rec, ColorD topLeft, ColorD bottomLeft, ColorD topRight, ColorD bottomRight) → void
override
DrawRectangleGradientH(num posX, num posY, num width, num height, ColorD left, ColorD right) → void
override
DrawRectangleGradientV(num posX, num posY, num width, num height, ColorD top, ColorD bottom) → void
override
DrawRectangleLines(num posX, num posY, num width, num height, ColorD color) → void
override
DrawRectangleLinesEx(RectangleD rec, num lineThick, ColorD color) → void
override
DrawRectanglePro(RectangleD rec, Vector2D origin, num rotation, ColorD color) → void
override
DrawRectangleRec(RectangleD rec, ColorD color) → void
override
DrawRectangleRounded(RectangleD rec, num roundness, num segments, ColorD color) → void
override
DrawRectangleRoundedLines(RectangleD rec, num roundness, num segments, ColorD color) → void
override
DrawRectangleRoundedLinesEx(RectangleD rec, num roundness, num segments, num lineThick, ColorD color) → void
override
DrawRectangleV(Vector2D position, Vector2D size, ColorD color) → void
override
DrawRing(Vector2D center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorD color) → void
override
DrawRingLines(Vector2D center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorD color) → void
override
DrawSphere(Vector3D centerPos, num radius, ColorD color) → void
override
DrawSphereEx(Vector3D centerPos, num radius, num rings, num slices, ColorD color) → void
override
DrawSphereWires(Vector3D centerPos, num radius, num rings, num slices, ColorD color) → void
override
DrawSplineBasis(List<Vector2D> points, num thick, ColorD color) → void
override
DrawSplineBezierCubic(List<Vector2D> points, num thick, ColorD color) → void
override
DrawSplineBezierQuadratic(List<Vector2D> points, num thick, ColorD color) → void
override
DrawSplineCatmullRom(List<Vector2D> points, num thick, ColorD color) → void
override
DrawSplineLinear(List<Vector2D> points, num thick, ColorD color) → void
override
DrawSplineSegmentBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num thick, ColorD color) → void
override
DrawSplineSegmentBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, num thick, ColorD color) → void
override
DrawSplineSegmentBezierQuadratic(Vector2D p1, Vector2D c2, Vector2D p3, num thick, ColorD color) → void
override
DrawSplineSegmentCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num thick, ColorD color) → void
override
DrawSplineSegmentLinear(Vector2D p1, Vector2D p2, num thick, ColorD color) → void
override
DrawText(String text, num posX, num posY, num fontSize, ColorD color) → void
override
DrawTextCodepoint(FontD font, num codepoint, Vector2D position, num fontSize, ColorD tint) → void
override
DrawTextCodepoints(FontD font, Int32List codepoints, Vector2D position, num fontSize, num spacing, ColorD tint) → void
override
DrawTextEx(FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint) → void
override
DrawTextPro(FontD font, String text, Vector2D position, Vector2D origin, num rotation, num fontSize, num spacing, ColorD tint) → void
override
DrawTexture(TextureD texture, num posX, num posY, ColorD tint) → void
override
DrawTextureEx(TextureD texture, Vector2D position, num rotation, num scale, ColorD tint) → void
override
DrawTextureNPatch(TextureD texture, NPatchInfoD nPatchInfo, RectangleD dest, Vector2D origin, num rotation, ColorD tint) → void
override
DrawTexturePro(TextureD texture, RectangleD source, RectangleD dest, Vector2D origin, num rotation, ColorD tint) → void
override
DrawTextureRec(TextureD texture, RectangleD source, Vector2D position, ColorD tint) → void
override
DrawTextureV(TextureD texture, Vector2D position, ColorD tint) → void
override
DrawTriangle(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
override
DrawTriangle3D(Vector3D v1, Vector3D v2, Vector3D v3, ColorD color) → void
override
DrawTriangleFan(List<Vector2D> points, ColorD color) → void
override
DrawTriangleLines(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
override
DrawTriangleStrip(List<Vector2D> points, ColorD color) → void
override
DrawTriangleStrip3D(List<Vector3D> points, ColorD color) → void
override
EnableCursor() → void
override
EnableEventWaiting() → void
override
EncodeDataBase64(Uint8List data) Uint8List
override
EndBlendMode() → void
override
EndDrawing() → void
override
EndMode2D() → void
override
EndMode3D() → void
override
EndScissorMode() → void
override
EndShaderMode() → void
override
EndTextureMode() → void
override
EndVrStereoMode() → void
override
ExportAutomationEventList(AutomationEventListD list, String fileName) bool
override
ExportDataAsCode(Uint8List data, String fileName) bool
override
ExportFontAsCode(FontD font, String fileName) bool
override
ExportImage(ImageD image, String fileName) bool
override
ExportImageAsCode(ImageD image, String fileName) bool
override
ExportImageToMemory(ImageD image, String fileType) → (int, int)
override
ExportMesh(MeshD mesh, String fileName) bool
override
ExportMeshAsCode(MeshD mesh, String fileName) bool
override
Fade(ColorD color, num alpha) ColorD
override
FileExists(String fileName) bool
override
GenImageCellular(num width, num height, num tileSize) ImageD
override
GenImageChecked(num width, num height, num checksX, num checksY, ColorD col1, ColorD col2) ImageD
override
GenImageColor(num width, num height, ColorD color) ImageD
override
GenImageFontAtlas(List<GlyphInfoD> glyphs, num fontSize, num padding, num packMethod) → (ImageD, List<RectangleD>)
override
GenImageGradientLinear(num width, num height, num direction, ColorD start, ColorD end) ImageD
override
GenImageGradientRadial(num width, num height, num density, ColorD inner, ColorD outer) ImageD
override
GenImageGradientSquare(num width, num height, num density, ColorD inner, ColorD outer) ImageD
override
GenImagePerlinNoise(num width, num height, num offsetX, num offsetY, num scale) ImageD
override
GenImageText(num width, num height, String text) ImageD
override
GenImageWhiteNoise(num width, num height, num factor) ImageD
override
GenMeshCone(num radius, num height, num slices) MeshD
override
GenMeshCube(num width, num height, num length) MeshD
override
GenMeshCubicmap(ImageD cubicmap, Vector3D cubeSize) MeshD
override
GenMeshCylinder(num radius, num height, num slices) MeshD
override
GenMeshHeightmap(ImageD heightmap, Vector3D size) MeshD
override
GenMeshHemiSphere(num radius, num rings, num slices) MeshD
override
GenMeshKnot(num radius, num size, num radSeg, num sides) MeshD
override
GenMeshPlane(num width, num length, num resX, num resZ) MeshD
override
GenMeshPoly(num sides, num radius) MeshD
override
GenMeshSphere(num radius, num rings, num slices) MeshD
override
GenMeshTangents(MeshD mesh) → void
override
GenMeshTorus(num radius, num size, num radSeg, num sides) MeshD
override
GenTextureMipmaps(TextureD texture) → void
override
GetApplicationDirectory() String
override
GetCameraMatrix(Camera3DD camera) MatrixD
override
GetCameraMatrix2D(Camera2DD camera) MatrixD
override
GetCharPressed() int
override
GetClipboardImage() ImageD
override
GetClipboardText() String
override
GetCodepoint(String text) → (int, int)
override
GetCodepointCount(String text) int
override
GetCodepointNext(String text) → (int, int)
override
GetCodepointPrevious(String text) → (int, int)
override
GetCollisionRec(RectangleD rec1, RectangleD rec2) RectangleD
override
GetColor(num hexValue) ColorD
override
GetCurrentMonitor() int
override
GetDirectoryPath(String filePath) String
override
GetFileExtension(String fileName) String
override
GetFileLength(String fileName) int
override
GetFileModTime(String fileName) int
override
GetFileName(String filePath) String
override
GetFileNameWithoutExt(String filePath) String
override
GetFontDefault() FontD
override
GetFPS() int
override
GetFrameTime() double
override
GetGamepadAxisCount(num gamepad) int
override
GetGamepadAxisMovement(num gamepad, GamepadAxis axis) double
override
GetGamepadButtonPressed() GamepadButton
override
GetGamepadName(num gamepad) String
override
GetGestureDetected() Gesture
override
GetGestureDragAngle() double
override
GetGestureDragVector() Vector2D
override
GetGestureHoldDuration() double
override
GetGesturePinchAngle() double
override
GetGesturePinchVector() Vector2D
override
GetGlyphAtlasRec(FontD font, num codepoint) RectangleD
override
GetGlyphIndex(FontD font, num codepoint) int
override
GetGlyphInfo(FontD font, num codepoint) GlyphInfoD
override
GetImageAlphaBorder(ImageD image, num threshold) RectangleD
override
GetImageColor(ImageD image, num x, num y) ColorD
override
GetKeyPressed() int
override
GetMeshBoundingBox(MeshD mesh) BoundingBoxD
override
GetModelBoundingBox(ModelD model) BoundingBoxD
override
GetMonitorCount() int
override
GetMonitorHeight(num monitor) int
override
GetMonitorName(num monitor) String
override
GetMonitorPhysicalHeight(num monitor) int
override
GetMonitorPhysicalWidth(num monitor) int
override
GetMonitorPosition(num monitor) Vector2D
override
GetMonitorRefreshRate(num monitor) int
override
GetMonitorWidth(num monitor) int
override
GetMouseButtonInfo(MouseButton button) MouseButtonInfo
inherited
GetMouseDelta() Vector2D
override
GetMouseInfo() MouseInfo<Vector2D>
inherited
GetMousePosition() Vector2D
override
GetMouseWheelMove() double
override
GetMouseWheelMoveV() Vector2D
override
GetMouseX() int
override
GetMouseY() int
override
GetPixelDataSize(num width, num height, PixelFormat format) int
override
GetPrevDirectoryPath(String dirPath) String
override
GetRandomValue(num min, num max) int
override
GetRayCollisionBox(RayD ray, BoundingBoxD box) RayCollisionD
override
GetRayCollisionMesh(RayD ray, MeshD mesh, MatrixD transform) RayCollisionD
override
GetRayCollisionQuad(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3, Vector3D p4) RayCollisionD
override
GetRayCollisionSphere(RayD ray, Vector3D center, num radius) RayCollisionD
override
GetRayCollisionTriangle(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3) RayCollisionD
override
GetRenderHeight() int
override
GetRenderWidth() int
override
GetScreenHeight() int
override
GetScreenToWorld2D(Vector2D position, Camera2DD camera) Vector2D
override
GetScreenToWorldRay(Vector2D position, Camera3DD camera) RayD
override
GetScreenToWorldRayEx(Vector2D position, Camera3DD camera, num width, num height) RayD
override
GetScreenWidth() int
override
GetShaderLocation(ShaderD shader, String uniformName) int
override
GetShaderLocationAttrib(ShaderD shader, String attribName) int
override
GetShapesTexture() TextureD
override
GetShapesTextureRectangle() RectangleD
override
GetSplinePointBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num t) Vector2D
override
GetSplinePointBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, num t) Vector2D
override
GetSplinePointBezierQuad(Vector2D p1, Vector2D c2, Vector2D p3, num t) Vector2D
override
GetSplinePointCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num t) Vector2D
override
GetSplinePointLinear(Vector2D startPos, Vector2D endPos, num t) Vector2D
override
GetTime() double
override
GetTouchPointCount() int
override
GetTouchPointId(num index) int
override
GetTouchPosition(num index) Vector2D
override
GetTouchX() int
override
GetTouchY() int
override
GetWindowPosition() Vector2D
override
GetWindowScaleDPI() Vector2D
override
GetWorkingDirectory() String
override
GetWorldToScreen(Vector3D position, Camera3DD camera) Vector2D
override
GetWorldToScreen2D(Vector2D position, Camera2DD camera) Vector2D
override
GetWorldToScreenEx(Vector3D position, Camera3DD camera, num width, num height) Vector2D
override
HideCursor() → void
override
ImageAlphaClear(ImageD image, ColorD color, num threshold) → void
override
ImageAlphaCrop(ImageD image, num threshold) → void
override
ImageAlphaMask(ImageD image, ImageD alphaMask) → void
override
ImageAlphaPremultiply(ImageD image) → void
override
ImageBlurGaussian(ImageD image, num blurSize) → void
override
ImageClearBackground(ImageD dst, ColorD color) → void
override
ImageColorBrightness(ImageD image, num brightness) → void
override
ImageColorContrast(ImageD image, num contrast) → void
override
ImageColorGrayscale(ImageD image) → void
override
ImageColorInvert(ImageD image) → void
override
ImageColorReplace(ImageD image, ColorD color, ColorD replace) → void
override
ImageColorTint(ImageD image, ColorD color) → void
override
ImageCopy(ImageD image) ImageD
override
ImageCrop(ImageD image, RectangleD crop) → void
override
ImageDither(ImageD image, num rBpp, num gBpp, num bBpp, num aBpp) → void
override
ImageDraw(ImageD dst, ImageD src, RectangleD srcRec, RectangleD dstRec, ColorD tint) → void
override
ImageDrawCircle(ImageD dst, num centerX, num centerY, num radius, ColorD color) → void
override
ImageDrawCircleLines(ImageD dst, num centerX, num centerY, num radius, ColorD color) → void
override
ImageDrawCircleLinesV(ImageD dst, Vector2D center, num radius, ColorD color) → void
override
ImageDrawCircleV(ImageD dst, Vector2D center, num radius, ColorD color) → void
override
ImageDrawLine(ImageD dst, num startPosX, num startPosY, num endPosX, num endPosY, ColorD color) → void
override
ImageDrawLineEx(ImageD dst, Vector2D start, Vector2D end, num thick, ColorD color) → void
override
ImageDrawLineV(ImageD dst, Vector2D start, Vector2D end, ColorD color) → void
override
ImageDrawPixel(ImageD dst, num posX, num posY, ColorD color) → void
override
ImageDrawPixelV(ImageD dst, Vector2D position, ColorD color) → void
override
ImageDrawRectangle(ImageD dst, num posX, num posY, num width, num height, ColorD color) → void
override
ImageDrawRectangleLines(ImageD dst, RectangleD rec, num thick, ColorD color) → void
override
ImageDrawRectangleRec(ImageD dst, RectangleD rec, ColorD color) → void
override
ImageDrawRectangleV(ImageD dst, Vector2D position, Vector2D size, ColorD color) → void
override
ImageDrawText(ImageD dst, String text, num posX, num posY, num fontSize, ColorD color) → void
override
ImageDrawTextEx(ImageD dst, FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint) → void
override
ImageDrawTriangle(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
override
ImageDrawTriangleEx(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD c1, ColorD c2, ColorD c3) → void
override
ImageDrawTriangleFan(ImageD dst, List<Vector2D> points, ColorD color) → void
override
ImageDrawTriangleLines(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
override
ImageDrawTriangleStrip(ImageD dst, List<Vector2D> points, ColorD color) → void
override
ImageFlipHorizontal(ImageD image) → void
override
ImageFlipVertical(ImageD image) → void
override
ImageFormat(ImageD image, PixelFormat newFormat) → void
override
ImageFromChannel(ImageD image, num selectedChannel) ImageD
override
ImageFromImage(ImageD image, RectangleD rec) ImageD
override
ImageKernelConvolution(ImageD image, List<double> kernel) → void
override
ImageMipmaps(ImageD image) → void
override
ImageResize(ImageD image, num newWidth, num newHeight) → void
override
ImageResizeCanvas(ImageD image, num newWidth, num newHeight, num offsetX, num offsetY, ColorD fill) → void
override
ImageResizeNN(ImageD image, num newWidth, num newHeight) → void
override
ImageRotate(ImageD image, num degrees) → void
override
ImageRotateCCW(ImageD image) → void
override
ImageRotateCW(ImageD image) → void
override
ImageText(String text, num fontSize, ColorD color) ImageD
override
ImageTextEx(FontD font, String text, num fontSize, num spacing, ColorD tint) ImageD
override
ImageToPOT(ImageD image, ColorD fill) → void
override
InitWindow(num width, num height, String title) → void
override
IsCursorHidden() bool
override
IsCursorOnScreen() bool
override
IsFileDropped() bool
override
IsFileExtension(String fileName, String ext) bool
override
IsFileNameValid(String fileName) bool
override
IsFontValid(FontD font) bool
override
IsGamepadAvailable(num gamepad) bool
override
IsGamepadButtonDown(num gamepad, GamepadButton button) bool
override
IsGamepadButtonPressed(num gamepad, GamepadButton button) bool
override
IsGamepadButtonReleased(num gamepad, GamepadButton button) bool
override
IsGamepadButtonUp(num gamepad, GamepadButton button) bool
override
IsGestureDetected(Gesture key) bool
override
IsImageValid(ImageD image) bool
override
IsKeyDown(KeyboardKey key) bool
override
IsKeyPressed(KeyboardKey key) bool
override
IsKeyPressedRepeat(KeyboardKey key) bool
override
IsKeyReleased(KeyboardKey key) bool
override
IsKeyUp(KeyboardKey key) bool
override
IsMaterialValid(MaterialD material) bool
override
IsModelAnimationValid(ModelD model, ModelAnimationD anim) bool
override
IsModelValid(ModelD model) bool
override
IsMouseButtonDown(MouseButton button) bool
override
IsMouseButtonPressed(MouseButton button) bool
override
IsMouseButtonReleased(MouseButton button) bool
override
IsMouseButtonUp(MouseButton button) bool
override
IsPathFile(String path) bool
override
IsRenderTextureValid(RenderTextureD target) bool
override
IsShaderValid(ShaderD shader) bool
override
IsTextureValid(TextureD texture) bool
override
IsWindowFocused() bool
override
IsWindowFullscreen() bool
override
IsWindowHidden() bool
override
IsWindowMaximized() bool
override
IsWindowMinimized() bool
override
IsWindowReady() bool
override
IsWindowResized() bool
override
IsWindowState(ConfigFlags flag) bool
override
load() → void
Override to perform one-time module initialization. Called by doLoad.
inherited
LoadAutomationEventList(String? fileName) AutomationEventListD
override
LoadCodepoints(String text) Int32List
override
LoadDirectoryFiles(String dirPath) FilePathListD
override
LoadDirectoryFilesEx(String basePath, String filter, bool scanSubdirs) FilePathListD
override
LoadDroppedFiles() FilePathListD
override
LoadFileData(String fileName) Uint8List
override
LoadFileText(String fileName) String
override
LoadFont(String fileName) FontD
override
LoadFontData(Uint8List fileData, num fontSize, Int32List? codepoints, num? codepointCount, FontType type) List<GlyphInfoD>
override
LoadFontEx(String fileName, num fontSize, [Int32List? codepoints, num? codePointCount]) FontD
override
LoadFontFromImage(ImageD image, ColorD key, num firstChar) FontD
override
LoadFontFromMemory(String fileType, Uint8List fileData, num fontSize, Int32List codepoints) FontD
override
LoadImage(String fileName) ImageD
override
LoadImageAnim(String fileName) ImageD
override
LoadImageAnimFromMemory(String fileType, Uint8List fileData) ImageD
override
LoadImageColors(ImageD image) List<ColorD>
override
LoadImageFromMemory(String fileType, Uint8List fileData) ImageD
override
LoadImageFromScreen() ImageD
override
LoadImageFromTexture(TextureD texture) ImageD
override
LoadImagePalette(ImageD image, num maxPaletteSize) List<ColorD>
override
LoadImageRaw(String fileName, num width, num height, PixelFormat format, num headerSize) ImageD
override
LoadMaterialDefault() MaterialD
override
LoadMaterials(String fileName) List<MaterialD>
override
LoadModel(String fileName) ModelD
override
LoadModelAnimations(String fileName) List<ModelAnimationD>
override
LoadModelFromMesh(MeshD mesh) ModelD
override
LoadRandomSequence(int count, int min, int max, [int? seed]) List<int>
override
LoadRenderTexture(num width, num height) RenderTextureD
override
LoadShader(String? vsFileName, String? fsFileName) ShaderD
override
LoadShaderFromMemory(String? vsCode, String? fsCode) ShaderD
override
LoadTexture(String fileName) TextureD
override
LoadTextureCubemap(ImageD image, CubemapLayout layout) TextureD
override
LoadTextureFromImage(ImageD image) TextureD
override
LoadUTF8(Int32List codepoints) String
override
LoadVrStereoConfig(VrDeviceInfoD device) VrStereoConfigD
override
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
MakeDirectory(String dirPath) int
override
MaximizeWindow() → void
override
MeasureText(String text, num fontSize) int
override
MeasureTextEx(FontD font, String text, num fontSize, num spacing) Vector2D
override
MinimizeWindow() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
OpenURL(String url) → void
override
PlayAutomationEvent(AutomationEventD event) → void
override
PollInputEvents() → void
override
RestoreWindow() → void
override
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
SaveFileData(String fileName, Uint8List data) bool
override
SaveFileText(String fileName, String text) bool
override
SetAutomationEventBaseFrame(int frame) → void
override
SetAutomationEventList(AutomationEventListD list) → void
override
SetClipboardText(String text) → void
override
SetConfigFlags(Iterable<ConfigFlags> flags) → void
override
SetExitKey(KeyboardKey key) → void
override
SetGamepadMappings(String mappings) int
override
SetGamepadVibration(num gamepad, num leftMotor, num rightMotor, num duration) → void
override
SetGesturesEnabled(Iterable<Gesture> flags) → void
override
SetLoadFileDataCallback(LoadFileDataCallbackD? callback) → void
override
SetLoadFileTextCallback(LoadFileTextCallbackD? callback) → void
override
SetMaterialTexture(MaterialD material, MaterialMapIndex mapType, TextureD texture) → void
override
SetModelMeshMaterial(ModelD model, num meshId, num materialId) → void
override
SetMouseCursor(MouseCursor cursor) → void
override
SetMouseOffset(num offsetX, num offsetY) → void
override
SetMousePosition(num x, num y) → void
override
SetMouseScale(num scaleX, num scaleY) → void
override
SetRandomSeed(num seed) → void
override
SetSaveFileDataCallback(SaveFileDataCallbackD? callback) → void
override
SetSaveFileTextCallback(SaveFileTextCallbackD? callback) → void
override
SetShaderValue(ShaderD shader, num locIndex, List<num> value, ShaderUniformDataType uniformType) → void
override
SetShaderValueMatrix(ShaderD shader, num locIndex, MatrixD mat) → void
override
SetShaderValueTexture(ShaderD shader, num locIndex, TextureD texture) → void
override
SetShaderValueV(ShaderD shader, num locIndex, List<num> value, ShaderUniformDataType uniformType, num count) → void
override
SetShapesTexture(TextureD texture, RectangleD source) → void
override
SetTargetFPS(num fps) → void
override
SetTextLineSpacing(num spacing) → void
override
SetTextureFilter(TextureD texture, TextureFilter filter) → void
override
SetTextureWrap(TextureD texture, TextureWrap wrap) → void
override
SetTraceLogLevel(TraceLogLevel logLevel) → void
override
SetWindowFocused() → void
override
SetWindowIcon(ImageD image) → void
override
SetWindowIcons(List<ImageD> images) → void
override
SetWindowMaxSize(num width, num height) → void
override
SetWindowMinSize(num width, num height) → void
override
SetWindowMonitor(num monitor) → void
override
SetWindowOpacity(num opacity) → void
override
SetWindowPosition(num x, num y) → void
override
SetWindowSize(num width, num height) → void
override
SetWindowState(Iterable<ConfigFlags> flags) → void
override
SetWindowTitle(String title) → void
override
ShowCursor() → void
override
StartAutomationEventRecording() → void
override
StopAutomationEventRecording() → void
override
SwapScreenBuffer() → void
override
TakeScreenshot(String fileName) → void
override
ToggleBorderlessWindowed() → void
override
ToggleFullscreen() → void
override
toString() String
A string representation of this object.
inherited
TraceLog(TraceLogLevel logLevel, String text) → void
override
UnloadAutomationEventList(AutomationEventListD list) → void
override
UnloadDroppedFiles(FilePathListD files) → void
override
UnloadFont(FontD font) → void
override
UnloadFontData(List<GlyphInfoD> glyphs) → void
override
UnloadImage(ImageD image) → void
override
UnloadMaterial(MaterialD material) → void
override
UnloadMesh(MeshD mesh) → void
override
UnloadModel(ModelD model) → void
override
UnloadModelAnimation(ModelAnimationD anim) → void
override
UnloadModelAnimations(List<ModelAnimationD> animations) → void
override
UnloadRenderTexture(RenderTextureD target) → void
override
UnloadShader(ShaderD shader) → void
override
UnloadTexture(TextureD texture) → void
override
UnloadVrStereoConfig(VrStereoConfigD config) → void
override
UpdateCamera(Camera3DD camera, CameraMode mode) → void
override
UpdateCameraPro(Camera3DD camera, Vector3D movement, Vector3D rotation, num zoom) → void
override
UpdateMeshBuffer(MeshD mesh, num index, TypedDataList data, num offset) → void
override
UpdateModelAnimation(ModelD model, ModelAnimationD anim, num frame) → void
override
UpdateModelAnimationBones(ModelD model, ModelAnimationD anim, num frame) → void
override
UpdateTexture(TextureD texture, Uint8List pixels) → void
override
UpdateTextureRec(TextureD texture, RectangleD rec, Uint8List pixels) → void
override
UploadMesh(MeshD mesh, bool dynamic) → void
override
WaitTime(num seconds) → void
override
WindowShouldClose() bool
override

Operators

operator ==(Object other) bool
The equality operator.
inherited