RaylibGame class abstract
- Inheritance
-
- Object
- RaylibGameBase<
Raylib> - RaylibGame
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
Raylib rl) → void -
Called once after shouldClose returns
true.inherited -
dispose(
Raylib rl) → void -
Called after close to release any remaining Dart-side resources.
inherited
-
init(
Raylib rl) → void -
Called once before the game loop starts.
inherited
-
loop(
Raylib rl) → void -
Called once per frame while shouldClose returns
false.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldClose(
Raylib rl) → bool -
Returns
truewhen the game loop should stop.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited