RaylibGui class
- Inheritance
-
- Object
- RaylibModule<
Raylib> - RaylibModuleWasm
- RaylibGui
- Mixed-in types
Properties
- GuiButton ↔ JSFunction
-
latefinal
- GuiCheckBox ↔ JSFunction
-
latefinal
- GuiColorBarAlpha ↔ JSFunction
-
latefinal
- GuiColorBarHue ↔ JSFunction
-
latefinal
- GuiColorPanel ↔ JSFunction
-
latefinal
- GuiColorPanelHSV ↔ JSFunction
-
latefinal
- GuiColorPicker ↔ JSFunction
-
latefinal
- GuiColorPickerHSV ↔ JSFunction
-
latefinal
- GuiComboBox ↔ JSFunction
-
latefinal
- GuiDisable ↔ JSFunction
-
latefinal
- GuiDisableTooltip ↔ JSFunction
-
latefinal
- GuiDrawIcon ↔ JSFunction
-
latefinal
- GuiDropdownBox ↔ JSFunction
-
latefinal
- GuiDummyRec ↔ JSFunction
-
latefinal
- GuiEnable ↔ JSFunction
-
latefinal
- GuiEnableTooltip ↔ JSFunction
-
latefinal
- GuiGetFont ↔ JSFunction
-
latefinal
- GuiGetIcons ↔ JSFunction
-
latefinal
- GuiGetState ↔ JSFunction
-
latefinal
- GuiGetStyle ↔ JSFunction
-
latefinal
- GuiGetTextWidth ↔ JSFunction
-
latefinal
- GuiGrid ↔ JSFunction
-
latefinal
- GuiGroupBox ↔ JSFunction
-
latefinal
- GuiIconText ↔ JSFunction
-
latefinal
- GuiIsLocked ↔ JSFunction
-
latefinal
- GuiLabel ↔ JSFunction
-
latefinal
- GuiLabelButton ↔ JSFunction
-
latefinal
- GuiLine ↔ JSFunction
-
latefinal
- GuiListView ↔ JSFunction
-
latefinal
- GuiListViewEx ↔ JSFunction
-
latefinal
- GuiLoadIcons ↔ JSFunction
-
latefinal
- GuiLoadStyle ↔ JSFunction
-
latefinal
- GuiLoadStyleDefault ↔ JSFunction
-
latefinal
- GuiLock ↔ JSFunction
-
latefinal
- GuiMessageBox ↔ JSFunction
-
latefinal
- GuiPanel ↔ JSFunction
-
latefinal
- GuiProgressBar ↔ JSFunction
-
latefinal
- GuiScrollPanel ↔ JSFunction
-
latefinal
- GuiSetAlpha ↔ JSFunction
-
latefinal
- GuiSetFont ↔ JSFunction
-
latefinal
- GuiSetIconScale ↔ JSFunction
-
latefinal
- GuiSetState ↔ JSFunction
-
latefinal
- GuiSetStyle ↔ JSFunction
-
latefinal
- GuiSetTooltip ↔ JSFunction
-
latefinal
- GuiSlider ↔ JSFunction
-
latefinal
- GuiSliderBar ↔ JSFunction
-
latefinal
- GuiSpinner ↔ JSFunction
-
latefinal
- GuiStatusBar ↔ JSFunction
-
latefinal
- GuiTabBar ↔ JSFunction
-
latefinal
- GuiTextBox ↔ JSFunction
-
latefinal
- GuiTextInputBox ↔ JSFunction
-
latefinal
- GuiToggle ↔ JSFunction
-
latefinal
- GuiToggleGroup ↔ JSFunction
-
latefinal
- GuiToggleSlider ↔ JSFunction
-
latefinal
- GuiUnlock ↔ JSFunction
-
latefinal
- GuiValueBox ↔ JSFunction
-
latefinal
- GuiValueBoxFloat ↔ JSFunction
-
latefinal
- GuiWindowBox ↔ JSFunction
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- n → String
-
finalinherited
- RAYGUI_COLORBARALPHA_CHECKED_SIZE → int
-
no setterinherited
- RAYGUI_GRID_ALPHA → double
-
no setterinherited
- RAYGUI_GROUPBOX_LINE_THICK → int
-
no setterinherited
- RAYGUI_ICON_DATA_ELEMENTS → int
-
no setterinherited
- RAYGUI_ICON_MAX_ICONS → int
-
no setterinherited
- RAYGUI_ICON_MAX_NAME_LENGTH → int
-
no setterinherited
- RAYGUI_ICON_SIZE → int
-
no setterinherited
- RAYGUI_ICON_TEXT_PADDING → int
-
no setterinherited
-
RAYGUI_ICONS
→ List<
int> -
no setterinherited
- RAYGUI_LINE_MARGIN_TEXT → int
-
no setterinherited
- RAYGUI_LINE_TEXT_PADDING → int
-
no setterinherited
- RAYGUI_MAX_CONTROLS → int
-
no setterinherited
- RAYGUI_MAX_LINE_BUFFER_SIZE → int
-
no setterinherited
- RAYGUI_MAX_PROPS_BASE → int
-
no setterinherited
- RAYGUI_MAX_PROPS_EXTENDED → int
-
no setterinherited
- RAYGUI_MAX_TEXT_LINES → int
-
no setterinherited
- RAYGUI_MESSAGEBOX_BUTTON_HEIGHT → int
-
no setterinherited
- RAYGUI_MESSAGEBOX_BUTTON_PADDING → int
-
no setterinherited
- RAYGUI_MIN_MOUSE_WHEEL_SPEED → int
-
no setterinherited
- RAYGUI_MIN_SCROLLBAR_HEIGHT → int
-
no setterinherited
- RAYGUI_MIN_SCROLLBAR_WIDTH → int
-
no setterinherited
- RAYGUI_PANEL_BORDER_WIDTH → int
-
no setterinherited
- RAYGUI_SCROLLBAR_LEFT_SIDE → int
-
no setterinherited
- RAYGUI_SCROLLBAR_RIGHT_SIDE → int
-
no setterinherited
- RAYGUI_TABBAR_ITEM_WIDTH → int
-
no setterinherited
- RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN → int
-
no setterinherited
- RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY → int
-
no setterinherited
- RAYGUI_TEXTFORMAT_MAX_SIZE → int
-
no setterinherited
- RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT → int
-
no setterinherited
- RAYGUI_TEXTINPUTBOX_BUTTON_PADDING → int
-
no setterinherited
- RAYGUI_TEXTINPUTBOX_HEIGHT → int
-
no setterinherited
- RAYGUI_TEXTSPLIT_MAX_ITEMS → int
-
no setterinherited
- RAYGUI_TEXTSPLIT_MAX_TEXT_SIZE → int
-
no setterinherited
- RAYGUI_TOGGLEGROUP_MAX_ITEMS → int
-
no setterinherited
- RAYGUI_VALUEBOX_MAX_CHARS → int
-
no setterinherited
- RAYGUI_VERSION → String
-
no setterinherited
- RAYGUI_VERSION_MAJOR → int
-
no setterinherited
- RAYGUI_VERSION_MINOR → int
-
no setterinherited
- RAYGUI_VERSION_PATCH → int
-
no setterinherited
- RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT → int
-
no setterinherited
- rl → Raylib
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s → String
-
finalinherited
Methods
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
doLoad(
) → void -
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
-
load(
) → void -
Override to perform one-time module initialization. Called by doLoad.
inherited
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited