RaylibLightFlat class
Constructors
- RaylibLightFlat(dynamic rl)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
CreateLight(
int type, Vector3D position, Vector3D target, ColorD color, ShaderD shader) → LightD -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
UpdateLightValues(
ShaderD shader, LightD light) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited