RaylibRlgl class
- Inheritance
-
- Object
- RaylibModule<
Raylib> - RaylibModuleWasm
- RaylibRlgl
- Mixed-in types
Constructors
- RaylibRlgl(Raylib rl)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- n → String
-
finalinherited
- rl → Raylib
-
finalinherited
- RL_BLEND_COLOR → int
-
no setterinherited
- RL_BLEND_DST_ALPHA → int
-
no setterinherited
- RL_BLEND_DST_RGB → int
-
no setterinherited
- RL_BLEND_EQUATION → int
-
no setterinherited
- RL_BLEND_EQUATION_ALPHA → int
-
no setterinherited
- RL_BLEND_EQUATION_RGB → int
-
no setterinherited
- RL_BLEND_SRC_ALPHA → int
-
no setterinherited
- RL_BLEND_SRC_RGB → int
-
no setterinherited
- RL_COMPUTE_SHADER → int
-
no setterinherited
- RL_CONSTANT_ALPHA → int
-
no setterinherited
- RL_CONSTANT_COLOR → int
-
no setterinherited
- RL_CULL_DISTANCE_FAR → double
-
no setterinherited
- RL_CULL_DISTANCE_NEAR → double
-
no setterinherited
- RL_DEFAULT_BATCH_BUFFER_ELEMENTS → int
-
no setterinherited
- RL_DEFAULT_BATCH_BUFFERS → int
-
no setterinherited
- RL_DEFAULT_BATCH_DRAWCALLS → int
-
no setterinherited
- RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEIDS → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEWEIGHTS → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_COLOR → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_INDICES → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_NORMAL → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_POSITION → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_TANGENT → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD → int
-
no setterinherited
- RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD2 → int
-
no setterinherited
- RL_DRAW_FRAMEBUFFER → int
-
no setterinherited
- RL_DST_ALPHA → int
-
no setterinherited
- RL_DST_COLOR → int
-
no setterinherited
- RL_DYNAMIC_COPY → int
-
no setterinherited
- RL_DYNAMIC_DRAW → int
-
no setterinherited
- RL_DYNAMIC_READ → int
-
no setterinherited
- RL_FLOAT → int
-
no setterinherited
- RL_FRAGMENT_SHADER → int
-
no setterinherited
- RL_FUNC_ADD → int
-
no setterinherited
- RL_FUNC_REVERSE_SUBTRACT → int
-
no setterinherited
- RL_FUNC_SUBTRACT → int
-
no setterinherited
- RL_LINES → int
-
no setterinherited
- RL_MAX → int
-
no setterinherited
- RL_MAX_MATRIX_STACK_SIZE → int
-
no setterinherited
- RL_MAX_SHADER_LOCATIONS → int
-
no setterinherited
- RL_MIN → int
-
no setterinherited
- RL_MODELVIEW → int
-
no setterinherited
- RL_ONE → int
-
no setterinherited
- RL_ONE_MINUS_CONSTANT_ALPHA → int
-
no setterinherited
- RL_ONE_MINUS_CONSTANT_COLOR → int
-
no setterinherited
- RL_ONE_MINUS_DST_ALPHA → int
-
no setterinherited
- RL_ONE_MINUS_DST_COLOR → int
-
no setterinherited
- RL_ONE_MINUS_SRC_ALPHA → int
-
no setterinherited
- RL_ONE_MINUS_SRC_COLOR → int
-
no setterinherited
- RL_PROJECTION → int
-
no setterinherited
- RL_QUADS → int
-
no setterinherited
- RL_READ_FRAMEBUFFER → int
-
no setterinherited
- RL_SHADER_LOC_MAP_DIFFUSE → int
-
no setterinherited
- RL_SHADER_LOC_MAP_SPECULAR → int
-
no setterinherited
- RL_SRC_ALPHA → int
-
no setterinherited
- RL_SRC_ALPHA_SATURATE → int
-
no setterinherited
- RL_SRC_COLOR → int
-
no setterinherited
- RL_STATIC_COPY → int
-
no setterinherited
- RL_STATIC_DRAW → int
-
no setterinherited
- RL_STATIC_READ → int
-
no setterinherited
- RL_STREAM_COPY → int
-
no setterinherited
- RL_STREAM_DRAW → int
-
no setterinherited
- RL_STREAM_READ → int
-
no setterinherited
- RL_TEXTURE → int
-
no setterinherited
- RL_TEXTURE_FILTER_ANISOTROPIC → int
-
no setterinherited
- RL_TEXTURE_FILTER_LINEAR → int
-
no setterinherited
- RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST → int
-
no setterinherited
- RL_TEXTURE_FILTER_MIP_LINEAR → int
-
no setterinherited
- RL_TEXTURE_FILTER_MIP_NEAREST → int
-
no setterinherited
- RL_TEXTURE_FILTER_NEAREST → int
-
no setterinherited
- RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR → int
-
no setterinherited
- RL_TEXTURE_MAG_FILTER → int
-
no setterinherited
- RL_TEXTURE_MIN_FILTER → int
-
no setterinherited
- RL_TEXTURE_MIPMAP_BIAS_RATIO → int
-
no setterinherited
- RL_TEXTURE_WRAP_CLAMP → int
-
no setterinherited
- RL_TEXTURE_WRAP_MIRROR_CLAMP → int
-
no setterinherited
- RL_TEXTURE_WRAP_MIRROR_REPEAT → int
-
no setterinherited
- RL_TEXTURE_WRAP_REPEAT → int
-
no setterinherited
- RL_TEXTURE_WRAP_S → int
-
no setterinherited
- RL_TEXTURE_WRAP_T → int
-
no setterinherited
- RL_TRIANGLES → int
-
no setterinherited
- RL_UNSIGNED_BYTE → int
-
no setterinherited
- RL_VERTEX_SHADER → int
-
no setterinherited
- RL_ZERO → int
-
no setterinherited
- rlActiveDrawBuffers ↔ JSFunction
-
latefinal
- rlActiveTextureSlot ↔ JSFunction
-
latefinal
- rlBegin ↔ JSFunction
-
latefinal
- rlBindFramebuffer ↔ JSFunction
-
latefinal
- rlBindImageTexture ↔ JSFunction
-
latefinal
- rlBindShaderBuffer ↔ JSFunction
-
latefinal
- rlBlitFramebuffer ↔ JSFunction
-
latefinal
- rlCheckErrors ↔ JSFunction
-
latefinal
- rlCheckRenderBatchLimit ↔ JSFunction
-
latefinal
- rlClearColor ↔ JSFunction
-
latefinal
- rlClearScreenBuffers ↔ JSFunction
-
latefinal
- rlColor3f ↔ JSFunction
-
latefinal
- rlColor4f ↔ JSFunction
-
latefinal
- rlColor4ub ↔ JSFunction
-
latefinal
- rlColorMask ↔ JSFunction
-
latefinal
- rlCompileShader ↔ JSFunction
-
latefinal
- rlComputeShaderDispatch ↔ JSFunction
-
latefinal
- rlCopyShaderBuffer ↔ JSFunction
-
latefinal
- rlCubemapParameters ↔ JSFunction
-
latefinal
- rlDisableBackfaceCulling ↔ JSFunction
-
latefinal
- rlDisableColorBlend ↔ JSFunction
-
latefinal
- rlDisableDepthMask ↔ JSFunction
-
latefinal
- rlDisableDepthTest ↔ JSFunction
-
latefinal
- rlDisableFramebuffer ↔ JSFunction
-
latefinal
- rlDisableScissorTest ↔ JSFunction
-
latefinal
- rlDisableShader ↔ JSFunction
-
latefinal
- rlDisableSmoothLines ↔ JSFunction
-
latefinal
- rlDisableStereoRender ↔ JSFunction
-
latefinal
- rlDisableTexture ↔ JSFunction
-
latefinal
- rlDisableTextureCubemap ↔ JSFunction
-
latefinal
- rlDisableVertexArray ↔ JSFunction
-
latefinal
- rlDisableVertexAttribute ↔ JSFunction
-
latefinal
- rlDisableVertexBuffer ↔ JSFunction
-
latefinal
- rlDisableVertexBufferElement ↔ JSFunction
-
latefinal
- rlDisableWireMode ↔ JSFunction
-
latefinal
- rlDrawRenderBatch ↔ JSFunction
-
latefinal
- rlDrawRenderBatchActive ↔ JSFunction
-
latefinal
- rlDrawVertexArray ↔ JSFunction
-
latefinal
- rlDrawVertexArrayElements ↔ JSFunction
-
latefinal
- rlDrawVertexArrayElementsInstanced ↔ JSFunction
-
latefinal
- rlDrawVertexArrayInstanced ↔ JSFunction
-
latefinal
- rlEnableBackfaceCulling ↔ JSFunction
-
latefinal
- rlEnableColorBlend ↔ JSFunction
-
latefinal
- rlEnableDepthMask ↔ JSFunction
-
latefinal
- rlEnableDepthTest ↔ JSFunction
-
latefinal
- rlEnableFramebuffer ↔ JSFunction
-
latefinal
- rlEnablePointMode ↔ JSFunction
-
latefinal
- rlEnableScissorTest ↔ JSFunction
-
latefinal
- rlEnableShader ↔ JSFunction
-
latefinal
- rlEnableSmoothLines ↔ JSFunction
-
latefinal
- rlEnableStereoRender ↔ JSFunction
-
latefinal
- rlEnableTexture ↔ JSFunction
-
latefinal
- rlEnableTextureCubemap ↔ JSFunction
-
latefinal
- rlEnableVertexArray ↔ JSFunction
-
latefinal
- rlEnableVertexAttribute ↔ JSFunction
-
latefinal
- rlEnableVertexBuffer ↔ JSFunction
-
latefinal
- rlEnableVertexBufferElement ↔ JSFunction
-
latefinal
- rlEnableWireMode ↔ JSFunction
-
latefinal
- rlEnd ↔ JSFunction
-
latefinal
- rlFramebufferAttach ↔ JSFunction
-
latefinal
- rlFramebufferComplete ↔ JSFunction
-
latefinal
- rlFrustum ↔ JSFunction
-
latefinal
- rlGenTextureMipmaps ↔ JSFunction
-
latefinal
- rlGetActiveFramebuffer ↔ JSFunction
-
latefinal
- rlGetCullDistanceFar ↔ JSFunction
-
latefinal
- rlGetCullDistanceNear ↔ JSFunction
-
latefinal
- rlGetFramebufferHeight ↔ JSFunction
-
latefinal
- rlGetFramebufferWidth ↔ JSFunction
-
latefinal
- rlGetGlTextureFormats ↔ JSFunction
-
latefinal
- rlGetLineWidth ↔ JSFunction
-
latefinal
- rlGetLocationAttrib ↔ JSFunction
-
latefinal
- rlGetLocationUniform ↔ JSFunction
-
latefinal
- rlGetMatrixModelview ↔ JSFunction
-
latefinal
- rlGetMatrixProjection ↔ JSFunction
-
latefinal
- rlGetMatrixProjectionStereo ↔ JSFunction
-
latefinal
- rlGetMatrixTransform ↔ JSFunction
-
latefinal
- rlGetMatrixViewOffsetStereo ↔ JSFunction
-
latefinal
- rlGetPixelFormatName ↔ JSFunction
-
latefinal
- rlGetShaderBufferSize ↔ JSFunction
-
latefinal
- rlGetShaderIdDefault ↔ JSFunction
-
latefinal
- rlGetShaderLocsDefault ↔ JSFunction
-
latefinal
- rlGetTextureIdDefault ↔ JSFunction
-
latefinal
- rlGetVersion ↔ JSFunction
-
latefinal
- RLGL_VERSION → String
-
no setterinherited
- rlglClose ↔ JSFunction
-
latefinal
- rlglInit ↔ JSFunction
-
latefinal
- rlIsStereoRenderEnabled ↔ JSFunction
-
latefinal
- rlLoadComputeShaderProgram ↔ JSFunction
-
latefinal
- rlLoadDrawCube ↔ JSFunction
-
latefinal
- rlLoadDrawQuad ↔ JSFunction
-
latefinal
- rlLoadExtensions ↔ JSFunction
-
latefinal
- rlLoadFramebuffer ↔ JSFunction
-
latefinal
- rlLoadIdentity ↔ JSFunction
-
latefinal
- rlLoadRenderBatch ↔ JSFunction
-
latefinal
- rlLoadShaderBuffer ↔ JSFunction
-
latefinal
- rlLoadShaderCode ↔ JSFunction
-
latefinal
- rlLoadShaderProgram ↔ JSFunction
-
latefinal
- rlLoadTexture ↔ JSFunction
-
latefinal
- rlLoadTextureCubemap ↔ JSFunction
-
latefinal
- rlLoadTextureDepth ↔ JSFunction
-
latefinal
- rlLoadVertexArray ↔ JSFunction
-
latefinal
- rlLoadVertexBuffer ↔ JSFunction
-
latefinal
- rlLoadVertexBufferElement ↔ JSFunction
-
latefinal
- rlMatrixMode ↔ JSFunction
-
latefinal
- rlMultMatrixf ↔ JSFunction
-
latefinal
- rlNormal3f ↔ JSFunction
-
latefinal
- rlOrtho ↔ JSFunction
-
latefinal
- rlPopMatrix ↔ JSFunction
-
latefinal
- rlPushMatrix ↔ JSFunction
-
latefinal
- rlReadScreenPixels ↔ JSFunction
-
latefinal
- rlReadShaderBuffer ↔ JSFunction
-
latefinal
- rlReadTexturePixels ↔ JSFunction
-
latefinal
- rlRotatef ↔ JSFunction
-
latefinal
- rlScalef ↔ JSFunction
-
latefinal
- rlScissor ↔ JSFunction
-
latefinal
- rlSetBlendFactors ↔ JSFunction
-
latefinal
- rlSetBlendFactorsSeparate ↔ JSFunction
-
latefinal
- rlSetBlendMode ↔ JSFunction
-
latefinal
- rlSetClipPlanes ↔ JSFunction
-
latefinal
- rlSetCullFace ↔ JSFunction
-
latefinal
- rlSetFramebufferHeight ↔ JSFunction
-
latefinal
- rlSetFramebufferWidth ↔ JSFunction
-
latefinal
- rlSetLineWidth ↔ JSFunction
-
latefinal
- rlSetMatrixModelview ↔ JSFunction
-
latefinal
- rlSetMatrixProjection ↔ JSFunction
-
latefinal
- rlSetMatrixProjectionStereo ↔ JSFunction
-
latefinal
- rlSetMatrixViewOffsetStereo ↔ JSFunction
-
latefinal
- rlSetRenderBatchActive ↔ JSFunction
-
latefinal
- rlSetShader ↔ JSFunction
-
latefinal
- rlSetTexture ↔ JSFunction
-
latefinal
- rlSetUniform ↔ JSFunction
-
latefinal
- rlSetUniformMatrices ↔ JSFunction
-
latefinal
- rlSetUniformMatrix ↔ JSFunction
-
latefinal
- rlSetUniformSampler ↔ JSFunction
-
latefinal
- rlSetVertexAttribute ↔ JSFunction
-
latefinal
- rlSetVertexAttributeDefault ↔ JSFunction
-
latefinal
- rlSetVertexAttributeDivisor ↔ JSFunction
-
latefinal
- rlTexCoord2f ↔ JSFunction
-
latefinal
- rlTextureParameters ↔ JSFunction
-
latefinal
- rlTranslatef ↔ JSFunction
-
latefinal
- rlUnloadFramebuffer ↔ JSFunction
-
latefinal
- rlUnloadRenderBatch ↔ JSFunction
-
latefinal
- rlUnloadShaderBuffer ↔ JSFunction
-
latefinal
- rlUnloadShaderProgram ↔ JSFunction
-
latefinal
- rlUnloadTexture ↔ JSFunction
-
latefinal
- rlUnloadVertexArray ↔ JSFunction
-
latefinal
- rlUnloadVertexBuffer ↔ JSFunction
-
latefinal
- rlUpdateShaderBuffer ↔ JSFunction
-
latefinal
- rlUpdateTexture ↔ JSFunction
-
latefinal
- rlUpdateVertexBuffer ↔ JSFunction
-
latefinal
- rlUpdateVertexBufferElements ↔ JSFunction
-
latefinal
- rlVertex2f ↔ JSFunction
-
latefinal
- rlVertex2i ↔ JSFunction
-
latefinal
- rlVertex3f ↔ JSFunction
-
latefinal
- rlViewport ↔ JSFunction
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s → String
-
finalinherited
Methods
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
doLoad(
) → void -
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
-
load(
) → void -
Override to perform one-time module initialization. Called by doLoad.
inherited
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited