RaylibRlgl class

Inheritance
Mixed-in types

Constructors

RaylibRlgl(Raylib rl)

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
rl → Raylib
finalinherited
RL_BLEND_COLOR → int
See RaylibRlglConstants.RL_BLEND_COLOR.
no setterinherited
RL_BLEND_DST_ALPHA → int
See RaylibRlglConstants.RL_BLEND_DST_ALPHA.
no setterinherited
RL_BLEND_DST_RGB → int
See RaylibRlglConstants.RL_BLEND_DST_RGB.
no setterinherited
RL_BLEND_EQUATION → int
See RaylibRlglConstants.RL_BLEND_EQUATION.
no setterinherited
RL_BLEND_EQUATION_ALPHA → int
See RaylibRlglConstants.RL_BLEND_EQUATION_ALPHA.
no setterinherited
RL_BLEND_EQUATION_RGB → int
See RaylibRlglConstants.RL_BLEND_EQUATION_RGB.
no setterinherited
RL_BLEND_SRC_ALPHA → int
See RaylibRlglConstants.RL_BLEND_SRC_ALPHA.
no setterinherited
RL_BLEND_SRC_RGB → int
See RaylibRlglConstants.RL_BLEND_SRC_RGB.
no setterinherited
RL_COMPUTE_SHADER → int
See RaylibRlglConstants.RL_COMPUTE_SHADER.
no setterinherited
RL_CONSTANT_ALPHA → int
See RaylibRlglConstants.RL_CONSTANT_ALPHA.
no setterinherited
RL_CONSTANT_COLOR → int
See RaylibRlglConstants.RL_CONSTANT_COLOR.
no setterinherited
RL_CULL_DISTANCE_FAR → double
See RaylibRlglConstants.RL_CULL_DISTANCE_FAR.
no setterinherited
RL_CULL_DISTANCE_NEAR → double
See RaylibRlglConstants.RL_CULL_DISTANCE_NEAR.
no setterinherited
RL_DEFAULT_BATCH_BUFFER_ELEMENTS → int
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFER_ELEMENTS.
no setterinherited
RL_DEFAULT_BATCH_BUFFERS → int
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFERS.
no setterinherited
RL_DEFAULT_BATCH_DRAWCALLS → int
See RaylibRlglConstants.RL_DEFAULT_BATCH_DRAWCALLS.
no setterinherited
RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS → int
See RaylibRlglConstants.RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS.
no setterinherited
RL_DRAW_FRAMEBUFFER → int
See RaylibRlglConstants.RL_DRAW_FRAMEBUFFER.
no setterinherited
RL_DST_ALPHA → int
See RaylibRlglConstants.RL_DST_ALPHA.
no setterinherited
RL_DST_COLOR → int
See RaylibRlglConstants.RL_DST_COLOR.
no setterinherited
RL_DYNAMIC_COPY → int
See RaylibRlglConstants.RL_DYNAMIC_COPY.
no setterinherited
RL_DYNAMIC_DRAW → int
See RaylibRlglConstants.RL_DYNAMIC_DRAW.
no setterinherited
RL_DYNAMIC_READ → int
See RaylibRlglConstants.RL_DYNAMIC_READ.
no setterinherited
RL_FLOAT → int
See RaylibRlglConstants.RL_FLOAT.
no setterinherited
RL_FRAGMENT_SHADER → int
See RaylibRlglConstants.RL_FRAGMENT_SHADER.
no setterinherited
RL_FUNC_ADD → int
See RaylibRlglConstants.RL_FUNC_ADD.
no setterinherited
RL_FUNC_REVERSE_SUBTRACT → int
See RaylibRlglConstants.RL_FUNC_REVERSE_SUBTRACT.
no setterinherited
RL_FUNC_SUBTRACT → int
See RaylibRlglConstants.RL_FUNC_SUBTRACT.
no setterinherited
RL_LINES → int
See RaylibRlglConstants.RL_LINES.
no setterinherited
RL_MAX → int
See RaylibRlglConstants.RL_MAX.
no setterinherited
RL_MAX_MATRIX_STACK_SIZE → int
See RaylibRlglConstants.RL_MAX_MATRIX_STACK_SIZE.
no setterinherited
RL_MAX_SHADER_LOCATIONS → int
See RaylibRlglConstants.RL_MAX_SHADER_LOCATIONS.
no setterinherited
RL_MIN → int
See RaylibRlglConstants.RL_MIN.
no setterinherited
RL_MODELVIEW → int
See RaylibRlglConstants.RL_MODELVIEW.
no setterinherited
RL_ONE → int
See RaylibRlglConstants.RL_ONE.
no setterinherited
RL_ONE_MINUS_CONSTANT_ALPHA → int
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_ALPHA.
no setterinherited
RL_ONE_MINUS_CONSTANT_COLOR → int
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_COLOR.
no setterinherited
RL_ONE_MINUS_DST_ALPHA → int
See RaylibRlglConstants.RL_ONE_MINUS_DST_ALPHA.
no setterinherited
RL_ONE_MINUS_DST_COLOR → int
See RaylibRlglConstants.RL_ONE_MINUS_DST_COLOR.
no setterinherited
RL_ONE_MINUS_SRC_ALPHA → int
See RaylibRlglConstants.RL_ONE_MINUS_SRC_ALPHA.
no setterinherited
RL_ONE_MINUS_SRC_COLOR → int
See RaylibRlglConstants.RL_ONE_MINUS_SRC_COLOR.
no setterinherited
RL_PROJECTION → int
See RaylibRlglConstants.RL_PROJECTION.
no setterinherited
RL_QUADS → int
See RaylibRlglConstants.RL_QUADS.
no setterinherited
RL_READ_FRAMEBUFFER → int
See RaylibRlglConstants.RL_READ_FRAMEBUFFER.
no setterinherited
RL_SHADER_LOC_MAP_DIFFUSE → int
See RaylibRlglConstants.RL_SHADER_LOC_MAP_DIFFUSE.
no setterinherited
RL_SHADER_LOC_MAP_SPECULAR → int
See RaylibRlglConstants.RL_SHADER_LOC_MAP_SPECULAR.
no setterinherited
RL_SRC_ALPHA → int
See RaylibRlglConstants.RL_SRC_ALPHA.
no setterinherited
RL_SRC_ALPHA_SATURATE → int
See RaylibRlglConstants.RL_SRC_ALPHA_SATURATE.
no setterinherited
RL_SRC_COLOR → int
See RaylibRlglConstants.RL_SRC_COLOR.
no setterinherited
RL_STATIC_COPY → int
See RaylibRlglConstants.RL_STATIC_COPY.
no setterinherited
RL_STATIC_DRAW → int
See RaylibRlglConstants.RL_STATIC_DRAW.
no setterinherited
RL_STATIC_READ → int
See RaylibRlglConstants.RL_STATIC_READ.
no setterinherited
RL_STREAM_COPY → int
See RaylibRlglConstants.RL_STREAM_COPY.
no setterinherited
RL_STREAM_DRAW → int
See RaylibRlglConstants.RL_STREAM_DRAW.
no setterinherited
RL_STREAM_READ → int
See RaylibRlglConstants.RL_STREAM_READ.
no setterinherited
RL_TEXTURE → int
See RaylibRlglConstants.RL_TEXTURE.
no setterinherited
RL_TEXTURE_FILTER_ANISOTROPIC → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_ANISOTROPIC.
no setterinherited
RL_TEXTURE_FILTER_LINEAR → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR.
no setterinherited
RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST.
no setterinherited
RL_TEXTURE_FILTER_MIP_LINEAR → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_LINEAR.
no setterinherited
RL_TEXTURE_FILTER_MIP_NEAREST → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_NEAREST.
no setterinherited
RL_TEXTURE_FILTER_NEAREST → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST.
no setterinherited
RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR.
no setterinherited
RL_TEXTURE_MAG_FILTER → int
See RaylibRlglConstants.RL_TEXTURE_MAG_FILTER.
no setterinherited
RL_TEXTURE_MIN_FILTER → int
See RaylibRlglConstants.RL_TEXTURE_MIN_FILTER.
no setterinherited
RL_TEXTURE_MIPMAP_BIAS_RATIO → int
See RaylibRlglConstants.RL_TEXTURE_MIPMAP_BIAS_RATIO.
no setterinherited
RL_TEXTURE_WRAP_CLAMP → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_CLAMP.
no setterinherited
RL_TEXTURE_WRAP_MIRROR_CLAMP → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_CLAMP.
no setterinherited
RL_TEXTURE_WRAP_MIRROR_REPEAT → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_REPEAT.
no setterinherited
RL_TEXTURE_WRAP_REPEAT → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_REPEAT.
no setterinherited
RL_TEXTURE_WRAP_S → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_S.
no setterinherited
RL_TEXTURE_WRAP_T → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_T.
no setterinherited
RL_TRIANGLES → int
See RaylibRlglConstants.RL_TRIANGLES.
no setterinherited
RL_UNSIGNED_BYTE → int
See RaylibRlglConstants.RL_UNSIGNED_BYTE.
no setterinherited
RL_VERTEX_SHADER → int
See RaylibRlglConstants.RL_VERTEX_SHADER.
no setterinherited
RL_ZERO → int
See RaylibRlglConstants.RL_ZERO.
no setterinherited
rlActiveDrawBuffers ↔ WF1<void>
Activate multiple draw color buffers
latefinal
rlActiveTextureSlot ↔ WF1<void>
Select and active a texture slot
latefinal
rlBegin ↔ WF1<void>
Initialize drawing mode (how to organize vertex)
latefinal
rlBindFramebuffer ↔ WF2<void>
Bind framebuffer (FBO)
latefinal
rlBindImageTexture ↔ WF4<void>
Bind image texture
latefinal
rlBindShaderBuffer ↔ WF2<void>
Bind SSBO buffer
latefinal
rlBlitFramebuffer ↔ WF9<void>
Blit active framebuffer to main framebuffer
latefinal
rlCheckErrors ↔ WF0<void>
Check and log OpenGL error codes
latefinal
rlCheckRenderBatchLimit ↔ WF1<bool>
Check internal buffer overflow for a given number of vertex
latefinal
rlClearColor ↔ WF4<void>
Clear color buffer with color
latefinal
rlClearScreenBuffers ↔ WF0<void>
Clear used screen buffers (color and depth)
latefinal
rlColor3f ↔ WF3<void>
Define one vertex (color) - 3 float
latefinal
rlColor4f ↔ WF4<void>
Define one vertex (color) - 4 float
latefinal
rlColor4ub ↔ WF4<void>
Define one vertex (color) - 4 byte
latefinal
rlColorMask ↔ WF4<void>
Color mask control
latefinal
rlComputeShaderDispatch ↔ WF3<void>
Dispatch compute shader (equivalent to draw for graphics pipeline)
latefinal
rlCopyFramebuffer ↔ WF6<void>
Copy framebuffer pixel data to internal buffer
latefinal
rlCopyShaderBuffer ↔ WF5<void>
Copy SSBO data between buffers
latefinal
rlCubemapParameters ↔ WF3<void>
Set cubemap parameters (filter, wrap)
latefinal
rlDisableBackfaceCulling ↔ WF0<void>
Disable backface culling
latefinal
rlDisableColorBlend ↔ WF0<void>
Disable color blending
latefinal
rlDisableDepthMask ↔ WF0<void>
Disable depth write
latefinal
rlDisableDepthTest ↔ WF0<void>
Disable depth test
latefinal
rlDisableFramebuffer ↔ WF0<void>
Disable render texture (fbo), return to default framebuffer
latefinal
rlDisablePointMode ↔ WF0<void>
Disable point mode
latefinal
rlDisableScissorTest ↔ WF0<void>
Disable scissor test
latefinal
rlDisableShader ↔ WF0<void>
Disable shader program
latefinal
rlDisableSmoothLines ↔ WF0<void>
Disable line aliasing
latefinal
rlDisableStatePointer ↔ WF1<void>
Disable attribute state pointer
latefinal
rlDisableStereoRender ↔ WF0<void>
Disable stereo rendering
latefinal
rlDisableTexture ↔ WF0<void>
Disable texture
latefinal
rlDisableTextureCubemap ↔ WF0<void>
Disable texture cubemap
latefinal
rlDisableVertexArray ↔ WF0<void>
Disable vertex array (VAO, if supported)
latefinal
rlDisableVertexAttribute ↔ WF1<void>
Disable vertex attribute index
latefinal
rlDisableVertexBuffer ↔ WF0<void>
Disable vertex buffer (VBO)
latefinal
rlDisableVertexBufferElement ↔ WF0<void>
Disable vertex buffer element (VBO element)
latefinal
rlDisableWireMode ↔ WF0<void>
Disable wire mode
latefinal
rlDrawRenderBatch ↔ WF1<void>
Draw render batch data (Update->Draw->Reset)
latefinal
rlDrawRenderBatchActive ↔ WF0<void>
Update and draw internal render batch
latefinal
rlDrawVertexArray ↔ WF2<void>
Draw vertex array (currently active vao)
latefinal
rlDrawVertexArrayElements ↔ WF3<void>
Draw vertex array elements
latefinal
rlDrawVertexArrayElementsInstanced ↔ WF4<void>
Draw vertex array elements with instancing
latefinal
rlDrawVertexArrayInstanced ↔ WF3<void>
Draw vertex array (currently active vao) with instancing
latefinal
rlEnableBackfaceCulling ↔ WF0<void>
Enable backface culling
latefinal
rlEnableColorBlend ↔ WF0<void>
Enable color blending
latefinal
rlEnableDepthMask ↔ WF0<void>
Enable depth write
latefinal
rlEnableDepthTest ↔ WF0<void>
Enable depth test
latefinal
rlEnableFramebuffer ↔ WF1<void>
Enable render texture (fbo)
latefinal
rlEnablePointMode ↔ WF0<void>
Enable point mode
latefinal
rlEnableScissorTest ↔ WF0<void>
Enable scissor test
latefinal
rlEnableShader ↔ WF1<void>
Enable shader program
latefinal
rlEnableSmoothLines ↔ WF0<void>
Enable line aliasing
latefinal
rlEnableStatePointer ↔ WF2<void>
Enable attribute state pointer
latefinal
rlEnableStereoRender ↔ WF0<void>
Enable stereo rendering
latefinal
rlEnableTexture ↔ WF1<void>
Enable texture
latefinal
rlEnableTextureCubemap ↔ WF1<void>
Enable texture cubemap
latefinal
rlEnableVertexArray ↔ WF1<bool>
Enable vertex array (VAO, if supported)
latefinal
rlEnableVertexAttribute ↔ WF1<void>
Enable vertex attribute index
latefinal
rlEnableVertexBuffer ↔ WF1<void>
Enable vertex buffer (VBO)
latefinal
rlEnableVertexBufferElement ↔ WF1<void>
Enable vertex buffer element (VBO element)
latefinal
rlEnableWireMode ↔ WF0<void>
Enable wire mode
latefinal
rlEnd ↔ WF0<void>
Finish vertex providing
latefinal
rlFramebufferAttach ↔ WF5<void>
Attach texture/renderbuffer to a framebuffer
latefinal
rlFramebufferComplete ↔ WF1<bool>
Verify framebuffer is complete
latefinal
rlFrustum ↔ WF6<void>
Multiply the current matrix by a perspective matrix generated by parameters
latefinal
rlGenTextureMipmaps ↔ WF5<void>
Generate mipmap data for selected texture
latefinal
rlGetActiveFramebuffer ↔ WF0<int>
Get the currently active render texture (fbo), 0 for default framebuffer
latefinal
rlGetCullDistanceFar ↔ WF0<double>
Get cull plane distance far
latefinal
rlGetCullDistanceNear ↔ WF0<double>
Get cull plane distance near
latefinal
rlGetFramebufferHeight ↔ WF0<int>
Get default framebuffer height
latefinal
rlGetFramebufferWidth ↔ WF0<int>
Get default framebuffer width
latefinal
rlGetGlTextureFormats ↔ WF4<void>
Get OpenGL internal formats
latefinal
rlGetLineWidth ↔ WF0<double>
Get the line drawing width
latefinal
rlGetLocationAttrib ↔ WF2<int>
Get shader location attribute, requires shader program id
latefinal
rlGetLocationUniform ↔ WF2<int>
Get shader location uniform, requires shader program id
latefinal
rlGetMatrixModelview ↔ WF1<void>
Get internal modelview matrix
latefinal
rlGetMatrixProjection ↔ WF1<void>
Get internal projection matrix
latefinal
rlGetMatrixProjectionStereo ↔ WF2<void>
Get internal projection matrix for stereo render (selected eye)
latefinal
rlGetMatrixTransform ↔ WF1<void>
Get internal accumulated transform matrix
latefinal
rlGetMatrixViewOffsetStereo ↔ WF2<void>
Get internal view offset matrix for stereo render (selected eye)
latefinal
rlGetPixelFormatName ↔ WF1<WasmMemoryPointer<RChar>>
Get name string for pixel format
latefinal
rlGetPointSize ↔ WF0<double>
Get the point drawing size
latefinal
rlGetProcAddress ↔ WF1<WasmMemoryPointer<RVoid>>
Get OpenGL procedure address
latefinal
rlGetShaderBufferSize ↔ WF1<int>
Get SSBO buffer size
latefinal
rlGetShaderIdDefault ↔ WF0<int>
Get default shader id
latefinal
rlGetShaderLocsDefault ↔ WF0<WasmMemoryPointer<RInt>>
Get default shader locations
latefinal
rlGetTextureIdDefault ↔ WF0<int>
Get default texture id
latefinal
rlGetVersion ↔ WF0<int>
Get current OpenGL version
latefinal
RLGL_VERSION → String
See RaylibRlglConstants.RLGL_VERSION.
no setterinherited
rlglClose ↔ WF0<void>
De-initialize rlgl (buffers, shaders, textures)
latefinal
rlglInit ↔ WF2<void>
Initialize rlgl (buffers, shaders, textures, states)
latefinal
rlIsStereoRenderEnabled ↔ WF0<bool>
Check if stereo render is enabled
latefinal
rlLoadDrawCube ↔ WF0<void>
Load and draw a cube
latefinal
rlLoadDrawQuad ↔ WF0<void>
Load and draw a quad
latefinal
rlLoadExtensions ↔ WF1<void>
Load OpenGL extensions (loader function required)
latefinal
rlLoadFramebuffer ↔ WF0<int>
Load an empty framebuffer
latefinal
rlLoadIdentity ↔ WF0<void>
Reset current matrix to identity matrix
latefinal
rlLoadRenderBatch ↔ WF3<void>
Load a render batch system
latefinal
rlLoadShader ↔ WF2<int>
Load (compile) shader and return shader id
latefinal
rlLoadShaderBuffer ↔ WF3<int>
Load shader storage buffer object (SSBO)
latefinal
rlLoadShaderProgram ↔ WF2<int>
Load shader from code strings
latefinal
rlLoadShaderProgramCompute ↔ WF1<int>
Load compute shader program
latefinal
rlLoadShaderProgramEx ↔ WF2<int>
Load shader program, using already loaded shader ids
latefinal
rlLoadTexture ↔ WF5<int>
Load texture data
latefinal
rlLoadTextureCubemap ↔ WF4<int>
Load texture cubemap data
latefinal
rlLoadTextureDepth ↔ WF3<int>
Load depth texture/renderbuffer (to be attached to fbo)
latefinal
rlLoadVertexArray ↔ WF0<int>
Load vertex array (vao) if supported
latefinal
rlLoadVertexBuffer ↔ WF3<int>
Load a vertex buffer object
latefinal
rlLoadVertexBufferElement ↔ WF3<int>
Load vertex buffer elements object
latefinal
rlMatrixMode ↔ WF1<void>
Choose the current matrix to be transformed
latefinal
rlMultMatrixf ↔ WF1<void>
Multiply the current matrix by another matrix
latefinal
rlNormal3f ↔ WF3<void>
Define one vertex (normal) - 3 float
latefinal
rlOrtho ↔ WF6<void>
Multiply the current matrix by an orthographic matrix generated by parameters
latefinal
rlPopMatrix ↔ WF0<void>
Pop latest inserted matrix from stack
latefinal
rlPushMatrix ↔ WF0<void>
Push the current matrix to stack
latefinal
rlReadScreenPixels ↔ WF2<WasmMemoryPointer<RUnsignedChar>>
Read screen pixel data (color buffer)
latefinal
rlReadShaderBuffer ↔ WF4<void>
Read SSBO buffer data (GPU->CPU)
latefinal
rlReadTexturePixels ↔ WF4<WasmMemoryPointer<RVoid>>
Read texture pixel data
latefinal
rlResizeFramebuffer ↔ WF2<void>
Resize internal framebuffer
latefinal
rlRotatef ↔ WF4<void>
Multiply the current matrix by a rotation matrix
latefinal
rlScalef ↔ WF3<void>
Multiply the current matrix by a scaling matrix
latefinal
rlScissor ↔ WF4<void>
Scissor test
latefinal
rlSetBlendFactors ↔ WF3<void>
Set blending mode factor and equation (using OpenGL factors)
latefinal
rlSetBlendFactorsSeparate ↔ WF6<void>
Set blending mode factors and equations separately (using OpenGL factors)
latefinal
rlSetBlendMode ↔ WF1<void>
Set blending mode
latefinal
rlSetClipPlanes ↔ WF2<void>
Set clip planes distances
latefinal
rlSetCullFace ↔ WF1<void>
Set face culling mode
latefinal
rlSetFramebufferHeight ↔ WF1<void>
Set current framebuffer height
latefinal
rlSetFramebufferWidth ↔ WF1<void>
Set current framebuffer width
latefinal
rlSetLineWidth ↔ WF1<void>
Set the line drawing width
latefinal
rlSetMatrixModelview ↔ WF1<void>
Set a custom modelview matrix (replaces internal modelview matrix)
latefinal
rlSetMatrixProjection ↔ WF1<void>
Set a custom projection matrix (replaces internal projection matrix)
latefinal
rlSetMatrixProjectionStereo ↔ WF2<void>
Set eyes projection matrices for stereo rendering
latefinal
rlSetMatrixViewOffsetStereo ↔ WF2<void>
Set eyes view offsets matrices for stereo rendering
latefinal
rlSetPointSize ↔ WF1<void>
Set the point drawing size
latefinal
rlSetRenderBatchActive ↔ WF1<void>
Set the active render batch for rlgl (NULL for default internal)
latefinal
rlSetShader ↔ WF2<void>
Set shader currently active (id and locations)
latefinal
rlSetTexture ↔ WF1<void>
Set current texture for render batch and check buffers limits
latefinal
rlSetUniform ↔ WF4<void>
Set shader value uniform
latefinal
rlSetUniformMatrices ↔ WF3<void>
Set shader value matrices
latefinal
rlSetUniformMatrix ↔ WF2<void>
Set shader value matrix
latefinal
rlSetUniformSampler ↔ WF2<void>
Set shader value sampler
latefinal
rlSetVertexAttribute ↔ WF6<void>
Set vertex attribute data configuration
latefinal
rlSetVertexAttributeDefault ↔ WF4<void>
Set vertex attribute default value, when attribute to provided
latefinal
rlSetVertexAttributeDivisor ↔ WF2<void>
Set vertex attribute data divisor
latefinal
rlTexCoord2f ↔ WF2<void>
Define one vertex (texture coordinate) - 2 float
latefinal
rlTextureParameters ↔ WF3<void>
Set texture parameters (filter, wrap)
latefinal
rlTranslatef ↔ WF3<void>
Multiply the current matrix by a translation matrix
latefinal
rlUnloadFramebuffer ↔ WF1<void>
Delete framebuffer from GPU
latefinal
rlUnloadRenderBatch ↔ WF1<void>
Unload render batch system
latefinal
rlUnloadShader ↔ WF1<void>
Unload shader, loaded with rlLoadShader();
latefinal
rlUnloadShaderBuffer ↔ WF1<void>
Unload shader storage buffer object (SSBO)
latefinal
rlUnloadShaderProgram ↔ WF1<void>
Unload shader program
latefinal
rlUnloadTexture ↔ WF1<void>
Unload texture from GPU memory
latefinal
rlUnloadVertexArray ↔ WF1<void>
Unload vertex array (vao)
latefinal
rlUnloadVertexBuffer ↔ WF1<void>
Unload vertex buffer object
latefinal
rlUpdateShaderBuffer ↔ WF4<void>
Update SSBO buffer data
latefinal
rlUpdateTexture ↔ WF7<void>
Update texture with new data on GPU
latefinal
rlUpdateVertexBuffer ↔ WF4<void>
Update vertex buffer object data on GPU buffer
latefinal
rlUpdateVertexBufferElements ↔ WF4<void>
Update vertex buffer elements data on GPU buffer
latefinal
rlVertex2f ↔ WF2<void>
Define one vertex (position) - 2 float
latefinal
rlVertex2i ↔ WF2<void>
Define one vertex (position) - 2 int
latefinal
rlVertex3f ↔ WF3<void>
Define one vertex (position) - 3 float
latefinal
rlViewport ↔ WF4<void>
Set the viewport area
latefinal
rn → String
Emscripten cwrap return type for anything other than structs and void.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rv → Null
Emscripten cwrap return type for functions returning void.
finalinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
dwrap0<R>(String name) → WF0<R>
Binds a cwraped C function taking 0 arguments and returning a plain (non-struct) value.
inherited
dwrap1<R>(String name) → WF1<R>
Binds a cwraped C function taking 1 argument and returning a plain (non-struct) value.
inherited
dwrap2<R>(String name) → WF2<R>
Binds a cwraped C function taking 2 arguments and returning a plain (non-struct) value.
inherited
dwrap3<R>(String name) → WF3<R>
Binds a cwraped C function taking 3 arguments and returning a plain (non-struct) value.
inherited
dwrap4<R>(String name) → WF4<R>
Binds a cwraped C function taking 4 arguments and returning a plain (non-struct) value.
inherited
dwrap5<R>(String name) → WF5<R>
Binds a cwraped C function taking 5 arguments and returning a plain (non-struct) value.
inherited
dwrap6<R>(String name) → WF6<R>
Binds a cwraped C function taking 6 arguments and returning a plain (non-struct) value.
inherited
dwrap7<R>(String name) → WF7<R>
Binds a cwraped C function taking 7 arguments and returning a plain (non-struct) value.
inherited
dwrap8<R>(String name) → WF8<R>
Binds a cwraped C function taking 8 arguments and returning a plain (non-struct) value.
inherited
dwrap9<R>(String name) → WF9<R>
Binds a cwraped C function taking 9 arguments and returning a plain (non-struct) value.
inherited
load() → void
Override to perform one-time module initialization.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
pwrap0<X extends RType>(String name) → WF0<WasmMemoryPointer<X>>
Binds a cwraped C function taking 0 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap1<X extends RType>(String name) → WF1<WasmMemoryPointer<X>>
Binds a cwraped C function taking 1 argument and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap2<X extends RType>(String name) → WF2<WasmMemoryPointer<X>>
Binds a cwraped C function taking 2 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap3<X extends RType>(String name) → WF3<WasmMemoryPointer<X>>
Binds a cwraped C function taking 3 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap4<X extends RType>(String name) → WF4<WasmMemoryPointer<X>>
Binds a cwraped C function taking 4 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap5<X extends RType>(String name) → WF5<WasmMemoryPointer<X>>
Binds a cwraped C function taking 5 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap6<X extends RType>(String name) → WF6<WasmMemoryPointer<X>>
Binds a cwraped C function taking 6 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap7<X extends RType>(String name) → WF7<WasmMemoryPointer<X>>
Binds a cwraped C function taking 7 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap8<X extends RType>(String name) → WF8<WasmMemoryPointer<X>>
Binds a cwraped C function taking 8 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
pwrap9<X extends RType>(String name) → WF9<WasmMemoryPointer<X>>
Binds a cwraped C function taking 9 arguments and returning a pointer, wrapped as WasmMemoryPointer<X>.
inherited
qwrap0<X extends RaylibStruct<X>>(String name) → WF0<StructPointer<X>>
Binds a cwraped C function taking 0 arguments and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap1<X extends RaylibStruct<X>>(String name) → WF1<StructPointer<X>>
Binds a cwraped C function taking 1 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap2<X extends RaylibStruct<X>>(String name) → WF2<StructPointer<X>>
Binds a cwraped C function taking 2 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap3<X extends RaylibStruct<X>>(String name) → WF3<StructPointer<X>>
Binds a cwraped C function taking 3 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap4<X extends RaylibStruct<X>>(String name) → WF4<StructPointer<X>>
Binds a cwraped C function taking 4 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap5<X extends RaylibStruct<X>>(String name) → WF5<StructPointer<X>>
Binds a cwraped C function taking 5 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap6<X extends RaylibStruct<X>>(String name) → WF6<StructPointer<X>>
Binds a cwraped C function taking 6 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap7<X extends RaylibStruct<X>>(String name) → WF7<StructPointer<X>>
Binds a cwraped C function taking 7 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap8<X extends RaylibStruct<X>>(String name) → WF8<StructPointer<X>>
Binds a cwraped C function taking 8 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
qwrap9<X extends RaylibStruct<X>>(String name) → WF9<StructPointer<X>>
Binds a cwraped C function taking 9 argument and returning a struct pointer, wrapped as StructPointer<X>.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
swrap0(String name) → WF1<void>
Binds a cwraped C function taking 0 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap1(String name) → WF2<void>
Binds a cwraped C function taking 1 argument that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap2(String name) → WF3<void>
Binds a cwraped C function taking 2 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap3(String name) → WF4<void>
Binds a cwraped C function taking 3 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap4(String name) → WF5<void>
Binds a cwraped C function taking 4 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap5(String name) → WF6<void>
Binds a cwraped C function taking 5 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap6(String name) → WF7<void>
Binds a cwraped C function taking 6 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap7(String name) → WF8<void>
Binds a cwraped C function taking 7 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
swrap8(String name) → WF9<void>
Binds a cwraped C function taking 8 arguments that returns a struct via the WASM structure-return (sret) convention.
inherited
symbol<X extends RType>(String name) → WasmMemoryPointer<X>
Resolves a global symbol exported by the WASM module and wraps its address as a WasmMemoryPointer.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited