Vector3D class
- Inheritance
- Mixed-in types
Constructors
-
Vector3D({WasmStructPointer<
Vector3D> ? originalPointer, double x = 0, double y = 0, double z = 0}) - Vector3D.barycenter(Vector3D p, Vector3D a, Vector3D b, Vector3D c)
-
factory
- Vector3D.one()
-
factory
- Vector3D.perpendicular(Vector3D o)
-
factory
- Vector3D.vec3(num x, num y, num z)
-
factory
- Vector3D.vec3Normalized(num x, num y, num z)
-
factory
- Vector3D.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → double
-
Euclidean length (magnitude) of this vector.
no setterinherited
- lengthSqr → double
-
Squared length of this vector.
no setterinherited
-
originalPointer
↔ WasmStructPointer<
Vector3D> ? -
The C-owned or RaylibTemp-owned native pointer for this struct, if any.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- structRequiresOriginalPointer → bool
-
Whether this struct requires an originalPointer to function correctly.
no setterinherited
- wasmByteSize → int
-
no setteroverride
- x ↔ double
-
X component
getter/setter pairoverride
- y ↔ double
-
Y component
getter/setter pairoverride
- z ↔ double
-
Z component
getter/setter pairoverride
Methods
-
add(
Vector3D o) → Vector3D -
Returns a new vector that is the component-wise sum of this and
o.inherited -
addValue(
num value) → Vector3D -
Returns a new vector with
valueadded to each component.inherited -
angle(
Vector3D o) → double -
Angle between this vector and
oin radians, in the range[0, π].inherited -
clamp(
Vector3D min, Vector3D max) → Vector3D -
Clamps each component of this vector between the corresponding components of
minandmax.inherited -
clampValue(
double min, double max) → Vector3D -
Clamps the length of this vector to the range
[min, max].inherited -
clone(
) → Vector3D -
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
override
-
copy(
) → Vector3D -
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
-
crossProduct(
Vector3D o) → Vector3D -
Cross product of this vector and
o.inherited -
cubicHermite(
Vector3D tangent1, Vector3D v2, Vector3D tangent2, double amount) → Vector3D -
Interpolates along a cubic Hermite spline between this and
v2.inherited -
distance(
Vector3D o) → double -
Euclidean distance between this vector and
o.inherited -
distanceSqr(
Vector3D o) → double -
Squared Euclidean distance between this vector and
o.inherited -
div(
Vector3D o) → Vector3D -
Returns a new vector that is the component-wise quotient of this and
o.inherited -
divideBy(
num o) → Vector3D -
Returns a new vector with all components divided by
o.inherited -
dotProduct(
Vector3D o) → double -
Dot product of this vector and
o.inherited -
equals(
Vector3D o) → bool -
Returns
trueif this vector is approximately equal too.inherited -
format(
[int x0 = 0, int? y0, int? z0]) → String -
Returns a formatted string representation of this vector.
inherited
-
getOriginalPointer(
) → WasmStructPointer< Vector3D> -
Returns originalPointer, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOriginalPointerAndDispose(
) → WasmStructPointer< Vector3D> -
Returns originalPointer and immediately calls structMarkDisposed.
inherited
-
invert(
) → Vector3D -
Returns a new vector with each component replaced by its reciprocal (
1/x,1/y,1/z).inherited -
lerp(
Vector3D o, double amount) → Vector3D -
Linear interpolation between this and
obyamount.inherited -
max(
Vector3D o) → Vector3D -
Returns a new vector with each component being the component-wise maximum of this and
o.inherited -
min(
Vector3D o) → Vector3D -
Returns a new vector with each component being the component-wise minimum of this and
o.inherited -
moveTowards(
Vector3D target, double maxDistance) → Vector3D -
Moves this vector towards
targetby at mostmaxDistance.inherited -
mul(
Vector3D o) → Vector3D -
Returns a new vector that is the component-wise product of this and
o.inherited -
negate(
) → Vector3D -
Returns a new vector with all components negated.
inherited
-
normalize(
) → Vector3D -
Returns a normalized (unit-length) copy of this vector.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orthoNormalize(
Vector3D o) → Vector3D -
Orthonormalizes this vector against
ousing the Gram-Schmidt process.inherited -
project(
Vector3D o) → Vector3D -
Projects this vector onto
o.inherited -
reflect(
Vector3D normal) → Vector3D -
Reflects this vector off a surface with the given
normal.inherited -
refract(
Vector3D n, double r) → Vector3D -
Refracts this vector through a surface with normal
nand ratior.inherited -
reject(
Vector3D o) → Vector3D -
Rejects
ofrom this vector.inherited -
rotateByAxisAngle(
Vector3D axis, double angle) → Vector3D -
Rotates this vector around
axisbyangleradians.inherited -
rotateByQuaternion(
QuaternionD q) → Vector3D -
Returns a new vector with
thisrotated by quaternionq.inherited -
scale(
num o) → Vector3D -
Returns a new vector with all components scaled by
o.inherited -
set(
num x, num y, num z) → Vector3D -
Sets all components at once.
inherited
-
setD(
Vector3D o) → Vector3D -
Copies the fields of
ointo this instance and returnsthis.override -
signature(
) → String -
Returns a human-readable representation of this struct.
inherited
-
structAllocateInto(
RaylibTemp temp, WasmStructPointer< Vector3D> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.inherited -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears originalPointer.
inherited
-
structOnOp(
void callback(WasmStructPointer< Vector3D> p)) → void -
Calls
callbackwith originalPointer if it is set, otherwise no-ops.inherited -
structReadFrom(
WasmStructPointer< Vector3D> p) → void -
Reads all fields from the memory at
p.inherited -
structSetTag(
String newTag) → Vector3D -
Sets RaylibTempStructState.tag to
newTagand returnsthisfor chaining.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires originalPointer.
inherited
-
structSyncInto(
RaylibTemp temp, WasmStructPointer< Vector3D> p, String key) → void -
Syncs Dart-side fields into the already-allocated native pointer
p. Defaults to structWriteInto.inherited -
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires originalPointer.
inherited
-
structWriteInto(
WasmStructPointer< Vector3D> p) → void -
Writes all fields into the memory at
p.inherited -
sub(
Vector3D o) → Vector3D -
Returns a new vector that is the component-wise difference of this and
o.inherited -
subValue(
num value) → Vector3D -
Returns a new vector with
valuesubtracted from each component.inherited -
toArray(
) → List< double> -
Returns the components as a new double list.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
MatrixD o) → Vector3D -
Transforms this vector by matrix
o.inherited -
unproject(
MatrixD projection, MatrixD view) → Vector3D -
Unprojects this screen-space vector back into world space.
inherited
-
wasmReader(
[int? offset]) → WasmReader -
inherited
-
wasmReaderOr(
int address) → WasmReader -
inherited
-
wasmReadFrom(
WasmReader reader) → void -
override
-
wasmWriteInto(
WasmWriter writer) → void -
override
-
wasmWriter(
[int? offset]) → WasmWriter -
inherited
-
wasmWriterOr(
int address) → WasmReader -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
wasmPointer(
int ptr) → WasmStructPointer< Vector3D> -
wasmPointerPointer(
int ptr) → WasmStructPointerPointer< Vector3D>