Vector3D class
- Inheritance
- Mixed-in types
Constructors
-
Vector3D({WasmStructPointer<
Vector3D> ? originalPointer, double x = 0, double y = 0, double z = 0}) - Vector3D.barycenter(Vector3D p, Vector3D a, Vector3D b, Vector3D c)
-
factory
- Vector3D.one()
-
factory
- Vector3D.perpendicular(Vector3D o)
-
factory
- Vector3D.vec3(num x, num y, num z)
-
factory
- Vector3D.vec3Normalized(num x, num y, num z)
-
factory
- Vector3D.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → double
-
no setterinherited
- lengthSqr → double
-
no setterinherited
-
originalPointer
↔ WasmStructPointer<
Vector3D> ? -
The C-owned or RaylibTemp-owned native pointer for this struct, if any.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- structRequiresOriginalPointer → bool
-
Whether this struct requires an originalPointer to function correctly.
no setterinherited
- wasmByteSize → int
-
no setteroverride
- x ↔ double
-
getter/setter pairoverride
- y ↔ double
-
getter/setter pairoverride
- z ↔ double
-
getter/setter pairoverride
Methods
-
add(
Vector3D o) → Vector3D -
inherited
-
addValue(
num value) → Vector3D -
inherited
-
angle(
Vector3D o) → double -
inherited
-
clamp(
Vector3D min, Vector3D max) → Vector3D -
inherited
-
clampValue(
double min, double max) → Vector3D -
inherited
-
clone(
) → Vector3D -
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
override
-
copy(
) → Vector3D -
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
-
crossProduct(
Vector3D o) → Vector3D -
inherited
-
cubicHermite(
Vector3D tangent1, Vector3D v2, Vector3D tangent2, double amount) → Vector3D -
inherited
-
distance(
Vector3D o) → double -
inherited
-
distanceSqr(
Vector3D o) → double -
inherited
-
div(
Vector3D o) → Vector3D -
inherited
-
divideBy(
num o) → Vector3D -
inherited
-
dotProduct(
Vector3D o) → double -
inherited
-
equals(
Vector3D o) → bool -
inherited
-
format(
[int x0 = 0, int? y0, int? z0]) → String -
inherited
-
getOriginalPointer(
) → WasmStructPointer< Vector3D> -
Returns originalPointer, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOriginalPointerAndDispose(
) → WasmStructPointer< Vector3D> -
Returns originalPointer and immediately calls structMarkDisposed.
inherited
-
invert(
) → Vector3D -
inherited
-
lerp(
Vector3D o, double amount) → Vector3D -
inherited
-
max(
Vector3D o) → Vector3D -
inherited
-
min(
Vector3D o) → Vector3D -
inherited
-
moveTowards(
Vector3D target, double maxDistance) → Vector3D -
inherited
-
mul(
Vector3D o) → Vector3D -
inherited
-
negate(
) → Vector3D -
inherited
-
normalize(
) → Vector3D -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orthoNormalize(
Vector3D o) → Vector3D -
inherited
-
project(
Vector3D o) → Vector3D -
inherited
-
reflect(
Vector3D normal) → Vector3D -
inherited
-
refract(
Vector3D n, double r) → Vector3D -
inherited
-
reject(
Vector3D o) → Vector3D -
inherited
-
rotateByAxisAngle(
Vector3D axis, double angle) → Vector3D -
inherited
-
rotateByQuaternion(
QuaternionD q) → Vector3D -
inherited
-
scale(
num o) → Vector3D -
inherited
-
set(
num x, num y, num z) → Vector3D -
inherited
-
setD(
Vector3D o) → Vector3D -
Copies the fields of
ointo this instance and returnsthis.override -
signature(
) → String -
Returns a human-readable representation of this struct's current field values.
inherited
-
structAllocateInto(
RaylibTemp temp, WasmStructPointer< Vector3D> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.inherited -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears originalPointer.
inherited
-
structOnOp(
void callback(WasmStructPointer< Vector3D> p)) → void -
Calls
callbackwith originalPointer if it is set, otherwise no-ops.inherited -
structReadFrom(
WasmStructPointer< Vector3D> p) → void -
Reads all fields from the memory at
p.inherited -
structSetTag(
String newTag) → Vector3D -
Sets RaylibTempStructState.tag to
newTagand returnsthisfor chaining.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires originalPointer.
inherited
-
structSyncInto(
RaylibTemp temp, WasmStructPointer< Vector3D> p, String key) → void -
Syncs Dart-side fields into the already-allocated native pointer
p. Defaults to structWriteInto.inherited -
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires originalPointer.
inherited
-
structWriteInto(
WasmStructPointer< Vector3D> p) → void -
Writes all fields into the memory at
p.inherited -
sub(
Vector3D o) → Vector3D -
inherited
-
subValue(
num value) → Vector3D -
inherited
-
toArray(
) → List< double> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
MatrixD o) → Vector3D -
inherited
-
unproject(
MatrixD projection, MatrixD view) → Vector3D -
inherited
-
wasmReader(
[int? offset]) → WasmReader -
inherited
-
wasmReaderOr(
int address) → WasmReader -
inherited
-
wasmReadFrom(
WasmReader reader) → void -
override
-
wasmWriteInto(
WasmWriter writer) → void -
override
-
wasmWriter(
[int? offset]) → WasmWriter -
inherited
-
wasmWriterOr(
int address) → WasmReader -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
wasmPointer(
int ptr) → WasmStructPointer< Vector3D> -
wasmPointerPointer(
int ptr) → WasmStructPointerPointer< Vector3D>