WasmMemory class

Constructors

WasmMemory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

heapF32 → Float32List
no setter
heapF64 → Float64List
no setter
heapI16 → Int16List
no setter
heapI32 → Int32List
no setter
heapI64 → Int64List
no setter
heapI8 → Int8List
no setter
heapU16 → Uint16List
no setter
heapU32 → Uint32List
no setter
heapU64 → Uint64List
no setter
heapU8 → Uint8List
no setter

Static Methods

allocString(String text, [int? bufferSize]) → int
calloc(int nmemb, int size) → int
free(int ptr) → void
lengthBytesUTF8(String str) → int
malloc(int size) → int
memset(int ptr, int value, int num) → void
read<T extends Object>(WasmType<T> t, int ptr, [int offset = 0]) → T
readBool(int ptr, [int offset = 0]) → bool
readChar(int ptr, [int offset = 0]) → int
readDouble(int ptr, [int offset = 0]) → double
readFloat(int ptr, [int offset = 0]) → double
readFloat32(int ptr, [int offset = 0]) → double
readFloat64(int ptr, [int offset = 0]) → double
readInt(int ptr, [int offset = 0]) → int
readInt16(int ptr, [int offset = 0]) → int
readInt32(int ptr, [int offset = 0]) → int
readInt64(int ptr, [int offset = 0]) → int
readInt8(int ptr, [int offset = 0]) → int
readPtr(int ptr, [int offset = 0]) → int
readShort(int ptr, [int offset = 0]) → int
readSize(int ptr, [int offset = 0]) → int
readString(int ptr, [int? maxLength]) → String
readUint16(int ptr, [int offset = 0]) → int
readUint32(int ptr, [int offset = 0]) → int
readUint64(int ptr, [int offset = 0]) → int
readUint8(int ptr, [int offset = 0]) → int
readUnsignedChar(int ptr, [int offset = 0]) → int
readUnsignedInt(int ptr, [int offset = 0]) → int
readUnsignedShort(int ptr, [int offset = 0]) → int
stringToUTF8(String str, int ptr, int maxLen) → void
write<T extends Object>(WasmType<T> t, int ptr, T value, [int offset = 0]) → void
writeBool(int ptr, bool value, [int offset = 0]) → void
writeChar(int ptr, int value, [int offset = 0]) → void
writeDouble(int ptr, double value, [int offset = 0]) → void
writeFloat(int ptr, double value, [int offset = 0]) → void
writeFloat32(int ptr, double value, [int offset = 0]) → void
writeFloat64(int ptr, double value, [int offset = 0]) → void
writeInt(int ptr, int value, [int offset = 0]) → void
writeInt16(int ptr, int value, [int offset = 0]) → void
writeInt32(int ptr, int value, [int offset = 0]) → void
writeInt64(int ptr, int value, [int offset = 0]) → void
writeInt8(int ptr, int value, [int offset = 0]) → void
writePtr(int ptr, int value, [int offset = 0]) → void
writeShort(int ptr, int value, [int offset = 0]) → void
writeSize(int ptr, int value, [int offset = 0]) → void
writeString(int ptr, String str) → void
writeUint16(int ptr, int value, [int offset = 0]) → void
writeUint32(int ptr, int value, [int offset = 0]) → void
writeUint64(int ptr, int value, [int offset = 0]) → void
writeUint8(int ptr, int value, [int offset = 0]) → void
writeUnsignedChar(int ptr, int value, [int offset = 0]) → void
writeUnsignedInt(int ptr, int value, [int offset = 0]) → void
writeUnsignedShort(int ptr, int value, [int offset = 0]) → void