WasmMemory class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
dumpHex(TypedDataList heap, int ptr, int count, {int? before, int? after})
→ void
-
-
free(int ptr)
→ void
-
-
lengthBytesUTF8(String str)
→ int
-
-
malloc(int size)
→ int
-
-
readFloat32(int ptr, [int offset = 0])
→ double
-
-
readFloat64(int ptr, [int offset = 0])
→ double
-
-
readInt16(int ptr, [int offset = 0])
→ int
-
-
readInt32(int ptr, [int offset = 0])
→ int
-
-
readInt64(int ptr, [int offset = 0])
→ int
-
-
readInt8(int ptr, [int offset = 0])
→ int
-
-
readString(int ptr)
→ String
-
-
readUint16(int ptr, [int offset = 0])
→ int
-
-
readUint32(int ptr, [int offset = 0])
→ int
-
-
readUint64(int ptr, [int offset = 0])
→ int
-
-
readUint8(int ptr, [int offset = 0])
→ int
-
-
stringToUTF8(String str, int ptr, int maxLen)
→ void
-
-
writeFloat32(int ptr, int offset, double value)
→ void
-
-
writeFloat64(int ptr, int offset, double value)
→ void
-
-
writeInt16(int ptr, int offset, int value)
→ void
-
-
writeInt32(int ptr, int offset, int value)
→ void
-
-
writeInt64(int ptr, int offset, int value)
→ void
-
-
writeInt8(int ptr, int offset, int value)
→ void
-
-
writeString(int ptr, String str)
→ void
-
-
writeUint16(int ptr, int offset, int value)
→ void
-
-
writeUint32(int ptr, int offset, int value)
→ void
-
-
writeUint64(int ptr, int offset, int value)
→ void
-
-
writeUint8(int ptr, int offset, int value)
→ void
-