WasmReader class

Constructors

WasmReader([int ptr = 0])

Properties

cursor int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

boolean() bool
charArray(int length) String
Float32([int? at]) double
Float32Array(int n, [int? at]) List<double>
Float32Pointer() WasmFloat32Pointer
Float32TypedArray(int n, [int? at]) Float32List
Float64([int? at]) double
Float64Array(int n, [int? at]) List<double>
Float64Pointer() WasmFloat64Pointer
Float64TypedArray(int n, [int? at]) Float64List
Int16([int? at]) int
Int16Array(int n, [int? at]) List<int>
Int16Pointer() WasmInt16Pointer
Int16TypedArray(int n, [int? at]) Int16List
Int32([int? at]) int
Int32Array(int n, [int? at]) List<int>
Int32Pointer() WasmInt32Pointer
Int32TypedArray(int n, [int? at]) Int32List
Int64([int? at]) int
Int64Array(int n, [int? at]) List<int>
Int64Pointer() WasmInt64Pointer
Int64TypedArray(int n, [int? at]) Int64List
Int8([int? at]) int
Int8Array(int n, [int? at]) List<int>
Int8Pointer() WasmInt8Pointer
Int8TypedArray(int n, [int? at]) Int8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointer() int
reset([int? ptr]) → void
string() String
stringArray(int count) List<String>
struct<T extends StructDWeb<T>>(T v) → void
structArray<T extends StructDWeb<T>>(int count, WasmStructPointer<T> pointerFactory(int ptr), {bool owned = false}) List<T>
toString() String
A string representation of this object.
inherited
Uint16([int? at]) int
Uint16Array(int n, [int? at]) List<int>
Uint16Pointer() WasmUint16Pointer
Uint16TypedArray(int n, [int? at]) Uint16List
Uint32([int? at]) int
Uint32Array(int n, [int? at]) List<int>
Uint32Pointer() WasmUint32Pointer
Uint32TypedArray(int n, [int? at]) Uint32List
Uint64([int? at]) int
Uint64Array(int n, [int? at]) List<int>
Uint64Pointer() WasmUint64Pointer
Uint64TypedArray(int n, [int? at]) Uint64List
Uint8([int? at]) int
Uint8Array(int n, [int? at]) List<int>
Uint8Pointer() WasmUint8Pointer
Uint8TypedArray(int n, [int? at]) Uint8List

Operators

operator ==(Object other) bool
The equality operator.
inherited