WasmStructPointer<T extends StructDWeb<T> > class
- Inheritance
-
- Object
- WasmPointer<
T> - WasmSizedPointer<
T> - WasmStructPointer
Constructors
- WasmStructPointer(int address, T factory(), int byteSize)
Properties
- address → int
-
finalinherited
- byteSize → int
-
finalinherited
- defaultValue → T
-
no setteroverride
- factory → T Function()
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotNull → bool
-
no setterinherited
- isNull → bool
-
no setterinherited
- ref ↔ T
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toJS → JSNumber
-
no setterinherited
- value ↔ T
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offset(
int index) → int -
inherited
-
owned(
int index) → T -
readArray(
int count, {bool owned = false}) → List< T> -
override
-
readerAt(
[int offset = 0]) → WasmReader -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeArray(
List< T> array) → void -
override
-
writerAt(
[int offset = 0]) → WasmWriter -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → T -
override
-
operator []=(
int index, T v) → void -
override