WasmStructPointerPointer<T extends StructDWeb<T>> class

Inheritance

Constructors

WasmStructPointerPointer(int address, WasmStructPointer<T> innerPointerAt(int ptr))

Properties

address int
finalinherited
byteSize int
finalinherited
defaultValue WasmStructPointer<T>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
innerPointerAt WasmStructPointer<T> Function(int ptr)
finalinherited
isNotNull bool
no setterinherited
isNull bool
no setterinherited
ref WasmStructPointer<T>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSNumber
no setterinherited
value WasmStructPointer<T>
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(int index) int
inherited
readArray(int count) List<WasmStructPointer<T>>
inherited
readerAt([int offset = 0]) WasmReader
inherited
readJaggedMatrix(List<int> innerCounts) List<List<T>>
inherited
readMatrix(int outerCount, int innerCount) List<List<T>>
inherited
toString() String
A string representation of this object.
inherited
writeArray(List<WasmStructPointer<T>> array) → void
inherited
writeMatrix(List<List<T>> matrix) → void
inherited
writerAt([int offset = 0]) WasmWriter
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) WasmStructPointer<T>
inherited
operator []=(int index, WasmStructPointer<T> v) → void
inherited