WasmWriter class
Properties
-
cursor
→ int
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
boolean(bool v)
→ void
-
-
charArray(String value, int length)
→ void
-
-
Float32(double v, [int? at])
→ void
-
-
Float32Array(List<double> v, [int? at])
→ void
-
-
Float64(double v, [int? at])
→ void
-
-
Float64Array(List<double> v, [int? at])
→ void
-
-
Int16(int v, [int? at])
→ void
-
-
Int16Array(List<int> v, [int? at])
→ void
-
-
Int32(int v, [int? at])
→ void
-
-
Int32Array(List<int> v, [int? at])
→ void
-
-
Int64(int v, [int? at])
→ void
-
-
Int64Array(List<int> v, [int? at])
→ void
-
-
Int8(int v, [int? at])
→ void
-
-
Int8Array(List<int> v, [int? at])
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
pointer(int ptr)
→ void
-
-
reset([int? ptr])
→ void
-
-
string(String str)
→ void
-
-
struct<T extends StructDWeb<T>>(T v)
→ void
-
-
structArray<T extends StructDWeb<T>>(List<T> array, WasmStructPointer<T> pointerFactory(int ptr))
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
Uint16(int v, [int? at])
→ void
-
-
Uint16Array(List<int> v, [int? at])
→ void
-
-
Uint32(int v, [int? at])
→ void
-
-
Uint32Array(List<int> v, [int? at])
→ void
-
-
Uint64(int v, [int? at])
→ void
-
-
Uint64Array(List<int> v, [int? at])
→ void
-
-
Uint8(int v, [int? at])
→ void
-
-
Uint8Array(List<int> v, [int? at])
→ void
-
-
wasmptr([WasmPointer? ptr])
→ void
-