ModelD class
Model, meshes, materials and animation data
- Inheritance
-
- Object
- RaylibStruct<
ModelD> - ModelD
Constructors
-
ModelD({StructPointer<
ModelD> ? op, MatrixD? transform, List<MeshD> ? meshes, List<MaterialD> ? materials, List<int> ? meshMaterial, ModelSkeletonD? skeleton, List<TransformD> ? currentPose, List<MatrixD> ? boneMatrices}) - ModelD.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
-
boneMatrices
↔ StructLiveListStruct<
MatrixD> -
Bones animated transformation matrices
getter/setter pair
-
currentPose
↔ StructLiveListStruct<
TransformD> -
Current animation pose (Transform[])
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- materialCount ↔ int
-
Number of materials
getter/setter pair
-
materials
↔ StructLiveListStruct<
MaterialD> -
Materials array
getter/setter pair
- meshCount ↔ int
-
Number of meshes
getter/setter pair
-
meshes
↔ StructLiveListStruct<
MeshD> -
Meshes array
getter/setter pair
-
meshMaterial
↔ StructLiveList<
int, RInt> -
Mesh material number
getter/setter pair
-
op
↔ StructPointer<
ModelD> ? -
The C-owned or RaylibTemp-owned typed pointer for this struct, if any.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skeleton ↔ ModelSkeletonD
-
Skeleton for animation
getter/setter pair
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- transform ↔ MatrixD
-
Local transform matrix
getter/setter pair
Methods
-
clone(
) → ModelD -
Returns a deep copy of this instance, preserving op if present.
override
-
copy(
) → ModelD -
Returns a deep copy of this instance without op.
inherited
-
getOp(
) → StructPointer< ModelD> -
Returns op, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOpAndDispose(
) → StructPointer< ModelD> -
Returns op and immediately disposes this struct.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDart(
ModelD o) → ModelD -
Copies the fields of
ointo this instance.override -
signature(
) → String -
Returns a human-readable representation of this struct.
override
-
structAllocateInto(
RaylibTemp< RaylibBase> temp, MemoryPointer<RType> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.override -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears op.
inherited
-
structOnOp(
void callback(StructPointer< ModelD> p)) → void -
Calls
callbackwith op if it is set, otherwise no-ops.inherited -
structReadFrom(
MemoryPointer< RType> p) → void -
override
-
structSetTag(
String newTag) → ModelD -
Sets RaylibTempStructState.tag to
newTag.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires op.
inherited
-
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires op.
inherited
-
structWriteInto(
MemoryPointer< RType> p) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
field_boneMatrices
→ StructPointerArrayField<
MatrixD, RStruct> -
Field descriptor for boneMatrices.
final
-
field_currentPose
→ StructPointerArrayField<
TransformD, RStruct> -
Field descriptor for currentPose.
final
-
field_materialCount
→ StructValueField<
int, RInt> -
Field descriptor for materialCount.
final
-
field_materials
→ StructPointerArrayField<
MaterialD, RStruct> -
Field descriptor for materials.
final
-
field_meshCount
→ StructValueField<
int, RInt> -
Field descriptor for meshCount.
final
-
field_meshes
→ StructPointerArrayField<
MeshD, RStruct> -
Field descriptor for meshes.
final
-
field_meshMaterial
→ StructPointerArrayField<
int, RInt> -
Field descriptor for meshMaterial.
final
-
field_skeleton
→ StructValueField<
ModelSkeletonD, RStruct> -
Field descriptor for skeleton.
final
-
field_transform
→ StructValueField<
MatrixD, RStruct> -
Field descriptor for transform.
final
-
struct
→ StructType<
ModelD> -
Describes the raw memory layout, construction, and pointer representation
of this struct type.
final
-
structLayout
→ StructLayout<
ModelField> -
Raw memory layout of this object.
final