RaylibConfig class
Global configuration for raylib_dartified package family.
Provides configurable limits and defaults used by the library's temporary memory allocators, struct handling, and Raylib integration.
Unless otherwise documented, values should be configured before initializing
Raylib.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isGPUSkinningSupported → bool
-
Whether GPU skinning is supported by the configured mesh vertex buffer
limit.
no setter
- maxMeshVertexBuffers ↔ int
-
Maximum vertex buffers (VBO) per mesh.
getter/setter pair
- maxStructByteSize ↔ int
-
Maximum size, in bytes, of a struct supported by internal scratch buffers.
getter/setter pair
- maxTrackedAllocations ↔ int
-
Maximum number of simultaneously tracked temporary allocations per
temporary allocator.
getter/setter pair
- tempStringSlots ↔ int
-
The number of string slots to pre-allocate.
getter/setter pair